%% LOBSTER_readin_MIDQ_19022013.m
%--------------------------------------------------------------------------
% Reads LOBSTER 1st level Book Files, aggregates contemporaneous obs and
% cleans data. Output are cleaned midquote revisions
%--------------------------------------------------------------------------
%
%Peter Malec, February 19, 2014
%
%Script uses elements of LOBSTER demo code written by Gustav Haitz.
% NOTE: * adjusted to new data format
%           * start and end day do not have to be trading days
%           * quote data processing follows BNHLS(2009) more closely
%           * save output in asset specific folder
%           * put everything into functions and use parfor across days
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear all;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath = 1;                               

% Stock names
ticker_a      ={'AAPL','AMZN'};

% {'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
%    'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','SPY','QQQ'};% apr 13

%{'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
   % 'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP', 'AMAT','ESRX','ADBE','FSLR','ATVI','BIIB','SYMC','JNPR','BRCM','SPY'};% may 10

%
% dates
startd=datenum('23 apr 13');
endd=datenum('23 apr 13');

%cleaning 
cl_ind=-1;           %if==1: cleaning is done
hwin=25;             % local window for cleaning
thresh_gl=50;      % threshold for global check
thresh_loc=10;     % threshold for local check

% Selected Time Interval (start & end)
startTrad   = 9.5*60*60;       % 9:30:00 in sec after midnight
endTrad     = 16*60*60;        % 16:00:00 in sec after midnight

% Trading hours (start & end)
startTradin   = 9.5*60*60*1000;       % 9:30:00 in milisec after midnight
endTradin     = 16*60*60*1000;        % 16:00:00 in milisec after midnight

% compute midprices ?
CompMidp= false;
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data


inpath=strcat(pathproject,'Data',filesep,'LOBSTER',filesep,'Raw',filesep);

addpath=strcat(pathproject,'Data',filesep,'Add',filesep);

outpath=strcat(pathproject,'Data',filesep,'LOBSTER',filesep,'Filtered',filesep);
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days


% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days.mat')); 
% -------------------------------------------------------------------------
%

% -------------------------------------------------------------------------
%% Start Loop over assets
% -------------------------------------------------------------------------

% Create vector of trading days in matlab date format
tdates=date_v(sort(find((date_v>=startd)&(date_v<=endd))));

%start loop
for j=1:length(ticker_a)

%choose ticker 
ticker=ticker_a{j};
% -------------------------------------------------------------------------
%
% -------------------------------------------------------------------------
%% Start Loop over trading days
% -------------------------------------------------------------------------

%start loop
for i=1:length(tdates) %parfor
% -------------------------------------------------------------------------
%
display([ticker ': ' datestr(tdates(i),'yyyy--mmm--dd')]);   
% -------------------------------------------------------------------------
%

% call proc
process_quote_core(ticker, tdates(i),cl_ind,hwin,thresh_gl,thresh_loc,...
    startTrad,endTrad,startTradin,endTradin,inpath,outpath,CompMidp)

% -------------------------------------------------------------------------
%% End Loop over trading days
% -------------------------------------------------------------------------

end

% -------------------------------------------------------------------------
%% End Loop over assets
% -------------------------------------------------------------------------

end


