%% LOBSTER_readin_trade_19022014.m
%--------------------------------------------------------------------------
% Reads LOBSTER Message Files, selects order executions, aggregates
% subtrades .
%--------------------------------------------------------------------------
%
%Peter Malec, February 19, 2014
%
%Script uses elements of LOBSTER demo code written by Gustav Haitz.
% NOTE: *adjusted to new data format
%           *start and end day do not have to be trading days
%           * BNHLS(2009) cleaning proc for trades implemented
%           * save output in asset specific folder
%           * put everything into functions and use parfor across days
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear all;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath = -1;                               

% Stock names
ticker_a      ={'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
   'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','AMAT','CMCSA','QQQ','SPY'}; % apr 13

%{'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
   % 'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP', 'AMAT','ESRX','ADBE','FSLR','ATVI','BIIB','SYMC','JNPR','BRCM','SPY'};% may 10

% dates
startd=datenum('1 jan 14');
endd=datenum('30 apr 14');

%cleaning trades
cl_indt=-1;

% Selected Time Interval (start & end)
startTrad   = 9.5*60*60;       % 9:30:00 in sec after midnight
endTrad     = 16*60*60;        % 16:00:00 in sec after midnight

% Trading hours (start & end)
startTradin   = 9.5*60*60*1000;       % 9:30:00 in milisec after midnight
endTradin     = 16*60*60*1000;        % 16:00:00 in milisec after midnight
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = 'D:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==2
    
    pathproject = 'D:\\WORK\\Spot_corr\\MATLAB\\';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';   
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';                   
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data


inpath=strcat(pathproject,'Data\\LOBSTER\\Raw\\');

addpath=strcat(pathproject,'Data\\Add\\');

outpath=strcat(pathproject,'Data\\LOBSTER\\Filtered\\');
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days


% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days.mat')); 
% -------------------------------------------------------------------------
%

% -------------------------------------------------------------------------
%% Start Loop over assets
% -------------------------------------------------------------------------

% Create vector of trading days in matlab date format
tdates=date_v(sort(find((date_v>=startd)&(date_v<=endd))));

%start loop
for j=1:length(ticker_a)

%choose ticker 
ticker=ticker_a{j};
% -------------------------------------------------------------------------
%
% -------------------------------------------------------------------------
%% Start Loop over trading days
% -------------------------------------------------------------------------

%start loop
parfor i=1:length(tdates)
% -------------------------------------------------------------------------
%
display([ticker ': ' datestr(tdates(i),'yyyy--mmm--dd')]);   
% -------------------------------------------------------------------------
%

% call proc
process_trade_core(ticker, tdates(i),...
    cl_indt,startTrad,endTrad,startTradin,endTradin,inpath,outpath)

% -------------------------------------------------------------------------
%% End Loop over trading days
% -------------------------------------------------------------------------

end

% -------------------------------------------------------------------------
%% End Loop over assets
% -------------------------------------------------------------------------

end


