        function [exeAdj] = AggExecutions_Core(book,mess)
            % Output: columns
            %   1       -> row event beginning
            %   2       -> row event ending
            %   3       -> agg volume
            %   4       -> transaction price (unit price obtained)
            %   5       -> direction
            %   6       -> event type (Note: types: 4,45,5,54)
            %--------------------------------------------------------------
            %NOTE: executions are aggregated if they occur at the same
            %time. Not Ruihong's half second rule.
            %--------------------------------------------------------------

            % Helpers
            lvl         = (size(book,2)-1)/4;
            bl          = size(book,1);
            tradeType   = [4,45,5,54];

            % Collection matrix
            exeAdj      = zeros(bl,5);

            jSave = 1;
            jBook = 1;

            while jBook <= bl

                if mess(jBook,2) == 4 || mess(jBook,2) == 5
                    k=0;
                    while jBook+k+1 <= bl && ...
                            mess(jBook + k + 1,1) == mess(jBook,1) && ...
                            mess(jBook + k + 1,6) == mess(jBook,6) && ...
                           (mess(jBook + k + 1,2) == 4 || mess(jBook+k+1,2) == 5)
                        % Check for ...
                        % ... not end of book, same time, same direction, next event execution (hidden or visible)
                        k=k+1;
                    end

                    % Save trade information
                    % ... postions and volume of trade
                    exeAdj(jSave,1:3) = [jBook, jBook+k, sum(mess(jBook:jBook+k,4))];

                    % ... direction
                    exeAdj(jSave,5) = mess(jBook,6);

                    % ... price (Unit price obtained)
                    exeAdj(jSave,4) = sum((mess(jBook:jBook+k,5).*mess(jBook:jBook+k,4)))./exeAdj(jSave,3);

                    % ... type
                    tradeTypePos = 1;
                    if mess(jBook,2) == 5
                        tradeTypePos = 3;
                    end
                    if sum(mess(jBook:jBook+k,2) ~= tradeType(tradeTypePos)) ~= 0
                        tradeTypePos = tradeTypePos + 1;
                    end
                    exeAdj(jSave,6) = tradeType(tradeTypePos);

                    % Update loop variables
                    jBook = jBook + k + 1;
                    jSave = jSave + 1;

                else
                    jBook = jBook+1;
                end

            end
            % Remove unneeded parts
            exeAdj = exeAdj(1:jSave-1,:);

        end
