        function [QuotesAgg] = AggQuotes_Core(book)
%% AggQuotes_Core
%--------------------------------------------------------------
% Aggregates simulatneous quotes by compouting medians of bid and ask
% prices
%--------------------------------------------------------------
% INPUT:
% book - matrix of 1st level LOB prices for given day
%   1st col     -> time
%   2nd col       -> ask price
%   3th col       -> bid price
%--------------------------------------------------------------
% OUTPUT:
% QuotesAgg - matrix with columns
%   1       -> time
%   2       -> aggreg. ask price
%   3       -> aggreg. bid price
% -------------------------------------------------------------------------
%
% Peter Malec, November 29, 2011
% Based on the (awesome!!!) function "AggExecutions_Core" by Gustav Haitz
% Peter Malec, December 9, 2011: depths dropped
% -------------------------------------------------------------------------
%       
 %% Preparations     
 
 % number of obs in book
  bl = size(book,1);
           
% Initialize Output Matrix (size of LOB file >>> will be shortened)
 QuotesAgg=zeros(bl,3);
% -------------------------------------------------------------------------
%     
 %% Loop for Aggregation

            % Initialize Indices
            jSave = 1;
            jBook = 1;
            
            
            % Loop over LOB file
            while jBook <= bl

                    %Gustav's Loop collecting indices at same time as current
                    k=0;
                    while jBook+k+1 <= bl && ...
                            book(jBook + k + 1,1) == book(jBook,1) 
                        % Check for ...
                        % ... not end of book, same time
                        k=k+1;
                    end

                    % Save Aggregated quote information
                    QuotesAgg(jSave,1:3) = [book(jBook,1) nanmedian(book(jBook:jBook+k,2)) nanmedian(book(jBook:jBook+k,3))];
                                                                                %time, ask, bid
                   
                    % Update loop variables
                    jBook = jBook + k + 1;
                    jSave = jSave + 1;

                

            end
            
            % Delete redundant part of QuotesAgg (has size of book)
            QuotesAgg =QuotesAgg(1:jSave-1,:);
                                                    %jSave-1 because jSave
                                                    %was just update by +1
        end
