%% LOBSTER_readin_preTR_23112011.m
%--------------------------------------------------------------------------
% Reads LOBSTER Book and Message Files, selects order executions, aggregates
% subtrades and merges LOB and trade data.
%NOTE: last LOB state BEFORE each trade is considered!
%--------------------------------------------------------------------------
%
%Peter Malec, November 23, 2011
%
%Script uses elements of LOBSTER demo code and the procedure AggExecutions_Core both 
% written by Gustav Haitz.
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear all;
clc;

% Choose basepath
basepath = 1;                               

% Stock name
ticker      = 'LZ';

% dates
startd=datenum('1 jul 09');
endd=datenum('9 jul 09');

% Trading hours (start & end)
startTrad   = 9.5*60*60*1000;       % 9:30:00.000 in ms after midnight
endTrad     = 16*60*60*1000;        % 16:00:00.000 in ms after midnight

% Levels
lvl         = 5;
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = 'D:\\RV_LOB\\MATLAB\\';
    
elseif basepath ==0
    
    pathproject = 'H:\\RV_LOB\\MATLAB\\';
    
else
    
    pathproject = 'H:\\RV_LOB\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data


inpath=strcat(pathproject,'Data\\Raw\\');

addpath=strcat(pathproject,'Data\\Add\\');

outpath=strcat(pathproject,'Data\\Filtered\\');
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days


% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days.mat')); 
% -------------------------------------------------------------------------
%
% -------------------------------------------------------------------------
% -------------------------------------------------------------------------
%% Start Loop over trading days
% -------------------------------------------------------------------------
% -------------------------------------------------------------------------


% Create vector of trading days in matlab date format
tdates=date_v(find(date_v==startd):find(date_v==endd));

%start loop
for i=1:length(tdates)

% -------------------------------------------------------------------------
%
%% Load Order Book and Message File

%clear "old" data
clear book;
clear mess;
clear trades;
clear LOBpTR;


% Load Order Book data
book = dlmread(strcat(inpath,ticker,'_',datestr(tdates(i),'yyyymmdd'),'_orderbook_',num2str(lvl),'.csv'));
   
% Order book file information:
% -------------------------------------------------------------------------
%   
%   - Dimension:    Matrix of size (NumberEvents X (NumberLevels*4+1))
%
%   - Structure:    Each row:
%                   timeStamp (Ms after midnight), Ask price 1, 
%                   Ask volume 1, Bid price 1, Bid volume 1, Ask price 2, 
%                   Ask volume 2, Bid price 2, Bid volume 2, ...   
% 
%   - Note:         Unoccupied bid (ask) price levels are set to -1 
%                   (99999999) with volume -1 
%
% -------------------------------------------------------------------------

% Load Message data
mess = dlmread(strcat(inpath,ticker,'_',datestr(tdates(i),'yyyymmdd'),'_message_',num2str(lvl),'.csv'));

% Message file information:
% -------------------------------------------------------------------------
%   
%   - Dimension:    Matrix of size (NumberEvents X 6)
%
%   - Structure:    Each row:
%                   timeStamp (Ms after midnight), EventType,
%                   Message ID, Size (# of shares), Price, Direction
%
%                   EventTypes: 
%                       - '1'   Submitted new limit order
%                       - '2'   Cancellation (partial)
%                       - '3'   Deletion (total order)
%                       - '4'   Execution against visible liquidity
%                       - '5'   Execution against hidden liquidity
%                       - '100' Other
%
%                   Direction:
%                       - '-1'  Sell limit order
%                       - '-2'  Buy limit order
%                       - NOTE: Execution of a sell (buy) limit order
%                               corresponds to a buyer-(seller-)initiated  
%                               trade, i.e a BUY (SELL) trade. 
%
% -------------------------------------------------------------------------

%% Data Preparation - Order Book and Message File File

% Remove observations outside the official trading hours
% -------------------------------------------------------------------------

% Get index of observations 
timeIdx = book(:,1) >= startTrad & book(:,1) <= endTrad;

% Remove observations
book = book(timeIdx,:);
mess = mess(timeIdx,:);
    % Note: Time index of the order book file can be used as the rows of 
    %       both files - order book and message - correspond to each other.

% Convert prices into dollars
% -------------------------------------------------------------------------
book(:,[2:2:(4*lvl)]) = book(:,[2:2:(4*lvl)])./10000;
    % Note: LOBSTER stores prices in dollar price times 10000
mess(:,5) = mess(:,5)./10000;    


%% Aggregate Order Executions to Trades and Select LOB States after Trades 

%Aggregation
trades=AggExecutions_Core(book,mess);

%Select LOB States just before Trades (index of first subtrade -1)
book=book(trades(:,1)-1,:);

%Merge Data trade and filtered LOB data
LOBpoTR=[mess(trades(:,2),1) book(:,2:end) trades(:,4) (trades(:,3).*trades(:,5)*(-1)) trades(:,6)];
        %Note: time of transaction (time of last subtrade), prices and quotes of first lvl levels (bid and
            %ask), Volume-Weighted Transaction Price, Signed Avol (1:buy),
            %event type: exec against visible(4), hidden(5) or
            %combined(45,54)
% -------------------------------------------------------------------------
%
%% Save Output Matrix


% save output 
save(strcat(outpath,ticker,'_',datestr(tdates(i),'yyyymmdd'),'_LOBpoTR_',num2str(lvl),'.mat'),'LOBpoTR')


% -------------------------------------------------------------------------
% -------------------------------------------------------------------------
%% End Loop over trading days
% -------------------------------------------------------------------------
% -------------------------------------------------------------------------

end





