function trades_cl=check_trade_spread(trades,quotes)
%% check_trade_spread
%--------------------------------------------------------------
% delete trade observations for which transaction price is 
% below bid minus spread or above ask + spread
%--------------------------------------------------------------
% INPUT:
% trades -> (n_tx2) matrix of transaction times and prices
% quotes   -> (n_qx3) matrix of times of quote revisions and
%                            best ask and bid quotes
%Output:
% trades -> (n_t_cx2) matrix of 'cleaned' transaction times and prices
%--------------------------------------------------------------
%
% Peter Malec,  February 14 2014 
%
% -------------------------------------------------------------------------
%   
%% Clean trades

% no of trades
n_tr=size(trades,1);

% index vector
keepind=zeros(n_tr,1);

% loop over trades and check
%-----------------------------------------------------

for i=1:n_tr
    
    % find last quote obs
    time_tr=trades(i,1);
    ind_time=(time_tr-quotes(:,1)>1e-15)|(abs(time_tr-quotes(:,1))<1e-15);
    if sum(ind_time)>0
        quote_ind=find(ind_time,1,'last');
    
        % check condition
        bmspr=quotes(quote_ind,3)-(quotes(quote_ind,2)-quotes(quote_ind,3));
        apspr=quotes(quote_ind,2)+(quotes(quote_ind,2)-quotes(quote_ind,3));
        keepind(i)=((trades(i,2)-bmspr>1e-15)|(abs(trades(i,2)-bmspr)<1e-15))&((apspr-trades(i,2)>1e-15)|(abs(apspr-trades(i,2))<1e-15));
    else
        keepind(i)=1;
    end
end

%retain "clean" obs
trades_cl=trades(logical(keepind),:);



    
  
    