function comp_acf_pacf(ticker,tdate,typed,cl_ind,rev_ind,lags,inpath,sourced,outpath)
%% comp_acf_pacf
%--------------------------------------------------------------
% computes empircal ACF and PACF of log returns for given stock
% and day
%--------------------------------------------------------------
% INPUT:
% ticker ->  ticker symbol (string)
% tdate   -> data in matlab format
% cl_ind    -> if ==1, data cleaned according to proc by BNHLS(2009) is used
% rev_ind    -> if ==1, only obs with price revisions are used
% lags   - The number of autocorrelations to compute
% inpath     -> path for loading data
% sourced   -> data source
% outpath  -> path for saving
%--------------------------------------------------------------
%
% Peter Malec,  March 6 2014 
%
% -------------------------------------------------------------------------
%   
%% Load Data

% clean?
if cl_ind==1
     cl_str='cl';            % cleaning string for output file
else
     cl_str='ncl';
end


% check for existence of files
%-----------------------------------------------------------------------------------
name=strcat(inpath,ticker,'\\',ticker,'_',datestr(tdate,'yyyymmdd'),'_',typed,'_',cl_str,'.mat');
index=isequal(exist(name,'file'),2);


if index
%---------------------------------------------------------
% Load
load(name);
if isequal(typed,'trades')
    midprice=trades;
end
if rev_ind==1
   midprice=keep_rev(midprice,2);
end

% log returns
lret=diff(log(midprice(:,2)));
% -------------------------------------------------------------------------
%   
%% Compute ACFs and PACFs

%ACF
[ac, acstd] = sacf(lret, lags, 0, 0);

%PACF
[pac, pacstd] = spacf(lret, lags, 0, 0);
% -------------------------------------------------------------------------
%   
%% Save Results

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

% output matrix
AC_res_mat=[ac acstd pac pacstd];

%name
 basename=strcat(outpath,'ACF_L',int2str(lags),sourced,'_',datestr(tdate,'yyyymmdd'),typed,cl_str,rev_str);

%save output
save(basename,'AC_res_mat')
% -------------------------------------------------------------------------
% 
%% files do not exist: do nothing

else
    disp(['Data missing for the following ticker: ' ticker '. Skip day.'])
end



    
  
    