function process_quote(ticker, tdates,cl_ind,hwin,thresh_gl,thresh_loc,...
    startTrad,endTrad,startTradin,endTradin,inpath,outpath)
%% process_quote
%------------------------------------------------------------
% process quote data
%--------------------------------------------------------------
% INPUT:
% ticker -> ticker symbol
% tdates   -> vector of trading dates (MATLAB date format)
% cl_ind    ->  if==1: cleaning of midprices is done
% hwin     -> local window for cleaning
% thresh_gl  -> threshold for global check
% thresh_loc  -> threshold for local check
% startTrad  ->  start of Selected Time Interval (in sec after midn)
% startTradin ->  start of Trading hours (in milisec after midnight)
%--------------------------------------------------------------
%
% Peter Malec,  February 18 2014 
%
% -------------------------------------------------------------------------
%   
% -------------------------------------------------------------------------
%% Start Loop over trading days
% -------------------------------------------------------------------------

%start loop
for i=1:length(tdates)
% -------------------------------------------------------------------------
%
display([ticker ': ' datestr(tdates(i),'yyyy--mmm--dd')]);   
% -------------------------------------------------------------------------
%
%% Load Order Book and Message File

%clear "old" data
clear book;
clear timeIdx;
clear keepIndx;
clear quote_rev;
clear quotes_agg;
clear quotes;
clear midprice;
clear mess;


% names
bname=strcat(inpath,ticker,'_',datestr(tdates(i),'yyyy-mm-dd'),'_',int2str(startTradin),'_',int2str(endTradin),'_orderbook_1','.csv');
mname=strcat(inpath,ticker,'_',datestr(tdates(i),'yyyy-mm-dd'),'_',int2str(startTradin),'_',int2str(endTradin),'_message_',num2str(1),'.csv');

% check if files do exits
%----------------------------------------------
bindex=isequal(exist(bname,'file'),2);
mindex=isequal(exist(mname,'file'),2);

if bindex&&mindex
%-----------------------------------------------

% Load Order Book data
book = dlmread(bname);
   
% Order book file information:
% -------------------------------------------------------------------------
%   
%   - Dimension:    Matrix of size (NumberEvents X (5))
%
%   - Structure:    Each row:
%                   timeStamp (Ms after midnight), Ask price 1, 
%                   Ask volume 1, Bid price 1, Bid volume 1
%
% -------------------------------------------------------------------------

% Load Message data
mess = dlmread(mname);

% Message file information:
% -------------------------------------------------------------------------
%   
%   - Dimension:    Matrix of size (NumberEvents X 6)
%
%   - Structure:    Each row:
%                   timeStamp (sec after midnight), EventType,
%                   Message ID, Size (# of shares), Price, Direction
%
% -------------------------------------------------------------------------
%
%% Data Preparation 

% Add time to book
book=[mess(:,1) book];


% Remove observations outside the official trading hours
% -------------------------------------------------------------------------

% Get index of observations 
timeIdx = book(:,1) >= startTrad & book(:,1) <= endTrad;

% Remove observations
book = book(timeIdx,:);

% Do Rough Cleaning
% -------------------------------------------------------------------------

%bid and ask positive, spread nonnegative
keepIndx=(book(:,2)>0) & (book(:,4)>0) & (book(:,2)-book(:,4) >= 0);
                                                                            
% select clean data
book=book(logical(keepIndx),:);
                                                                            
% Convert prices into dollars
% -------------------------------------------------------------------------
book(:,[2 4]) = book(:,[2 4])./10000;
    % Note: LOBSTER stores prices in dollar price times 10000

%% Aggregate Contemporaneous Obs

%Aggregation
quotes_agg=AggQuotes_Core(book(:,[1 2 4]));
% -------------------------------------------------------------------------
%
%% Data Cleaning

% Clean if desired using method by Barndorff-Nielsen et al. (2009)
if cl_ind==1
    keep_ind=QuoteClean_Core(quotes_agg,hwin,thresh_gl,thresh_loc);
    quotes=quotes_agg(logical(keep_ind),:);     % choose "clean" observations
    cl_str='cl';            % cleaning string for output file
else
    quotes= quotes_agg;     % do nothing
    cl_str='ncl';
end
% -------------------------------------------------------------------------
%
%% Save Output Matrix

% Compute midquotes
midprice=[quotes(:,1) 0.5*(quotes(:,2)+quotes(:,3))];

% save output 
save(strcat(outpath,ticker,'\\',ticker,'_',datestr(tdates(i),'yyyymmdd'),'_midp_',cl_str,'.mat'),'midprice')


% -------------------------------------------------------------------------
%% End Loop over trading days
% -------------------------------------------------------------------------

% book or mesage file do not exit: do nothing
%----------------------------------------------
else
    
disp(['Book and/or message file for ' ticker ' are missing. Skip.'])

end

end