function process_quote_trade_core(ticker, tdate,trade_read,cl_ind,hwin,thresh_gl,thresh_loc,...
    cl_indt,startTrad,endTrad,startTradin,endTradin,inpath,outpath)
%% process_quote_trade_core
%------------------------------------------------------------
% process trade and quote data
%--------------------------------------------------------------
% INPUT:
% ticker -> ticker symbol
% tdate   -> trading date (MATLAB date format)
% trade_read -> if==1: process message file and read out trades, as well
% cl_ind    ->  if==1: cleaning of midprices is done
% hwin     -> local window for cleaning
% thresh_gl  -> threshold for global check
% thresh_loc  -> threshold for local check
% cl_indt   ->  if==1: cleaning of trades is done
% startTrad  ->  start of Selected Time Interval (in sec after midn)
% startTradin ->  start of Trading hours (in milisec after midnight)
%--------------------------------------------------------------
%
% Peter Malec,  February 18 2014 
%
% -------------------------------------------------------------------------
%   
%% Load Order Book and Message File

% names
bname=strcat(inpath,ticker,'_',datestr(tdate,'yyyy-mm-dd'),'_',int2str(startTradin),'_',int2str(endTradin),'_orderbook_1','.csv');
mname=strcat(inpath,ticker,'_',datestr(tdate,'yyyy-mm-dd'),'_',int2str(startTradin),'_',int2str(endTradin),'_message_',num2str(1),'.csv');

% check if files do exits
%----------------------------------------------
bindex=isequal(exist(bname,'file'),2);
mindex=isequal(exist(mname,'file'),2);

% special case QQQ
if isequal(ticker,'QQQ')
    bname2=strcat(inpath,'QQQQ_',datestr(tdate,'yyyy-mm-dd'),'_',int2str(startTradin),'_',int2str(endTradin),'_orderbook_1','.csv');
    mname2=strcat(inpath,'QQQQ_',datestr(tdate,'yyyy-mm-dd'),'_',int2str(startTradin),'_',int2str(endTradin),'_message_',num2str(1),'.csv');
    bindex2=isequal(exist(bname2,'file'),2);
    mindex2=isequal(exist(mname2,'file'),2);
end

if (bindex&&mindex)||((isequal(ticker,'QQQ'))&&bindex2&&mindex2)
%-----------------------------------------------
% adjustment for QQQQ

if ((isequal(ticker,'QQQ'))&&bindex2&&mindex2)
    bname=bname2;
    mname=mname2;
end
%-----------------------------------------------

% Load Order Book data
book = dlmread(bname);
   
% Order book file information:
% -------------------------------------------------------------------------
%   
%   - Dimension:    Matrix of size (NumberEvents X (5))
%
%   - Structure:    Each row:
%                   timeStamp (Ms after midnight), Ask price 1, 
%                   Ask volume 1, Bid price 1, Bid volume 1
%
% -------------------------------------------------------------------------

% Load Message data
mess = dlmread(mname);

% Message file information:
% -------------------------------------------------------------------------
%   
%   - Dimension:    Matrix of size (NumberEvents X 6)
%
%   - Structure:    Each row:
%                   timeStamp (sec after midnight), EventType,
%                   Message ID, Size (# of shares), Price, Direction
%
% -------------------------------------------------------------------------
%
%% Process Quote Data
%
% -------------------------------------------------------------------------
%
%% Data Preparation 

% Add time to book
book=[mess(:,1) book];


% Remove observations outside the official trading hours
% -------------------------------------------------------------------------

% Get index of observations 
timeIdx = book(:,1) >= startTrad & book(:,1) <= endTrad;

% Remove observations
book = book(timeIdx,:);

% Do Rough Cleaning
% -------------------------------------------------------------------------

%bid and ask positive, spread nonnegative
keepIndx=(book(:,2)>0) & (book(:,4)>0) & (book(:,2)-book(:,4) >= 0);
                                                                            
% select clean data
book=book(logical(keepIndx),:);
                                                                            
% Convert prices into dollars
% -------------------------------------------------------------------------
book(:,[2 4]) = book(:,[2 4])./10000;
    % Note: LOBSTER stores prices in dollar price times 10000

%% Aggregate Contemporaneous Obs

%Aggregation
quotes_agg=AggQuotes_Core(book(:,[1 2 4]));
% -------------------------------------------------------------------------
%
%% Data Cleaning

% Clean if desired using method by Barndorff-Nielsen et al. (2009)
if cl_ind==1
    keep_ind=QuoteClean_Core(quotes_agg,hwin,thresh_gl,thresh_loc);
    quotes=quotes_agg(logical(keep_ind),:);     % choose "clean" observations
    cl_str='cl';            % cleaning string for output file
else
    quotes= quotes_agg;     % do nothing
    cl_str='ncl';
end
% -------------------------------------------------------------------------
%
%% Save Output Matrix

% Compute midquotes
midprice=[quotes(:,1) 0.5*(quotes(:,2)+quotes(:,3))];

% save output 
save(strcat(outpath,ticker,'\\',ticker,'_',datestr(tdate,'yyyymmdd'),'_midp_',cl_str,'.mat'),'midprice')
%
% -------------------------------------------------------------------------
%
%% Process Trade Data
%
if trade_read==1
% -------------------------------------------------------------------------
%
%% Data Preparation 

% Remove observations outside the official trading hours
% -------------------------------------------------------------------------

% Get index of observations 
timeIdxm = mess(:,1) >= startTrad & mess(:,1) <= endTrad;

% Remove observations
mess = mess(timeIdxm,:);

% Do Rough Cleaning
% -------------------------------------------------------------------------

%price positive
keepIndxm=mess(:,5)>0;
                                                                            
% select clean data
mess=mess(logical(keepIndxm),:);

% Convert prices into dollars
% -------------------------------------------------------------------------

    % Note: LOBSTER stores prices in dollar price times 10000
mess(:,5) = mess(:,5)./10000;    
% -------------------------------------------------------------------------
%
%% Select Executions and Aggregate Order Executions to Trades 

%Aggregation
trades_agg=AggExecutions_Core_l1(mess);
trades_agg_r=[mess(trades_agg(:,2),1) trades_agg(:,4)];
%2nd order Aggregation
trades_agg2 = AggExecutions_Core_l1_after(trades_agg_r);
trades_agg_r2=[trades_agg_r(trades_agg2(:,2),1) trades_agg2(:,3)];
%Note: time of transaction (time of last subtrade), price 
% -------------------------------------------------------------------------
%
%% Data Cleaning

% Clean if desired using method by Barndorff-Nielsen et al. (2009)
if cl_indt==1
    trades=check_trade_spread(trades_agg_r2,book(:,[1 2 4]));
    cl_strt='cl';            % cleaning string for output file
else
    trades= trades_agg_r2;     % do nothing
    cl_strt='ncl';
end
% -------------------------------------------------------------------------
%
%% Save Output Matrix

% save output 
save(strcat(outpath,ticker,'\\',ticker,'_',datestr(tdate,'yyyymmdd'),'_trades_',cl_strt,'.mat'),'trades')

% -------------------------------------------------------------------------
%
end



% book or mesage file do not exist: do nothing
%----------------------------------------------
else
    
disp(['Book and/or message file for ' ticker ' are missing. Skip.'])

end

