function process_trade(ticker, tdates,...
    cl_indt,startTrad,endTrad,startTradin,endTradin,inpath,outpath)
%% process_trade
%------------------------------------------------------------
% process trade data
%--------------------------------------------------------------
% INPUT:
% ticker -> ticker symbol
% tdates   -> vector of trading dates (MATLAB date format)
% cl_indt   ->  if==1: cleaning of trades is done
% startTrad  ->  start of Selected Time Interval (in sec after midn)
% startTradin ->  start of Trading hours (in milisec after midnight)
%--------------------------------------------------------------
%
% Peter Malec,  February 18 2014 
%
% -------------------------------------------------------------------------
%   
% -------------------------------------------------------------------------
%% Start Loop over trading days
% -------------------------------------------------------------------------

%start loop
for i=1:length(tdates)
% -------------------------------------------------------------------------
%
display([ticker ': ' datestr(tdates(i),'yyyy--mmm--dd')]);   
% -------------------------------------------------------------------------
%
%% Load Order Book and Message File

%clear "old" data
clear mess;
clear timeIdxm;
clear trades_agg;
clear trades_agg_r;
clear trades;
clear keepIndxm;

% names
mname=strcat(inpath,ticker,'_',datestr(tdates(i),'yyyy-mm-dd'),'_',int2str(startTradin),'_',int2str(endTradin),'_message_',num2str(1),'.csv');

% check if files do exits
%----------------------------------------------
mindex=isequal(exist(mname,'file'),2);

if cl_indt==1
    % names
    bname=strcat(inpath,ticker,'_',datestr(tdates(i),'yyyy-mm-dd'),'_',int2str(startTradin),'_',int2str(endTradin),'_orderbook_1','.csv');
    % check if files does exit
    bindex=isequal(exist(bname,'file'),2);
else
    bindex=true(1);    
end

if bindex&&mindex
%-----------------------------------------------

% Load Message data
mess = dlmread(mname);

% Message file information:
% -------------------------------------------------------------------------
%   
%   - Dimension:    Matrix of size (NumberEvents X 6)
%
%   - Structure:    Each row:
%                   timeStamp (sec after midnight), EventType,
%                   Message ID, Size (# of shares), Price, Direction
%
% -------------------------------------------------------------------------
%
%% Book Data

if cl_indt==1
    
    % clear old data
    clear book;
    clear timeIdx;
    clear keepIndx;

    
    % Load Order Book data
    book = dlmread(bname);
   
    % Order book file information:
    % -------------------------------------------------------------------------
    %   
    %   - Dimension:    Matrix of size (NumberEvents X (5))
    %
    %   - Structure:    Each row:
    %                   timeStamp (Ms after midnight), Ask price 1, 
    %                   Ask volume 1, Bid price 1, Bid volume 1
    %
    % -------------------------------------------------------------------------
    
    % Add time to book
    book=[mess(:,1) book];

    % Remove observations outside the official trading hours
    % -------------------------------------------------------------------------

    % Get index of observations 
    timeIdx = book(:,1) >= startTrad & book(:,1) <= endTrad;

    % Remove observations
    book = book(timeIdx,:);

    % Do Rough Cleaning
    % -------------------------------------------------------------------------

    %bid and ask positive, spread nonnegative
    keepIndx=(book(:,2)>0) & (book(:,4)>0) & (book(:,2)-book(:,4) >= 0);
                                                                            
    % select clean data
    book=book(logical(keepIndx),:);
                                                                            
    % Convert prices into dollars
    % -------------------------------------------------------------------------
    book(:,[2 4]) = book(:,[2 4])./10000;
    % Note: LOBSTER stores prices in dollar price times 10000
    
end
% -------------------------------------------------------------------------
%
%% Data Preparation 

% Remove observations outside the official trading hours
% -------------------------------------------------------------------------

% Get index of observations 
timeIdxm = mess(:,1) >= startTrad & mess(:,1) <= endTrad;

% Remove observations
mess = mess(timeIdxm,:);

% Do Rough Cleaning
% -------------------------------------------------------------------------

%price positive
keepIndxm=mess(:,5)>0;
                                                                            
% select clean data
mess=mess(logical(keepIndxm),:);

% Convert prices into dollars
% -------------------------------------------------------------------------

    % Note: LOBSTER stores prices in dollar price times 10000
mess(:,5) = mess(:,5)./10000;    
% -------------------------------------------------------------------------
%
%% Select Executions and Aggregate Order Executions to Trades 

%Aggregation
trades_agg=AggExecutions_Core_l1(mess);
trades_agg_r=[mess(trades_agg(:,2),1) trades_agg(:,4)];
%Note: time of transaction (time of last subtrade), price 
% -------------------------------------------------------------------------
%
%% Data Cleaning

% Clean if desired using method by Barndorff-Nielsen et al. (2009)
if cl_indt==1
    trades=check_trade_spread(trades_agg_r,book(:,[1 2 4]));
    cl_strt='cl';            % cleaning string for output file
else
    trades= trades_agg_r;     % do nothing
    cl_strt='ncl';
end
% -------------------------------------------------------------------------
%
%% Save Output Matrix

% save output 
save(strcat(outpath,ticker,'\\',ticker,'_',datestr(tdates(i),'yyyymmdd'),'_trades_',cl_strt,'.mat'),'trades')

% -------------------------------------------------------------------------
%% End Loop over trading days
% -------------------------------------------------------------------------

% book or mesage file do not exit: do nothing
%----------------------------------------------
else
    
disp(['Message file for ' ticker ' is missing. Skip.'])

end

end