function process_trade_core(ticker, tdate,...
    cl_indt,startTrad,endTrad,startTradin,endTradin,inpath,outpath)
%% process_trade_core
%------------------------------------------------------------
% process trade data
%--------------------------------------------------------------
% INPUT:
% ticker -> ticker symbol
% tdate   -> trading date (MATLAB date format)
% cl_indt   ->  if==1: cleaning of trades is done
% startTrad  ->  start of Selected Time Interval (in sec after midn)
% startTradin ->  start of Trading hours (in milisec after midnight)
%--------------------------------------------------------------
%
% Peter Malec,  February 19 2014 
%
% -------------------------------------------------------------------------
%   
%% Load Order Book and Message File

% names
mname=strcat(inpath,ticker,'_',datestr(tdate,'yyyy-mm-dd'),'_',int2str(startTradin),'_',int2str(endTradin),'_message_',num2str(1),'.csv');

% check if files do exits
%----------------------------------------------
mindex=isequal(exist(mname,'file'),2);

if cl_indt==1
    % names
    bname=strcat(inpath,ticker,'_',datestr(tdate,'yyyy-mm-dd'),'_',int2str(startTradin),'_',int2str(endTradin),'_orderbook_1','.csv');
    % check if files does exit
    bindex=isequal(exist(bname,'file'),2);
else
    bindex=true(1);    
end

% special case QQQ
if isequal(ticker,'QQQ')
    mname2=strcat(inpath,'QQQQ_',datestr(tdate,'yyyy-mm-dd'),'_',int2str(startTradin),'_',int2str(endTradin),'_message_',num2str(1),'.csv');  
    mindex2=isequal(exist(mname2,'file'),2);
    bname2=strcat(inpath,'QQQQ_',datestr(tdate,'yyyy-mm-dd'),'_',int2str(startTradin),'_',int2str(endTradin),'_orderbook_1','.csv');
    if cl_indt==1
        bindex2=isequal(exist(bname2,'file'),2);
    else
        bindex2=true(1);    
    end
end

if (bindex&&mindex)||((isequal(ticker,'QQQ'))&&bindex2&&mindex2)
%-----------------------------------------------
% adjustment for QQQQ

if ((isequal(ticker,'QQQ'))&&bindex2&&mindex2)
    bname=bname2;
    mname=mname2;
end
%-----------------------------------------------

% Load Message data
mess = dlmread(mname);

% Message file information:
% -------------------------------------------------------------------------
%   
%   - Dimension:    Matrix of size (NumberEvents X 6)
%
%   - Structure:    Each row:
%                   timeStamp (sec after midnight), EventType,
%                   Message ID, Size (# of shares), Price, Direction
%
% -------------------------------------------------------------------------
%
%% Book Data

if cl_indt==1
    
    % clear old data
    clear book;
    clear timeIdx;
    clear keepIndx;

    
    % Load Order Book data
    book = dlmread(bname);
   
    % Order book file information:
    % -------------------------------------------------------------------------
    %   
    %   - Dimension:    Matrix of size (NumberEvents X (5))
    %
    %   - Structure:    Each row:
    %                   timeStamp (Ms after midnight), Ask price 1, 
    %                   Ask volume 1, Bid price 1, Bid volume 1
    %
    % -------------------------------------------------------------------------
    
    % Add time to book
    book=[mess(:,1) book];

    % Remove observations outside the official trading hours
    % -------------------------------------------------------------------------

    % Get index of observations 
    timeIdx = book(:,1) >= startTrad & book(:,1) <= endTrad;

    % Remove observations
    book = book(timeIdx,:);

    % Do Rough Cleaning
    % -------------------------------------------------------------------------

    %bid and ask positive, spread nonnegative
    keepIndx=(book(:,2)>0) & (book(:,4)>0) & (book(:,2)-book(:,4) >= 0);
                                                                            
    % select clean data
    book=book(logical(keepIndx),:);
                                                                            
    % Convert prices into dollars
    % -------------------------------------------------------------------------
    book(:,[2 4]) = book(:,[2 4])./10000;
    % Note: LOBSTER stores prices in dollar price times 10000
    
end
% -------------------------------------------------------------------------
%
%% Data Preparation 

% Remove observations outside the official trading hours
% -------------------------------------------------------------------------

% Get index of observations 
timeIdxm = mess(:,1) >= startTrad & mess(:,1) <= endTrad;

% Remove observations
mess = mess(timeIdxm,:);

% Do Rough Cleaning
% -------------------------------------------------------------------------

%price positive
keepIndxm=mess(:,5)>0;
                                                                            
% select clean data
mess=mess(logical(keepIndxm),:);

% Convert prices into dollars
% -------------------------------------------------------------------------

    % Note: LOBSTER stores prices in dollar price times 10000
mess(:,5) = mess(:,5)./10000;    
% -------------------------------------------------------------------------
%
%% Select Executions and Aggregate Order Executions to Trades 

%Aggregation
trades_agg=AggExecutions_Core_l1(mess);
trades_agg_r=[mess(trades_agg(:,2),1) trades_agg(:,4)];
%2nd order Aggregation
trades_agg2 = AggExecutions_Core_l1_after(trades_agg_r);
trades_agg_r2=[trades_agg_r(trades_agg2(:,2),1) trades_agg2(:,3)];
%Note: time of transaction (time of last subtrade), price 
% -------------------------------------------------------------------------
%
%% Data Cleaning

% Clean if desired using method by Barndorff-Nielsen et al. (2009)
if cl_indt==1
    trades=check_trade_spread(trades_agg_r2,book(:,[1 2 4]));
    cl_strt='cl';            % cleaning string for output file
else
    trades= trades_agg_r2;     % do nothing
    cl_strt='ncl';
end
% -------------------------------------------------------------------------
%
%% Save Output Matrix

% save output 
save(strcat(outpath,ticker,'\\',ticker,'_',datestr(tdate,'yyyymmdd'),'_trades_',cl_strt,'.mat'),'trades')

% book or mesage file do not exit: do nothing
%----------------------------------------------
else
    
disp(['Message file for ' ticker ' is missing. Skip.'])

end

