function GMV_Intraday_PerformComp_func(ticker_a,tdate,tdate_l,typed,cl_ind,rev_ind,input_v,startt,endt,...
    J_p,theta_h,theta_J,theta_K,K_p_thr,twost,lKb,ccorr,inpath,sourced,outpath)
%% GMV_Intraday_PerformComp_func
%--------------------------------------------------------------
% Compares Intraday Portfolio Volatility for GMW portfolio chosen
% on intraday basis using spot LMM estimator (adaptive version) 
% vs GMW portfolio chosen at beginning of day using
% integrated LMM estimate from the previous day
%
%--------------------------------------------------------------
% INPUT:
% ticker_a-> (mx1) cell array of ticker symbols
% tdate   -> data in matlab format
% % tdate   -> data of previous day in matlab format
% cl_ind    -> if >0, data cleaned according to proc by BNHLS(2009) is used
% typed   -> type of data: midp (quotes) or trades
% rev_ind  -> indicator for quote revisions
% input_v -> points of estimation
% startt -> start of trading (in hours)
% endt   -> end of trading (in hours)
% J_p-> spectral cutoff for pilot estimates of spot covariances
% theta_h   -> proportionality parameter for block length (relevant if B
%                           not specified)
% theta_J     -> proportionaliy parameter for cutoff (relevant if J
%                           or J_p not specified)
% theta_K    -> proportionality parameter for smoothing bandwidth (relevant if K
%                           or K_p not specified)
% K_p_thr    -> lower threshold for pilot smoothing bandwidth (relevant if
%                           K_p not specified): default=1
% twst     -> if >0: twostep estimation is used (estimates from first step
%                   used as pilots for second step
% lkB         -> if >0, shorter smoothing windows at beginning and end of
%                   day are used for spot cov estim (NOT PILOT!)
% ccorr -> if >0, correlation and variance estimates are corrected
% inpath     -> path for loading data
% sourced   -> data source
% outpath  -> path for saving
%--------------------------------------------------------------
%
% Peter Malec, january 31 2014
%
% -------------------------------------------------------------------------
%   
%% Preparations

% clean?
if cl_ind==1
    cl_str='cl';            % cleaning string for output file
else
    cl_str='ncl';
end

% revisions?
if rev_ind==1
    rev_str='rev';   
else
    rev_str='nrev';   
end

%venue label
if isequal(source_d,'LOBSTER')
venuel='';
else
    venuel=strcat('_',venue);
end
% -------------------------------------------------------------------------
% 
%% Load Data

% names
name1=strcat(inpath,ticker1,'_',datestr(tdate,'yyyymmdd'),'_midp_',cl_str,'.mat');
name2=strcat(inpath,ticker2,'_',datestr(tdate,'yyyymmdd'),'_midp_',cl_str,'.mat');

% check for existence of files
index1=isequal(exist(name1,'file'),2);
index2=isequal(exist(name2,'file'),2);

if index1&&index2
%---------------------------------------------------------

% data for day of interest
%-------------------------------------------------------------------------------

%empty cell array
PRICETIME=cell(length(ticker_a),1);

% loop across assets
for i=1:length(ticker_a)
    load(strcat(inpath,ticker_a{i},venuel,'_',datestr(tdate,'yyyymmdd'),'_',typed,'_',cl_str,'_',rev_str,'.mat'));
    if isequal(typed,'trades')
        midprice=trades;
    end
    PRICETIME{i}=midprice;
end

% data for previous day
%-------------------------------------------------------------------------------

%empty cell array
PRICETIMEl=cell(2*length(ticker_a),1);

% loop across assets
for i=1:length(ticker_a)
    load(strcat(inpath,ticker_a{i},venuel,'_',datestr(tdate_l,'yyyymmdd'),'_',typed,'_',cl_str,'_',rev_str,'.mat'));
    if isequal(typed,'trades')
        midprice=trades;
    end
    PRICETIMEl{2*(i-1)+1}=midprice(:,2); %note: first price, then time (for MRK)
    PRICETIMEl{2*(i-1)+2}=midprice(:,1);
end
% -------------------------------------------------------------------------
%
%% Compute GMW weights and Evaluate

% Estimate Intraday GMW weights
%------------------------------------------------

% spot covs
[SCov_mat,block_st,block_end,J_opt,J_p,K,K_p,noisev_m,nobs_v]=lle_spot_cov_md_adpt_mult(input_v,PRICETIME,startt,endt,...
        1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,twostc,ccorr);
    
% GMW weights including variances
[GMWwID_mat,~]=GMW_weights(SCov_mat);

% Estimate 'Daily' GMW weights from Previous day
%---------------------------------------------------------

% estimate noise variance
noisevl=NaN*zeros(length(ticker_a),1);
for i=1:length(ticker_a)
    data_temp=PRICETIMEl{i};
    eta2=noise_cov_est(data_temp(:,2),'cov');
     if eta2<=0
           eta2=noise_cov_est(data_temp(:,2),'var');
     end
     noisevl(i)=eta2;   
end

% spot covs
 [ICov,block_stD,block_endD,J_optvD,J_pD,K_pD]=lle_icov_md(PRICETIMEl,noisevl,startt,endt,...
  1,1,[],[],J_p,[],theta_h,theta_J,theta_K,K_p_thr,twost,twostc,ccorr);
    
% GMW weights including variances
[GMWwD_mat,~]=GMW_weights(ICov');
GMWwD_mat=GMWwD_mat(ones(length(input_v),1),:);

% Estimate GMW Portfolio Volatility using 'classis' spot LMM
%-------------------------------------------------------------------

% estimate noise variance
noisev=NaN*zeros(length(ticker_a),1);
for i=1:length(ticker_a)
    data_temp=PRICETIME{i};
    eta2=noise_cov_est(data_temp(:,2),'cov');
     if eta2<=0
           eta2=noise_cov_est(data_temp(:,2),'var');
     end
     noisev(i)=eta2;   
end

% spot covs
[SigmaSpot_outE,block_stE,block_endE,J_optvE,J_pE,KE,K_pE]=lle_spot_cov_md(input_v,PRICETIME,...
        noisev,startt,endt,1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,twostc,lKb,ccorr);
    
% PV Volatilities
[pfvol_vec_ID,~]=pf_vol(GMWwID_mat',SigmaSpot_outE);
[pfvol_vec_D,~]=pf_vol(GMWwD_mat',SigmaSpot_outE);    
% -------------------------------------------------------------------------
%   
%% Save outputs

% label lKb
if lKb>0
     lKbl='_lKb';
else
     lKbl='';
end

% label ccorr
if ccorr>0
     ccorrl='_ccorr';
else
     ccorrl='';
end

%label twostep
if twost>0
     twostl='_2st';
else
     twostl='';
end

% label: estimator covariance
if twostc>0
      twostcl='_2stc';
else
      twostcl='';
end

%clean labels
theta_hl=num2str(theta_h);
theta_hl(theta_hl=='.')='';
theta_Jl=num2str(theta_J);
theta_Jl(theta_Jl=='.')='';
theta_Kl=num2str(theta_K);
theta_Kl(theta_Kl=='.')='';

%basename
basename=strcat(outpath,sourced,'_',ticker1,'_',ticker2,'_',datestr(tdate,'yyyymmdd'),'_',cl_str,...
            '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,twostl,twostcl);
        
%save spot covariance matrices
scov_out.est=SigmaSpot_out;
scov_out.var=CovSigmaSpot_out;
scov_out_nout=strcat(basename,'_scov');
save(scov_out_nout,'scov_out')

%save spot correlation
scorr_out.est=SpotCorr;
scorr_out.var=SpotCorr_var;
scorr_out_nout=strcat(basename,'_scorr');
save(scorr_out_nout,'scorr_out')

%save LMM config
LMM_conf.gen=[length(block_st) max(J_optv) J_p K K_p];
LMM_conf.Jex=J_optv;
LMM_conf_nout=strcat(basename,'_LMM_conf');
save(LMM_conf_nout,'LMM_conf')

%file do not exist: do nothing
%----------------------------------------
else
    disp(['Data for ' ticker1 ' or ' ticker2 ' are missing. Skip.'])
end



    
  
    