function [GMWwVar_vec]=GMW_weights_var(GMWw,SCov_mat,Covmat)
%------------------------------------------------------------------
%% GMW_weights_var
%  Computes variance of GMV weights based on GMW weights,
% spot covariance matrix estimate and its vec transformations' covariance matrix
%------------------------------------------------------------------
%
% INPUTS
% GMWw      -> (mx1) vector of GMW weights
% SCov_mat-> (mxm) spot covariance matrix
% Covmat->(m^2xm^2) covariance matrix of the vech transformation of 
%                       the above spot covariance matrix estimate
%------------------------------------------------------------------
% OUTPUTS
% GMWwVar_vec -> (mx1) vector of variances of 
%------------------------------------------------------------------
%
%   Peter Malec, January 23, 2014
%
%------------------------------------------------------------------
%
%% Preparations

% no of assets
m= size(SCov_mat,1);

% check
if (~isequal(size(Covmat,1),m^2))||(~isequal(length(GMWw),m))
    error('Dimensions of Inputs are not compatible!')
end

% matrix of ones
J_d=ones(m,m);

%matrix of zeros
zero_d=zeros(m,m);

%vector of ones
iota=ones(1,m);

% sum of spot covariance matrix elements
SCov_mat_S=sum(sum(SCov_mat));
%------------------------------------------------------------------
%
%% Compute Variance of GMW weights

% initialize 
GMWwVar_vec=NaN*zeros(m,1);

%loop across assets
%---------------------------------------------
for i=1:m
    
    % compute derivative of ith weight wrt spot covariance matrix
    temp_mat=zero_d;
    temp_mat(i,:)=iota;
    Sigma_delta=(temp_mat-GMWw(i)*J_d)/SCov_mat_S; %(mxm) matrix
    
    % variance of weight follows from delta method
    GMWwVar_vec(i)= Sigma_delta(:)'*Covmat* Sigma_delta(:);
end

