function est_seas_ret_func(ticker,tdate_v,typed,cl_ind,rev_ind,...
    freqrv,nss,freqs,startt,endt,maxD,spec,inpathd,inpathrv,sourced,outpath)
%% est_seas_ret_func
%--------------------------------------------------------------
% estimate intraday seasonality from plain returns. daily vola
% estimate is subsampled 5min-RV. Outputs are saved directly
%--------------------------------------------------------------
% INPUT:
% ticker -> ticker symbol (string)
% tdate   -> vector of dates in matlab format
% cl_ind    -> if ==1, data cleaned according to proc by BNHLS(2009) is used
% rev_ind    -> if ==1, only obs with price revisions are used
% freqrv    -> sampling frequency in seconds for rv
% nss    -> no of subsamples (empty if no subsampling)
% freqs    -> frequency for intraday returns
% startt   -> start of trading period (in hours)
% endt     -> end of trading period (in hours)
% maxD     -> maximum order of the fourier transform
% spec  -> specification indicator: =0 -> no polynomial and intercept
%                                                 =1  ->polynomial, but no
%                                                 intercept
%                                                 = 2   -> intercept, but
%                                                 no polynomial
%                                                  =3  -> intercept and
%                                                  polynomial
% inpathd     -> path for loading data
% inpathrv     -> path for loading rv estimates
% sourced   -> data source
% outpath  -> path for saving
%--------------------------------------------------------------
%
% Peter Malec,  April 7, 2014 
%
% -------------------------------------------------------------------------
%   
%% Load Data

% clean?
if cl_ind==1
     cl_str='cl';            % cleaning string for output file
else
     cl_str='ncl';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

% Number of Rets per day
N=(endt-startt)*(3600/freqs);  

% empty vectors for intraday returns and IV estimates
Ret_vec=NaN*zeros(N*length(tdate_v),1);
rvSSv=NaN*zeros(length(tdate_v),1);

% loop over trading days
%----------------------------------------------
%----------------------------------------------
for j=1:length(tdate_v)

% select date 
tdate=tdate_v(j);
disp([ticker ':' datestr(tdate,'yyyy--mm--dd')])

    
% check for existence of file
%-----------------------------------------------------------------------------------
name=strcat(inpathd,ticker,filesep,ticker,'_',datestr(tdate,'yyyymmdd'),'_',typed,'_',cl_str,'.mat');
index=isequal(exist(name,'file'),2);

if index
%---------------------------------------------------------
load(name);
if isequal(typed,'trades')
        midprice=trades;
end
if rev_ind==1
        midprice=keep_rev(midprice,2);
end
  
% Sample Prices and assign
%----------------------------------------------------------
[filteredPrice,~,~] = realized_price_filter(midprice(:,2),midprice(:,1),'seconds','CalendarTime',freqs);
lret=diff(log(filteredPrice));
Ret_vec(((j-1)*N+1):j*N,:)=[lret;NaN*zeros(N-length(lret),1)];


% Sub-Sampled RV
%----------------------------------------------------------
%----------------------------------------------------------

% check for existence of file
if ~isempty(nss)
        namerv=strcat(inpathrv,'rv_',sourced,'_',ticker,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                '_freq',int2str(freqrv),'_nss',int2str(nss),'.mat');
else
        namerv=strcat(inpathrv,'rv_',sourced,'_',ticker,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                '_freq',int2str(freqrv),'.mat');
end
indexrv=isequal(exist(namerv,'file'),2);

if indexrv
%---------------------------------------------------------
    indat=iload(namerv,'rvest');
    rvSSv(j)=indat.rvest.rvSS;
    
else
    disp(['RV estimate missing for ticker: ' ticker '. Skip day.'])
end

%file do not exist: do nothing
%----------------------------------------
else
    disp(['Data missing for ticker: ' ticker '. Skip day.'])
end


end
% -------------------------------------------------------------------------
%   
%% Estimate FFF Parameters

% timesvector for FF regressions
time_v=(1:1:N)'/N;
times=reshape(time_v(:,ones(length(tdate_v),1)),length(time_v)*length(tdate_v),1);

% compute dependent variable for regression "x"
%-------------------------------------------------------------------
% expand rv vector
rvSSv=rvSSv(:)';  % row vector
rvSSv_ext=reshape(rvSSv(ones(length(time_v),1),:),length(time_v)*length(tdate_v),1);

% compute x
x_vec=2*log(abs(Ret_vec-nanmean(Ret_vec)))-log(rvSSv_ext)+log(N);

% perform FFF regression
[theta_FF, regfit_FF]=reg_fourier_gen_optD_Ret(x_vec,times,maxD,spec);
FF_res.theta_FF=theta_FF;
FF_res.regfit_FF=regfit_FF;
% -------------------------------------------------------------------------
%   
%% Save outputs

%save estimates
%-----------------------------------------------------
if ~isempty(nss)
    basename=strcat(outpath,'FFF_maxD',int2str(maxD),'_spec',int2str(spec),sourced,'_',ticker,'_',datestr(tdate_v(1),'yyyymmdd'),'_',datestr(tdate_v(end),'yyyymmdd'),...
        typed,'_',cl_str,rev_str,...
                '_freqs',int2str(freqs),'_freq',int2str(freqrv),'_nss',int2str(nss));
 else
   basename=strcat(outpath,'FFF_maxD',int2str(maxD),'_spec',int2str(spec),sourced,'_',ticker,'_',datestr(tdate_v(1),'yyyymmdd'),'_',datestr(tdate_v(end),'yyyymmdd'),...
       typed,'_',cl_str,rev_str,...
                '_freqs',int2str(freqs),'_freq',int2str(freqrv));
end
save(basename,'FF_res')     






    
  
    