%% plot_sim_eval_2d_detvol_05022012.m
%--------------------------------------------------------------------------
% Evaluates  and plots RMSEs for estimates of integrated 
% (co-)variance based on  2-dimensional diffusion process with deterministic
%  spot volatility functions dillluted by microstructure noise
%--------------------------------------------------------------------------
%
% Peter Malec, February 05, 2012
%
% mods on January 14, 2012:
% lle estimator, different noise levels
%
% modifications February 12, 2012
% additional constant variance case
%
% modifications February 27, 2012
% adjustment for lle estimates based on 1000 reps
% -------------------------------------------------------------------------------------------------
%

% -------------------------------------------------------------------------
%
%% Define INPUTS

% Clear system
clear all;
clc;

% Choose basepath
basepath = 0;                               

%# number of steps within a day
steps=23400;                                            

% # of replications
repl=1000;%10000;                                               

% Indices of DGPs
eff_pr_dgp_v=1:7;    
noise_dgp_v=2; %1:3;    % ignore lasrge noise case   

% correlation vector
rho_v=[-(1-1e-2) -0.7 -0.3 0  0.3 0.7 (1-1e-2)];

% which plot
wplot=3;        % 1: var1, 2:var2, 3:cov

% estimators
estim_ch='lle';         %'gen': general comparison, 
                                 %'gen_nrc': general comparison w/o rcov mrk, 
                                    %'lle': LLE with comparison of block lengths.
                                    %'lle1':
% volatility type
sig_typ='tv'; % else const
% -------------------------------------------------------------------------
%
%% Check which estimaators to consider

if isequal(estim_ch,'gen')

    estim_v={'lle1';'rcov';'mrk';'mscrc';'preav1';'preav033'};
     
elseif isequal(estim_ch,'gen_nrc')

   %estim_v={'lle1';'mrk';'mscrc';'preav1';'preav033'};
   estim_v={'lle1';'mscrc';'preav1';'preav033'};
     
elseif isequal(estim_ch,'lle')
    
    %estim_v={'lle1';'lle30';'lle20';'lle10';'lle8';'lle5'};     
    estim_v={'lle1';'lle20';'lle10';'lle8';'lle5'};     
    
elseif isequal(estim_ch,'lle_spec')
    
    %estim_v={'lle8';'spec8';'specJ1h8'};    
     estim_v={'lle1';'spec1'};    
    
elseif isequal(estim_ch,'spec')
    
    estim_v={'spec1';'spec30';'spec20';'spec10';'spec8';'spec5'};     
    
else
    
    estim_v={estim_ch};     
     
end

% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = 'D:\\Spectr_Cov\\MATLAB\\';
    
elseif basepath ==0
    
    pathproject = 'H:\\Spectr_Cov\\MATLAB\\';
    
elseif basepath ==2
    
    pathproject = 'D:\\Work\\Spectr_Cov\\MATLAB\\';

    
else
    
    pathproject = 'H:\\Spectr_Cov\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpaths

inpath=strcat(pathproject,'Sim\\Sim_simp_est\\');

isigpath=strcat(pathproject,'Sim\\Sim_simp_data\\');

outpath=strcat(pathproject,'Sim\\Sim_simp_res\');
% -------------------------------------------------------------------------
%
%% Define Color Cell array for Plots

% colors:
color_a={'Black','DarkGrey','DarkRed','DarkBlue','DarkGreen','indianred','lightblue','lightgrey','lightgreen'};

% -------------------------------------------------------------------------
%
%% Load integrated covariances 

% output labels
if isequal(sig_typ,'tv')
    sig_lab='detvol';
else
    sig_lab='constvol';
end

% integrated covariance
if isequal(sig_typ,'tv')
    load(strcat(isigpath,'sim_2d_detvol_isigma.mat'));  
 else
    sigma=0.204;
    isigma_mat=[repmat([sigma^2  sigma^2],length(rho_v),1) (sigma^(2) *rho_v')];
end
% -------------------------------------------------------------------------
%
%% Compute Bias and RMSE

% Empty arrays for results
res_isigma1_arr=NaN*zeros(length(eff_pr_dgp_v),length(estim_v),length(noise_dgp_v));
res_isigma2_arr=NaN*zeros(length(eff_pr_dgp_v),length(estim_v),length(noise_dgp_v));
res_isigma12_arr=NaN*zeros(length(eff_pr_dgp_v),length(estim_v),length(noise_dgp_v));
 
% Loop over different estimators and scenarios
%------------------------------------------------------------------------

for i=1:length(estim_v)


    for j=1:length(eff_pr_dgp_v)
        
        % choose eff price a
        eff_pr_dgp_i=eff_pr_dgp_v(j);
     
        % integrated covariances and quarticities
        isigma_vec=(isigma_mat(j,:))';
   
       for k=1:length(noise_dgp_v)
            
            % noise dgp index
            noise_dgp_i=noise_dgp_v(k);
         
            %load estimates
           if ~isequal(estim_v{i},'lle1') && ~isequal(estim_v{i},'lle5')  && ~isequal(estim_v{i},'lle8')  && ~isequal(estim_v{i},'lle10') ...
                     && ~isequal(estim_v{i},'lle20')  && ~isequal(estim_v{i},'lle30') && ~isequal(estim_v{i},'spec8') && ~isequal(estim_v{i},'specJ1h8') && ...
                     ~isequal(estim_v{i},'spec1') && ~isequal(estim_v{i},'spec5')  && ~isequal(estim_v{i},'spec8')  && ~isequal(estim_v{i},'spec10') ...
                     && ~isequal(estim_v{i},'spec20')  && ~isequal(estim_v{i},'spec30') 
                 
                load(strcat(inpath,'sim_2d_',sig_lab,'_',estim_v{i},'_eff_pr', num2str(eff_pr_dgp_i),'_ksi', num2str(noise_dgp_i),'_st',num2str(steps),'_repl',num2str(3000),'.mat'));
                isigmaest=x(1:repl,:);
                
            else
                load(strcat(inpath,'sim_2d_',sig_lab,'_',estim_v{i},'_eff_pr', num2str(eff_pr_dgp_i),'_ksi', num2str(noise_dgp_i),'_st',num2str(steps),'_repl',num2str(repl),'.mat'));
                isigmaest=x; 
           end
            
            % Compute rmse
            rmse=sqrt(nanmean((isigmaest-repmat(isigma_vec',[size(isigmaest,1) 1])).^2));
            
            % write results into arrays
            res_isigma1_arr(j,i,k)=rmse(1);
            res_isigma2_arr(j,i,k)=rmse(2);
            res_isigma12_arr(j,i,k)=rmse(3);
            
        end
        
   end
    
end
% -------------------------------------------------------------------------
%
%% Create Plots

% choose series
 if wplot==1
        plotm=res_isigma1_arr;
        plot_l='_var1';
 elseif wplot==2
        plotm=res_isigma2_arr;
        plot_l='_var2';
 else 
        plotm=res_isigma12_arr;
        plot_l='_cov';
 end

 % check if relative RMSEs needed
 if isequal(estim_ch,'gen') || isequal(estim_ch,'gen_nrc') || isequal(estim_ch,'lle')|| isequal(estim_ch,'lle_spec')|| isequal(estim_ch,'spec')
     plotm=plotm./repmat(plotm(:,1,:),[1 (size(plotm,2)) 1]);
     ylab_str='Rel. RMSE';
 else
     ylab_str='RMSE';
 end

for i=1:length(noise_dgp_v)       % loop over noise dgps
    
    % noise dgp index
    noise_dgp_i=noise_dgp_v(i);
    
    fh=figure;
 
    set(fh, 'color', 'white');
    h=plot(rho_v(eff_pr_dgp_v),plotm(:,:,i),'--d');  
     
    for j=1:length(estim_v)
        set(h(j),'color',rgb(color_a(j)),'linewidth',1,'MarkerEdgeColor',rgb(color_a(j)),'MarkerFaceColor',rgb(color_a(j)),'MarkerSize',5);
    end

    l = legend(estim_v);
    xl = xlabel('Correlation');
    yl = ylabel(ylab_str);
    
    set(gca, 'TickDir', 'out', 'Box', 'off' ,'XMinorTick','Off','YMinorTick','Off','linewidth',1.5); % here gca means get current axis
    
    set(l,'Location','Northwest','Orientation','vertical');
    set(l,'FontSize',12','FontName',' Helvetica','FontWeight','demi');
    set(xl,'FontSize',12,'FontName','Helvetica','FontWeight','demi');
    set(yl,'FontSize',12,'FontName','Helvetica','FontWeight','demi');
 
    parent = get(h(1),'Parent');
    set(parent,'FontSize',12,'FontName','Helvetica','FontWeight','demi');    


    % save plot:
    savefig(strcat(outpath,'sim_2d_',sig_lab,'_rmse_',estim_ch,plot_l,'_ksi', num2str(noise_dgp_i),'_st',num2str(steps),'_repl',num2str(repl)), 'pdf');

end





 
