function param=reg_fourier(ret,dvar,time,N,D)
%% reg_fourier
%--------------------------------------------------------------
% estimates parameters of Fourier transform for 
% determinisctic intraday volatility function by OLS
% following Andersen & Bollerslev (JempFin,1997)
%--------------------------------------------------------------
% INPUT:
% ret ->  (Tx1) vector of returns
% dvar -> (Tx1) vector of (T/N) daily volatilities
% time -> (Tx1) vector of observation times as 
% fraction of trading day (n/N)
% N     -> number of observations per day 
% D     -> order of the fourier transform
%--------------------------------------------------------------
% OUTPUT:
% param -> ((3+D*2)x1) vector of OLS estimates of Fourier parameters
% -------------------------------------------------------------------------
%
% Peter Malec, January 24, 2012
%
% -------------------------------------------------------------------------
%       
%% Prepare Dependent Variable and Regressor Matrix

% dependent variable
%------------------------------
y=2*log(abs(ret-mean(ret)))-log(dvar)+log(N);

% regressors
%------------------------------

% rescaling terms
N1=(N+1)/2;
N2=(N+1)*(N+2)/6;

% polynomial terms
poly1=time*N/N1;
poly2=time.^(2)*(N^2)/N2;

% trigonometric terms
trig=[];

for i=1:D
    trig_i=[cos(time*2*pi*i) sin(time*2*pi*i)];
    trig=[trig trig_i];
end

% collect terms
x=[poly1 poly2 trig];

%       
%% OLS estimation

% OLS estimation with constant
param= ols(y,x,1);