function param=reg_fourier_gen(svar,time,D,spec)
%% reg_fourier_gen
%--------------------------------------------------------------
% estimates parameters of Fourier transform with or w/o polynomial
% terms and intercept for 
% determinisctic intraday volatility function by OLS
% based on (absolute) spot (co-)variance estimates directly
%--------------------------------------------------------------
% INPUT:
% svar ->  (Tx1) vector of spot variance estimates
% time -> (Tx1) vector of observation times as 
% fraction of trading day (time \in [0,1])
% D     -> order of the fourier transform
% spec  -> specification indicator: =0 -> no polynomial and intercept
%                                                 =1  ->polynomial, but no
%                                                 intercept
%                                                 = 2   -> intercept, but
%                                                 no polynomial
%                                                  =3  -> intercept and
%                                                  polynomial
%--------------------------------------------------------------
% OUTPUT:
% param -> ((D*2)x1) vector of OLS estimates of Fourier parameters
% -------------------------------------------------------------------------
%
% Peter Malec, November 29, 2013
%
% -------------------------------------------------------------------------
%       
%% Prepare Dependent Variable and Regressor Matrix

% input check
%-------------------------------------------

% remove exact zeros and negative obs
svar(svar<=0)=NaN;
svar=svar(~isnan(svar));
time=time(~isnan(svar));

% default specification
if nargin<4
    spec=0;
end

% dependent variable
%------------------------------
y=log(svar);

% regressors: 
%------------------------------
%-----------------------------------

%trigonometric terms
%--------------------------------------
trig=NaN*zeros(length(time),(2*D));

for i=1:D
    trig(:,[(2*i-1)  2*i])=[cos(time*2*pi*i) sin(time*2*pi*i)];
end

% construct regressor matrix
if isequal(spec,1)||isequal(spec,3)
    x=[time time.^2 trig];
else
    x=trig;
end
%       
%% OLS estimation

% OLS estimation with constant
param= ols(y,x,1);

% drop constant or not
if isequal(spec,0)||isequal(spec,1)
    param=param(2:end);%constant is estimate of Expected stochastic component
end