function [corrtf,var_tot,var_exp]=vola_fit_uni(time,param_var1,var1,spec)
%% vola_fit
%--------------------------------------------------------------
% checks in-sample fit of FFF-based volatility estimates
% Note: observation times are the same for each trading day
%--------------------------------------------------------------
% INPUT:
% time -> (Nx1) vector of observation times as 
%       fraction of trading day (time \in [0,1]): 
% param_var1 ->vector of Fourier parameters
% var1 -> (NTx1) vector of spot variance estimates:
%               T is number of days
% spec  -> specification indicator: =0 -> no polynomial and intercept
%                                                 =1  ->polynomial, but no
%                                                 intercept
%                                                 = 2   -> intercept, but
%                                                 no polynomial
%                                                  =3  -> intercept and
%                                                  polynomial
%--------------------------------------------------------------
% OUTPUT:
% corrtf -> correlation between true and fitted
%                values
% var_tot -> total variation
% var_exp   -> explained variation
% -------------------------------------------------------------------------
%
% Peter Malec, March 24, 2014
%
% -------------------------------------------------------------------------
%       
%% Input Check


if (abs(length(var1)/length(time)-floor(length(var1)/length(time)))>0)
     error('Number of estimates and times inconsistent')
end
% -------------------------------------------------------------------------
%   
%% Compute Estimates


%var 1
var1_fit=vola_fourier_gen(time,param_var1,spec);

% compute explained variation
var_exp=mean((var1_fit-mean(var1_fit)).^2) ;

% expand fitted values
%--------------------------------------------------------
var1_fit=reshape(var1_fit(:,ones(length(var1)/length(var1_fit),1)),length(var1),1);
% -------------------------------------------------------------------------
%   
%% Correct

% remove exact zeros and negative obs from original observations
var1(var1<=0)=NaN;
var1=var1(~isnan(var1));

%correct
var1_fit=var1_fit(~isnan(var1));
% -------------------------------------------------------------------------
%   
%% Compute Measures of Fit

% correlation
corrtf=corr(var1,var1_fit);

% total variation
var_tot=mean((var1-mean(var1)).^2);





