function sigma2=vola_fourier(time,N,D,param)
%% vola_fourier
%--------------------------------------------------------------
% computes deterministic intraday volatility function
% following Andersen & Bollerslev (JempFin,1997)
% NOTE: no normalization!
%--------------------------------------------------------------
% INPUT:
% time -> (Tx1) vector of observation times as 
% fraction of trading day (n/N)
% N      -> number of observations per day
% D     -> order of the fourier transform
% param -> ((3+D*2)x1) vector of Fourier parameters
%--------------------------------------------------------------
% OUTPUT:
% sigma2 -> (Tx1) vector of intraday variances
% -------------------------------------------------------------------------
%
% Peter Malec, January 24, 2012
%
% -------------------------------------------------------------------------
%       
% -------------------------------------------------------------------------
%       
%% Input Check

if length(param)~=(3+D*2)
    error('Wrong number of parameters!')
end
% -------------------------------------------------------------------------
%      
%% Compute terms depending on obs time

% rescaling terms
N1=(N+1)/2;
N2=(N+1)*(N+2)/6;

% polynomial terms
poly1=time*N/N1;
poly2=time.^(2)*(N^2)/N2;

% trigonometric terms
trig=[];

for i=1:D
    trig_i=[cos(time*2*pi*i) sin(time*2*pi*i)];
    trig=[trig trig_i];
end

% collect terms including constant
x=[ones(length(time),1) poly1 poly2 trig];

% -------------------------------------------------------------------------
%       
%% Compute Intraday variances

sigma2=exp(x*param);

