function sigma2=vola_fourier_gen(time,D,param,spec)
%% vola_fourier_gen
%--------------------------------------------------------------
% computes deterministic intraday volatility function
% based on Fourier form with or without polyn and constant
% NOTE: Including normalization ensuring integration to one
%--------------------------------------------------------------
% INPUT:
% time -> (Tx1) vector of observation times as 
% fraction of trading day (time \in [0,1])
% D     -> order of the fourier transform
% param -> ((D*2)x1) vector of Fourier parameters
% spec  -> specification indicator: =0 -> no polynomial and intercept
%                                                 =1  ->polynomial, but no
%                                                 intercept
%                                                 = 2   -> intercept, but
%                                                 no polynomial
%                                                  =3  -> intercept and
%                                                  polynomial
%--------------------------------------------------------------
% OUTPUT:
% sigma2 -> (Tx1) vector of intraday variances
% -------------------------------------------------------------------------
%
% Peter Malec, November 29, 2012
%
% -------------------------------------------------------------------------
%       
% -------------------------------------------------------------------------
%       
%% Input Check

% default specification
if nargin<4
    spec=0;
end

% number parameters
switch spec
    case 0
        if length(param)~=(D*2)
            error('Wrong number of parameters!')
        end
    case 1
        if length(param)~=(2+D*2)
            error('Wrong number of parameters!')
        end
     case 2
        if length(param)~=(1+D*2)
            error('Wrong number of parameters!')
        end
    otherwise
        if length(param)~=(3+D*2)
            error('Wrong number of parameters!')
        end
end
    
% -------------------------------------------------------------------------
%      
%% Compute fitted Intraday variances

% regressors: 
%------------------------------
%-----------------------------------

%trigonometric terms
%--------------------------------------
trig=NaN*zeros(length(time),(2*D));

for i=1:D
    trig(:,[(2*i-1)  2*i])=[cos(time*2*pi*i) sin(time*2*pi*i)];
end

% construct regressor matrix
if isequal(spec,1)||isequal(spec,3)
    x=[time time.^2 trig];
else
    x=trig;
end

if isequal(spec,2)||isequal(spec,3)
    x=[ones(length(time),1) x];
end

% fitted variances
sigma2=exp(x*param);
% -------------------------------------------------------------------------
%       
%% Normalization

sigma2=sigma2/mean(sigma2);

