function sigma2=vola_fourier_simp(time,D,param)
%% vola_fourier_simp
%--------------------------------------------------------------
% computes deterministic intraday volatility function
% based on Fourier form without constant
% NOTE: Including normalization ensuring integration to one
%--------------------------------------------------------------
% INPUT:
% time -> (Tx1) vector of observation times as 
% fraction of trading day (time \in [0,1])
% D     -> order of the fourier transform
% param -> ((D*2)x1) vector of Fourier parameters
%--------------------------------------------------------------
% OUTPUT:
% sigma2 -> (Tx1) vector of intraday variances
% -------------------------------------------------------------------------
%
% Peter Malec, November 29, 2012
%
% -------------------------------------------------------------------------
%       
% -------------------------------------------------------------------------
%       
%% Input Check

if length(param)~=(D*2)
    error('Wrong number of parameters!')
end
% -------------------------------------------------------------------------
%      
%% Compute fitted Intraday variances

% trigonometric terms
%------------------------------
trig=NaN*zeros(length(time),(2*D));

for i=1:D
    trig(:,[(2*i-1) 2*i])=[cos(time*2*pi*i) sin(time*2*pi*i)];
end

% fitted variances
sigma2=exp(trig*param);
% -------------------------------------------------------------------------
%       
%% Normalization

sigma2=sigma2/mean(sigma2);

