function Sigma_out=lle_cov_oracle_faster_const1(data_a1,data_a2,H,startt,endt,I_jk_m,Phi_norm)
%% lle_cov_oracle_faster_const
%--------------------------------------------------------------
% local likelihood estimation of covolatility matrix 
%  fastwe oracle version for constant vola case and one block
%--------------------------------------------------------------
% INPUT:
% data_a1 -> (n_a x 2) matrix of synchronous data for asset 1
%       - 1st  col: observation times  (sec after midnight)
%       - 2nd col: prices 
% H -> (2x2) covariance matrix of noise
% startt -> start of trading (in hours)
% endt   -> end of trading (in hours)
% I_jk_m-> (Jx6) matrix of distinct elements of fisher infos
% Phi_norm_m -> (Jx1) matrix of norms of spectral weights
% J_max -> spectral cutoff 
%--------------------------------------------------------------
% OUTPUT:
% Sigma_out -> (2 x 2) matrix containg estimates of integrated (co-)
% volatilities
% -------------------------------------------------------------------------
%
% Peter Malec, March 23, 2012
%
% -------------------------------------------------------------------------
%       
%% Prepare Data and Inputs

%price  is (n_rft x 2) matrix
price=[data_a1(:,2) data_a2(:,2)];
                                    
% standardize times (time_rft in [0,1])                                    
time_st= (data_a1(:,1)-startt*3600)/((endt-startt)*3600);         

% log-returns
lret=diff(log(price));

% number of obs and times
n=size(price,1)-1;      %adjust for returns
t=time_st(2:end);

% number of blocks and freqs
J =length(Phi_norm);

% extract noise (co-)variances
nu2_x=H(1,1);
nu2_y=H(2,2);
nu_xy=H(1,2);



% -------------------------------------------------------------------------
%       
%% Compute Local Likelihood Estimator

if J~=1
    
    %empty matrix of product of fisher info and cjk
    IC_jk_m=NaN*zeros(J,3);

    for j=1:J
        
      % spectral weights
     numer= sin(j*pi*t(:));        % (n x 1) matrix
     denom=sqrt(2)*n*sin(j*pi/(2*n));       
     Phi=numer./denom;                          % (n x 1) vector
     
     % local blockwise averages
    lret1_avb=lret(:,1)'*Phi;     
    lret2_avb=lret(:,2)'*Phi;
    

    % vector of dist. elements of outer poduct matrices of local ret avgs 
    S_jk=[(lret1_avb^2); (lret1_avb*lret2_avb); (lret2_avb^2)];          %(3x1)
 
    %vector of noise (co-)variances divided by sample size
    nu2_v=[nu2_x; nu_xy ;nu2_y]/n;                                                %(3x1)
    
    % vector spot vola estimates using only given freq
    C_jk=(S_jk-nu2_v)/Phi_norm(j);     %(3x1)
    
     % Fisher Info Matrix
    I_jk=ivech(I_jk_m(j,:));
    
    % product of fisher info and cjk
    IC_jk_m(j,:)=(I_jk*C_jk)';
 
    end 
    
    %sum of fisher infos
    I_k=ivech(sum(I_jk_m));
 
    %LLE
    Sigma_v=I_k\(sum(IC_jk_m))';
   
 % create output matrix
 %----------------------------------------------------------
 Sigma_out=[Sigma_v(1) Sigma_v(2);Sigma_v(2) Sigma_v(3)];

%-----------------------------------------------------
%-----------------------------------------------------

else  % if J=1
    
 % spectral weights
j=1:J;
numer= sin(pi*t(:)/(h)*j');        % (n x J) matrix
denom=sqrt(2)*n*sin(j*pi/(2*n));        % (J x 1) vector
Phi=numer./repmat(denom',n,1);                          % (n x J) matrix   

 % local blockwise averages
    lret1_avb=nansum(repmat(lret(:,1),1,J).*Phi);     % (1 x J) matrix
    lret2_avb=nansum(repmat(lret(:,2),1,J).*Phi);
    
% transpose matrices of local blockwise averages
lret1_avb=lret1_avb';
lret2_avb=lret2_avb';
    
% matrices of inverses of empirical norms of spectral weights 
i_Phi_norm=Phi_norm.^(-1);                  % (J x 1) matrix

%empty output matrix
Sigma_out=NaN*zeros(2,2);

% Var of asset 1
Sigma_out(1,1)=(sum(lret1_avb.^(2).*i_Phi_norm,1)-nu2_x/n*sum(i_Phi_norm,1));          

%Covar of asset 1,2
Sigma_out(1,2)=(sum(lret1_avb.*lret2_avb.*i_Phi_norm,1)-nu_xy/n*sum(i_Phi_norm,1));  
Sigma_out(2,1)=Sigma_out(1,2);

% Var of asset 2
Sigma_out(2,2)=(sum(lret2_avb.^(2).*i_Phi_norm,1)-nu2_y/n*sum(i_Phi_norm,1));          
    
end










