function [fourthMom] = Est_fourthMom_Noise(dx,r,rp,q,AC_diff_r,AC_diff_rm1,AC_diff_rp,AC_diff_rpm1)
%% Est_fourthMom_Noise
%------------------------------------------------------------
% Estimates fourth moment of microstructure noise:
% cov(\delta\eps_i \delta\eps_{i+r}, \delta\eps_{i+q} \delta\eps_{i+q+rp})
%--------------------------------------------------------------
% INPUT:
% dx -> (nx1) vector containing 1st differences of realizeation of observed process
% r,rp, q -> lag orders
% AC_diff_r -> estimate of difference between rth and(r+1)th order autocovariance of
%                       noise process: \hat\eta_r-\hat\eta_{r+1}
%--------------------------------------------------------------
% OUTPUT:
% fourthMom -> estimate of fourth moment
% -------------------------------------------------------------------------
%
% Peter Malec, March 4, 2014
%
%Note: 2 corrections wrt Markus' original approach:
%       * normalize sum by n
%       * subtract product of gamma_r and gamma_rp
% -------------------------------------------------------------------------
%       
%% Estimate Fourth Moment

% adjust
dx=dx(:);

%maxlag
maxl=max([r (rp+q)]);

% construct leads and adjusted series
dxst=dx(1:(end-maxl));
dxlr=dx((1+r):(end-maxl+r));
dxlq=dx((1+q):(end-maxl+q));
dxlqrp=dx((1+q+rp):(end-maxl+q+rp));

% adjust differences of rth and(r+1)th order AC of noise
if isequal(r,0)
    AC_diff_rm1=(-1)*AC_diff_r;
end
if isequal(rp,0)
    AC_diff_rpm1=(-1)*AC_diff_rp;
end

% compute gammas
gamma_r=AC_diff_r-AC_diff_rm1;
gamma_rp=AC_diff_rp-AC_diff_rpm1;


% Estimate Fourth Moment
fourthMom=sum(dxst.*dxlr.*dxlq.*dxlqrp)/(length(dx)-maxl)-gamma_r*gamma_rp;





