function [fourthMom] = Est_fourthMom_Noise(dx,r,rp,q,AC_diff_r,AC_diff_q)
%% Est_fourthMom_Noise
%------------------------------------------------------------
% Estimates fourth moment of microstructure noise:
% cov(\delta\eps_i \delta\eps_{i+r}, \delta\eps_{i+q} \delta\eps_{i+q+rp})
%--------------------------------------------------------------
% INPUT:
% dx -> (nx1) vector containing 1st differences of realizeation of observed process
% r,rp, q -> lag orders
% AC_diff_r -> estimate of difference between rth and(r+1)th order autocovariance of
%                       noise process: \hat\eta_r-\hat\eta_{r+1}
%--------------------------------------------------------------
% OUTPUT:
% fourthMom -> estimate of fourth moment
% -------------------------------------------------------------------------
%
% Peter Malec, March 3, 2014
%
% -------------------------------------------------------------------------
%       
%% Estimate Fourth Moment

% adjust
dx=dx(:);

%maxlag
maxl=max([r (rp+q)]);

% construct leads and adjusted series
dxst=dx(1:(end-maxl));
dxlr=dx((1+r):(end-maxl+r));
dxlq=dx((1+q):(end-maxl+q));
dxlqrp=dx((1+q+rp):(end-maxl+q+rp));

% Estimate Fourth Moment
fourthMom=sum(dxst.*dxlr.*dxlq.*dxlqrp)-4*AC_diff_r^2-4*AC_diff_q^2;





