function [eta_est]=LR_noise_var_est(price,R)
%% LR_noise_var_est
%--------------------------------------------------------------
% Estimates LR variance of microstructure noise under the
% assumption of R dependence
% eta= eta_0 + 2 \sum_{i=1}^R eta_i
%--------------------------------------------------------------
% INPUT:
% price -> ((n+1) x 1) vector of price data
% R      -> assumed order of dependence
%--------------------------------------------------------------
% OUTPUT:
% eta_est -> LR variance estimate
% -------------------------------------------------------------------------
%
% Peter Malec, March 5, 2014
% -------------------------------------------------------------------------
%       
%% Estimate LR variance

% log returns
dx=diff(log(price(:)));

%initialize vecror of differences between rth and (r+1)th AC
AC_diff_vec=NaN*zeros(R+1,1);

% difference between 0th and 1st order autocovariance
AC_diff_vec(1)=ACov(dx,0)/2; 

% loop over lag order and compute AC differences
%---------------------------------------------------------------
for i=1:R
   AC_diff_vec(i+1)=AC_diff_vec(i)+ACov(dx,i);
end

% vector of estimates of noise autocovariances
eta_est_vec=flipud(cumsum(flipud(AC_diff_vec)));  %((R+1)x1) vector: lag order increasing

% LR variance estimate
eta_est=eta_est_vec(1)+2*sum(eta_est_vec(2:end));



