function Noise_EST_proc(ticker,tdate,typed,cl_ind,rev_ind,alpha,Q_max,inpath,sourced,outpath,skipv)
%% Noise_EST_proc
%--------------------------------------------------------------
% Estimate Long-Run Noise Variance and test for order of dependence
%--------------------------------------------------------------
% INPUT:
% ticker ->  ticker symbol (string)
% tdate   -> data in matlab format
% cl_ind    -> if ==1, data cleaned according to proc by BNHLS(2009) is used
% rev_ind    -> if ==1, only obs with price revisions are used
% alpha   -> significance level
% Q_max -> Q_max
% inpath     -> path for loading data
% sourced   -> data source
% outpath  -> path for saving
% skipv     -> vector of skip sampling frequency in seconds (1)
%                   and length of trading day in hours
%--------------------------------------------------------------
%
% Peter Malec,  March 6 2014 
%
% -------------------------------------------------------------------------
%   
%% Load Data

% input check
if (nargin<11)||isempty(skipv)||isequal(length(skipv),1)
    skips=[];
else
    if ~isequal(length(skipv),2)
        error('Skipv has to be 2-dim vector!')
    end
    skips=skipv(1);
    ltday=skipv(2);
    if abs(skips-floor(skips))>0
        error('Skips has to be an integer!')
    end
end

% clean?
if cl_ind==1
     cl_str='cl';            % cleaning string for output file
else
     cl_str='ncl';
end


% check for existence of files
%-----------------------------------------------------------------------------------
name=strcat(inpath,ticker,filesep,ticker,'_',datestr(tdate,'yyyymmdd'),'_',typed,'_',cl_str,'.mat');
index=isequal(exist(name,'file'),2);


if index
%---------------------------------------------------------
% Load
load(name);
if isequal(typed,'trades')
    midprice=trades;
end
if rev_ind==1
   midprice=keep_rev(midprice,2);
end
% -------------------------------------------------------------------------
%   
%% Estimate Noise Variance

if ~isempty(skips)

        % skip sampling frequency
        delta=min([max([floor(size(midprice(:,1),1)/((ltday)*3600)*skips) 2]) floor(size(midprice(:,1),1)/2)]);

        %noise var
        [eta_est,stat_val_vec,AC_diff_vec] = test_noise_AC_mod(log(midprice(:,2)),alpha,Q_max,delta);
        
else
    
         %noise var
        [eta_est,stat_val_vec,AC_diff_vec] = test_noise_AC(log(midprice(:,2)),alpha,Q_max);

end
% -------------------------------------------------------------------------
%   
%% Save Results

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

% output structures
add_res.stat_val_vec=stat_val_vec;
add_res.AC_diff_vec=AC_diff_vec;

% alpha_label
alpha_l=num2str(alpha);
alpha_l(alpha_l=='.')='';

%name
if ~isempty(skips)
    basename=strcat(outpath,ticker,filesep,'noise_est_',ticker,'_',sourced,'_',datestr(tdate,'yyyymmdd'),typed,cl_str,rev_str,'_alpha',alpha_l,'_Q',int2str(Q_max),'_ss',int2str(skips));
else
     basename=strcat(outpath,ticker,filesep,'noise_est_',ticker,'_',sourced,'_',datestr(tdate,'yyyymmdd'),typed,cl_str,rev_str,'_alpha',alpha_l,'_Q',int2str(Q_max));
end

%save output
save(strcat(basename,'.mat'),'eta_est')
save(strcat(basename,'_add_res.mat'),'add_res')
% -------------------------------------------------------------------------
% 
%% files do not exist: do nothing

else
    disp(['Data missing for the following ticker: ' ticker '. Skip day.'])
end



    
  
    