function [Phi_norm_k_m,lret1_avb,lret2_avb,qvtbx,qvtby]=Phi_norm_block(block_st,block_end,h,avgt1,avgt2,t1,t2,tl1,tl2,lret1,lret2,...
   J_val)
%% Phi_norm_block
%--------------------------------------------------------------
% computes empirical norms of spectral weights on block etc. 
%
% Note:      * norms of spectral weights corrected for discr sampling
%               (only in bias correction -> save comp time)
%               * spectral weights based on cont approximations
%               % only for cross-sectionally independent noise
%--------------------------------------------------------------
% INPUT:
% k-> block index
% block_st -> block start
% block_end -> block end
% h -> block length
% n_rft -> max number of obs of series 1 and 2
% avgt1 -> vector of centered obs times of returns (or times at end of return spells)
% t1-> vector of observation times at end of return spells
% tl1-> vector of lags of t1 (same length)
% lret1   -> vector of log-returns
% nkex -> if >0, exact number of obs on each block is used to determine
% cutoff
% J_val -> spectral cutoff
%--------------------------------------------------------------
% OUTPUT:
% Phi_norm_k_m -> (3xJ_val) matrix of empirical norms of Phis
% lret1_avb -> (J_valx1) vector of local spectral means of asset 1
% qvtbx -> quadratic variation of time on block 
% -------------------------------------------------------------------------
%
% Peter Malec, April 19, 2013 
%
% -------------------------------------------------------------------------
%       
%%  Compute number of obs etc on block
  
 % index of observations on each block (based on centers)
     t_ind1=logical(((avgt1 >= block_st) & (avgt1 <=block_end)));  
     t_ind2=logical(((avgt2 >= block_st) & (avgt2 <=block_end)));  
     
    % centered observations times on block (since beginning)
     avgtb1=avgt1(t_ind1)-block_st;
     avgtb2=avgt2(t_ind2)-block_st;
     
     % time and lagged times on block  (since beginning)
     tb1=t1(t_ind1)-block_st;
     tlb1=tl1(t_ind1)-block_st;
      tb2=t2(t_ind2)-block_st;
     tlb2=tl2(t_ind2)-block_st;
     
     % quadratic variation of time on block 
     qvtbx=nansum((tb1-tlb1).^2);
     qvtby=nansum((tb2-tlb2).^2);
     
     % log returns on block
     lret_b1=lret1(t_ind1,:);
     lret_b2=lret2(t_ind2,:);
% -------------------------------------------------------------------------
%        
%% Compute Local Blockwise Averages of Log-Returns and Emp Phi Norms
   

    %empty matrices for local blockwise averages
    lret1_avb=NaN*zeros(J_val,1);   % (J_valx1) vector
    lret2_avb=lret1_avb;
    
    %empty matrix of empirical norms of Phis 
    Phi_norm_k_m=NaN*zeros(3,J_val);   % (3xJ_val) matrix
    
    %length of overlap of return spells of x,y (else zero)
    mat_ind=return_overlap_faster(tb1,tlb1,tb2,tlb2);
    
   
% loop
  for j=1:J_val
            
            % spectral weights for given block and frequency
            Phi1=spectr_weights_j_onbl_cont(avgtb1,h,j);
            Phi2=spectr_weights_j_onbl_cont(avgtb2,h,j);
            
            % local blockwise averages using frequency j
            lret1_avb(j)=lret_b1'*Phi1; 
            lret2_avb(j)=lret_b2'*Phi2;
            
            % empirical norms of Phis 
            [Phi_norm_jk_x,Phi_norm_jk_y,Phi_norm_jk_xy]=Phi_norm_emp_block_faster(Phi1,Phi2,tb1,tlb1,tb2,tlb2,mat_ind);
            Phi_norm_k_m(:,j)=[Phi_norm_jk_x;Phi_norm_jk_xy;Phi_norm_jk_y];
            
  end
        
       
    
    
    