function [Phi_norm_xk,Phi_norm_yk,Phi_norm_xyk]=Phi_norm_emp_block(Phi_xk,Phi_yk,t_xk,tl_xk,t_yk,tl_yk,mat_ind)
%% Phi_norm_emp
%--------------------------------------------------------------------------------
% empirical norms on block k of (continuously approximated) spectral weights
% corrected for discrete sampling
%-------------------------------------------------------------------------------
% INPUTS:
% Phi_xk -> (n_k_x x 1) vector of values of spectral weights for
% observations of x on block
% t_xk    -> (n_k_x x 1) vector of observations times of x on block
% tl_xk    -> (n_k_x x 1) vector of lagged observations times of x on block
%mat_ind -> matrix of lengths of overlap of return spells of x,y (else 0)
%--------------------------------------------------------------
% OUTPUT:
% Phinorm_xk -> empirical norm of spectral weights on block k based on
%                       squared observation times of x series
%Phi_norm_yk -> empirical norm of spectral weights on block k based on
%                       squared observation times of y series
% Phi_norm_yk -> empirical norm of spectral weights on block k based on
%                       product of observation times of x and y series
% -------------------------------------------------------------------------
%
% Peter Malec, August 18, 2012 
%
% -------------------------------------------------------------------------
%       
%% Norms based on univariate cases

%x
Phi_norm_xk=(Phi_xk.^2)'*(t_xk-tl_xk);
%y
Phi_norm_yk=(Phi_yk.^2)'*(t_yk-tl_yk);
% -------------------------------------------------------------------------
%  
%% Norm based on multivariate case


% check for computational intensity
if ~isempty(mat_ind)
    
    % vector of increments
    Phi_x1_incr=mat_ind*Phi_yk;       %(n_k_x x 1) vector  

    % norm based on cross product
    Phi_norm_xyk=Phi_xk'*Phi_x1_incr;
    
else
    
   % approximation by univariate case
    if length(t_xk)>=length(t_yk)
        Phi_norm_xyk=Phi_norm_xk;
    else
        Phi_norm_xyk=Phi_norm_yk;
    end
    
end





