function [Phi_norm_xk,Phi_norm_yk,Phi_norm_xyk]=Phi_norm_emp_block_faster(Phi_xk,Phi_yk,t_xk,tl_xk,t_yk,tl_yk,inter_mat)
%% Phi_norm_emp_faster
%--------------------------------------------------------------------------------
% empirical norms on block k of (continuously approximated) spectral weights
% corrected for discrete sampling
% Note: algorithm is faster in large dimensions and needs less memory 
% than the original proc
%-------------------------------------------------------------------------------
% INPUTS:
% Phi_xk -> (n_k_x x 1) vector of values of spectral weights for
% observations of x on block
% t_xk    -> (n_k_x x 1) vector of observations times of x on block
% tl_xk    -> (n_k_x x 1) vector of lagged observations times of x on block
% inter_mat -> (n_inters x 3) matrix : each row is a return intervall
% intersection. 1st col: obs index of x; 2nd col: obs index of y;
%   3rd col: interval length (optional)
%--------------------------------------------------------------
% OUTPUT:
% Phinorm_xk -> empirical norm of spectral weights on block k based on
%                       squared observation times of x series
%Phi_norm_yk -> empirical norm of spectral weights on block k based on
%                       squared observation times of y series
% Phi_norm_xyk -> empirical norm of spectral weights on block k based on
%                       product of observation times of x and y series
%                       
% -------------------------------------------------------------------------
%
% Peter Malec, August 18, 2012 
%
% modification on May 14, 2013: empirical norm based on product of
% observation times does not have to be computed
% -------------------------------------------------------------------------
%       
%% Norms based on univariate cases

%x
Phi_norm_xk=(Phi_xk.^2)'*(t_xk-tl_xk);
%y
Phi_norm_yk=(Phi_yk.^2)'*(t_yk-tl_yk);
% -------------------------------------------------------------------------
%  
%% Norm based on multivariate case

if nargin>6
    Phi_norm_xyk=sum(Phi_xk(inter_mat(:,1)).*Phi_yk(inter_mat(:,2)).*inter_mat(:,3));
else
    Phi_norm_xyk=NaN;
end






