function J_max=find_maxJ_const(W_k_a,cv)
%% find_maxJ_const
%--------------------------------------------------------------
% finds spectral cutoff by looking Weight matrix with frobenious 
% norm <= cv
%--------------------------------------------------------------
% INPUT:
% W_k_a -> (3x3xnh) array of Weight matrices
% cv -> critival value, default: 1e-6
%--------------------------------------------------------------
% OUTPUT:
% J_max -> spectral cutoff
% -------------------------------------------------------------------------
%
% Peter Malec, April 2, 2012
%
% -------------------------------------------------------------------------
%       
%% Check Inputs

% critical value
if nargin<2
    cv=1e-6;
end

% largest frequency possible
nh=size(W_k_a,3);
% -------------------------------------------------------------------------
%       
%% Find Spectral Cutoff

% starting value for Frobenius norm 
fnorm_W=1;

% starting cutoff
j=1;

% loop for further frequencies
%--------------------------------
while (fnorm_W >= cv) && (j<= nh) 

    fnorm_W=norm(W_k_a(:,:,j),'fro');

    j=j+1;

end

% Output
J_max=j-1;