function I_k_m=info_mat_block_adapt_md(J_val,h,lnoise_v,Sigma_p)
%% info_mat_block_adapt_md
%--------------------------------------------------------------
% computes information matrix on block k using pilot estimate
% in m-dimensional case
%
% Note:      
%               * spectral weights based on cont approximations
%               % only for cross-sectionally independent noise
%--------------------------------------------------------------
% INPUT:
% J_val -> cutoff value
% h -> block length
% lnoise_v -> (mx1) vector of local noise level estimates
% Sigma_p -> pilot estimate of (mxm) spot covariance matrix on block
%--------------------------------------------------------------
% OUTPUT:
% I_k_m  -> (m^2xm^2) matrix: sum of fisher info matrices across freqs on block
% -------------------------------------------------------------------------
%
% Peter Malec, January 8, 2014 
%
% -------------------------------------------------------------------------
%       
%% check if there were too few observations on blocks

if  (sum(isnan(lnoise_v))==0)%normal  
% -------------------------------------------------------------------------
%  
%% Preparation

% dimension
m=size(Sigma_p,1);

% frequencies up to spectral cutoff
 j=(1:J_val)';

% vector of (inverse) empirical norms  (continuous approximations)
i_Phi_norm=h^(-2)*(pi^2)*j(:).^2;
% -------------------------------------------------------------------------
%       
%% Compute Weights

% compute c_jk matrix
Sigma_p_v=vech(Sigma_p);
C_jk_m=Sigma_p_v(:,ones(J_val,1))+vech(diag(lnoise_v))*i_Phi_norm';%[m*(m+1)/2xJ_val] matrix

% empty array for info matrices
I_jk_a=NaN*zeros(m^2,m^2,J_val);

% Loop over frequencies and compute info matrices
%--------------------------------------------------------
for k=1:J_val
    
    %invert C_jk matrix
    i_C_jk=inv(ivech(C_jk_m(:,k)));
    
    %compute info matrix
    I_jk_a(:,:,k)=kronf(i_C_jk,i_C_jk);
    
end

% compute weights
%--------------------------------------------------------
% compute sum of fisher info matrices across freqs on block
I_k_m=nansum(I_jk_a,3);                    % (mxm) matrix
% -------------------------------------------------------------------------
%         
%% if too few observations
    
else
    
    % dimension
    m=size(Sigma_p,1);
    
    % empty output
     I_k_m=NaN*zeros(m^2,m^2);
 end   


     
   