function [W_k_a,J_opt_k]=lle_cov_weight_array_discr(J_max,cv,nrft,i_Phi_norm,i_Phi_norm_2,nu2_x,sigma2_x,nu2_y,sigma2_y,sigma_xy,J_all)
%% lle_cov_weight_array_discr
%--------------------------------------------------------------
% computes array of weights (based on Fisher Infos) on block k for LLE
%
% Note:      * spectral weights based discrete values
%               % only for cross-sectionally independent noise
%--------------------------------------------------------------
% INPUT:
% J_opts -> max value of spectral cutoff
% cv-> critical value for choice of spectral cutoff (frobenius norm of
% "last" weight matrix <=cv). 
% i_Phi_norm -> (J_opt_kx1) vector of (inverse) empirical
% norms  of spectral weights
% nu2_x -> noise variance
% nrft -> number of obs
% sigma2_x -> cosntant spot variance on block k
% sigma2_xy -> cosntant spot covariance on block k
% J_all -> if>0: all frequencies j are used 
%--------------------------------------------------------------
% OUTPUT:
% W_k_a -> (3x3xJ_opt_k) array of weight matrices for block k
% J_opt_k -> optimal spectral cutoff
% 
% -------------------------------------------------------------------------
%
% Peter Malec, August 9, 2012 
%
% -------------------------------------------------------------------------
%       
%% Compute elements of inverse fisher information and put into structure

   
    % weights
     i_I_jk_11=2*(i_Phi_norm.*nu2_x/nrft+sigma2_x).^2;     % (J x 1) matrix

    i_I_jk_22=i_Phi_norm_2.*nu2_x*nu2_y/(nrft^2)+(sigma2_x.*sigma2_y+(sigma_xy).^2)+...
    (i_Phi_norm/nrft).*(sigma2_x*nu2_y+sigma2_y*nu2_x);   % (J x 1) matrix

    i_I_jk_33=2*(i_Phi_norm.*nu2_y/nrft+sigma2_y).^2;     % (J x 1) matrix

    i_I_jk_12=2*sigma2_x.*sigma_xy+...
    2*i_Phi_norm.*sigma_xy*nu2_x/nrft;   % (J x 1) matrix

    i_I_jk_23=2*sigma2_y.*sigma_xy+...
    2*i_Phi_norm.*sigma_xy*nu2_y/nrft;   % (J x 1) matrix

    i_I_jk_13=2*(sigma_xy).^(2)*ones(J_max,1); % (J x 1) matrix

%% Compute elements of inverse fisher information and weights
   
   % matrix of distinct elements of inverse Fisher infos for all freqs
    i_I_jk_m=[i_I_jk_11';i_I_jk_12';i_I_jk_13';i_I_jk_22'...
        ;i_I_jk_23';i_I_jk_33'];      % (6 x J) matrix
    
    % create array of (symmetric) inverse fisher info matrices for all freqs
     i_I_jk_a=ivech3(i_I_jk_m);             % (3x3xJ) array
     
     % compute array of fisher info matrices by inversion
     I_jk_a=inv3(i_I_jk_a);
     
     % compute sum of fisher info matrices across freqs on block
     I_k_m=nansum(I_jk_a,3);                    % (3x3) matrix
   
     % compute array of weights
     W_k_a=inv3(I_k_m,I_jk_a);
     
    % find cutoff
    if J_all<=0
        J_opt_k=find_maxJ_const(W_k_a,cv);
    else
       J_opt_k=J_max;
    end
   
   % adjust weights 
   %--------------------------------
   if J_opt_k<J_max
     I_jk_a=I_jk_a(:,:,1:J_opt_k);
     I_k_m=nansum(I_jk_a,3);                    % (3x3) matrix
     W_k_a=inv3(I_k_m,I_jk_a);
   end