function [W_k_a,i_Phi_norm,I_k_m]=lle_cov_weight_array_md(J_val,h,lnoise_v,Sigma_p)
%% lle_cov_weight_md
%--------------------------------------------------------------
% computes array of weights (based on Fisher Infos) on block k for LLE
% in m-dimensional case
%
% Note:      * cutoff value fixed
%               * spectral weights based on cont approximations
%               % only for cross-sectionally independent noise
%--------------------------------------------------------------
% INPUT:
% J_val -> cutoff value
% h -> block length
% lnoise_v -> (mx1) vector of local noise level estimates
% Sigma_p -> pilot estimate of (mxm) spot covariance matrix on block
%--------------------------------------------------------------
% OUTPUT:
% W_k_a -> (m^2xm^2xJ_val) array of weight matrices for block k
% i_Phi_norm -> (J_opt_kx1) vector of (inverse) empirical
%                   norms  (continuous approximations) of spectral weights
%                   NOTE: norms are squared
% I_k_m  -> (m^2xm^2) matrix: sum of fisher info matrices across freqs on block
% -------------------------------------------------------------------------
%
% Peter Malec, January 7, 2013 
%
% -------------------------------------------------------------------------
%       
%% Preparation

% dimension
m=size(Sigma_p,1);

% frequencies up to spectral cutoff
 j=(1:J_val)';

% vector of (inverse) empirical norms  (continuous approximations)
i_Phi_norm=h^(-2)*(pi^2)*j(:).^2;
% -------------------------------------------------------------------------
%       
%% Compute Weights

% compute c_jk matrix
Sigma_p_v=vech(Sigma_p);
C_jk_m=Sigma_p_v(:,ones(J_val,1))+vech(diag(lnoise_v))*i_Phi_norm';%[m*(m+1)/2xJ_val] matrix

% empty array for info matrices
I_jk_a=NaN*zeros(m^2,m^2,J_val);

% Loop over frequencies and compute info matrices
%--------------------------------------------------------
for k=1:J_val
    
    %invert C_jk matrix
    i_C_jk=inv(ivech(C_jk_m(:,k)));
    
    %compute info matrix
    I_jk_a(:,:,k)=kronf(i_C_jk,i_C_jk);
    
end

% compute weights
%--------------------------------------------------------
% compute sum of fisher info matrices across freqs on block
I_k_m=nansum(I_jk_a,3);                    % (mxm) matrix

% compute array of weights
W_k_a=mtimesx(inv(I_k_m),I_jk_a,'MATLAB');                     


     
   