function theta_vec_out=lle_theta_choice(theta_vec_st,price_a,time_a,noisev,startt,endt,J_p,K_p_thr,...
    twost,ccorr,IV_bench_v,options)
%------------------------------------------------------------------
%% lle_theta_choice
% chooses proportionality parameters
% theta in LMM estimator by minimizing distance between
% univariate integrated LMM estimator and suitable benchmark
%------------------------------------------------------------------
%
% INPUTS
% theta_vec_st  -> vector of starting values of proportionality parameters: theta_h,theta_J,theta_K
% price_a      -> (n_dx1) array of (nx1) vectors of intraday prices
% time_a      -> (n_dx1) array of (nx1) vectors of obs times
% noisev         ->(n_dx1) vector of noise estimates
% startt -> start of trading (in hours)
% endt   -> end of trading (in hours)
% J_p-> spectral cutoff for pilot estimates of spot covariances
% K_p_thr    -> lower threshold for pilot smoothing bandwidth
% twst     -> if >0: twostep estimation is used (estimates from first step
%                   used as pilots for second step
% ccorr -> if >0, correlation and variance estimates are corrected
% IV_bench_v > (n_dx1) vector of IV estimates using benchmark estimator
% options     -> options for fmincon
%------------------------------------------------------------------
% OUTPUTS
% theta_vec_out ->    vector of optimal proportionality parameters: theta_h,theta_J,theta_K
%------------------------------------------------------------------
%
%   Peter Malec, March 26, 2014
%
%------------------------------------------------------------------
%
%% Preparations

% check data
if ~isequal(length(price_a),length(time_a))
    error('Price/time data have to be of the same dimension!!!')
end
if ~isequal(length(price_a),length(noisev))||~isequal(length(price_a),length(IV_bench_v))||...
        ~isequal(length(IV_bench_v),length(noisev))
    error('Price/time data and noise or benchmark estimates have to be of the same dimension!!!')
end
%------------------------------------------------------------------
%
%% Optimal Proportionality parameters by minimization of obj function

% Set Bounds on theta parameters
LB=(1e-6)*ones(3,1);           %lower bound of is zero(+eps)
UB=(1/eps)*ones(3,1);        %no upper bound

% optim
[theta_vec,~,exitflag,~]=fmincon('lle_theta_choice_obj',theta_vec_st,[],[],[],[],LB,UB,[],options,...
    price_a,time_a,noisev,startt,endt,J_p,K_p_thr,twost,ccorr,IV_bench_v);

% output check
if ~any(exitflag==[-1 -2 -3])      % "normal convergence"
        theta_vec_out=theta_vec;
else
        theta_vec_out=theta_vec_st;
        disp('Optimization proc did not converge! Use starting values.');
end