function theta_vec_out=lle_theta_choice_func(theta_vec_st,ticker,tdate_v,startt,endt,J_p,K_p_thr,twost,ccorr,options,typed,...
    cl_ind,rev_ind,freq,nss,inpath,inpath_noise,inpath_rvss)
%------------------------------------------------------------------
%% lle_theta_choice
% chooses proportionality parameters
% theta in LMM estimator by minimizing distance between
% univariate integrated LMM estimator and subsampled rv
%------------------------------------------------------------------
%
% INPUTS
% theta_vec_st  -> vector of starting values of proportionality parameters: theta_h,theta_J,theta_K
% ticker > ticker symbol: string
% tdate_v -> vector of trading days matlab date format
% startt -> start of trading (in hours)
% endt   -> end of trading (in hours)
% J_p-> spectral cutoff for pilot estimates of spot covariances
% K_p_thr    -> lower threshold for pilot smoothing bandwidth
% twst     -> if >0: twostep estimation is used (estimates from first step
%                   used as pilots for second step
% ccorr -> if >0, correlation and variance estimates are corrected
% IV_bench_v _> (n_dx1) vector of IV estimates using benchmark estimator
% options     -> options for fmincon
% cl_ind    -> if ==1, data cleaned according to proc by BNHLS(2009) is used
% rev_ind    -> if ==1, only obs with price revisions are used
% freq    -> sampling frequency in seconds (for rv)
% nss    -> no of subsamples (empty if no subsampling)
%------------------------------------------------------------------
% OUTPUTS
% theta_vec_out ->    vector of optimal proportionality parameters: theta_h,theta_J,theta_K
%------------------------------------------------------------------
%
%   Peter Malec, March 26, 2014
%
%------------------------------------------------------------------
%
%% Obtain price and time data

% clean?
if cl_ind==1
     cl_str='cl';            % cleaning string for output file
else
     cl_str='ncl';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

%initialize
price_a=cell(length(tdate_v),1);
time_a=cell(length(tdate_v),1);
indv=NaN*zeros(length(tdate_v),1);

%loop across days and collect data
%---------------------------------------------------------------
parfor i=1:length(tdate_v)

    % check for existence of file
    name=strcat(inpath,ticker,'\\',ticker,'_',datestr(tdate_v(i),'yyyymmdd'),'_',typed,'_',cl_str,'.mat');
    index=isequal(exist(name,'file'),2);

    if index
    %---------------------------------------------------------
    if ~isequal(typed,'trades')
        indat=iload(name,'midprice');
        midprice=indat.midprice;
    else
        indat=iload(name,'trades');
        midprice=indat.trades;
    end
    if rev_ind==1
        midprice=keep_rev(midprice,2);
    end
    
    %assign
    price_a{i}=midprice(:,2);
    time_a{i}=midprice(:,1);
    indv(i)=1;
    
    end
    
end
%------------------------------------------------------------------
%
%% Obtain noise estimates

% check for existence of file
name2=strcat(inpath_noise,ticker,'\\noise_est_',ticker,'_',sourced,...
    '_',datestr(tdate_v(1),'yyyymmdd'),'_',datestr(tdate_v(end),'yyyymmdd'),typed,cl_str,rev_str,'.mat');
index2=isequal(exist(name2,'file'),2);

if ~index2
%---------------------------------------------------------

%initialize
noisev=NaN*zeros(length(tdate_v),1);

%loop across days and collect data
%---------------------------------------------------------------
parfor i=1:length(tdate_v)
    
    % check for existence of file
    name3=strcat(inpath_noise,ticker,'\\noise_est_',ticker,'_',sourced,'_',datestr(tdate_v(i),'yyyymmdd'),typed,cl_str,rev_str,'.mat');
    index3=isequal(exist(name3,'file'),2);
    
    if index3
    %---------------------------------------------------------
    indat=iload(name3,'eta_est');
    noisev(i)=indat.eta_est;
    end
    
end

%save
save(name2,'noisev')

else
    
    % load "old" results
    load(name2);

end
%------------------------------------------------------------------
%
%% Obtain subsampled rv estimates

% check for existence of file
if ~isempty(nss)
    name4=strcat(inpath_rvss,'rv_',sourced,'_',ticker,'_',datestr(tdate_v(1),'yyyymmdd'),'_',datestr(tdate_v(end),'yyyymmdd'),typed,'_',cl_str,rev_str,...
                '_freq',int2str(freq),'_nss',int2str(nss),'.mat');
else
    name4=strcat(inpath_rvss,'rv_',sourced,'_',ticker,'_',datestr(tdate_v(1),'yyyymmdd'),'_',datestr(tdate_v(end),'yyyymmdd'),typed,'_',cl_str,rev_str,...
                '_freq',int2str(freq),'.mat');
end
index4=isequal(exist(name4,'file'),2);

if ~index4
%---------------------------------------------------------

%initialize
rvSSv=NaN*zeros(length(tdate_v),1);

%loop across days and collect data
%---------------------------------------------------------------
parfor i=1:length(tdate_v)
    
    % check for existence of file
    if ~isempty(nss)
        name5=strcat(inpath_rvss,'rv_',sourced,'_',ticker,'_',datestr(tdate_v(i),'yyyymmdd'),typed,'_',cl_str,rev_str,...
                '_freq',int2str(freq),'_nss',int2str(nss),'.mat');
    else
        name5=strcat(inpath_rvss,'rv_',sourced,'_',ticker,'_',datestr(tdate_v(i),'yyyymmdd'),typed,'_',cl_str,rev_str,...
                '_freq',int2str(freq),'.mat');
    end
    index5=isequal(exist(name5,'file'),2);
    
    if index5
    %---------------------------------------------------------
    indat=iload(name5,'rvest');
    rvSSv(i)=indat.rvest.rvSS;
    end
    
end

%save
save(name4,'rvSSv')

else
    
    % load "old" results
    load(name4);

end
%------------------------------------------------------------------
%
%% Optimization

% remove obs corresponding to NaNs
indv_joint=sum(~isnan([indv noisev rvSSv]),2)==3;
noisev=noisev(indv_joint);
rvSSv=rvSSv(indv_joint);
price_a=price_a(indv_joint);
time_a=time_a(indv_joint);

% obtain values of proprtionality parameters by optim
theta_vec_out=lle_theta_choice(theta_vec_st,price_a,time_a,noisev,startt,endt,J_p,K_p_thr,...
    twost,ccorr,rvSSv,options);


