function func_val=lle_theta_choice_obj_alt(theta_vec,price_a,time_a,noisev,startt,endt,J_p,K_p_thr,twost,ccorr,IV_bench_v,...
    theta_J,theta_K)
%------------------------------------------------------------------
%% lle_theta_choice_obj
% objective function for choosing proportionality parameters
% theta in LMM estimator
% Note: Based on univariate integrated estimator
%------------------------------------------------------------------
%
% INPUTS
% theta_vec  -> vector of proportionality parameters: theta_h,theta_J,theta_K
% price_a      -> (n_dx1) array of (nx1) vectors of intraday prices
% time_a      -> (n_dx1) array of (nx1) vectors of obs times
% noisev         ->(n_dx1) vector of noise estimates
% startt -> start of trading (in hours)
% endt   -> end of trading (in hours)
% J_p-> spectral cutoff for pilot estimates of spot covariances
% K_p_thr    -> lower threshold for pilot smoothing bandwidth
% twst     -> if >0: twostep estimation is used (estimates from first step
%                   used as pilots for second step
% ccorr -> if >0, correlation and variance estimates are corrected
% IV_bench_v _> (n_dx1) vector of IV estimates using benchmark estimator
%------------------------------------------------------------------
% OUTPUTS
% value of objection function ->    squared norm of difference between LMM
%                                                 and benchmark
%------------------------------------------------------------------
%
%   Peter Malec, March 26, 2014
%
%------------------------------------------------------------------
%
%% Preparations

% check data
if ~isequal(length(price_a),length(time_a))
    error('Price/time data have to be of the same dimension!!!')
end
if ~isequal(length(price_a),length(noisev))||~isequal(length(price_a),length(IV_bench_v))||...
        ~isequal(length(IV_bench_v),length(noisev))
    error('Price/time data and noise or benchmark estimates have to be of the same dimension!!!')
end

% get single parameters
theta_h=theta_vec(1);
%------------------------------------------------------------------
%
%% Compute LMM

% initialize
IV_LMM=NaN*zeros(length(price_a),1);

% loop across days
parfor i=1:length(price_a)
    
    % compute estimator
    [IV,~,~,~,~,~]=lle_icov_md({[time_a{i} price_a{i}]},noisev(i),startt,endt,...
  1,1,[],[],J_p,[],theta_h,theta_J,theta_K,K_p_thr,twost,0,ccorr);

    % assign
    IV_LMM(i)=IV;
end
%------------------------------------------------------------------
%
%% Compute Loss Function

func_val=mean((IV_bench_v-IV_LMM).^2)*252^2;



        
    