function inter_mat=return_overlap_faster(t_xk,tl_xk,t_yk,tl_yk)
%% return_overlap_faster
%--------------------------------------------------------------------------------
% computes length of overlap of return spells of x,y
% Note: algorithm is faster in large dimensions and needs less memory 
% than the original proc
%-------------------------------------------------------------------------------
% INPUTS:
% t_xk    -> (n_k_x x 1) vector of observations times of x on block
% tl_xk    -> (n_k_x x 1) vector of lagged observations times of x on block
%--------------------------------------------------------------
% OUTPUT:
% inter_mat -> (n_inters x 3) matrix : each row is a return intervall
% intersection. 1st col: obs index of x; 2nd col: obs index of y;
%   3rd col: interval length
% -------------------------------------------------------------------------
%
% Peter Malec, August 20, 2012 
%
% -------------------------------------------------------------------------
%       
%% compute overlaps

% number of observations of x
n_k_x=length(t_xk);

% vector containing obs indices of y
n_k_y_ind=(1:length(t_yk))';

% empty  matrix of intersections
inter_mat=NaN*zeros(1,3);

% loop over observation times of x
%--------------------------------------------
for i=1:n_k_x
   
    % length of overlap of return spells of x,y 
    vec_ind=min(t_xk(i),t_yk)-max(tl_xk(i),tl_yk);
    
    %indices of y where vec_ind is positive
    ind_n_k_y_pos=n_k_y_ind(vec_ind>0);
    
    % store obs indices and interval lengths in inters matrix
    inter_mat=[inter_mat; (i*ones(length(ind_n_k_y_pos),1)) ind_n_k_y_pos ...
        vec_ind(ind_n_k_y_pos)];
    
end

%drop first element
inter_mat=inter_mat(2:end,:);


