function [SCov_mat_sm_sel,CovSCov_mat_sm_sel]=select_block_vola_md(input_v,block_st,block_end,SCov_mat_sm,CovSCov_mat_sm)
%------------------------------------------------------------------
%% select_block_vola_md
% Selects spot vola estimates and their covariances for estimation points
% in m-dimensional case
%------------------------------------------------------------------
%
% INPUTS
% input_v -> (n_inx1) vector of estimation points
% block_st -> (Bx1) vector of block starts
% SCov_mat_sm -> (Bxm(m+1)/2) matrix of smoothed spot cov matrices on blocks
% CovSCov_mat_sm -> (m^2(m^2+1)/2xB) matrix of estimated covariance matrices of above
%                                   estimates
%------------------------------------------------------------------
% OUTPUTS
% SCov_mat_sm_sel-> (n_inxm(m+1)/2) matrix of spot cov matrices for each point of
%                               estimation
% CovSCov_mat_sm_sel -> (m^2(m^2+1)/2xn_in) matrix of estimated covariance matrices of above
%                                   estimates
%------------------------------------------------------------------
%
%   Peter Malec, January 8, 2014
%
%------------------------------------------------------------------
%
%% Preparations

% make column vectors
input_v=input_v(:);
block_st=block_st(:);
block_end=block_end(:);

% no of inputs
nin=length(input_v);

% number of unique cov mat elements
elu=size(SCov_mat_sm,2);

% check if some input=1
one_ind=find(input_v==1);

% set of "normal" inputs
normin=setdiff(1:nin,one_ind);
%------------------------------------------------------------------
%
%% Select estimates and their covariance matrices

% empty output matrix
SCov_mat_sm_sel=NaN*zeros(nin,elu);

% selection
%%%%%%%%%%%%%%%%%%%%%%%
if nargin>4 % including covariances
    
    % no of distinct elements in cov matrix
     elcov=size(CovSCov_mat_sm,1);
    
    % empty output matrix
     CovSCov_mat_sm_sel=NaN*zeros(elcov,nin);
     
     % loop over "normal" estimation points
     for i=normin
         b_ind=((input_v(i)-block_st>1e-15)|(abs(input_v(i)-block_st)<1e-15))&(block_end-input_v(i)>1e-15);% block indicator
         SCov_mat_sm_sel(i,:)=SCov_mat_sm(b_ind,:); % select spot covariance est
         CovSCov_mat_sm_sel(:,i)=CovSCov_mat_sm(:,b_ind); % select covariances of spot covariance est
     end
     
     %input =1 ->always last block
     if ~isempty(one_ind)
         SCov_mat_sm_sel(one_ind,:)=SCov_mat_sm(end,:); % select spot covariance est
         CovSCov_mat_sm_sel(:,one_ind)=CovSCov_mat_sm(:,end); % select covariances of spot covariance est
     end
    
    else     % w/o covariances
    
    % empty scalar
     CovSCov_mat_sm_sel=NaN;
     
     % loop over "normal" estimation points
     for i=normin
        b_ind=((input_v(i)-block_st>1e-15)|(abs(input_v(i)-block_st)<1e-15))&(block_end-input_v(i)>1e-15);% block indicator
         SCov_mat_sm_sel(i,:)=SCov_mat_sm(b_ind,:); % select spot covariance est
     end
     
     %input =1 ->always last block
     if ~isempty(one_ind)
         SCov_mat_sm_sel(one_ind,:)=SCov_mat_sm(end,:); % select spot covariance est
     end
    
end






