function Phi=spectr_weights_j(t,block_st,block_end,h,j)
%------------------------------------------------------------------
%% spectr_weight
% Computes spectral weights for given block for local blockwise averages of returns
% following Bibinger & Reiss (2001)
%------------------------------------------------------------------
%
% INPUTS
% t -> (n x 1) vector of observation times (as fraction of daily trading
% period, i.e. t in [0,1]
% block_st -> lower bound of block: k*h with k=0,...,h^{-1}-1 
% block_end -> upper bound of block: (k+1)*h with k=0,...,h^{-1}-1
% h -> length of block
% j ->  frequency 
%------------------------------------------------------------------
% OUTPUTS
% Phi -> (n x 1) vector of spectral weights
%------------------------------------------------------------------
%
%Peter Malec, April 3, 2012
%
%% Preparations

% # obs
n=length(t);


%------------------------------------------------------------------
%
%% Compute spectral weights

% weights
%--------------------------------------------------------------------------------------
Phi= sin(pi*(t-block_st)/(h)*j)/(sqrt(2*h)*n*sin(j*pi/(2*n*h)));        % (n x 1) vector
    
% set weights to 0 for t outside given block
Phi=Phi.*((t >= block_st) & (t <block_end));   % (n x 1) vector


                       
                        
    
    
   


                        
