function Phi=spectr_weights_kf(t,block_st,block_end,h,J)
%------------------------------------------------------------------
%% spectr_weight
% Computes spectral weights for given block for local blockwise averages of returns
% following Bibinger & Reiss (2001)
%------------------------------------------------------------------
%
% INPUTS
% t -> (n x 1) vector of observation times (as fraction of daily trading
% period, i.e. t in [0,1]
% block_st -> lower bound of block: k*h with k=0,...,h^{-1}-1 
% block_end -> upper bound of block: (k+1)*h with k=0,...,h^{-1}-1
% h -> length of block
% J ->  spectral cutoff: maximum frequency per block
%------------------------------------------------------------------
% OUTPUTS
% Phi -> (n x J) matrix of spectral weights
%------------------------------------------------------------------
%
%Peter Malec, January 15, 2012
%
%% Preparations

% # obs
n=length(t);

% frequencies up to spectral cutoff
j=(1:J)';
%------------------------------------------------------------------
%
%% Compute spectral weights

% Numerator
%--------------------------------------------------------------------------------------
numer= sin(pi*(t-block_st)/(h)*j');        % (n x J) matrix
    
% set numerator to 0 for t outside given block
time_ind=((t >= block_st) & (t <block_end));
Phi_numer=numer.*time_ind(:,ones(J,1)); % (n x J) matrix

% denominator
j=j';
denom=sqrt(2*h)*n*sin(j*pi/(2*n*h));        % (1xJ) vector

% spectral weights
Phi=Phi_numer./denom(ones(n,1),:);   % (n x J) matrix
                        % divide each row of Phi_numer by transp. of denom vector
                        
    
    
   


                        
