function [Sigma_k,I_k_m]=spot_cov_block_adapt_rweights_md(h,lret_avb_m,Sigma_p,lnoise_v,J_val,ccorr)
%% spot_cov_block_adapt_rweights_md
%--------------------------------------------------------------
% computes spot covolatility estimate on block k using pilot estimate
% based on re-evaluated weights in m-dimensional case
%
% Note:     
%               * blocks of equal size and inputs fixed
%                * norms of spectral weights uncorrected (based on continuous approximations)
%               * spectral weights based on cont approximations
%               % only for cross-sectionally independent noise
%               % computation has to be the same as in 
%                   "spot_cov_block_adapt_corrd"
%--------------------------------------------------------------
% INPUT:
% h -> block length
% Sigma_p -> pilot estimate of (mxm) spot covariance matrix on block
% lret_avb_m-> (J_pilotxm) matrix of local spectral means of assets
% lnoise_v -> (mx1) vector of local noise level estimates
% J_val -> input value for cutoff 
% ccorr -> if >0, correlation and variance estimates are corrected
%--------------------------------------------------------------
% OUTPUT:
% Sigma_k -> (mxm) matrix of spot (co-)volatility estimates on block 
%  I_k_m  -> (m^2xm^2) matrix: sum of fisher info matrices across freqs on
%  block 
% -------------------------------------------------------------------------
%
% Peter Malec, January 8, 2013 
%
% -------------------------------------------------------------------------
%       
%% check if there were too few observations on blocks

if (sum(sum(isnan(lret_avb_m)))==0)&&(sum(isnan(lnoise_v))==0)%normal  
% -------------------------------------------------------------------------
%  
%% Compute weight matrices

% array of weight matrices for each freq j
[W_k_a,i_Phi_norm,I_k_m]=lle_cov_weight_array_md(J_val,h,lnoise_v,Sigma_p);
% -------------------------------------------------------------------------
%  
%% Compute Spot Covariance Estimate on Block as weighted average acr freqs

% number of assets
m=size(lret_avb_m,2);

% compute 3d-array containing matrix of products of local blockwise averages
S_arr=permute(lret_avb_m,[2 3 1]); %(mx1xJ) array
SS_arr=mtimesx(S_arr,S_arr,'t');  %(mxmxJ) array

% matrix of dist. elements of bias-corr. spot vola matrix estimator on 
lnoise_arr=diag(lnoise_v); % (mxm)
lnoise_arr=lnoise_arr(:,:,ones(J_val,1)); % (mxmxJ)
i_Phi_norm_arr=permute(i_Phi_norm,[2 3 1]); % (1x1xJ)
V_arr=(SS_arr-lnoise_arr).*i_Phi_norm_arr(ones(m,1),ones(m,1),:);

%  spot vola estimates on block: sum of prod of fisher info and spot vola estimates based on diff freq
Sigma_k=nansum(mtimesx(W_k_a,reshape(V_arr,[m^2 1 J_val])),3);   % (m^2x1) vector
Sigma_k=reshape(Sigma_k,m,m);

% correction of correlation and variance estimates
if ccorr>0
    [Sigma_k,~]=check_spot_covm_md(Sigma_k); 
end
% -------------------------------------------------------------------------
%         
%% if too few observations
    
else
    
     % number of assets
    m=size(lret_avb_m,2);
    
    % empty outputs
    Sigma_k=zeros(m,m);
     I_k_m=NaN*zeros(m^2,m^2);
     
 end
    
    
    