function Sigma_kh_reg=spot_vola_reg(Sigma_kh)
%------------------------------------------------------------------
%% spot_vola_reg
% regularizes 2x2 spot volatility matrices by 
% retaining only largest eigenvalue
%------------------------------------------------------------------
%
% INPUTS
% Sigma_kh -> (2x2xB) array of spot volatility matrices at beginning of
%                     each block
%------------------------------------------------------------------
% OUTPUTS
% Sigma_kh_reg -> (2 x 2 x B) array of regularized spot volatility matrices
%------------------------------------------------------------------
%
% Peter Malec, January 20, 2012
%
%% Regularization

% initialize output matrix
Sigma_kh_reg=Sigma_kh;

% loop across blocks
    for i=1:size(Sigma_kh,3)
        Sigma_kh_m=Sigma_kh(:,:,i);
        if det(Sigma_kh_m)<=eps
            [q s v]=svds(Sigma_kh_m,2);
            Sigma_kh_reg(:,:,i)=q(:,1)*s(1,1)*q(:,1)';
        end
    end