function SCov_mat_sm=spot_vola_smooth(SCov_mat,K)
%------------------------------------------------------------------
%% spot_vola_smooth
% Smooths Spot (Co-variance) estimates for each block
%------------------------------------------------------------------
%
% INPUTS
% SCov_mat -> (Bx3) matrix of spot (co-)volatility estimates on
% blocks (kth row: [sigma_(x,k)^2 sigma_(xy,k) sigma_(y,k)^2])
% K             -> bandwidth of spot volatility estimator: # of blocks to
%                     average over. We build local window around (beginning
%                     of) block k using K/2 blocks before and K/2-1 blocks
%                     after 
%------------------------------------------------------------------
% OUTPUTS
% SCov_mat_sm -> (Bx3) matrix of smoothed spot (co-)volatility estimates on
% blocks (kth row: [sigma_(x,k)^2 sigma_(xy,k) sigma_(y,k)^2])
%------------------------------------------------------------------
%
%   Peter Malec, October 6, 2012
%
%   based on function "spot_vola.m"
%------------------------------------------------------------------
%
%% Preparations

%number of blocks
B=size(SCov_mat,1);

% check bandwidth
if K < 2
    error('supplied bandwidth K has to be >= 2!')
else
    if (mod(K,2)~=0)   % has to be even integer!!!!
        K=K-1;
    end
end

% empty output matrix
SCov_mat_sm =NaN*zeros(B,3);
%------------------------------------------------------------------
%
%% Smooth by computing moving averages

% "First" blocks: we do not have K/2 blocks before
block_ind=1:K;          % fixed window at beginning
SFWind_beg=mean(SCov_mat(block_ind,:));
SCov_mat_sm(1:K/2,:)=SFWind_beg(ones(length(1:K/2),1),:);

% "Intermediate" blocks: standard proc
for i=(K/2+1):(B-K/2+1)
    block_ind=(i-K/2):(i+K/2-1);        % local window around (beginning of) block k using K/2 blocks before and K/2-1 blocks after 
    SCov_mat_sm(i,:)=mean(SCov_mat(block_ind,:));
end

if K>=4
    % "Last" blocks: we do not have K/2-1 blocks after
    block_ind=(B-K+1):B;    % fixed window at end
    SFWind_end=mean(SCov_mat(block_ind,:));
    SCov_mat_sm((B-K/2+2):B,:)=SFWind_end(ones(length((B-K/2+2):B),1),:);
end






