function [SCov_mat_sm,CovSCov_mat_sm]=spot_vola_smooth_beta(input,b,block_st,SCov_mat,modi,i_I_k_m_arr)
%------------------------------------------------------------------
%% spot_vola_smooth_beta
% Smooths Spot (Co-variance) estimates using beta-kernel regression
%------------------------------------------------------------------
%
% INPUTS
% input       -> vector of points of estimation
% b             -> smoothing bandwidth
% block_st    -> (Bx1) vector of block start times
% SCov_mat -> (Bx3) matrix of spot (co-)volatility estimates on
% blocks (kth row: [sigma_(x,k)^2 sigma_(xy,k) sigma_(y,k)^2])
% modi -> if >0, modified beta kernel is used, else
%             standard kernel
% i_I_k_m_arr -> (3x3xB) array of inverses of sum of fisher infos on each
%                       block (optional)
%------------------------------------------------------------------
% OUTPUTS
% SCov_mat_sm -> (length(input)x3) matrix of smoothed spot (co-)volatility estimates 
%           (ith row: [sigma_(x,i)^2 sigma_(xy,i) sigma_(y,i)^2])
% CovSCov_mat_sm -> (3x3xlength(input)) array: Covariance matrices of smoothed spot (co-)volatilities
%   under the local parametric experiment
%------------------------------------------------------------------
%
%   Peter Malec, May 3, 2013
%
%------------------------------------------------------------------
%
%% Preparations

% make column vector
block_st=block_st(:);
input=input(:);

% number of points of estimation
nin=length(input);

% check bandwidth
if  b<=0   % has to be even integer!!!!
        error('bandwidth has to be positive')
end
%------------------------------------------------------------------
%
%% Smoothing

% empty output matrix
SCov_mat_sm =NaN*zeros(nin,3);

if nargin>5 % compute Covariance matrices  of estimates
    
    % empty output matrix
    CovSCov_mat_sm =NaN*zeros(3,3,nin);
    
    % evaluate Smoothed estimates
    for i=1:nin
        kernelv=beta_kernel(block_st,input(i),b,modi);
        weightv=kernelv/sum(kernelv); %(Bx1 vector)
        SCov_mat_sm(i,:)=sum(SCov_mat.*weightv(:,ones(3,1))); %(1x3 vector)
        weightarr=(permute(weightv,[3 2 1])).^2; %(1x1xB array)
        CovSCov_mat_sm(:,:,i)=sum(i_I_k_m_arr.*weightarr(ones(3,1),ones(3,1),:),3);%(3x3x1 array)
    end
    
else % do not compute Covariance matrices  of estimates
    
     CovSCov_mat_sm=NaN;
     
     % evaluate Smoothed estimates
    for i=1:nin
        kernelv=beta_kernel(block_st,input(i),b,modi);
        weightv=kernelv/sum(kernelv); %(Bx1 vector)
        SCov_mat_sm(i,:)=sum(SCov_mat.*weightv(:,ones(3,1))); %(1x3 vector)
    end
    
    
    
end







