function SCov_mat_sm=spot_vola_smooth_bound(SCov_mat,K,SCov_mat_sm_in)
%------------------------------------------------------------------
%% spot_vola_smooth_bound
% Smooths Spot (Co-variance) estimates for boundary blocks
%------------------------------------------------------------------
%
% INPUTS
% SCov_mat -> (Bx3) matrix of spot (co-)volatility estimates on
% blocks (kth row: [sigma_(x,k)^2 sigma_(xy,k) sigma_(y,k)^2])
% 
% K             -> bandwidth of spot volatility estimator: # of blocks to
%                     average over. We build local window around (beginning
%                     of) block k using K/2 blocks before and K/2-1 blocks
%                     after 
% SCov_mat_sm_in -> (Bx3) matrix of "old" smoothed spot (co-)volatility estimates on
% blocks (kth row: [sigma_(x,k)^2 sigma_(xy,k) sigma_(y,k)^2])
%------------------------------------------------------------------
% OUTPUTS
% SCov_mat_sm -> (Bx3) matrix of smoothed spot (co-)volatility estimates on
% blocks (kth row: [sigma_(x,k)^2 sigma_(xy,k) sigma_(y,k)^2])
%------------------------------------------------------------------
%
%   Peter Malec, April 24, 2013
%
%   based on function "spot_vola.m"
%------------------------------------------------------------------
%
%% Preparations

%number of blocks
B=size(SCov_mat,1);

% check input estimates
if (size(SCov_mat_sm_in,1)~=B)||(size(SCov_mat_sm_in,2)~=3)
    error('matrix of supplied spot cov estimates has to be of dimension (Bx3)!')
end

% check bandwidth
if K < 2
    error('supplied bandwidth K has to be >= 2!')
else
    if (mod(K,2)~=0)   % has to be even integer!!!!
        K=K-1;
    end
end

% output matrix
SCov_mat_sm =SCov_mat_sm_in;
%------------------------------------------------------------------
%
%% Re-Smooth on boundary blocks with constant bandwidth

% "First" blocks: we do not have K/2 blocks before
block_ind=1:K;          % fixed window at beginning
SFWind_beg=mean(SCov_mat(block_ind,:));
SCov_mat_sm(1:K/2,:)=SFWind_beg(ones(length(1:K/2),1),:);

if K>=4
    % "Last" blocks: we do not have K/2-1 blocks after
    block_ind=(B-K+1):B;    % fixed window at end
    SFWind_end=mean(SCov_mat(block_ind,:));
    SCov_mat_sm((B-K/2+2):B,:)=SFWind_end(ones(length((B-K/2+2):B),1),:);
end






