function CovSCov_mat_sm=spot_vola_smooth_cov(i_I_k_m_arr,K)
%------------------------------------------------------------------
%% spot_vola_smooth_cov
% Covariance matrices of moothed Spot (Co-variance) estimates for each block
%------------------------------------------------------------------
%
% INPUTS
% i_I_k_m_arr -> (3x3xB) array of inverses of sum of fisher infos on each
%                       block
% K             -> bandwidth of spot volatility estimator: # of blocks to
%                     average over. We build local window around (beginning
%                     of) block k using K/2 blocks before and K/2-1 blocks
%                     after 
%------------------------------------------------------------------
% OUTPUTS
% CovSCov_mat_sm -> (3x3xB) array: Covariance matrices of smoothed spot (co-)volatilities
%   under the local parametric experiment
%------------------------------------------------------------------
%
%   Peter Malec, October 31, 2012
%
%   based on function "spot_vola_smooth.m"
%------------------------------------------------------------------
%
%% Preparations

%number of blocks
B=size(i_I_k_m_arr,3);

% check bandwidth
if K < 2
    error('supplied bandwidth K has to be >= 2!')
else
    if (mod(K,2)~=0)   % has to be even integer!!!!
        K=K-1;
    end
end

% empty output matrix
CovSCov_mat_sm =NaN*zeros(3,3,B);
%------------------------------------------------------------------
%
%% Smooth by computing moving averages

% "First" blocks: we do not have K/2 blocks before
block_ind=1:K;          % fixed window at beginning
SFWind_beg=sum(i_I_k_m_arr(:,:,block_ind),3);
CovSCov_mat_sm(:,:,1:K/2)=SFWind_beg(:,:,ones(length(1:K/2),1));

% "Intermediate" blocks: standard proc
for i=(K/2+1):(B-K/2+1)
    block_ind=(i-K/2):(i+K/2-1);        % local window around (beginning of) block k using K/2 blocks before and K/2-1 blocks after 
    CovSCov_mat_sm(:,:,i)=sum(i_I_k_m_arr(:,:,block_ind),3);
end

if K>=4
    % "Last" blocks: we do not have K/2-1 blocks after
    block_ind=(B-K+1):B;    % fixed window at end
    SFWind_end=sum(i_I_k_m_arr(:,:,block_ind),3);
    CovSCov_mat_sm(:,:,(B-K/2+2):B)=SFWind_end(:,:,ones(length((B-K/2+2):B),1));
end

% divide by squared bandwidth
CovSCov_mat_sm=CovSCov_mat_sm/(K^2);




