function CovSCov_mat_sm=spot_vola_smooth_cov_md(i_I_k_mat,K)
%------------------------------------------------------------------
%% spot_vola_smooth_cov_md
% Covariance matrices of moothed Spot (Co-variance) estimates for each block
% in m-dimensional case
%------------------------------------------------------------------
%
% INPUTS
% i_I_k_mat -> (m^2(m^2+1)/2xB) matrix of inverses of sum of fisher infos on each
%                       block (each column is vech(inv(I_k_m)))
% K             -> bandwidth of spot volatility estimator: # of blocks to
%                     average over. We build local window around (beginning
%                     of) block k using K/2 blocks before and K/2-1 blocks
%                     after 
%------------------------------------------------------------------
% OUTPUTS
% CovSCov_mat_sm ->  (m^2(m^2+1)/2xB) matrix: Covariance matrices of smoothed spot (co-)volatilities
%   under the local parametric experiment (again, vech operator used)
%------------------------------------------------------------------
%
%   Peter Malec, January 8, 2014
%
%   based on function "spot_vola_smooth.m"
%------------------------------------------------------------------
%
%% Preparations

%number of blocks
B=size(i_I_k_mat,2);

% no of distinct elements in cov matrix
elcov=size( i_I_k_mat,1);

% check bandwidth
if K < 2
    error('supplied bandwidth K has to be >= 2!')
else
    if (mod(K,2)~=0)   % has to be even integer!!!!
        K=K-1;
    end
end

% empty output matrix
CovSCov_mat_sm =NaN*zeros(elcov,B);
%------------------------------------------------------------------
%
%% Smooth by computing moving averages

% "First" blocks: we do not have K/2 blocks before
block_ind=1:K;          % fixed window at beginning
SFWind_beg=sum(i_I_k_mat(:,block_ind),2);
CovSCov_mat_sm(:,1:K/2)=SFWind_beg(:,ones(length(1:K/2),1));

% "Intermediate" blocks: standard proc
for i=(K/2+1):(B-K/2+1)
    block_ind=(i-K/2):(i+K/2-1);        % local window around (beginning of) block k using K/2 blocks before and K/2-1 blocks after 
    CovSCov_mat_sm(:,i)=sum(i_I_k_mat(:,block_ind),2);
end

if K>=4
    % "Last" blocks: we do not have K/2-1 blocks after
    block_ind=(B-K+1):B;    % fixed window at end
    SFWind_end=sum(i_I_k_mat(:,block_ind),2);
    CovSCov_mat_sm(:,(B-K/2+2):B)=SFWind_end(:,ones(length((B-K/2+2):B),1));
end

% divide by squared bandwidth
CovSCov_mat_sm=CovSCov_mat_sm/(K^2);




