function SCov_mat_sm=spot_vola_smooth_lKb_md(SCov_mat,K)
%------------------------------------------------------------------
%% spot_vola_smooth_lKb_md
% Smooths Spot (Co-variance) estimates for each block
% NOTE: less smoothing at the lower and upper bound 
% in m-dimensional case
%------------------------------------------------------------------
%
% INPUTS
% SCov_mat -> (Bxm(m+1)/2) matrix of spot (co-)volatility estimates on
%                   blocks (each row is vech(Sigma_t)')
% K             -> bandwidth of spot volatility estimator: # of blocks to
%                     average over. We build local window around (beginning
%                     of) block k using K/2 blocks before and K/2-1 blocks
%                     after 
%------------------------------------------------------------------
% OUTPUTS
% SCov_mat_sm -> (Bxm(m+1)/2) matrix of smoothed spot (co-)volatility estimates on
%                           blocks
%------------------------------------------------------------------
%
%   Peter Malec, January 8, 2014
%
%   based on function "spot_vola.m"
%------------------------------------------------------------------
%
%% Preparations

%number of blocks
B=size(SCov_mat,1);

% number of unique cov mat elements
elu=size(SCov_mat,2);

% check bandwidth
if K < 2
    error('supplied bandwidth K has to be >= 2!')
else
    if (mod(K,2)~=0)   % has to be even integer!!!!
        K=K-1;
    end
end

% empty output matrix
SCov_mat_sm =NaN*zeros(B,elu);
%------------------------------------------------------------------
%
%% Smooth by computing moving averages

% "First" blocks: we do not have K/2 blocks before
for i=1:K/2
    block_ind=1:(i+K/2-1);        % local window around (beginning of) block k using K/2-x blocks before and K/2-1 blocks after 
    SCov_mat_sm(i,:)=mean(SCov_mat(block_ind,:));
end

% "Intermediate" blocks: standard proc
for i=(K/2+1):(B-K/2+1)
    block_ind=(i-K/2):(i+K/2-1);        % local window around (beginning of) block k using K/2 blocks before and K/2-1 blocks after 
    SCov_mat_sm(i,:)=mean(SCov_mat(block_ind,:));
end

if K>=4
    % "Last" blocks: we do not have K/2-1 blocks after
    for i=(B-K/2+2):B
        block_ind=(i-K/2):B;        % local window around (beginning of) block k using K/2 blocks before and K/2-1-x blocks after 
        SCov_mat_sm(i,:)=mean(SCov_mat(block_ind,:));
    end
 end






