function [Cov_mat_reg,Reg]=check_spot_covm_md(Sigma_k)
%% check_spot_covm_md
%--------------------------------------------------------------
% checks m-dimensional spot covariance matrix for positive definitess.
% Otherwise projection on space of positive semi-definitve matrices
%
%--------------------------------------------------------------
% INPUT:
% Sigma_k -> (mxm) covariance matrix
%--------------------------------------------------------------
% OUTPUT:
% Cov_mat_reg -> cleaned (mxm) covariance matrix
% Reg      -> regularization indicator: >0 if reg necessary
% -------------------------------------------------------------------------
%
% Peter Malec, January 14, 2013 
%
% -------------------------------------------------------------------------
%       
%% Check of Covariance Matrix

% obtain eigenvalues 
%---------------------------------------------------------
% Spec Decomp
[U, S] = eig(Sigma_k);

% Put eigenvalues into vector
lambd=diag(S);                                  

% correction if Sigma_k is not positive definite
%---------------------------------------------------------
if (sum(lambd<=0)>0)%||(abs(cond(Sigma_k))>(10*p)) 
    
    %replace negative eigenvalues by small positive values
    S_neg_ind=lambd<=0;
    lambd(S_neg_ind)=1e-10*ones(sum(S_neg_ind),1);
    
    % sort eigenvalues by size
    [lambd,ix]=sort(lambd,'descend');
    U=U(:,ix);
    
    %recompute covariance matrix 
    Cov_mat_reg=U*diag(lambd)*U';
      
    %indicator
    Reg=1;
    
else
         %disp('No regularization of corr matrix necessary!')
         
         % Covariance Matrix     
        Cov_mat_reg=Sigma_k;
         
     %indicator
    Reg=0;

end

    
    




