function [Sigma_k_corr,Reg]=check_spot_covm_md_evcl(Sigma_k,n_obs_b)
%% check_spot_covm_md_evcl
%--------------------------------------------------------------
% checks m-dimensional spot covariance matrix for positivity of variances
% and well-conditioning of correlation matrix. Regularization by eigenvalue
% cleaning
%--------------------------------------------------------------
% INPUT:
% Sigma_k -> (mxm) covariance matrix
% n_obs_b -> number of observations on block: take minimum number! 
%--------------------------------------------------------------
% OUTPUT:
% Sigma_k_corr -> cleaned (mxm) covariance matrix
% Reg      -> regularization indicator: >0 if reg necessary
% -------------------------------------------------------------------------
%
% Peter Malec, January 8, 2013 
%
% -------------------------------------------------------------------------
%       
%% Check of variances

% obtain values
Variances=diag(Sigma_k);

% replace negative variances
Variances(Variances<=0)=1e-10;
% -------------------------------------------------------------------------
%       
%% Check of Correlation Matrix

% obtain correlation matrix
Corr_mat=diag(Variances.^(-.5))*Sigma_k*diag(Variances.^(-.5));

% get dimension
p=size(Corr_mat,1);

% obtain signs of eigenvalues order by magnitude
%---------------------------------------------------------
% Spec Decomp
[U S] = eig(Corr_mat);
% Take real eigenvals and order by magnitude
lambd=diag(S);                                      % cond no is lambd_s(1)/lambd_s(end)
[lambd_s ix]=sort(abs(lambd),'descend'); %real symm matrix has real eigenvalues, complex are errors
% compute sign
lamb_sign=sign(real(lambd(ix)));     %imprecse sign for small evals does not matter: will be below threshold anyway

 

% regularization if corr is indefinite or ill-conditioned
%---------------------------------------------------------
if (sum(lamb_sign==-1)>0)||(sum(lamb_sign==0)>0)||(abs(cond(Corr_mat))>(10*p)) 

    % regularization
     [Corr_mat_rnb, ~]=eigenval_clean(Corr_mat,lamb_sign,n_obs_b,1);         
    
     
    % Covariance Matrix     
     Sigma_k_corr=diag(sqrt(Variances))*Corr_mat_rnb*diag(sqrt(Variances));
    
    %indicator
    Reg=1;
    
else
         %disp('No regularization of corr matrix necessary!')
         
         % Covariance Matrix     
        Sigma_k_corr=diag(sqrt(Variances))*Corr_mat*diag(sqrt(Variances));
         
     %indicator
    Reg=0;

end

    
    




