function [Sigma_k_corr,Reg]=check_spot_covm_md(Sigma_k)
%% check_spot_covm_md
%--------------------------------------------------------------
% checks m-dimensional spot covariance matrix for positivity of variances
% and positive definitess. Otherwise projection on space of positive
% semi-definitve matrices
%
%--------------------------------------------------------------
% INPUT:
% Sigma_k -> (mxm) covariance matrix
%--------------------------------------------------------------
% OUTPUT:
% Sigma_k_corr -> cleaned (mxm) covariance matrix
% Reg      -> regularization indicator: >0 if reg necessary
% -------------------------------------------------------------------------
%
% Peter Malec, January 14, 2013 
%
% -------------------------------------------------------------------------
%       
%% Check of variances

% obtain values
Variances=diag(Sigma_k);

% replace negative variances
Variances(Variances<=0)=1e-10;
% -------------------------------------------------------------------------
%       
%% Check of Correlation Matrix

% obtain correlation matrix
Corr_mat=diag(Variances.^(-.5))*Sigma_k*diag(Variances.^(-.5));

% obtain signs of eigenvalues order by magnitude
%---------------------------------------------------------
% Spec Decomp
[U, S] = eig(Corr_mat);

% Put eigenvalues into vector
lambd=diag(S);                                  

% correction if corr is not positive definite
%---------------------------------------------------------
if (sum(lambd<=0)>0)%||(abs(cond(Corr_mat))>(10*p)) 
    
    %replace negative eigenvalues by small positive values
    S_neg_ind=lambd<=0;
    lambd(S_neg_ind)=1e-10*ones(sum(S_neg_ind),1);
    
    % sort eigenvalues by size
    [lambd,ix]=sort(lambd,'descend');
    U=U(:,ix);
    
    %recompute correlation matrix 
    Corr_mat_reg=U*diag(lambd)*U';
      
    % Covariance Matrix     
     Sigma_k_corr=diag(sqrt(Variances))*Corr_mat_reg*diag(sqrt(Variances));
    
    %indicator
    Reg=1;
    
else
         %disp('No regularization of corr matrix necessary!')
         
         % Covariance Matrix     
        Sigma_k_corr=Sigma_k;
         
     %indicator
    Reg=0;

end

    
    




