function [SCov_k_v_corr]=check_spot_covs(SCov_k_v,block_end,h)
%% check_spot_covs
%--------------------------------------------------------------
% checks spot variance estimates for nonnegativity and correlations for
% \in [-1,1]
%--------------------------------------------------------------
% INPUT:
% SCov_k_v -> (3x1) vector of spot (co-)volatility estimates on block 
% ([sigma_(x,k)^2;sigma_(xy,k);sigma_(y,k)^2])
% block_end -> end of block
% h ->block length
%--------------------------------------------------------------
% OUTPUT:
% SCov_k_v_corr-> (3x1) vector of corrected spot (co-)volatility estimates on block 
% ([sigma_(x,k)^2;sigma_(xy,k);sigma_(y,k)^2])
% -------------------------------------------------------------------------
%
% Peter Malec, May 14, 2013 
%
% -------------------------------------------------------------------------
%       
%% Check of variances

% assign values
sigma2_x=SCov_k_v(1);
sigma2_y=SCov_k_v(3);
sigma_xy=SCov_k_v(2);

% replace negative variances
if sigma2_x<=0
   % disp(['Negative Variance Estimate  for Asset 1 on block' num2str(round(block_end/h)) '!'])
    sigma2_x=1e-10;
end

if sigma2_y<=0
    %disp(['Negative Variance Estimate  for Asset 2 on block' num2str(round(block_end/h)) '!'])
    sigma2_y=1e-10;
end
% -------------------------------------------------------------------------
%       
%% Check of Correlation

% compute implied correlation
rho_xy=sigma_xy/sqrt(sigma2_x*sigma2_y);

% check and correct
if abs(rho_xy)>(1-1e-13)
    %disp(['Spot correlation on block ' num2str(round(block_end/h)) ' too close to one. Correction necessary!'])
    sigma_xy=sign(rho_xy)*(1-1e-13)*sqrt(sigma2_x*sigma2_y);
end                             %replace rho by threshold


% output values
SCov_k_v_corr=[sigma2_x;sigma_xy;sigma2_y];




