function [beta_vec,beta_var_vec]=comp_beta(SCov_mat,Covmat_arr)
%------------------------------------------------------------------
%% comp_beta
%   Computes betas and associated Standard Errors from 
%   (2x2) covariance matrices
%   NOTE: series y corresponds to the market proxy
%------------------------------------------------------------------
%
% INPUTS
% SCov_mat-> (Bx3) matrix of smoothed spot (co-)volatility estimates
%                       with kth row:[sigma_(x,k)^2 sigma_(xy,k) sigma_(y,k)^2]
% Covmat_arr -> (3x3xB) array: Covariance matrices of smoothed spot (co-)volatilities
%   under the local parametric experiment    
%------------------------------------------------------------------
% OUTPUTS
% beta_vec -> (Bx1) vector of beta estimates
% beta_var_vec ->(Bx1) vector of beta standard errors
%------------------------------------------------------------------
%
%   Peter Malec, April 22, 2013
%
%------------------------------------------------------------------
%
%% Compute Correlations

%number of blocks
B=size(SCov_mat,1);

% betas
beta_vec=SCov_mat(:,2)./SCov_mat(:,3);

% correct for 0/0=nan
beta_vec(isnan(beta_vec))=0;
%------------------------------------------------------------------
%
%% Compute Standard errors

if nargin>1
    
    % compute gradient of beta wrt var1,cov and var2
    %--------------------------------------------------------
    gam_vec=(SCov_mat(:,3)).^(-1);
    dbeta_mat=gam_vec(:,ones(3,1)).*[zeros(B,1) ones(B,1) ((-1)*beta_vec)];
                                            %(Bx3) matrix
     
     % correct for 0/0=nan
    dbeta_mat(isnan(dbeta_mat))=0;                                                       
                                            
     % compute variance of correlation estimate
     %--------------------------------------------------
    dbeta_arr=permute(dbeta_mat,[3 2 1]);%(1x3xB) array
    dbeta_arr=dbeta_arr(ones(3,1),:,:); %(3x3xB) array
    var_dbeta_arr=sum(Covmat_arr.*dbeta_arr,2);%(3x1xB) array
    beta_var_vec=sum(permute(dbeta_arr(1,:,:),[2 1 3]).*var_dbeta_arr ,1);%(1x1xB) array
    beta_var_vec=squeeze(beta_var_vec);
else
    
    beta_var_vec=NaN*zeros(B,1);
    
end