function [rho_vec,rho_var_vec]=comp_corr(SCov_mat,Covmat_arr)
%------------------------------------------------------------------
%% comp_corr
%   Computes correlations and associated Standard Errors from 
%   (2x2) covariance matrices
%------------------------------------------------------------------
%
% INPUTS
% SCov_mat-> (Bx3) matrix of smoothed spot (co-)volatility estimates
%                       with kth row:[sigma_(x,k)^2 sigma_(xy,k) sigma_(y,k)^2]
% Covmat_arr -> (3x3xB) array: Covariance matrices of smoothed spot (co-)volatilities
%   under the local parametric experiment    
%------------------------------------------------------------------
% OUTPUTS
% rho_vec -> (Bx1) vector of correlations
% rho_var_vec ->(Bx1) vector of correlation standard errors
%------------------------------------------------------------------
%
%   Peter Malec, October 31, 2012
%
%------------------------------------------------------------------
%
%% Compute Correlations

%number of blocks
B=size(SCov_mat,1);

% correlations
rho_vec=SCov_mat(:,2)./sqrt(SCov_mat(:,1).*SCov_mat(:,3));

% correct for 0/0=nan
rho_vec(isnan(rho_vec))=0;
%------------------------------------------------------------------
%
%% Compute Standard errors

if nargin>1
    
    % compute gradient of corr wrt var1,cov and var2
    %--------------------------------------------------------
    gam_vec=(sqrt(SCov_mat(:,1).*SCov_mat(:,3))).^(-1);
    beta21_vec=SCov_mat(:,2)./SCov_mat(:,1);
    beta12_vec=SCov_mat(:,2)./SCov_mat(:,3);
    drho_mat=gam_vec(:,ones(3,1)).*[((-0.5)*beta21_vec) ones(B,1) ((-0.5)*beta12_vec)];
                                            %(Bx3) matrix
     % correct for 0/0=nan
    drho_mat(isnan(drho_mat))=0;                                       
                                            
                                            
     % compute variance of correlation estimate
     %--------------------------------------------------
    drho_arr=permute(drho_mat,[3 2 1]);%(1x3xB) array
    drho_arr=drho_arr(ones(3,1),:,:); %(3x3xB) array
    var_drho_arr=sum(Covmat_arr.*drho_arr,2);%(3x1xB) array
    rho_var_vec=sum(permute(drho_arr(1,:,:),[2 1 3]).*var_drho_arr ,1);%(1x1xB) array
    rho_var_vec=squeeze(rho_var_vec);
else
    
    rho_var_vec=NaN*zeros(B,1);
    
end