function [SCov_mat,Covmat_vec]=retrieve_cov_el_univ(asseti,SCov_mat,Covmat_mat,Z_tilde)
%------------------------------------------------------------------
%% retrieve_cov_el_univ
% Retrieves  specific variance from bigger
% stacked covariance matrix
%------------------------------------------------------------------
%
% INPUTS
% asseti        -> asset index
% SCov_mat-> (n_inxm(m+1)/2) matrix of spot cov matrices for each point of
%                               estimation
%                    each row: vech(\hat Sigma_t)'
% Covmat_mat ->(m^2(m^2+1)/2xn_in) matrix: Stacked Covariance matrices of smoothed spot (co-)volatilities
%                       under the local parametric experiment      (optional)
%                    each column:vech(Cov(\hat Sigma_t))
% Z_tilde -> (m^2 x m^2)  matrix of fourth moments of d-dimensional
%                   standard Gaussian vector (optional)
%------------------------------------------------------------------
% OUTPUTS
% SCov_mat -> (n_inx1) vector of spot variances for each point of
%                       estimation.
%                        each row: \hat Sigma^{sub}_t
% Covmat_vec ->(n_inx1) vector of variances of spot variance estimates     
%------------------------------------------------------------------
%
%   Peter Malec,February 14, 2014
%
%------------------------------------------------------------------
%
%% Preparations

% no of assets
m= (sqrt(1+size(SCov_mat,2)*8)-1)/2;

% check asset indices
if (asseti>m)
    error('Asset index larger than no of assets.')
end
%------------------------------------------------------------------
%
%% Sub covariance matrix

%number of inputs
nin=size(SCov_mat,1);

% obtain column indices for SCov_mat
if asseti>1
    indv1=sum(m-((1:(asseti-1))-1))+asseti-asseti+1;
else
    indv1=asseti-asseti+1;
end
              
% retrieve necessary elements of SCov_mat
SCov_mat=SCov_mat(:,indv1);
%------------------------------------------------------------------
%
%% Covariance Matrices of spot estimators

if nargin>2
    
    % compute Z_tilde???
    if (nargin<4)
        Z_tilde=[];
    end
    if (isempty(Z_tilde))||(size(Z_tilde,1)~=m^2)||(size(Z_tilde,2)~=m^2)
        disp('Z_tilde has to be computed!')
        Z_tilde = constrZ_tilde(m);
    end
    
    % obtain indices for Covmat_mat
    indv1=(asseti-1)*m+asseti;
    
    % retrieve necessary elements of Covmat_mat
    %--------------------------------------------------------
   Covmat_vec=NaN*zeros(nin,1);
    for i=1:size(Covmat_mat,2)
        Covmat_temp=ivech(Covmat_mat(:,i))*Z_tilde;
        Covmat_vec(i)=Covmat_temp(indv1,indv1);
    end

else
    
    Covmat_vec=NaN;
    
end