function [SCov_mat_sm_sel,CovSCov_mat_sm_sel]=select_block_vola(input_v,block_st,block_end,SCov_mat_sm,CovSCov_mat_sm)
%------------------------------------------------------------------
%% spot_vola_smooth
% Selects spot vola estimates and their covariances for estimation points
%------------------------------------------------------------------
%
% INPUTS
% input_v -> (n_inx1) vector of estimation points
% block_st -> (Bx1) vector of block starts
% SCov_mat_sm -> (Bx3) matrix of smoothed spot cov matrices on blocks
% CovSCov_mat_sm -> (3x3xB) array of estimated covariance matrices of above
%                                   estimates
%------------------------------------------------------------------
% OUTPUTS
% SCov_mat_sm_sel-> (n_inx3) matrix of spot cov matrices for each point of
%                               estimation
% CovSCov_mat_sm_sel -> (3x3xn_in) array of estimated covariance matrices of above
%                                   estimates
%------------------------------------------------------------------
%
%   Peter Malec, May 7, 2013
%
%------------------------------------------------------------------
%
%% Preparations

% make column vectors
input_v=input_v(:);
block_st=block_st(:);
block_end=block_end(:);

% no of inputs
nin=length(input_v);

% check if some input=1
one_ind=find(input_v==1);

% set of "normal" inputs
normin=setdiff(1:nin,one_ind);
%------------------------------------------------------------------
%
%% Select estimates and their covariance matrices

% empty output matrix
SCov_mat_sm_sel=NaN*zeros(nin,3);

% selection
%%%%%%%%%%%%%%%%%%%%%%%
if nargin>4 % including covariances
    
    % empty output array
     CovSCov_mat_sm_sel=NaN*zeros(3,3,nin);
     
     % loop over "normal" estimation points
     for i=normin
         b_ind=((input_v(i)-block_st>1e-12)|(abs(input_v(i)-block_st)<1e-12))&(block_end-input_v(i)>1e-12);% block indicator
         SCov_mat_sm_sel(i,:)=SCov_mat_sm(b_ind,:); % select spot covariance est
         CovSCov_mat_sm_sel(:,:,i)=CovSCov_mat_sm(:,:,b_ind); % select covariances of spot covariance est
     end
     
     %input =1 ->always last block
     if ~isempty(one_ind)
         SCov_mat_sm_sel(one_ind,:)=SCov_mat_sm(end,:); % select spot covariance est
         CovSCov_mat_sm_sel(:,:,one_ind)=CovSCov_mat_sm(:,:,end); % select covariances of spot covariance est
     end
    
    else     % w/o covariances
    
    % empty scalar
     CovSCov_mat_sm_sel=NaN;
     
     % loop over "normal" estimation points
     for i=1:normin
        b_ind=((input_v(i)-block_st>1e-12)|(abs(input_v(i)-block_st)<1e-12))&(block_end-input_v(i)>1e-12);% block indicator
         SCov_mat_sm_sel(i,:)=SCov_mat_sm(b_ind,:); % select spot covariance est
     end
     
     %input =1 ->always last block
     if ~isempty(one_ind)
         SCov_mat_sm_sel(one_ind,:)=SCov_mat_sm(end,:); % select spot covariance est
     end
    
end






