function [M1,M2,M3] = MSCRCOV_2x2_oracle_M(N,Omega_mat,ICov,ICoQuart)
%% MSCRCOV_2x2_oracle_M
%--------------------------------------------------------------
% optimal subsampling scales for oracle version of Multi-Scale 
%Realized (2x2) Covariance Estimator as proposed by  Bibinger (2011) 
%--------------------------------------------------------------
% INPUT:
% N -> number of observations
% Omega_mat -> (2x2) noise covariance matrix
% ICov-> (3x1) vector of integrated covariances
% ICoQuart -> (6x1) vector of integrated coquarticities
%--------------------------------------------------------------
% OUTPUT:
% M1, M2 M3 -> largest subsampling scales for two variances and covariance
% -------------------------------------------------------------------------
%
% Peter Malec, February 10, 2012
%
% May 5, 2012
% Choice of optimal c in univariate case corrected
% -------------------------------------------------------------------------
%       
%% Compute Optimal Max Scale

% compute c* for all elements
Vn_vec=24*[2*Omega_mat(1,1)^2;2*Omega_mat(2,2)^2;Omega_mat(1,1)*Omega_mat(2,2)];
Vd_vec=26/35*[2*ICoQuart(1);2*ICoQuart(2);ICoQuart(4)+ICoQuart(3)];
Vc_vec=12/5*[2*(Omega_mat(1,1)^2+2*Omega_mat(1,1)*ICov(1));2*(Omega_mat(2,2)^2+2*Omega_mat(2,2)*ICov(2));...
   Omega_mat(1,1)*Omega_mat(2,2)+Omega_mat(1,1)*ICov(2)+Omega_mat(2,2)*ICov(1)];
c_vec=([1;1;1]).*((-Vc_vec+sqrt(Vc_vec.^2+12*Vd_vec.*Vn_vec))./(6*Vn_vec)).^(-1/2);    

% Vector of Ms
M_vec=sqrt(N)*c_vec;

% round
M1=min(max(ceil(M_vec(1)),2),N);       %   2<= M <= N
M2=min(max(ceil(M_vec(2)),2),N);       %   2<= M <= N
M3=min(max(ceil(M_vec(3)),2),N);       %   2<= M <= N

