function [MSCRCOV] = MSCRCOV_2x2_oracle_fast_alt(data_a1,data_a2,M1,M2,M3)
%% MSCRCOV_2x2_oracle_fast_alt
%--------------------------------------------------------------
% Multi-Scale Realized (2x2) Covariance Estimator as proposed by 
% Bibinger (2011) with distinct max subsampling scales for elements 
% of covariance matrix
% NOTE: faster oracle version
% Note: using alternative RCovSS proc based on loop
%--------------------------------------------------------------
% INPUT:
% data_a1 -> (n_a x 2) matrix of (synchronous) data for asset 1
%       - 1st  col: observation times 
%       - 2nd col: prices 
% M1, M2 M3 -> largest subsampling scales for two variances and covariance
%--------------------------------------------------------------
% OUTPUT:
% MSCRCOV -> multi-scale estimate of (2x2) integrated covariance matrix
% -------------------------------------------------------------------------
%
% Peter Malec, February 1, 2012
%
% May 8, 2012
% -------------------------------------------------------------------------
%       
%% Compute Multi-Scale Estimator

% Log Prices
LogPrice=[log(data_a1(:,2)) log(data_a2(:,2))];

% max of all rounded Ms
M=max([M1;M2;M3]);          

% array for subsampled estimates
RCOVSS_arr=NaN*zeros(2,2,M);

% loop to compute subsampled estimates
for i=1:M
    RCOVSS_arr(:,:,i)=RCovSS_loop(LogPrice,i); 
end

% weight vectors
ivec1=(1:M1)';
alpha_vec1=12*ivec1.^(2)/(M1^3-M1)-6*ivec1/(M1^2-M1);
ivec2=(1:M2)';
alpha_vec2=12*ivec2.^(2)/(M2^3-M2)-6*ivec2/(M2^2-M2);
ivec3=(1:M3)';
alpha_vec3=12*ivec3.^(2)/(M3^3-M3)-6*ivec3/(M3^2-M3);

% compute estimators
MSCRCOV=NaN*zeros(2,2);
MSCRCOV(1,1)=nansum(RCOVSS_arr(1,1,1:(M1)).*permute(alpha_vec1,[2 3 1]),3);
MSCRCOV(2,2)=nansum(RCOVSS_arr(2,2,1:(M2)).*permute(alpha_vec2,[2 3 1]),3);
MSCRCOV(1,2)=nansum(RCOVSS_arr(1,2,1:(M3)).*permute(alpha_vec3,[2 3 1]),3);
MSCRCOV(2,1)=MSCRCOV(1,2);



