function [MSCRV] = MSCRV_oracle_fast(data_a,M)
%% MSCRV_oracle_fast
%--------------------------------------------------------------
% Multi-Scale Realized Variance Estimator as proposed by 
% Bibinger (2011) with distinct max subsampling scales for elements 
% of covariance matrix
% NOTE: faster oracle version
%--------------------------------------------------------------
% INPUT:
% data_a -> (n_a x 2) matrix of (synchronous) data for asset
%       - 1st  col: observation times 
%       - 2nd col: prices 
% M-> largest subsampling scale
%--------------------------------------------------------------
% OUTPUT:
% MSCRV -> multi-scale estimate of integrated variance
% -------------------------------------------------------------------------
%
% Peter Malec, May 6, 2012
% -------------------------------------------------------------------------
%       
%% Compute Multi-Scale Estimator

% Log Prices
LogPrice=log(data_a(:,2));

%matrix for subsampled estimates
RCOVSS_mat=NaN*zeros(M-1,1);

% loop to compute subsampled estimates
for i=1:M-1
    RCOVSS_mat(i)=RCovSS(LogPrice,i+1); %RCOVSS=0 for K=1
end

% weight vectors
ivec=(2:M)';
% alpha_vec=12*ivec.^(2)/(M^3-M)-6*ivec/(M^2-M);
alpha_vec=12*ivec.^(2)/(M^3-M)-6*ivec/(M^2-1)-6*ivec/(M^3-M);

% compute estimators
MSCRV=alpha_vec'*RCOVSS_mat;




