function RCovSS=RCovSS(LogPrice,K)
%%  RCovSS
%--------------------------------------------------------------
% Subsampled Realized Covariance Estimator
%--------------------------------------------------------------
% INPUT:
% Log-Price -> (n x p) matrix of Log-Prices
% K -> number of subsamples + 1: compute (rescaled) average of (K-1) RCovs on 
% frequency (K-1) based on shifting 1 observation for each Rcov estimate
% Note: rescaling of the average is because of later weighting MSCROV
% E.g. for 15 minute subsampled RV we need: (901/900)*RCovSS(901)
%--------------------------------------------------------------
% OUTPUT:
% RCovSS -> subsampled (p x p) realized covariance estimate
% -------------------------------------------------------------------------
%
% Peter Malec, February 1, 2012
% -------------------------------------------------------------------------
%       
%% Compute Subsampled Realized Covariance

% compute Kth differences
KL=K-1;
Lret=LogPrice(KL+1:end,:)-LogPrice(1:end-KL,:);

% compute estimate
RCovSS=Lret'*Lret/K;