function [avar_var1,avar_var2,avar_cov]=avar_mscrc_bm_m(sigma21,sigma22,sigma12,eta21,eta22,M,n)
%% avar_mscrc_bm
%--------------------------------------------------------------
% asymptotic variance of mscrc estimator of integrated 
% variances and covariances for process with brownian 
% efficient price and iid noise (cross-sectionally independent)
% Note: constant c computed from m,n
%--------------------------------------------------------------
% INPUT:
% sigma21 -> spot variance of asset 1 
% sigma22 -> spot variance of asset 2
% sigma12 -> spot covariance of asset 1,2
% eta21 -> noise variance asset 1
% eta22 -> noise variance asset 2
% M         -> (3x1) vector of bandwidths (var1, var2, cov)
% n        -> number of obs
%--------------------------------------------------------------
% OUTPUT:
% avar_var1 -> asymptotic variance of mscrc estimator of integrated 
% variance of asset 1
% avar_var2 -> asymptotic variance of mscrc estimator of integrated 
% variance of asset 2
% avar_cov   -> asymptotic variance of mscrc estimator of integrated 
% covariance of asset 1,2
% -------------------------------------------------------------------------
%
% Peter Malec, May 8, 2012
%
% -------------------------------------------------------------------------
%   
%%  Asymptotic Variances 

% compute constant c from M,n
c_vec=M(:)/sqrt(n);

% compute quarticities
quart1=sigma21.^2;
quart2=sigma22.^2;

% define vectors
eta2_vec=[eta21;eta22];
eta4_vec=eta2_vec.^2;
sigma2_vec=[sigma21;sigma22];
quart_vec=[quart1;quart2];

% avars of variance estimators
avar_vars=c_vec(1:2).^(-3).*48.*eta4_vec+c_vec(1:2).*(52/35).*quart_vec+c_vec(1:2).^(-1)*(24/5).*(eta4_vec+2.*eta2_vec.*sigma2_vec);
avar_var1=avar_vars(1);
avar_var2=avar_vars(2);

% avars of covariance estimator
c=c_vec(3);
avar_cov=c^(-3)*24*eta21*eta22+c*(26/35)*(sigma12^2+sigma21*sigma22)+...
    c^(-1)*(12/5)*(eta21*eta22+eta21*sigma22+eta22*sigma21);










