function [RC_pre,k] = Preavg_rcov(price,theta,Omega_mat)
%% Preavg_rcov_oracle
%--------------------------------------------------------------
% Preaveraging Realized Covariance following Christensen et al. (JE, 2010)
%--------------------------------------------------------------------------
% INPUT:
% lprice -> (n x p) matrix of prices for p assets
% theta -> scaling factor for length of preaveraging window k
% Omega_mat -> (2x2) noise covariance matrix
%--------------------------------------------------------------
% OUTPUT:
% RC_pre -> preaveraging realized covariance
%  k -> length of preaveraging window in observations
% -------------------------------------------------------------------------
%
% Peter Malec, February 3, 2012
% -------------------------------------------------------------------------
%       
%% Preparations

% returns and size of input matrix
lret=diff(log(price));
N=size(lret,1);

% size of preaveraging window
k=min(max(floor(theta*sqrt(N)),2),N+1);       %   2<= k <= N+1

% psi functions
%------------------------------------------------
g_val=g_func((0:k)/k);      % for i=0,...,k
g_val_i=g_val(2:end);       % for i=1,...,k
g_val_li=g_val(1:end-1);       % for i=0,...,k-1
psi_1=k*sum((g_val_i-g_val_li).^2);
psi_2=(1/k)*sum(g_val_i(1:end-1).^2);
% -------------------------------------------------------------------------
%       
%% Compute Estimator

% Preaveraged Returns
Pre_lret=preaavg_ret(lret,k);

% Multiplicative Factor
Mult_fac=N/((N-k+2)*psi_2*k);

% Bias correction
BCorr=(psi_1/(theta^(2)*psi_2))*Omega_mat;

% Estimator
RC_pre=Mult_fac*(Pre_lret'*Pre_lret)-BCorr;

