function [avar_var1,avar_var2,avar_cov]=avar_preavg_bm(sigma21,sigma22,sigma12,eta21,eta22,theta)
%% avar_preavg_bm
%--------------------------------------------------------------
% asymptotic variance of preaveraging estimator of integrated 
% variances and covariances for process with brownian 
% efficient price and iid noise (cross-sectionally independent)
% Note: for g(x)=min(x,1-x)
%--------------------------------------------------------------
% INPUT:
% sigma21 -> spot variance of asset 1 
% sigma22 -> spot variance of asset 2
% sigma12 -> spot covariance of asset 1,2
% eta21 -> noise variance asset 1
% eta22 -> noise variance asset 2
% theta -> proportionality factor of window length
%--------------------------------------------------------------
% OUTPUT:
% avar_var1 -> asymptotic variance of estimator of integrated 
% variance of asset 1
% avar_var2 -> asymptotic variance of estimator of integrated 
% variance of asset 2
% avar_cov   -> asymptotic variance of estimator of integrated 
% covariance of asset 1,2
% -------------------------------------------------------------------------
%
% Peter Malec, April 14, 2012
% -------------------------------------------------------------------------
%   
%%  Asymptotic Variances 

% compute quarticities
quart1=sigma21.^2;
quart2=sigma22.^2;

% define vectors
eta2_vec=[eta21;eta22];
eta4_vec=eta2_vec.^2;
sigma2_vec=[sigma21;sigma22];
quart_vec=[quart1;quart2];

% avars of variance estimators
avar_vars=((151/80640)*theta*quart_vec+(48*theta)^(-1)*sigma2_vec.*eta2_vec+eta4_vec/(6*theta^3))*576;
avar_var1=avar_vars(1);
avar_var2=avar_vars(2);

% avars of covariance estimator
avar_cov=((151/80640)*theta*(sigma12^2+sigma21*sigma22)+(eta21*sigma22+eta22*sigma21)/(96*theta)+...
    (6*theta^3)^(-1)*eta21*eta22)*288;











