function Pre_lret_mat=preaavg_ret(lret_mat,k)
%% preaavg_ret
%--------------------------------------------------------------
% Computation of preaveraged returns for preaveraged
% realized covariance
%--------------------------------------------------------------
% INPUT:
% lret_mat -> (n x p) matrix of log-returns for p assets
% k -> length of preaveraging window in observations
%--------------------------------------------------------------
% OUTPUT:
% Pre_lret_mat -> ((n-k+2)*p) matrix of preaveraged returns
% -------------------------------------------------------------------------
%
% Peter Malec, February 3, 2012
% -------------------------------------------------------------------------
%       
%%  Preparations

% size of return matrix
[n,p]=size(lret_mat);

% values of g-function within preaveraging windows
g_val=g_func((1:k-1)/k);          % (k-1)x1 vector
% -------------------------------------------------------------------------
%       
%%  Compute preaveraged returns

% empty matrix
Pre_lret_mat=NaN*zeros(n-k+2,p);

% loop
%----------------------------------------
for i=0:(n-k+1)
    
    % choose returns to average
    lret_wind=lret_mat(i+(1:k-1),:);
    
    % preaveraged returns
    Pre_lret_mat(i+1,:)=(lret_wind'*g_val)';
    
end








