function Hval= HvalParzenOmega_2x2_noss(data_a1,data_a2,nval)
%% HvalParzenOmega_2x2_noss
%--------------------------------------------------------------
% Vector of optimal univariate bandwidths for realized kernel (parzen) in
% (2x2) case. No subsampling for estimatin of IQ
%--------------------------------------------------------------
% INPUT:
% data_a1 -> (n_a x 2) matrix of (asynchronous) data for asset 1
%       - 1st  col: observation times 
%       - 2nd col: prices 
% nval -> number of refreshed returns
%--------------------------------------------------------------
% OUTPUT:
% Hval     -> average optimal bandwidth
% -------------------------------------------------------------------------
%
% Peter Malec, January 6, 2012
% -------------------------------------------------------------------------
%       
%% Estimation of Noise Variances for both assets separately

% Retain nonzero returns
rtn_nz1=diff(log(data_a1(logical([1;diff(data_a1(:,2))~=0]),2)));
rtn_nz2=diff(log(data_a2(logical([1;diff(data_a2(:,2))~=0]),2)));
    
% estimation of noise variance
omegahat2_1=max([0  abs(noise_cov_est(rtn_nz1,'var'))]);
omegahat2_2=max([0  abs(noise_cov_est(rtn_nz2,'var'))]);
% -------------------------------------------------------------------------
%  
%% Estimation of integrated quarticity for both assets separately       

% Estimate  15 min RVs using Kevin Sheppard's Proc
[~,rvSS1]=realized_variance(data_a1(:,2),data_a1(:,1),'Seconds','CalendarTime',900);
[~,rvSS2]=realized_variance(data_a2(:,2),data_a2(:,1),'Seconds','CalendarTime',900);

% Estimate IQ as IV^2: sqrt(IQ)==RV
IVhat=[rvSS1;rvSS2];
% -------------------------------------------------------------------------
%  
%% Compute Bandwidths  

% noise to signal ratios
nts_ratio = [omegahat2_1; omegahat2_2]./IVhat;         

%constant depending on kernel type (Parzen)
cstar = ((12^2)/(0.269))^(1/5); 

% optimal bandwidth for each asset
Hval_vec = cstar.*nts_ratio.^(2/5).*nval^(3/5);     

% average optimal bandwidth
Hval = nanmean(Hval_vec);               