function Hval= HvalParzenOmega_OM_IQ(Omega_mat,IQ_mat,nval)
%% HvalParzenOmega_OM_IQ
%--------------------------------------------------------------
% Average of vector of optimal univariate bandwidths for realized kernel (parzen). 
% Noise Cov and IQ supplied.
%--------------------------------------------------------------
% INPUT:
% Omega_mat -> Estimate of Noise Covariance for Bandwidth Choice
% IQ_mat -> Estimate of integrated quarticity for Bandwidth Choice
% nval -> number of refreshed returns
%--------------------------------------------------------------
% OUTPUT:
% Hval     -> average optimal bandwidth
% -------------------------------------------------------------------------
%
% Peter Malec, January 9, 2012
% -------------------------------------------------------------------------
%       
%% Prepare Estimates of Noise Variance and Integrated Quarticity

% noise variance
omegahat2=max([diag(Omega_mat) zeros(size(Omega_mat,1),1)],[],2);  % variance has to be positive

% Integrated Quarticity
IVhat=diag(IQ_mat);
% -------------------------------------------------------------------------
%  
%% Compute Bandwidths  

% noise to signal ratios
nts_ratio = omegahat2./IVhat;         

%constant depending on kernel type (Parzen)
cstar = ((12^2)/(0.269))^(1/5); 

% optimal bandwidth for each asset
Hval_vec = cstar.*(nts_ratio).^(2/5).*nval^(3/5);     

% average optimal bandwidth
Hval = nanmean(Hval_vec);               