function [Hvalstar] =Hval_crk(RFTrtn,crk_cov)
% determines  optimal bandwidth Hval for estimation of (2x2)- submatrices
% to obtain composite realized kernel estimate according to LSS (2011) 

%INPUTS:
%%%%%%%
%RFTrtn >>> log-returns obtained from refresh-time sampling
%crk_cov >>> estimate of (2x2)- submatrix using crk based on average
%bandwidths

%Output:
%%%%%%%
%Hvalstar >>> optimal bandwidth according to LSS (2011) 



% Peter Malec
% July 28, 2011

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%Re-Arrange Data

[n p] = size(RFTrtn);


%%%%%%%%%%%%%%
%Compute weighted average of noise variances and covariances
%%%%%%%%%%%%%%

%Estimate noise long-run-covariance matrix using HAC(1) estimator

Sigma_hat=(RFTrtn'*RFTrtn+0.5*RFTrtn(2:end,:)'*RFTrtn(2:end,:))/(2*n);

%Define A matrix

A=[Sigma_hat(1,1);Sigma_hat(1,2);Sigma_hat(2,2)];

%Define v-vector

v=[(-0.5)*crk_cov(2,1)/crk_cov(1,1);1;(-0.5)*crk_cov(2,1)/crk_cov(2,2)];


%weighted average of noise variances and covariances (omega)

omega=v'*A/sqrt(crk_cov(1,1)*crk_cov(2,2));



%%%%%%%%%%%%%%
%Compute weighted average of  Integrated Quarticities
%%%%%%%%%%%%%%

%Compute Matrix of Integrated Quarticities

B=zeros(3,3);


B(logical(diag(1:2,1)))=[2*crk_cov(1,1)*crk_cov(1,2);2*crk_cov(2,2)*crk_cov(1,2)];
B(1,3)=2*crk_cov(1,2)^2;

B=B+B';     %mirror across main diagonal
B(logical(eye(3)))=[2*crk_cov(1,1)^2;crk_cov(1,1)*crk_cov(2,2)+crk_cov(1,2)^2;2*crk_cov(2,2)^2];        %set elements on main diagonal


%weighted average of Integrated Quarticities (IQ)

IQ=v'*B*v/(crk_cov(1,1)*crk_cov(2,2));



%%%%%%%%%%%%%%
%Compute optimal bandwidth
%%%%%%%%%%%%%%

%Compute Noise-to-Signal-Ratio

NtS=omega^2/IQ;


%Compute cstar 

cstar = ((12^2)/(0.269))^(1/5);         %depends on kernel derivatives>>tabulated for parzen kernel (BNHLS_2008b)


%Compute optimal bandwidth

Hvalstar = cstar*(NtS)^(1/5)*(n)^(3/5);            %optimal bandwidth 












