function [Hvalstar] =Hval_crk_oracle(n,ICov,ICoQuart,Sigma_hat)
% determines  optimal bandwidth Hval for estimation of (2x2)- submatrices
% to obtain composite realized kernel estimate according to LSS (2011) 
% oracle version

%INPUTS:
%%%%%%%
% n >>> number of log-returns obtained from refresh-time sampling
% ICov>>> (2x2) integrated covariance matrix
% ICoQuart >>> (6x1) vector of integrated coquarticities
% Sigma_hat >>> (2x2) noise covariance matrix

%Output:
%%%%%%%
%Hvalstar >>> optimal bandwidth according to LSS (2011) 

% Peter Malec
% January 30, 2012

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%
%Compute weighted average of noise variances and covariances
%%%%%%%%%%%%%%

%Define A matrix
A=[Sigma_hat(1,1);Sigma_hat(1,2);Sigma_hat(2,2)];

%Define v-vector
v=[(-0.5)*ICov(2,1)/ICov(1,1);1;(-0.5)*ICov(2,1)/ICov(2,2)];


%weighted average of noise variances and covariances (omega)
omega=v'*A/sqrt(ICov(1,1)*ICov(2,2));


%%%%%%%%%%%%%%
%Compute weighted average of  Integrated Quarticities
%%%%%%%%%%%%%%

%Compute Matrix of Integrated Quarticities
B=zeros(3,3);
B(logical(diag(1:2,1)))=[2*ICoQuart(5);2*ICoQuart(6)];
B(1,3)=2*ICoQuart(3);
B=B+B';     %mirror across main diagonal
B(logical(eye(3)))=[2*ICoQuart(1);ICoQuart(4)+ICoQuart(3);2*ICoQuart(2)];        %set elements on main diagonal

%weighted average of Integrated Quarticities (IQ)
IQ=v'*B*v/(ICov(1,1)*ICov(2,2));

%%%%%%%%%%%%%%
%Compute optimal bandwidth
%%%%%%%%%%%%%%

%Compute Noise-to-Signal-Ratio
NtS=omega^2/IQ;

%Compute cstar 
cstar = ((12^2)/(0.269))^(1/5);         %depends on kernel derivatives>>tabulated for parzen kernel (BNHLS_2008b)

%Compute optimal bandwidth
Hvalstar = cstar*(NtS)^(1/5)*(n)^(3/5);            %optimal bandwidth 












