function [Hvalstar] =Hval_mrk_oracle(n,IQuart,Sigma_hat)
% determines optimal bandwidth Hval for estimation of (2x2)- covariance
% matrix as maximum value of univariate bandwidths based on oracle inputs

%INPUTS:
%%%%%%%
% n >>> number of log-returns obtained from refresh-time sampling
% ICoQuart >>> (2x1) vector of integrated quarticities
% Sigma_hat >>> (2x1) vector of noise variances

%Output:
%%%%%%%
%Hvalstar >>> optimal bandwidth 

% Peter Malec
% March 21, 2012

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%
%Compute optimal bandwidth
%%%%%%%%%%%%%%

% Compute Noise-to-Signal-Ratio
NtS=Sigma_hat(:)./sqrt(IQuart(:));

% Compute cstar 
cstar = ((12^2)/(0.269))^(1/5);         %depends on kernel derivatives>>tabulated for parzen kernel (BNHLS_2008b)

% Compute optimal bandwidth
Hvalstar_vec = cstar*(NtS).^(2/5)*(n)^(3/5);            %optimal bandwidth 

% Joint Bandwidth is max
Hvalstar=max(Hvalstar_vec);











