function [mrk_est] = MRK_2x2_sync_nb(data_a1,data_a2,Hvalstar)
%% MRK_2x2_sync_nb
%--------------------------------------------------------------
% Bivariate Realized Kernel estimation as stated in BNHLS (2009) 
% for the (2x2) case with synchronous data. 
% Note: bandwidth has to be provided
%--------------------------------------------------------------
% INPUT:
% data_a1 -> (n_a x 2) matrix of (synchronous) data for asset 1
%       - 1st  col: observation times 
%       - 2nd col: prices 
% Hvalstar -> bandwidth
%--------------------------------------------------------------
% OUTPUT:
% mrk_est-> (2x2) matrix of integrated covariance 
% -------------------------------------------------------------------------
%
% Peter Malec, February 10, 2012
% -------------------------------------------------------------------------
%       
%% refreshtime sampling

%price _rft is (n_rft x 2) matrix
if size(data_a1,2)>1
    price_rft=[data_a1(:,2) data_a2(:,2)];
else
    price_rft=[data_a1 data_a2];
end
    
% Jittering: average over first and last two obs

price_rftJ =[mean(price_rft(1:2,:),1); price_rft(3:(end-2),:); mean(price_rft((end-1):end,:),1)]; 

% Returns (RFT)
rtn_rft = diff(log(price_rftJ)); 
% -------------------------------------------------------------------------
%       
%% Compute MRK based on jointly optimal bandwidth

mrk_est=MRK(rtn_rft,Hvalstar);                

                                                                           
                                                                           

