function [mrk_corr, Hvalstar] = MRK_2x2_sync_optb_oracle(data_a1,data_a2,Omega_mat,ICov,ICoQuart)
%% MRK_2x2_sync
%--------------------------------------------------------------
% Bivariate Realized Kernel estimation as stated in BNHLS (2009) 
% for the (2x2) case with synchronous data. Adjustment of bandwidth selection
% following (LSS, 2011).
% NOTE: oracle version
%--------------------------------------------------------------
% INPUT:
% data_a1 -> (n_a x 2) matrix of (synchronous) data for asset 1
%       - 1st  col: observation times 
%       - 2nd col: prices 
% startt -> start of trading (in hours)
% Omega_mat -> (2x2) noise covariance matrix
% ICov   -> (2x2) integrated covariance matrix
% ICoQuart -> (6x1) vector of integrated coquarticities
%--------------------------------------------------------------
% OUTPUT:
% mrk_corr-> (2x2) matrix of integrated covariance using jointly optimal
% bandwidth
% Hvalstar -> corresponding bandwidth
% -------------------------------------------------------------------------
%
% Peter Malec, January 6, 2012
% -------------------------------------------------------------------------
%       
%% refreshtime sampling

%price _rft is (n_rft x 2) matrix
price_rft=[data_a1(:,2) data_a2(:,2)];

% Jittering: average over first and last two obs

price_rftJ =[mean(price_rft(1:2,:),1); price_rft(3:(end-2),:); mean(price_rft((end-1):end,:),1)]; 

% Returns (RFT)
rtn_rft = diff(log(price_rftJ)); 

% number of returns (RFT)
n_rft=size(rtn_rft,1);      
% -------------------------------------------------------------------------
%       
%% MRK based on jointly optimal bandwidth

 % Compute jointly optimal bandwidth (2x2) bandwidth following LSS (2011)
 Hvalstar = Hval_crk_oracle(n_rft,ICov,ICoQuart,Omega_mat);        %oracle version !!!
 Hvalstar = nanmax(1, nanmin(Hvalstar, n_rft-1));% sanity check  
                                                                % Note: autocov of higher orders than n2-1 cannot be computed  

                                                                % Compute MRK estimates using jointly optimal bandwidth                                                                         
mrk_corr=MRK(rtn_rft,Hvalstar);                

                                                                           
                                                                           

