function [LLH] = LLH_MA_1_Exact(theta,y)
%% LLH_MA_1_Exact
%--------------------------------------------------------------
% Exact likelihood function (mu=0) following Hamilton pp.128
%--------------------------------------------------------------
% INPUT:
% theta -> (2 x 1) parameter vector: [theta;sigma2]
% y -> (nx1) vector of observations
%--------------------------------------------------------------
% OUTPUT:
% LLH -> (-1) x value of log-likelihood function
% -------------------------------------------------------------------------
%
% Peter Malec, January 31, 2012
%
% based on code by Gustav Haitz
% -------------------------------------------------------------------------
%       
%% Preparations

% Input Check
if size(theta,1) ~= 2
    error('Current specification: inputs theta and sigma!') ;
end

% Extract Parameters
sigma2 = theta(2);   
theta = theta(1);

 % number obs
 n = size(y,1);
% -------------------------------------------------------------------------
%       
%% Compute Likelihood
 
%  geometric theta  series
exp_vec=2*(1:n)';        %exponent
thetaExpand=1+cumsum(theta.^exp_vec);  %theta series

% d series
d = sigma2*thetaExpand./[1;thetaExpand(1:end-1)];

% ytildetheta series: quotient in yTilde
yTildeTheta = (theta.*[0;1;thetaExpand(1:end-2)])./([1;thetaExpand(1:end-1)]);

% ytilde series
%-----------------------------
yTilde  = zeros(n,1);
yTilde(1) = y(1);

 for i=2:n
 yTilde(i) = y(i) - yTildeTheta(i)*yTilde(i-1);
 end
 
% Log - Likelihood (x (-1))
%-----------------------------
LLH = -n*log(2*pi) - sum(log(d)) - sum(((yTilde.^2)./d));
LLH = -0.5.*LLH;        % we take (-1) * LL

end