function [avar_var1,avar_var2,avar_cov]=avar_qml_bm(sigma21,sigma22,sigma12,eta21,eta22)
%% avar_preavg_bm
%--------------------------------------------------------------
% asymptotic variance of the qml estimator of integrated 
% variances and covariances for process with brownian 
% efficient price and iid noise (cross-sectionally independent)
%--------------------------------------------------------------
% INPUT:
% sigma21 -> spot variance of asset 1 
% sigma22 -> spot variance of asset 2
% sigma12 -> spot covariance of asset 1,2
% eta21 -> noise variance asset 1
% eta22 -> noise variance asset 2
%--------------------------------------------------------------
% OUTPUT:
% avar_var1 -> asymptotic variance of estimator of integrated 
% variance of asset 1
% avar_var2 -> asymptotic variance of estimator of integrated 
% variance of asset 2
% avar_cov   -> asymptotic variance of estimator of integrated 
% covariance of asset 1,2
% -------------------------------------------------------------------------
%
% Peter Malec, April 14, 2012
% -------------------------------------------------------------------------
%   
%%  Asymptotic Variances of variance estimators


% define vectors
eta_vec=sqrt([eta21;eta22]);
sigma_vec=sqrt([sigma21;sigma22]);

% avars 
avar_vars=8*eta_vec.*sigma_vec.^3;
avar_var1=avar_vars(1);
avar_var2=avar_vars(2);
% -------------------------------------------------------------------------
%   
%%  Asymptotic Variances of covariance estimator

% "star" epressions
sigma2st1=sigma21+sigma22+2*sigma12;
sigma2st2=sigma2st1-4*sigma12;
a2st1=eta21+eta22;
a2st2=a2st1;

%"v" expressions
%------------------------------
v1m1=8*sqrt(sigma2st1)^3*sqrt(a2st1);
vm11=8*sqrt(sigma2st2)^3*sqrt(a2st2);
v11=(16/(sqrt(a2st1)*(sqrt(sigma2st1)+sqrt(sigma2st2))^3))*(...
    (a2st1/2)*(sigma2st1+sigma2st2+3*sqrt(sigma2st1*sigma2st2))*(sigma21-sigma22)^2+...
    (eta21-eta22)*sigma2st1*sigma2st2*(sigma21-sigma22)+...
    (eta21-eta22)^2*sqrt(sigma2st1*sigma2st2)^(3)/(2*a2st1));

% avar
a_vec=[1/4 -1/4];
avar_cov=a_vec*[v1m1 v11;v11 vm11]*a_vec';











