function [iSigma_hat,H_mat_hat,output1,output2,output12s,output12d]=rcov_qmle(data_a1,data_a2,iSigma,H_mat,options)
%% rcov_qmle
%--------------------------------------------------------------
% QMLE of integrated covariance following Ait-Sahalia et al. (JASA, 2010)
%--------------------------------------------------------------
% INPUT:
% data_a1 -> (n_a x 1) vector of synchronous price data for asset 1
% isigma-> starting value for (2x2) integrated covariance matrix estimate
% H_mat -> starting value for (2x2) covariance matrix of noise
% options -> options for optimization
%--------------------------------------------------------------
% OUTPUT:
% iSigma_hat -> (2 x 2) matrix containg estimates of integrated (co-)
% volatilities
% H_mat_hat -> estimate of (2 x 2) noise covariance matrix
% output-> output structures from optimization procedures
% -------------------------------------------------------------------------
%
% Peter Malec, January 31, 2012
% -------------------------------------------------------------------------
%       
%% Estimate integrated variances

% asset 1
[iSigma_hat1,H_mat_hat1,output1]=rv_qmle(log(data_a1),iSigma(1,1),H_mat(1,1),options);

% asset 2
[iSigma_hat2,H_mat_hat2,output2]=rv_qmle(log(data_a2),iSigma(2,2),H_mat(2,2),options);
% -------------------------------------------------------------------------
%       
%% Estimate integrated co-variance

% consider sum lof log-prices
sum_lprice=log(data_a1)+log(data_a2);
sum_iSigma=iSigma(1,1)+iSigma(2,2)+2*iSigma(1,2);
sum_Hmat=H_mat(1,1)+H_mat(2,2)+2*H_mat(1,2);
[iSigma_hat12s,H_mat_hat12s,output12s]=rv_qmle(sum_lprice,sum_iSigma,sum_Hmat,options);

% consider difference lof log-prices 
diff_lprice=log(data_a1)-log(data_a2);
diff_iSigma=iSigma(1,1)+iSigma(2,2)-2*iSigma(1,2);
diff_Hmat=H_mat(1,1)+H_mat(2,2)-2*H_mat(1,2);
[iSigma_hat12d,H_mat_hat12d,output12d]=rv_qmle(diff_lprice,diff_iSigma,diff_Hmat,options);

% Integrated and Noise Covariance Estimates
iSigma_hat12=(iSigma_hat12s-iSigma_hat12d)/4;
H_mat_hat12=(H_mat_hat12s-H_mat_hat12d)/4;
% -------------------------------------------------------------------------
%       
%% Join Output Matrices

% integrated covariance matrix
iSigma_hat=[iSigma_hat1 iSigma_hat12;iSigma_hat12 iSigma_hat2];

% noise covariance matrix
H_mat_hat=[H_mat_hat1 H_mat_hat12;H_mat_hat12 H_mat_hat2];


