function MRK_func(ticker_a,tdate,typed,cl_ind,rev_ind,...
    inpath,sourced,outpath)
%% MRK_func
%--------------------------------------------------------------
% multivariate realised kernel estimation
% following BNHLS (2011, JE)
% of integrated covariance matrices. Data
% is loaded. Outputs are saved directly
%
%--------------------------------------------------------------
% INPUT:
% ticker_a -> (mx1) cell array of ticker symbols (strings)
% tdate   -> data in matlab format
% cl_ind    -> if ==1, data cleaned according to proc by BNHLS(2009) is used
% rev_ind    -> if ==1, only obs with price revisions are used
% inpath     -> path for loading data
% sourced   -> data source
% outpath  -> path for saving
%--------------------------------------------------------------
%
% Peter Malec,  April 20 2016 
%
% -------------------------------------------------------------------------
%   
%% Load Data

% clean?
if cl_ind==1
     cl_str='cl';            % cleaning string for output file
else
     cl_str='ncl';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end


% no of stocks
m=length(ticker_a);

% check for existence of files
%-----------------------------------------------------------------------------------
name_arr=cell(m,1);
index_v=NaN*zeros(m,1);

for i=1:m
    name_arr{i}=strcat(inpath,ticker_a{i},filesep,ticker_a{i},'_',datestr(tdate,'yyyymmdd'),'_',typed,'_',cl_str,'.mat');
    index_v(i)=isequal(exist(name_arr{i},'file'),2);
end

if isequal(sum(index_v),m)
%---------------------------------------------------------

%empty cell array
PRICES=cell(m,1);
TIMES=cell(m,1);

% loop across assets
for i=1:m
    load(name_arr{i});
    if isequal(typed,'trades')
        midprice=trades;
    end
    if rev_ind==1
        midprice=keep_rev(midprice,2);
    end
    PRICES{i}=midprice(:,2);
    TIMES{i}=midprice(:,1);
end
% -------------------------------------------------------------------------
%   
%% Compute MRK Estimates

 
[rmk,diagnostics]=realized_multivariate_kernel(PRICES,TIMES,'seconds',1);

% Save outputs
%----------------------------------------------

%basename
if m>2
    basename=strcat(outpath,sourced,'_',datestr(tdate,'yyyymmdd'),typed,'_d',int2str(m),'_',cl_str,rev_str);

elseif isequal(m,2)
    basename=strcat(outpath,sourced,'_',ticker_a{1},'_',ticker_a{2},'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str);

else
    basename=strcat(outpath,sourced,'_',ticker_a{1},'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str);
end        

%save integrated covariance matrices
mrk_nout=strcat(basename,'_MRK');
save(mrk_nout,'rmk')
%save diagnostics
diag_nout=strcat(basename,'_MRK_diag');
save(diag_nout,'diagnostics')

%file do not exist: do nothing
%----------------------------------------
else
    disp(['Data missing for the following tickers: ' ticker_a{logical(1-index_v)} '. Skip day.'])
end



    
  
    