function RV_ss_func(ticker,tdate,typed,cl_ind,rev_ind,...
    freq,nss,inpath,sourced,outpath)
%% RV_ss_func
%--------------------------------------------------------------
% sub-sampled rv estimation. Date is loaded. Outputs are saved directly
%--------------------------------------------------------------
% INPUT:
% ticker -> ticker symbol (string)
% tdate   -> data in matlab format
% cl_ind    -> if ==1, data cleaned according to proc by BNHLS(2009) is used
% rev_ind    -> if ==1, only obs with price revisions are used
% freq    -> sampling frequency in seconds
% nss    -> no of subsamples (empty if no subsampling)
% inpath     -> path for loading data
% sourced   -> data source
% outpath  -> path for saving
%--------------------------------------------------------------
%
% Peter Malec,  march 26, 2014 
%
% -------------------------------------------------------------------------
%   
%% Load Data

% clean?
if cl_ind==1
     cl_str='cl';            % cleaning string for output file
else
     cl_str='ncl';
end


% check for existence of file
%-----------------------------------------------------------------------------------
name=strcat(inpath,ticker,filesep,ticker,'_',datestr(tdate,'yyyymmdd'),'_',typed,'_',cl_str,'.mat');
index=isequal(exist(name,'file'),2);

if index
%---------------------------------------------------------
load(name);
if isequal(typed,'trades')
        midprice=trades;
end
if rev_ind==1
        midprice=keep_rev(midprice,2);
end
% -------------------------------------------------------------------------
%   
%% Compute RV estimates

% Estimate RVss
%------------------------------
if ~isempty(nss)
    [rv,rvSS]=realized_variance(midprice(:,2),midprice(:,1),'seconds','CalendarTime',freq,nss);
else
    [rv]=realized_variance(midprice(:,2),midprice(:,1),'seconds','CalendarTime',freq);
end
% -------------------------------------------------------------------------
%   
%% Save outputs

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

%save estimates
%-----------------------------------------------------
if ~isempty(nss)
    basename=strcat(outpath,'rv_',sourced,'_',ticker,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                '_freq',int2str(freq),'_nss',int2str(nss));
    rvest.rv=rv;
    rvest.rvSS=rvSS;
 else
   basename=strcat(outpath,'rv_',sourced,'_',ticker,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                '_freq',int2str(freq));
  rvest.rv=rv;          
end
save(basename,'rvest')     


%file do not exist: do nothing
%----------------------------------------
else
    disp(['Data missing for ticker: ' ticker '. Skip day.'])
end



    
  
    