function [Cov_mat]=noise_cov_est(price,est_type)
%% noise_cov_est
%--------------------------------------------------------------
% Estimates (2 x 2) covariance matrix for i.i.d. or dependent microstructure noise
%--------------------------------------------------------------
% INPUT:
% price -> (n x 2) matrix of (synchronized) price data for 2 assets
% est_type -> type of estimator:
%       -- 'cov': autocovariance based (default)
%       -- 'var': variance based 
%       -- 'HAC: long-run covarinace estimator
%--------------------------------------------------------------
% OUTPUT:
% Cov_mat -> (2 x 2) matrix containg estimates of noise (co-variances)
% -------------------------------------------------------------------------
%
% Peter Malec, December 6, 2011
% update December 14, 2011: HAC version included
% -------------------------------------------------------------------------
%       
%% Determine type of estimator

if nargin <2
    est_ind=1;
else
    if isequal(est_type,'cov')
         est_ind=1;
    elseif isequal(est_type,'var')
        est_ind=2;
    elseif isequal(est_type,'HAC')
        est_ind=3;
    else
        error('choose "cov" or "var" or "HAC" as estimator type')
    end
end
% -------------------------------------------------------------------------
%
%% Compute Estimators

% log-prices and  number of obs
lprice=log(price);
n_obs=length(price);

% covariance based estimator
% ----------------------------------
if   est_ind==1
    Cov_mat=-(1/(n_obs-2))*diff(lprice(1:end-1,:))'*(lprice(3:end,:)-lprice(2:end-1,:));        %multiply 1st diff with forward 1st diff
    
% variance based estimator
% ----------------------------------
    elseif est_ind==2
    Cov_mat=(1/(2*(n_obs-1)))*diff(lprice)'*diff(lprice);    
    
 % HAC based estimator
% ----------------------------------
    elseif est_ind==3
    Cov_mat=(diff(lprice)'*diff(lprice)+0.5*diff(lprice(2:end,:))'*(lprice(2:end-1,:)-lprice(1:end-2,:)))/(2*(n_obs-1));
end

