function pticdata = ptic_inter(pricedata, obsdata, freqval, offset)
%------------------------------------------------------------------
%% pticinter
% Previous tick interpolation for Lada's QPL data
%------------------------------------------------------------------
%
% INPUTS
% pricedata -> (nxp) matrix of price observations incl NaNs
% obsdata   -> (nxp) matrix of observation indices
% freqval    -> calendar time sampling frequency in seconds
% offset      -> we delay start by offset seconds. NOTE: HAS to be 900
% like price data (15 min delay). 
%------------------------------------------------------------------
% OUTPUTS
% pticdata -> (n2 x p) matrix of interpolated prices with 
% n2= (2340-offset)/freqval+1, containing NaNs 
% where no observations available.
%------------------------------------------------------------------
%
%Peter Malec,January 23, 2012
%
% based on code by Lada Kyj
%
%% Prepare grids

% get dimensions
[n p] = size(pricedata);


% sampling grid in seconds  (measured after 9:30) 
grid = (offset +1):freqval:23401;    %23401>>+ one obs for the start  
                                                                                                                                                  

% create vector with zeros where no sampling occurs
%--------------------------------------------------------------

% initialize
prevtime = zeros(1,n);  

% loop
for i= grid
    prevtime(i-offset) = max(offset, 1);      %starts one sec after offset, goes to 23401. Places offset at sampling times
end                                                                                                
%------------------------------------------------------------------
%
%% Determines Latest observation indices at sampling times

% initialize vector for indices of last observations       
rtc = NaN*zeros(1,p);    % if no obs: nan and not 0!

% initialize output matrix
myrtc = []; 

% loop to determine obsrvation indices at sampling times
%--------------------------------------------------------------
for i=1:n
    
    % latest observation index for each asset at time i 
    rtc(logical(obsdata(i,:))) = i;  
    
    % check if we are at sampling timepoint (prevtime(i)=offset)
    if (logical(prevtime(i)))     
        myrtc = [myrtc; rtc];  % if yes, then save latest obs indices
    end
end
%------------------------------------------------------------------
%
%% Sample Prices at observation times

% size of matrix of observation indices
[n2 p2] = size(myrtc);

%initialize output matrix
pticdata = NaN*zeros(n2,p2);
    
% loop for sampling prices
%--------------------------------------------------------------                           
for k=1:p2
    
    % indices of obs of kth asset, where no NaN at sampling times
    idgood = find(myrtc(:,k) > 0);   
    
    % sample prices
    pticdata(idgood, k) =  pricedata(myrtc(idgood,k),k);  
end                                                                               
                                                                                              
                                                                                                           

