function BiaNg = BiaNg2002(covariance,maxM,Tval, k)
%% BiaNg2002
%--------------------------------------------------------------
% Computes Bia NG Critera
% Note: Corrected for possibly negative eigenvalues
%--------------------------------------------------------------
%INPUTS
%covariance -> we need to assume that endog variables of PCA have zero mean
%                       note: computed eigenvalues are variances of factors, transpose of
%                       eigenvector matrix contains loading
%maxM -> maximum number of factors (cap K in formula)
%Tval    -> number of obs (T in formula)
%          k -> number of dimensions (p in formula)
%--------------------------------------------------------------
%
%% Compute Criteria

% spectral decomposition
[Q S]=eig(covariance);
    
%replace negative eigenvalues by zeros
S=diag(S);
S_neg_ind=S<0;
S(S_neg_ind)=zeros(sum(S_neg_ind),1);
    
% sort eigenvalues by size
[S,ix]=sort(S,'descend');
Q=Q(:,ix);

% retain maxM factors
S=S(1:maxM);
Q=Q(:,1:maxM);

%compute cov matrix of errors
Sigma2M = mean(diag(covariance-Q*diag(S)*Q'));  % diff between observed cov matrix and cov matrix predicted by factors (for max number of factors)
                                                                     %>>>estimate sigma^2(K) from formula by averaging over est variances of the individual errors

%empty matrix for biaNg criterion for every number of factors                                                                                   
BiaNg = NaN*zeros(maxM, 2);                                                 %2 columns (2 indicators)

% loop over possible numbers of factors
for m = 1:maxM
    
    % choose m factors
    Sm=S(1:m);
    Qm=Q(:,1:m);
    % biaNg1 for m factors 
    BiaNg(m,1) = mean(diag(covariance-Qm*diag(Sm)*Qm')) + m*Sigma2M*((k+Tval)/(k*Tval))*log((k*Tval)/(k+Tval));          %(sigma^2(k) from formula estimated as for max number of factors above)
    % biaNg2 for m factors
    BiaNg(m,2) = mean(diag(covariance-Qm*diag(Sm)*Qm')) + m*Sigma2M*((k+Tval)/(k*Tval))*log((min(sqrt(k),sqrt(Tval)))^2); % (sigma^2(k) from formula estimated as for max number of factors above)
end
