function [cov_cl lambda_cl] = eigenval_clean(cov_org,lambda_sign,n_obs,first)
%% eigenval_clean
%--------------------------------------------------------------------------
% eigenvalue cleaning following Hautsch,Kyj & Oomen (2010)
% Note: matrix does NOT have to be psd. neg eigenvalues are replaced
% by zeros and drop out in cleaning procedure (below threshold, which is
% positive by construction)
%--------------------------------------------------------------------------
%INPUTS
%cov_org -> original covariance matrix (pxp)
% lambda_sign -> (px1) vector containing signs of eigenvalues that were
%                       ordered according to magnitude
%n_obs -> observations used for computation
% first -> if >0: max eigenvalue according to marchenko-pastur distribution
% computed excluding the maximal eigenvalue
%Outputs
% cov_cl -> cleaned covariance matrix
% lambda -> vector of clean correlation eigenvalues
%--------------------------------------------------------------------------
%
%% Regularize Cov Matrix

p=size(cov_org,1);

%compute correlation matrix

corr_org=diag(diag(cov_org).^(-.5))*cov_org*diag(diag(cov_org).^(-.5));


%perform singular value decomposition
[u s v]=svd(corr_org);

%obtain eigenvalues from singular values
lambda=diag(s).*lambda_sign;

%compute max eigenvalue according to marchenko pastur distribution
%--------------------------------------------------------------------------
if first>0
 
    lambda_max=(1-lambda(1)/p)*(1+p/n_obs+2*sqrt(p/n_obs));%tightening of the threshold value
    
else

    lambda_max=1+p/n_obs+2*sqrt(p/n_obs);
    
end


%identify small eigenvalues
lambda_sm_ind=lambda<=lambda_max;


%compute clean eigenvalues
lambda_t=sum(max(lambda(lambda_sm_ind),0))/length(lambda(lambda_sm_ind));


%compute clean covariance matrix
%--------------------------------------------------------------------------
lambda_cl=lambda;
lambda_cl(lambda_sm_ind)=lambda_t*ones(sum(lambda_sm_ind),1);

corr_cl=u*diag(lambda_cl)*u';

cov_cl=diag(diag(cov_org).^(.5))*corr_cl*diag(diag(cov_org).^(.5));






    
    




