function [cov_cl lambda_cl] = eigenval_clean_faster_tr(cov_org,n_obs,first)
%eigenvalue cleaning following Hautsch,Kyj & Oomen (2010)
% faster version using eig
% preservation of trace indluced
%INPUTS
%%%%%%%%%%%%
%cov_org >>> original covariance matrix
%n_obs >>> observations used for computation
% first >>> if >0: max eigenvalue according to marchenko-pastur distribution
% computed excluding the maximal eigenvalue
%%%%%%%%%%%%%
%Outputs
%%%%%%%%%%%%
% cov_cl >>> cleaned covariance matrix
% lambda >>> vector of clean correlation eigenvalues
%
%Note: This proc should NOT be applied to high dimensional matrices
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

p=size(cov_org,1);

%compute correlation matrix

corr_org=diag(diag(cov_org).^(-.5))*cov_org*diag(diag(cov_org).^(-.5));


%perform singular value decomposition
[u s]=eig(corr_org);

%compute max eigenvalue according to marchenko pastur distribution

[lambda,ix]=sort(diag(s),'descend');
u=u(:,ix);

if first>0
 
    lambda_max=(1-lambda(1)/p)*(1+p/n_obs+2*sqrt(p/n_obs));%tightening of the threshold value
    
else

    lambda_max=1+p/n_obs+2*sqrt(p/n_obs);
    
end


%identify small eigenvalues
lambda_sm_ind=lambda<=lambda_max;


%compute clean eigenvalues
lambda_t=sum(max(lambda(lambda_sm_ind),0))/length(lambda(lambda_sm_ind));


%compute clean covariance matrix
lambda_cl=lambda;
lambda_cl(lambda_sm_ind)=lambda_t*ones(sum(lambda_sm_ind),1);


corr_cl=u*diag(lambda_cl)*u';

cov_cl=diag(diag(cov_org).^(.5))*corr_cl*diag(diag(cov_org).^(.5));






    
    




