function [cov_cl lambda_cl] = eigenval_clean_psd(cov_org,n_obs,first)
%eigenvalue cleaning following Hautsch,Kyj & Oomen (2010) for POSITIVE 
% SEMIDEFINITE covariances matrices (no neg eigenvalues)

%INPUTS
%%%%%%%%%%%%
%cov_org >>> original psd covariance matrix
%n_obs >>> observations used for computation
% first >>> if >0: max eigenvalue according to marchenko-pastur distribution
% computed excluding the maximal eigenvalue
%%%%%%%%%%%%%
%Outputs
%%%%%%%%%%%%
% cov_cl >>> cleaned covariance matrix
% lambda >>> vector of clean correlation eigenvalues
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

p=size(cov_org,1);

%compute correlation matrix

corr_org=diag(diag(cov_org).^(-.5))*cov_org*diag(diag(cov_org).^(-.5));


%perform singular value decomposition
[u s v]=svd(corr_org);% all svds are >0!!

%compute max eigenvalue according to marchenko pastur distribution

lambda=diag(s);

if first>0
 
    lambda_max=(1-lambda(1)/p)*(1+p/n_obs+2*sqrt(p/n_obs));%tightening of the threshold value
    
else

    lambda_max=1+p/n_obs+2*sqrt(p/n_obs);
    
end


%identify small eigenvalues


lambda_sm=lambda(lambda<=lambda_max);


%compute clean eigenvalues
lambda_t=sum(lambda_sm)/length(lambda_sm);


%compute clean covariance matrix
lambda_cl=[lambda(lambda>lambda_max);(lambda_t*ones(length(lambda_sm),1))];

corr_cl=u*diag(lambda_cl)*u';

cov_cl=diag(diag(cov_org).^(.5))*corr_cl*diag(diag(cov_org).^(.5));






    
    




