function [cov_cl lambda_cl] = eigenval_clean_sh(lambda,u,var_org,n_obs,first)
%eigenvalue cleaning following Hautsch,Kyj & Oomen (2010)
% correlation eigenvalues and vectors are supplied
%INPUTS
%%%%%%%%%%%%
% lambda >>> vector of eigenvalues
% u >>> matrix of eigenvectors
% var_org >>> vector of variances
%n_obs >>> observations used for computation
% first >>> if >0: max eigenvalue according to marchenko-pastur distribution
% computed excluding the maximal eigenvalue
%%%%%%%%%%%%%
%Outputs
%%%%%%%%%%%%
% cov_cl >>> cleaned covariance matrix
% lambda >>> vector of clean correlation eigenvalues
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

p=size(lambda,1);

%compute max eigenvalue according to marchenko pastur distribution
if first>0
 
    lambda_max=(1-lambda(1)/p)*(1+p/n_obs+2*sqrt(p/n_obs));%tightening of the threshold value
    
else

    lambda_max=1+p/n_obs+2*sqrt(p/n_obs);
    
end


%identify small eigenvalues


lambda_sm=lambda(lambda<=lambda_max);


%compute clean eigenvalues
lambda_t=sum(max(lambda_sm,0))/length(lambda_sm);


%compute clean covariance matrix

lambda_cl=[lambda(lambda>lambda_max);(lambda_t*ones(length(lambda_sm),1))];

corr_cl=u*diag(lambda_cl)*u';

cov_cl=diag(var_org.^(.5))*corr_cl*diag(var_org.^(.5));


