function [x,omega2]=endog_noise(y,sigma,ksi2)
%% endog_noise
%--------------------------------------------------------------
% Adds endogenous iid noise to efficient prices following approach
% by Barndorff-Nielsen et al. (JE, 2011)
%--------------------------------------------------------------
% INPUT:
% Y  -> vector of efficient prices
% sigma - vector of spot volatilities
% ksi2 - > noise to signal ratio
%--------------------------------------------------------------
% OUTPUT:
% x -> vector of noise dilluted prices
% omega2 -> noise variance
% -------------------------------------------------------------------------
%
% Peter Malec, January 2, 2012
% -------------------------------------------------------------------------
%   
%% Compute noise variance

% Average sigma4
msigma4=mean(sigma.^4);

% noise variance
omega2=ksi2*sqrt(msigma4);
% -------------------------------------------------------------------------
%   
%% Add simulated noise

% simulate noise
u=randn(length(y),1)*sqrt(omega2);

% Add noise
x=y+u;



