function [x,eta]=endog_noise_ar1(y,sigma,gamma2,N,rho_u)
%% endog_noise_ar1
%--------------------------------------------------------------
% Adds endogenous iid or ar(1) noise to 
%efficient prices 
%--------------------------------------------------------------
% INPUT:
% Y  -> vector of efficient prices
% sigma - vector of spot volatilities (including starting values)
% gamma2 - > noise to signal ratio per obs as in Oomen(2006)
% N -> number of obs
% rho_u -> 1st order autocorrelation of noise process (=AR par)
%--------------------------------------------------------------
% OUTPUT:
% x -> vector of noise dilluted prices
% eta -> noise variance or LR noise variance (if AR(1))
% -------------------------------------------------------------------------
%
% Peter Malec, April 22, 2014
% -------------------------------------------------------------------------
%   
%% Compute noise variance

% integrated quarticity
iquart=integ_quart_1d(sigma.^2);

%noise variance or LR noise variance (if AR(1))
eta=gamma2*sqrt(iquart)/N;
% -------------------------------------------------------------------------
%   
%% Add simulated noise

% simulate noise
if (nargin<5)||isempty(rho_u)
    u=randn(length(y),1)*sqrt(eta);
else
    u=filter(1,[1 (-rho_u)],randn(length(y),1)*sqrt(eta*(1-rho_u)^2));
end
    
% Add noise
x=y+u;



