function [x,omega2]=endog_noise_autocorr(y,sigma,ksi2,rho_u)
%% endog_noise
%--------------------------------------------------------------
% Adds endogenous iid or AR(1) noise to 
%efficient prices following approach by Barndorff-Nielsen et al. (JE, 2011)
%--------------------------------------------------------------
% INPUT:
% Y  -> vector of efficient prices
% sigma - vector of spot volatilities
% ksi2 - > noise to signal ratio
% rho_u -> 1st order autocorrelation of noise process
%               (in tick time)
%--------------------------------------------------------------
% OUTPUT:
% x -> vector of noise dilluted prices
% omega2 -> noise variance
% -------------------------------------------------------------------------
%
% Peter Malec, October 10, 2012
% -------------------------------------------------------------------------
%   
%% Compute noise variance

% Average sigma4
msigma4=mean(sigma.^4);

% noise variance
omega2=ksi2*sqrt(msigma4);
% -------------------------------------------------------------------------
%   
%% Add simulated noise

% simulate noise
if isequal(rho_u,0)
    u=randn(length(y),1)*sqrt(omega2);
else
    u=filter(1,[1 (-rho_u)],randn(length(y),1)*sqrt(omega2));
end
    
% Add noise
x=y+u;



