function [x,eta]=endog_noise_ma(y,sigma,gamma2,N,theta)
%% endog_noise_ma
%--------------------------------------------------------------
% Adds endogenous iid or ma(q) noise to 
%efficient prices 
%--------------------------------------------------------------
% INPUT:
% Y  -> vector of efficient prices
% sigma - vector of spot volatilities (including starting values)
% gamma2 - > noise to signal ratio per obs as in Oomen(2006)
% N -> number of obs
% theta -> vector of Ma parameters
%--------------------------------------------------------------
% OUTPUT:
% x -> vector of noise dilluted prices
% eta -> noise variance or LR noise variance (if MA(q))
% -------------------------------------------------------------------------
%
% Peter Malec, April 9, 2014
% -------------------------------------------------------------------------
%   
%% Compute noise variance

% integrated quarticity
iquart=integ_quart_1d(sigma.^2);

%noise variance or LR noise variance (if MA(q))
eta=gamma2*sqrt(iquart)/N;
% -------------------------------------------------------------------------
%   
%% Add simulated noise

% simulate noise
if (nargin<5)||isempty(theta)
    u=randn(length(y),1)*sqrt(eta);
else
    u=sim_maq(length(y),theta,sqrt(eta)/(1+sum(theta)));
end
    
% Add noise
x=y+u;



