function [ivar1,ivar2,icov]=integ_cov(sigma1,sigma2,sigma12)
%% integ_cov
%--------------------------------------------------------------
% Computes integrated variances and covariances on unit interval by numerical
% integration using simpson rule on spot (co-) variances 
%--------------------------------------------------------------
% INPUT:
% sigma1 -> vector of spot variances of asset 1 (including starting value)
% sigma2 -> vector of spot variances of asset 2 (including starting value)
% sigma12 -> vector of spot covariances of asset 1,2 (including starting value)
%--------------------------------------------------------------
% OUTPUT:
% ivar1 -> integr variance asset 1
% ivar2 -> integr variance asset 2
% icov   -> integr covariance 
% -------------------------------------------------------------------------
%
% Peter Malec, January 3, 2012
% -------------------------------------------------------------------------
%   
%%  Preparations

% # of intervals in euler discretization = # segments * 2
N=length(sigma1)-1;

% 1/2 width of segments
h=1/N; %(1-0)/(N/2)/2

%% Compute integrated variances and covariances

% select spot (co-)variances at segment limits and centers
sigma1_t=sigma1(1:2:end);       %t=0:2/N:1 (segment limits)
sigma2_t=sigma2(1:2:end);
sigma12_t=sigma12(1:2:end);
sigma_t=[sigma1_t sigma2_t sigma12_t];   %join

% select spot (co-)variances at segment centers
sigma1_t_m=sigma1(2:2:end-1);  %t_m=1/N:2/N:(1-1/N) (segment centers)
sigma2_t_m=sigma2(2:2:end-1);
sigma12_t_m=sigma12(2:2:end-1);
sigma_t_m=[sigma1_t_m sigma2_t_m sigma12_t_m];   %join

% simpson rule
isigma= sum((h/3)*(sigma_t(1:end-1,:)+4*sigma_t_m(1:end,:)+sigma_t(2:end,:)));
ivar1=isigma(:,1);
ivar2=isigma(:,2);
icov=isigma(:,3);










