function [icov1]=integ_covmat(sigma1)
%% integ_covmat
%--------------------------------------------------------------
% Computes integrated covariance matrix on unit interval by numerical
% integration using simpson rule on spot variances 
%--------------------------------------------------------------
% INPUT:
% sigma1 -> (nxd(d+1)/2) matrix of spot (co-)variances for distinct 
%                       elements and pairs (including starting value)
%--------------------------------------------------------------
% OUTPUT:
% icov1 -> (1xd(d+1)/2) vector of corresponding integrated
%                  (co-)variances
% -------------------------------------------------------------------------
%
% Peter Malec, April 26, 2016
% -------------------------------------------------------------------------
%   
%%  Preparations

% # of intervals in euler discretization = # segments * 2
N=size(sigma1,1)-1;

% 1/2 width of segments
h=1/N; %(1-0)/(N/2)/2

%% Compute integrated variances and covariances

% select spot (co-)variances at segment limits and centers
sigma_t=sigma1(1:2:end,:);       %t=0:2/N:1 (segment limits)

% select spot (co-)variances at segment centers
sigma_t_m=sigma1(2:2:end-1,:);  %t_m=1/N:2/N:(1-1/N) (segment centers)

% simpson rule
icov1= sum((h/3)*(sigma_t(1:end-1,:)+4*sigma_t_m(1:end,:)+sigma_t(2:end,:)));











