function [iquart1]=integ_quart_1d(sigma1)
%% integ_quart_1d
%--------------------------------------------------------------
% Computes integrated quarticities on unit interval by numerical
% integration using simpson rule on spot variances 
%--------------------------------------------------------------
% INPUT:
% sigma1 -> vector of spot variances  (including starting value)
%--------------------------------------------------------------
% OUTPUT:
% iquart1 -> integr quart (int sigma1^2 ) 
% -------------------------------------------------------------------------
%
% Peter Malec, April 8, 2014
% -------------------------------------------------------------------------
%   
%%  Preparations

% # of intervals in euler discretization = # segments * 2
N=length(sigma1)-1;

% 1/2 width of segments
h=1/N; %(1-0)/(N/2)/2

%% Compute integrated quarticity

% compute squared series
quart1=sigma1.^2;

% select spot variances at segment limits and centers
sigma_t=quart1(1:2:end);       %t=0:2/N:1 (segment limits)

% select spot variances at segment centers
sigma_t_m=quart1(2:2:end-1);       %t_m=1/N:2/N:(1-1/N) (segment centers)

% simpson rule
iquart1= sum((h/3)*(sigma_t(1:end-1,:)+4*sigma_t_m(1:end,:)+sigma_t(2:end,:)));













