function [isigma3]=integ_sigma3(sigma2)
%% integ_cov
%--------------------------------------------------------------
% Computes integral of spot vola^2 on unit interval by numerical
% integration using simpson rule on spot (co-) variances 
%--------------------------------------------------------------
% INPUT:
% sigma -> vector of spot variances of asset 1 (including starting value)
%--------------------------------------------------------------
% OUTPUT:
% isigma3 -> \int sigma_t^3 \dt 
% -------------------------------------------------------------------------
%
% Peter Malec, April 20, 2012
% -------------------------------------------------------------------------
%   
%%  Preparations

% # of intervals in euler discretization = # segments * 2
N=length(sigma2)-1;

% 1/2 width of segments
h=1/N; %(1-0)/(N/2)/2

%% Compute integrated variances and covariances

% select spot (co-)variances at segment limits and centers
sigma_t=(sqrt(sigma2(1:2:end))).^3;       %t=0:2/N:1 (segment limits)

% select spot (co-)variances at segment centers
sigma_t_m=(sqrt(sigma2(2:2:end-1))).^3;  %t_m=1/N:2/N:(1-1/N) (segment centers)

% simpson rule
isigma3= sum((h/3)*(sigma_t(1:end-1,:)+4*sigma_t_m(1:end,:)+sigma_t(2:end,:)));











