function [ivar1]=integ_var(sigma1)
%% integ_var
%--------------------------------------------------------------
% Computes integrated variance on unit interval by numerical
% integration using simpson rule on spot variances 
%--------------------------------------------------------------
% INPUT:
% sigma1 -> vector of spot variances (including starting value)
%--------------------------------------------------------------
% OUTPUT:
% ivar1 -> integr variance 
% -------------------------------------------------------------------------
%
% Peter Malec, April 8, 2014
% -------------------------------------------------------------------------
%   
%%  Preparations

% # of intervals in euler discretization = # segments * 2
N=length(sigma1)-1;

% 1/2 width of segments
h=1/N; %(1-0)/(N/2)/2

%% Compute integrated variances and covariances

% select spot (co-)variances at segment limits and centers
sigma_t=sigma1(1:2:end);       %t=0:2/N:1 (segment limits)

% select spot (co-)variances at segment centers
sigma_t_m=sigma1(2:2:end-1);  %t_m=1/N:2/N:(1-1/N) (segment centers)

% simpson rule
ivar1= sum((h/3)*(sigma_t(1:end-1,:)+4*sigma_t_m(1:end,:)+sigma_t(2:end,:)));











