function y=sim_2d_constvol(sigma21,sigma22,rho,N)
%% sim_2d_detvol
%--------------------------------------------------------------
% Simulates 2-dimensional diffusion process with deterministic
% spot volatility functions
%--------------------------------------------------------------
% INPUT:
% sigma21 -> (scalar) constant spot variance for asset 1 
% sigma22 -> ...
% rho -> spot correlation (constant)
% N             -> # of intervals for euler discretization (usually 23400,
% corresponds to T=1 and 6.5 h hours of trading)
%--------------------------------------------------------------
% OUTPUT:
% y  -> (Nx2) vmatrix of simulated obs of log-prices of asset 1&2
% -------------------------------------------------------------------------
%
% Peter Malec, November 30, 2012
%
% -------------------------------------------------------------------------
%   
%% Preparations

% step size
h=1/N;

%starting values
y01=0;
y02=0;
% -------------------------------------------------------------------------
%   
%% Simulations of Brownian Increments

% generate (uncorrelated) N(0,1) pseudo-random numbers
Bmat=randn(N,2);

% assign to BM processes
dB1=Bmat(:,1);
dW=Bmat(:,2);

% derive brownian motion entering y2 process
dB2=rho*dB1+sqrt(1-rho^2)*dW;%rho: (spot) corr between B1 & B2
% -------------------------------------------------------------------------
%   
%% Simulate Diffusions by euler discretization

% y1
y1=sqrt(sigma21*h)*cumsum(dB1,1)+y01;
    
% y
y2=sqrt(sigma22*h)*cumsum(dB2,1)+y02;

% join
y=[y1 y2];





