function y=sim_2d_constvol_dur(sigma21,sigma22,rho,dt)
%% sim_2d_constvol
%--------------------------------------------------------------
% Simulates 2-dimensional diffusion process with deterministic
% spot volatility functions given duratoins
%--------------------------------------------------------------
% INPUT:
% sigma21 -> (scalar) constant spot variance for asset 1 
% sigma22 -> ...
% rho -> spot correlation (constant)
% dt    ->  vector of durations of intervals for euler discr
%--------------------------------------------------------------
% OUTPUT:
% y  -> (Nx2) vmatrix of simulated obs of log-prices of asset 1&2
% -------------------------------------------------------------------------
%
% Peter Malec, November 30, 2012
%
% -------------------------------------------------------------------------
%   
%% Preparations

% no of intervals
N=length(dt);

%starting values
y01=0;
y02=0;
% -------------------------------------------------------------------------
%   
%% Simulations of Brownian Increments

% generate (uncorrelated) N(0,1) pseudo-random numbers
Bmat=randn(N,2);

% assign to BM processes
dB1=Bmat(:,1);
dW=Bmat(:,2);

% derive brownian motion entering y2 process
dB2=rho*dB1+sqrt(1-rho^2)*dW;%rho: (spot) corr between B1 & B2
% -------------------------------------------------------------------------
%   
%% Simulate Diffusions by euler discretization

% y1
y1=cumsum(sqrt(sigma21*dt).*dB1,1)+y01;
    
% y
y2=cumsum(sqrt(sigma22*dt).*dB2,1)+y02;

% join
y=[y1 y2];





