function y=sim_2d_constvol_old(sigma21,sigma22,rho,N,j)
%% sim_2d_constvol_old
%--------------------------------------------------------------
% Simulates 2-dimensional diffusion process with constant 
% volatility
%--------------------------------------------------------------
% INPUT:
% sigma21 -> constant variance for asset 1
% sigma22 -> ...
% rho -> spot correlation (constant)
% N             -> # of intervals for euler discretization (usually 23400,
% corresponds to T=1 and 6.5 h hours of trading)
% j       -> number of iterations (if used in bigger procedure)
%
%--------------------------------------------------------------
% OUTPUT:
% y  -> (Nx2) vmatrix of simulated obs of log-prices of asset 1&2
% -------------------------------------------------------------------------
%
% Peter Malec, February 12, 2012
%
% -------------------------------------------------------------------------
%   
%% Preparations

% step size
h=1/N;

%initialize matrix
y=NaN*zeros(N,2);

%starting values
y0=zeros(1,2);

% Simulations of Brownian Increments
dB=randn(N,2);
% -------------------------------------------------------------------------
%   
%% Simulate Diffusions by euler discretization

% Add one row to matrix (for starting values)
y=[y0;y];

% compute square root of Spot Covariance Matrix
%-------------------------------------------------------
    
% Construct Spot Covariance Matrix
Sigma=[sigma21 rho*sqrt(sigma21*sigma22);rho*sqrt(sigma21*sigma22)...
        sigma22];
    
% Cholesky Decomposition
 [Sigma05,cval]=chol(Sigma);
    

 % Start Loop
% --------------------------------------
for i=1:N
    
    
    % simulate sv processes
    %-----------------------------------
    y(i+1,:)=y(i,:)'+Sigma05'*sqrt(h)*dB(i,:)';
   
    
end
% -------------------------------------------------------------------------
%   
%% Adjust Output

% remove 1st row from output matrix
y=y(2:end,:);




