function z=sim_2d_constvol(sigmax2,sigmay2,rho,N,j)
%% sim_2d_constvol
%--------------------------------------------------------------
% Simulates 2-dimensional diffusion process with constant 
% volatility
%--------------------------------------------------------------
% INPUT:
% sigmax2 -> constant variance for asset 1
% sigmay2 -> ...
% rho -> spot correlation (constant)
% N             -> # of intervals for euler discretization (usually 23400,
% corresponds to T=1 and 6.5 h hours of trading)
% j       -> number of iterations (if used in bigger procedure)
%
%--------------------------------------------------------------
% OUTPUT:
% z  -> (Nx2) vmatrix of simulated obs of log-prices of asset 1&2
% -------------------------------------------------------------------------
%
% Peter Malec, February 12, 2012
%
% -------------------------------------------------------------------------
%   
%% Preparations

% step size
h=1/N;

%starting values
x0=0;
y0=0;

% Simulations of Brownian Increments
dB=randn(N,2);
% -------------------------------------------------------------------------
%   
%% Simulate Diffusions by euler discretization

% x
x=cumsum(sqrt(sigmax2*h)*dB(:,1),1)+x0;
    
% y
y=cumsum(rho*sqrt(sigmay2*h)*dB(:,1)+sqrt((1-rho^2)*sigmay2*h)*dB(:,2),1)+y0;

% join
z=[x y];


