function y=sim_constvol_seas(sigma2,N,phisq)
%% sim_constvol_seas
%--------------------------------------------------------------
% Simulates diffusion process with constant 
% spot volatility around seasonal pattern
%--------------------------------------------------------------
% INPUT:
% sigma2 -> (scalar) constant spot variance 
% N             -> # of intervals for euler discretization (usually 23400,
% corresponds to T=1 and 6.5 h hours of trading)
% phisq         -> ((N+1)x2) matrix of deterministic seasonal spot variance
%                       factor (N+1 elements due to starting value)
%--------------------------------------------------------------
% OUTPUT:
% y  -> (Nx1) vector of simulated obs of log-prices 
% -------------------------------------------------------------------------
%
% Peter Malec,April 8, 2014
%
% -------------------------------------------------------------------------
%   
%% Preparations

%check argument
if nargin<3||isempty(phisq)
    phisq =ones(N+1,1);
end

% check dimensions
if ~isequal(length(phisq),(N+1))
    error('phi has needs to have (N+1) elements !!!')
end

% make phisq column
phisq=phisq(:);

% step size
h=1/N;

%starting values
y0=0;
% -------------------------------------------------------------------------
%   
%% Simulations of Brownian Increments

% generate N(0,1) pseudo-random numbers
dB=randn(N,1);
% -------------------------------------------------------------------------
%   
%% Simulate Diffusions by euler discretization

% y
y=sqrt(sigma2*h)*cumsum(sqrt(phisq(2:end)).*dB,1)+y0;
    






