function S_vec=sim_poisson(lambda,T)
%% sim_poisson
%--------------------------------------------------------------
% Simulates a Poisson Process by adding up exponential 
% waiting times
%--------------------------------------------------------------
% INPUT:
% lambda -> intensity
% T -> fixed end time
%--------------------------------------------------------------
% OUTPUT:
% S_vec -> vector of event times
% -------------------------------------------------------------------------
%
% Peter Malec, March 17, 2012
%
% -------------------------------------------------------------------------
%       
%% Simulation

% Initiation of vector of observation times
S_vec=[];   % vector of observation times

% Simulate first event time
%-----------------------------------
U=rand(1);  % unfiform rv
t=-log(U)/lambda; % waiting time is exponential rv (use inverse cdf)

% Loop for remaining waiting times
%-------------------------------------------

while t<T   %ending times is fixed
    
    % include event time from last iter
    S_vec=[S_vec;t];    
    % unfiform rv
    U=rand(1);
    % waiting time as exponential rv
    t=t-log(U)/lambda; 
    
end
    