function y=sim_sim_2d_detvol_old(sigma21,sigma22,rho,N,j)
%% sim_2d_detvol_old
%--------------------------------------------------------------
% Simulates 2-dimensional diffusion process with deterministic
% spot volatility functions
%--------------------------------------------------------------
% INPUT:
% sigma21 -> (Nx1) vector of spot variances for asset 1
% sigma22 -> ...
% rho -> spot correlation (constant)
% N             -> # of intervals for euler discretization (usually 23400,
% corresponds to T=1 and 6.5 h hours of trading)
% j       -> number of iterations (if used in bigger procedure)
%
%--------------------------------------------------------------
% OUTPUT:
% y  -> (Nx2) vmatrix of simulated obs of log-prices of asset 1&2
% -------------------------------------------------------------------------
%
% Peter Malec, January 25, 2012
%
% modification February 11, 2012
% no check for psd of Sigma matrix
% -------------------------------------------------------------------------
%   
%% Preparations

% step size
h=1/N;

%initialize matrix
y=NaN*zeros(N,2);

%starting values
y0=zeros(1,2);

% Simulations of Brownian Increments
dB=randn(N,2);
% -------------------------------------------------------------------------
%   
%% Simulate Diffusions by euler discretization

% Add one row to matrix and vector (for starting values)
y=[y0;y];
sigma21=[sigma21(1);sigma21];
sigma22=[sigma22(1);sigma22];

% Start Loop
% --------------------------------------
for i=1:N
    
    % compute square root of Spot Covariance Matrix
    %-------------------------------------------------------
    
    % Construct Spot Covariance Matrix
    Sigma=[sigma21(i) rho*sqrt(sigma21(i)*sigma22(i));rho*sqrt(sigma21(i)*sigma22(i))...
        sigma22(i)];
    
    % Cholesky Decomposition
    [Sigma05,cval]=chol(Sigma);
    
%     % check for psd 
%     if cval ~= 0
%         w_mssg=strcat('Sigma not positive definite. Correction for day ',int2str(j));
%         display(w_mssg)
%         while cval ~=0
%             Sigma=(1-0.01)*Sigma+0.01*eye(length(y0));              %shrink towards identity matrix
%             [Sigma05,cval]=chol(Sigma);
%         end
%     end
    
    % simulate sv processes
    %-----------------------------------
    y(i+1,:)=y(i,:)'+Sigma05'*sqrt(h)*dB(i,:)';
   
    
end
% -------------------------------------------------------------------------
%   
%% Adjust Output

% remove 1st row from output matrix
y=y(2:end,:);




