function Sigma_arr=spot_cov_grid_func_icov(input_v,PRICETIME,noise_v,startt,endt,...
    J_p,theta_h_v,theta_J_v,theta_K_v,K_p_thr,twost,lKb,ccorr,ccorrlast)
%% spot_cov_grid_func_cov
%--------------------------------------------------------------
% local likelihood estimation of spot covariances for specified
% estimation points. For grid of values
% of theta_h, theta_J and theta_K (see below)
% integrated covariance estimate is computed based on spot estimates
% using riemann approximation
%--------------------------------------------------------------
% INPUT:
% input_v -> points of estimation (normalized)
% PRICETIME -> (mx1) cell array with ith cell containing (n0ix2) matrix:
%                   1st col  -  observation times for asset i (in sec after midnight)
%                   2nd col    - high frequency prices for asset i
% noise_v -> (mx1) vector of noise variance estimates
% startt -> start of trading (in hours)
% endt   -> end of trading (in hours)
% J_p-> spectral cutoff for pilot estimates of spot covariances
% theta_h_v   -> vector of values of proportionality parameter for block length
% theta_J_v     -> vector of values of proportionaliy parameter for cutoff
% theta_K_v  -> vector of values of proportionality parameter for smoothing bandwidth
% K_p_thr    -> lower threshold for pilot smoothing bandwidth (relevant if
%                           K_p not specified): default=1
% twst     -> if >0: twostep estimation is used (estimates from first step
%                   used as pilots for second step
% lkB         -> if >0, shorter smoothing windows at beginning and end of
%                   day are used for spot cov estim (NOT PILOT!)
% ccorr -> if >0, correlation and variance estimates are corrected
% ccorrlast -> if >0, correlation and variance estimates are corrected (last estimation step)
%--------------------------------------------------------------
% INPUT:
% Sigma_arr -> (length(theta_h_v),length(theta_J_v),length(theta_K_v))
%                       array of integrated variance estimates for
%                       different values of proportionality parameters
%--------------------------------------------------------------
%
% Peter Malec,  April 24, 2016 
%
% -------------------------------------------------------------------------
%   
%% Loop over Grid and Compute Spot Var estimates

% determine dimension of data
m=length(PRICETIME);

%initialize
Sigma_arr=NaN*zeros(m*(m+1)/2,length(theta_h_v),length(theta_J_v),length(theta_K_v));

% make input_v col vector
input_v=input_v(:);

%loop
%-----------------------------------
for k=1:length(theta_h_v)
    
    %select value
    theta_h=theta_h_v(k);

    for i=1:length(theta_J_v)
    
            %select value
            theta_J=theta_J_v(i);
    
                for j=1:length(theta_K_v)
        
                    %select value
                    theta_K=theta_K_v(j);

                    % Estimate Spot cov mat
                    [SigmaSpot_out,~,~,~,~,~,~]=lle_spot_cov_md(input_v,PRICETIME,...
                    noise_v,startt,endt,1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,-1,lKb,ccorr,ccorrlast);
    
                    %assign icov as riemann sum
                    Sigma_arr(:,k,i,j)=SigmaSpot_out(1:(end-1),:)'*diff(input_v);
    
                end
    
    end

end

    
  
    