function Sigma_mat=spot_cov_grid_func_icov_kern(input_v,PRICETIME,noise_v,startt,endt,...
    J_p,theta_h,theta_J,theta_K_v,K_p_thr,twost,kern,ccorr,ccorrlast)
%% spot_cov_grid_func_cov_kern
%--------------------------------------------------------------
% local likelihood estimation of spot covariances for specified
% estimation points with final smoothing based on kernel weights. 
% For fixed value of theta_h and theta_J and grid of values
% of theta_K (see below)
% integrated covariance estimate is computed based on spot estimates
% using riemann approximation
%--------------------------------------------------------------
% INPUT:
% input_v -> points of estimation (normalized)
% PRICETIME -> (mx1) cell array with ith cell containing (n0ix2) matrix:
%                   1st col  -  observation times for asset i (in sec after midnight)
%                   2nd col    - high frequency prices for asset i
% noise_v -> (mx1) vector of noise variance estimates
% startt -> start of trading (in hours)
% endt   -> end of trading (in hours)
% J_p-> spectral cutoff for pilot estimates of spot covariances
% theta_h   -> proportionality parameter for block length
% theta_J     -> proportionaliy parameter for cutoff
% theta_K_v  -> vector of values of proportionality parameter for smoothing bandwidth
% K_p_thr    -> lower threshold for pilot smoothing bandwidth (relevant if
%                           K_p not specified): default=0+eps
% twst     -> if >0: twostep estimation is used (estimates from first step
%                   used as pilots for second step
% kern   -> string, type of kernel:
%                   -- 'gauss' (Gaussian)
%                   -- 'beta'   (Beta)
%                   -- 'betamod'   (modified Beta)
% ccorr -> if >0, correlation and variance estimates are corrected
% ccorrlast -> if >0, correlation and variance estimates are corrected (last estimation step)
%--------------------------------------------------------------
% INPUT:
% Sigma_mat -> (m*(m+1)/2 x length(theta_K_v))
%                       matrix of integrated co-variance estimates for
%                       different values of proportionality parameters for
%                       K
%--------------------------------------------------------------
%
% Peter Malec,  May 16, 2016 
%
% -------------------------------------------------------------------------
%   
%% Loop over Grid and Compute Spot Var estimates

% determine dimension of data
m=length(PRICETIME);

%initialize
Sigma_mat=NaN*zeros(m*(m+1)/2,length(theta_K_v));

% make input_v col vector
input_v=input_v(:);

%loop
%-----------------------------------
    
for j=1:length(theta_K_v)

    %select value
    theta_K=theta_K_v(j);

    % Estimate Spot cov mat
    [SigmaSpot_out,~,~,~,~,~,~]=lle_spot_cov_md_kern(input_v,PRICETIME,...
    noise_v,startt,endt,1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,-1,kern,ccorr,ccorrlast);

    %assign icov as riemann sum
    Sigma_mat(:,j)=SigmaSpot_out(1:(end-1),:)'*diff(input_v);

end
    

    
  
    