function Sigma_arr=spot_var_grid_func_ivar(input_v,midprice,eta2,startt,endt,...
    J_p,theta_h_v,theta_J_v,theta_K_v,K_p_thr,twost,lKb,ccorr)
%% spot_var_grid_func_ivar
%--------------------------------------------------------------
% local likelihood estimation of spot variances for specified
% estimation points. For fixed value of theta_h and grid of values
% of theta_J and theta_K (see below)
% integrated variance estimate is computed based on spot estimates
% using riemann approximation
%--------------------------------------------------------------
% INPUT:
% input_v -> points of estimation (normalized)
% midprice -> (nx2) matrix of observation times (col1) and prices (col2)
% eta2      -> noise variance
% startt -> start of trading (in hours)
% endt   -> end of trading (in hours)
% J_p-> spectral cutoff for pilot estimates of spot covariances
% theta_h_v   -> vector of values of proportionality parameter for block length
% theta_J_v     -> vector of values of proportionaliy parameter for cutoff
% theta_K_v  -> vector of values of proportionality parameter for smoothing bandwidth
% K_p_thr    -> lower threshold for pilot smoothing bandwidth (relevant if
%                           K_p not specified): default=1
% twst     -> if >0: twostep estimation is used (estimates from first step
%                   used as pilots for second step
% lkB         -> if >0, shorter smoothing windows at beginning and end of
%                   day are used for spot cov estim (NOT PILOT!)
% ccorr -> if >0, correlation and variance estimates are corrected
%--------------------------------------------------------------
% INPUT:
% Sigma_arr -> (length(theta_h_v),length(theta_J_v),length(theta_K_v))
%                       array of integrated variance estimates for
%                       different values of proportionality parameters
%--------------------------------------------------------------
%
% Peter Malec,  April 8, 2014 
%
% -------------------------------------------------------------------------
%   
%% Loop over Grid and Compute Spot Var estimates

%initialize
Sigma_arr=NaN*zeros(length(theta_h_v),length(theta_J_v),length(theta_K_v));

%make mid price a cell array
midprice={midprice};

% make input_v col vector
input_v=input_v(:);

%loop
%-----------------------------------
for k=1:length(theta_h_v)
    
    %select value
    theta_h=theta_h_v(k);

    for i=1:length(theta_J_v)
    
            %select value
            theta_J=theta_J_v(i);
    
                for j=1:length(theta_K_v)
        
                    %select value
                    theta_K=theta_K_v(j);

                    % Estimate Spot cov mat
                    [SigmaSpot_out,~,~,~,~,~,~]=lle_spot_cov_md(input_v,midprice,...
                    eta2,startt,endt,1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,-1,lKb,ccorr);
    
                    %assign ivar as riemann sum
                    Sigma_arr(k,i,j)=SigmaSpot_out(1:(end-1))'*diff(input_v);
    
                end
    
    end

end

    
  
    