        function [dens] = beta_dens(t,aalpha,bbeta)
%% beta_dens
%--------------------------------------------------------------
% density of beta(alpha,beta) distribution
%--------------------------------------------------------------
% INPUT:
% t -> (Nx1) data vector
% aalpha -> shape parameter I
% bbeta  -> shape parameter II
%--------------------------------------------------------------
% OUTPUT:
% dens - > (Nx1) vector of density values
% -------------------------------------------------------------------------
%
% Peter Malec, May 3, 2013
% -------------------------------------------------------------------------
%       
 %% Check inputs
 
 %make column vector
 t=t(:);
 
 %dimension
 if size(t,2)>1
     error('Input has to be be vector')
 end
 
 % retain inputs between 0 and 1
 t_cl_ind= t >=0 & t <= 1;
 t_cl=t( t_cl_ind);
 
 % warning
 if length( t_cl)<length(t)
     disp('Warning: some inputs were outside the unit interval')
 end
 % -------------------------------------------------------------------------
%       
 %% Compute density
 
 %numerator
 numer= t_cl.^(aalpha-1).*(1- t_cl).^(bbeta-1);
 
 %density nonzero
 dens_pre=numer./beta(aalpha,bbeta);
 
 %density full
 dens=zeros(length(t),1);
 dens(t_cl_ind)= dens_pre;
 

 

