        function [kernv] = beta_kernel(t,y,b,modi)
%% beta_kernel
%--------------------------------------------------------------
% evaluates beta kernel
%--------------------------------------------------------------
% INPUT:
% t -> (Nx1) data vector
% y -> point of estimation
% b  -> bandwidth
% modi -> if >0, modified beta kernel is used, else
%             standard kernel (default)
%--------------------------------------------------------------
% OUTPUT:
% kernv - > (Nx1) vector of kernel values
% -------------------------------------------------------------------------
%
% Peter Malec, May 3, 2013
% -------------------------------------------------------------------------
%   
%% Input Check

% point of estimation
if (y <0) || (y > 1)
    error('Point of estimation has to be between 0 and 1!')
end

% modified kernel
if (nargin<4)
    modi=0;
end
% -------------------------------------------------------------------------
%  
 %% Evaluate Kernel
 
 %modified kernel
 %%%%%%%%%%%%%%%%
 if modi>0
     
     % case distinction dep. on point of estimation
     if (y>=2*b)&&(y<=1-2*b)
         kernv=beta_dens(t,y/b,(1-y)/b);
     elseif (y>1-2*b);
         kernv=beta_dens(t,y/b,rho_func_beta(1-y,b));
     else
         kernv=beta_dens(t,rho_func_beta(y,b),(1-y)/b);
     end
     
 %standard kernel
 %%%%%%%%%%%%%%%%
 else
     
    % kernel values
    kernv=beta_dens(t,y/b+1,(1-y)/b+1);
 
  end
 
 
      
 
 

 

