function [dens_est,b] = dens_est_gamma_kernel(data_in,input,b,modi)
%% dens_est_gamma_kernel
%--------------------------------------------------------------
% density estimation based on gamma kernel 
%--------------------------------------------------------------
% INPUT:
% data_in -> (Nx1) data vector
% input -> (Mx1) vector of points of estimation
% b  -> bandwidth: if empty, rot-bandwidth using exponential
%                           reference is used
% modi -> if >0, modified gamma kernel is used, else
%             standard kernel (default)
%--------------------------------------------------------------
% OUTPUT:
% dens_est - > (Mx1) vector of density estimates
% -------------------------------------------------------------------------
%
% Peter Malec, March 24, 2014
% -------------------------------------------------------------------------
%   
%% Input Check

% points of estimation
if (sum(input <0)>0)
    error('Points of estimation have to be >=0 !')
end

% modified kernel
if (nargin<4)
    modi=0;
end
% -------------------------------------------------------------------------
%  
%% Bandwidth

% check if bw is provided
if isempty(b)
    % estimate of lamba parameter
    lambda_hat=min([mean(data_in)^(-1) 2-1e-3]);
    % rot with exponential reference
    b=(lambda_hat/4)^(-1/5)*(2-lambda_hat)^(-4/5)*length(data_in)^(-4/9);
end
% -------------------------------------------------------------------------
%  
 %% Compute Density Estimates
 
 %initialize
 dens_est=NaN*zeros(length(input),1);
 
 % Loop over estimation points
 for i=1:length(input)
     dens_est(i)=mean(gamma_kernel(data_in,input(i),b,modi));
 end