        function [dens] = gamma_dens(t,aalpha,bbeta)
%% gamma_dens
%--------------------------------------------------------------
% density of gamma(alpha,beta) distribution
%--------------------------------------------------------------
% INPUT:
% t -> (Nx1) data vector
% aalpha -> shape parameter 
% bbeta  -> scale parameter
%--------------------------------------------------------------
% OUTPUT:
% dens - > (Nx1) vector of density values
% -------------------------------------------------------------------------
%
% Peter Malec,March 24, 2014
%
% Note: computation based on logs to prevent numerical issues
% -------------------------------------------------------------------------
%       
 %% Check inputs
 
 %make column vector
 t=t(:);
 
 %dimension
 if size(t,2)>1
     error('Input has to be be vector')
 end
 
 % retain inputs >0
 t_cl_ind= t >0;
 t_cl=t( t_cl_ind);
 
 % warning
 if length( t_cl)<length(t)
     disp('Warning: some data points were smaller than zero')
 end
 % -------------------------------------------------------------------------
%       
 %% Compute density
 
 %log of numerator
 lognumer= (aalpha-1)*log(t_cl)-t_cl/bbeta;
 
 %density nonzero
 dens_pre=exp(lognumer-aalpha*log(bbeta)-gammaln(aalpha));
 
 %density full
 dens=zeros(length(t),1);
 dens(t_cl_ind)= dens_pre;
 

 

