        function [dens] = gamma_dens(t,aalpha,bbeta)
%% gamma_dens
%--------------------------------------------------------------
% density of gamma(alpha,beta) distribution
%--------------------------------------------------------------
% INPUT:
% t -> (Nx1) data vector
% aalpha -> shape parameter 
% bbeta  -> scale parameter
%--------------------------------------------------------------
% OUTPUT:
% dens - > (Nx1) vector of density values
% -------------------------------------------------------------------------
%
% Peter Malec,March 24, 2014
% -------------------------------------------------------------------------
%       
 %% Check inputs
 
 %make column vector
 t=t(:);
 
 %dimension
 if size(t,2)>1
     error('Input has to be be vector')
 end
 
 % retain inputs >0
 t_cl_ind= t >0;
 t_cl=t( t_cl_ind);
 
 % warning
 if length( t_cl)<length(t)
     disp('Warning: some data points were smaller than zero')
 end
 % -------------------------------------------------------------------------
%       
 %% Compute density
 
 %numerator
 numer= t_cl.^(aalpha-1).*exp(-t_cl/bbeta);
 
 %density nonzero
 dens_pre=numer./(bbeta.^(aalpha).*gamma(aalpha));
 
 %density full
 dens=zeros(length(t),1);
 dens(t_cl_ind)= dens_pre;
 

 

