        function [kernv] = gamma_kernel(t,y,b,modi)
%% gamma_kernel
%--------------------------------------------------------------
% evaluates gamma kernel
%--------------------------------------------------------------
% INPUT:
% t -> (Nx1) data vector
% y -> point of estimation
% b  -> bandwidth
% modi -> if >0, modified gamma kernel is used, else
%             standard kernel (default)
%--------------------------------------------------------------
% OUTPUT:
% kernv - > (Nx1) vector of kernel values
% -------------------------------------------------------------------------
%
% Peter Malec, March 24, 2014
% -------------------------------------------------------------------------
%   
%% Input Check

% point of estimation
if (y <0)
    error('Point of estimation has to be >=0 !')
end

% modified kernel
if (nargin<4)
    modi=0;
end
% -------------------------------------------------------------------------
%  
 %% Evaluate Kernel
 
 %modified kernel
 %%%%%%%%%%%%%%%%
 if modi>0
     
     % case distinction dep. on point of estimation
     if (y>=2*b)
         kernv=gamma_dens(t,y/b,b);
     else
         rho_val=0.25*(y/b)^2+1;
         kernv=gamma_dens(t,rho_val,b);
     end
     
 %standard kernel
 %%%%%%%%%%%%%%%%
 else
     
    % kernel values
    kernv=gamma_dens(t,y/b+1,b);
 
  end
 
 
      
 
 

 

