function b_out=spot_vola_smooth_beta_lscvb(block_st,SCov_mat,options,modi)
%------------------------------------------------------------------
%% spot_vola_smooth_beta_lscvb
% bandwidth choice by least-squares cross
% validation
%------------------------------------------------------------------
%
% INPUTS
% block_st    -> (Bx1) vector of block start times
% SCov_mat -> (Bx3) matrix of spot (co-)volatility estimates on
% blocks (kth row: [sigma_(x,k)^2 sigma_(xy,k) sigma_(y,k)^2])
% options     -> options for fmincon
% modi -> if >0, modified beta kernel is used, else
%             standard kernel
%------------------------------------------------------------------
% OUTPUTS
% b_out ->    lscv bandwidth
%------------------------------------------------------------------
%
%   Peter Malec, May 6, 2013
%
%------------------------------------------------------------------
%
%% Starting value for bandwidth

% number of blocks
B=length(block_st);

% standard deviations
std_v=std(SCov_mat); %std(block_st)]

% interquartile range
iqr_v=iqr(SCov_mat);

% robust variation measure
s_v=min([std_v;(iqr_v/1.34)],[],1);

%starting value
b_st=min([(1.06*max(s_v)*B^(-1/5)*(1/16)) B]) ;
%------------------------------------------------------------------
%
%% Optimal bandwidth by minimization of obj function

% Set Bounds on parameters
LB=1e-6;           %lower bound of alpha is zero(+eps)
UB=B;        %no upper bound: 5 for numercial stability  during inversion

% optim
[b,~,exitflag,~]=fmincon('spot_vola_smooth_beta_lscvb_obj',b_st,[],[],[],[],LB,UB,[],options,block_st,SCov_mat,modi);

% output check
if ~any(exitflag==[-1 -2 -3])      % "normal convergence"
        b_out=b;
else
        b_out=b_st;
        disp('The LSCV Proc did not converge! Use starting values.');
end



        
    end