function m_ise=spot_vola_smooth_beta_lscvb_obj(b,block_st,SCov_mat,modi)
%------------------------------------------------------------------
%% spot_vola_smooth_beta_lscvb_obj
% objective function for bandwidth choice by least-squares cross
% validation
%------------------------------------------------------------------
%
% INPUTS
% b             -> smoothing bandwidth
% block_st    -> (Bx1) vector of block start times
% SCov_mat -> (Bx3) matrix of spot (co-)volatility estimates on
% blocks (kth row: [sigma_(x,k)^2 sigma_(xy,k) sigma_(y,k)^2])
% modi -> if >0, modified beta kernel is used, else
%             standard kernel
%------------------------------------------------------------------
% OUTPUTS
% m_ise ->    average of estimated ise across three dimensions
%------------------------------------------------------------------
%
%   Peter Malec, May 6, 2013
%
%------------------------------------------------------------------
%
%% Preparations

% make column vector
block_st=block_st(:);

% no of blocks
B=length(block_st);

% block indices
b_ind=1:B;
%------------------------------------------------------------------
%
%% Compute Loss Function

% empty output matrix
SCov_mat_sm =NaN*zeros(B,3);

% evaluate Smoothed estimates
    for i=1:B
        ind_red=setdiff(b_ind,i);
        kernelv=beta_kernel(block_st(ind_red),block_st(i),b,modi);
        weightv=kernelv/sum(kernelv); %((B-1)x1 vector)
        SCov_mat_sm(i,:)=sum(SCov_mat(ind_red,:).*weightv(:,ones(3,1))); %(1x3 vector)
     end   
 
% average of estimated ise across three dimensions
m_ise=mean(mean((SCov_mat-SCov_mat_sm).^2));



        
    end