function spot_covm_simp_grid_func(ticker,tdate,typed,cl_ind,rev_ind,input_v,startt,endt,...
    J_p,theta_h,theta_J_v,theta_K_v,K_p_thr,twost,lKb,ccorr,sdnoise_in,inpath,sourced,outpath)
%% spot_covm_simp_grid_func
%--------------------------------------------------------------
% local likelihood estimation of spot covariance matrices for specified
% estimation points. For fixed value of theta_h and grid of values
% of theta_J and theta_K (see below)
% Date is loaded. Outputs are saved directly
%
%--------------------------------------------------------------
% INPUT:
% ticker -> ticker symbol (string)
% tdate   -> data in matlab format
% cl_ind    -> if ==1, data cleaned according to proc by BNHLS(2009) is used
% rev_ind    -> if ==1, only obs with price revisions are used
% input_v -> points of estimation
% startt -> start of trading (in hours)
% endt   -> end of trading (in hours)
% J_p-> spectral cutoff for pilot estimates of spot covariances
% theta_h   -> proportionality parameter for block length
% theta_J_v     -> vector of values of proportionaliy parameter for cutoff
% theta_K_v  -> vector of values of proportionality parameter for smoothing bandwidth
% K_p_thr    -> lower threshold for pilot smoothing bandwidth (relevant if
%                           K_p not specified): default=1
% twst     -> if >0: twostep estimation is used (estimates from first step
%                   used as pilots for second step
% lkB         -> if >0, shorter smoothing windows at beginning and end of
%                   day are used for spot cov estim (NOT PILOT!)
% ccorr -> if >0, correlation and variance estimates are corrected
% sdnoise_in -> "non iid noise" strcture with elemensts [alpha,Q_max,skips,inpathn], where
%                       alpha-> significance level for AC test
%                       Q_max-> maximum order of serial dependence + 1
%                       skips->skip sampling frequency (for correction as
%                       in H&L (2006, JBES)) in seconds, if empty, then no
%                                                       correction
%                       inpathn-> path for loading noise estimates
%                   Note: if sdnoise_in is empty, iid noise case is considered
%                       (variance estimated on the fly)
% inpath     -> path for loading data
% sourced   -> data source
% outpath  -> path for saving
%--------------------------------------------------------------
%
% Peter Malec,  February 12 2014 
%
% -------------------------------------------------------------------------
%   
%% Load Data

% clean?
if cl_ind==1
     cl_str='cl';            % cleaning string for output file
else
     cl_str='ncl';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end


% check for existence of file
%-----------------------------------------------------------------------------------
name=strcat(inpath,ticker,'\\',ticker,'_',datestr(tdate,'yyyymmdd'),'_',typed,'_',cl_str,'.mat');
index=isequal(exist(name,'file'),2);


if index
%---------------------------------------------------------
load(name);
if isequal(typed,'trades')
   midprice=trades;
end
if rev_ind==1
   midprice=keep_rev(midprice,2);
end

% estimate noise variance
%----------------------------------------------------
%----------------------------------------------------

% check if non-iid noise
if ~isempty(sdnoise_in)
    
    alpha=sdnoise_in.alpha;
    Q_max=sdnoise_in.Q_max;
    skips=sdnoise_in.skips;
    inpathn=sdnoise_in.inpathn;
    % alpha_label
    alpha_l=num2str(alpha);
    alpha_l(alpha_l=='.')='';
    
    % check for existence of files
        if ~isempty(skips)
            name_arrn=strcat(inpathn,ticker,'\\noise_est_',ticker,'_',sourced,'_',datestr(tdate,'yyyymmdd'),typed,cl_str,rev_str,'_alpha',alpha_l,'_Q',int2str(Q_max),'_ss',int2str(skips));
        else
            name_arrn=strcat(inpathn,ticker,'\\noise_est_',ticker,'_',sourced,'_',datestr(tdate,'yyyymmdd'),typed,cl_str,rev_str,'_alpha',alpha_l,'_Q',int2str(Q_max));
        end
        index_vn=isequal(exist(name_arrn,'file'),2);

      if index_vn
%---------------------------------------------------------  
    
        % load noise variance estimates
        load(name_arrn);
        if eta_est<=0
            disp(['Noise estimate for: ' ticker ' nonpositive. Use iid-based approach.'])
            data_temp=midprice;
            eta_est=noise_cov_est(data_temp(:,2),'cov');
            if eta_est<=0
                eta_est=noise_cov_est(data_temp(:,2),'var');
            end
        end
        eta2=eta_est;   
        
        % Loop over Grid and Compute Spot Cov- and Corr estimates
    %----------------------------------------------------------------------
    %initialize
    SigmaSpot_arr=NaN*zeros(length(input_v),length(theta_J_v),length(theta_K_v));
    LMM_conf_arr=NaN*zeros(5,length(theta_J_v),length(theta_K_v));
    %loop
    %-----------------------------------
    for i=1:length(theta_J_v)  
        %select value
        theta_J=theta_J_v(i);
        for j=1:length(theta_K_v)
                %select value
                theta_K=theta_K_v(j);
                % Estimate Spot cov mat
                [SigmaSpot_out,block_st,~,J_optv,J_p,K,K_p]=lle_spot_cov_md(input_v,{midprice},...
                eta2,startt,endt,1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,-1,lKb,ccorr);   
                %assign
                SigmaSpot_arr(:,i,j)=SigmaSpot_out;
                LMM_conf_arr(:,i,j)=[length(block_st); max(J_optv); J_p; K; K_p]; 
        end 
    end

    % Save outputs
    % -------------------------------------------------------------------------
    % label lKb
    if lKb>0
        lKbl='_lKb';
    else
        lKbl='';
    end
    % label ccorr
    if ccorr>0
        ccorrl='_ccorr';
    else
        ccorrl='';
    end
    %label twostep
    if twost>0
        twostl='_2st';
    else
        twostl='';
    end
    % revisions?
    if rev_ind==1
        rev_str='_rev';            
    else
        rev_str='';     
    end
    %clean labels
    theta_hl=num2str(theta_h);
    theta_hl(theta_hl=='.')='';
    %basename
    basename=strcat(outpath,ticker,'\\',sourced,'_',ticker,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJv',int2str(length(theta_J_v)),'tKv',int2str(length(theta_K_v)),'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,twostl,'_alpha',alpha_l,'_Q',int2str(Q_max));
    if ~isempty(skips)
        basename=strcat(basename,'_ss',int2str(skips));
    end
    %save spot covariance matrices
    scov_out_nout=strcat(basename,'_scov');
    save(scov_out_nout,'SigmaSpot_arr')
    %save LMM config
    LMM_conf_nout=strcat(basename,'_LMM_conf');
    save(LMM_conf_nout,'LMM_conf_arr')
        
        %---------------------------------------------------------   
    else
        
        disp(['Noise estimates missing for: ' ticker '. Skip day.'])

    
     end
    
else
    % iid noise: estimate noise variances on the fly
    %-----------------------------------------------

    eta2=noise_cov_est(midprice(:,2),'cov');
    if eta2<=0
    eta2=noise_cov_est(midprice(:,2),'var');
    end
 
    % Loop over Grid and Compute Spot Cov- and Corr estimates
    %----------------------------------------------------------------------
    %initialize
    SigmaSpot_arr=NaN*zeros(length(input_v),length(theta_J_v),length(theta_K_v));
    LMM_conf_arr=NaN*zeros(5,length(theta_J_v),length(theta_K_v));
    %loop
    %-----------------------------------
    for i=1:length(theta_J_v)  
        %select value
        theta_J=theta_J_v(i);
        for j=1:length(theta_K_v)
                %select value
                theta_K=theta_K_v(j);
                % Estimate Spot cov mat
                [SigmaSpot_out,block_st,~,J_optv,J_p,K,K_p]=lle_spot_cov_md(input_v,{midprice},...
                eta2,startt,endt,1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,-1,lKb,ccorr);   
                %assign
                SigmaSpot_arr(:,i,j)=SigmaSpot_out;
                LMM_conf_arr(:,i,j)=[length(block_st); max(J_optv); J_p; K; K_p]; 
        end 
    end

    % Save outputs
    % -------------------------------------------------------------------------
    % label lKb
    if lKb>0
        lKbl='_lKb';
    else
        lKbl='';
    end
    % label ccorr
    if ccorr>0
        ccorrl='_ccorr';
    else
        ccorrl='';
    end
    %label twostep
    if twost>0
        twostl='_2st';
    else
        twostl='';
    end
    % revisions?
    if rev_ind==1
        rev_str='_rev';            
    else
        rev_str='';     
    end
    %clean labels
    theta_hl=num2str(theta_h);
    theta_hl(theta_hl=='.')='';
    %basename
    basename=strcat(outpath,ticker,'\\',sourced,'_',ticker,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJv',int2str(length(theta_J_v)),'tKv',int2str(length(theta_K_v)),'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,twostl);
    %save spot covariance matrices
    scov_out_nout=strcat(basename,'_scov');
    save(scov_out_nout,'SigmaSpot_arr')
    %save LMM config
    LMM_conf_nout=strcat(basename,'_LMM_conf');
    save(LMM_conf_nout,'LMM_conf_arr')

end

%% file do not exist: do nothing
%----------------------------------------
else
    disp(['Data missing for ticker: ' ticker '. Skip day.'])
end



    
  
    