function L = chol3(A)
%% chol3
%---------------------------------------------------------
% cholesky decomposition of 3d array of symmetric 3x3 matrices 
%---------------------------------------------------------
% INPUT:
% A -> (3x3xn) array 
%--------------------------------------------------------------
% OUTPUT:
% L -> (3x3xn) array of lower triangular 3x3 matrices 
% -------------------------------------------------------------------------
%
% Peter Malec, April 19, 2012
%
% -------------------------------------------------------------------------
%       
%% Cholesky Decomp

% check dimensions
if size(A,1) ~= 3 || size(A,2) ~= 3
    error('A must be [3x3xn] array');
end

% no pages
n=size(A,3);

% initialize output array
L=zeros(3,3,n);

%compute elements
L(1,1,:)=sqrt(A(1,1,:));
L(2,1,:)=A(1,2,:)./L(1,1,:);
L(3,1,:)=A(1,3,:)./L(1,1,:);  %((1x1xn) arrays)

L(2,2,:)=sqrt(A(2,2,:)-L(2,1,:).^2);
L(3,2,:)=(A(2,3,:)-L(2,1,:).*L(3,1,:))./L(2,2,:);
L(3,3,:)=sqrt(A(3,3,:)-L(3,1,:).^2-L(3,2,:).^2);






