function Z_tilde = constrZ_tilde(d)
%% constrZ_tilde
%---------------------------------------------------------
% constructs matrix of fourth moments of d-dimensional
% standard Gaussian vector
%---------------------------------------------------------
% INPUT:
% d -> scalar: dimension of Gaussian vector
%--------------------------------------------------------------
% OUTPUT:
% Z_tilde -> (d^2 x d^2)  matrix of fourth moments of d-dimensional
%                   standard Gaussian vector
% -------------------------------------------------------------------------
%   Z ~ N(0, I_d), Z \in R^d
% Then: Z_tilde:=Cov(vec(ZZ'))
% -------------------------------------------------------------------------
% Peter Malec, December 10, 2013
%
% -------------------------------------------------------------------------
%       
%% Construct Z_tilde

% initialize output matrix
Z_tilde=zeros(d^2,d^2);


% use loop to assign values below and on main diag
%----------------------------------------------
for i=1:d
    for j=1:d
         ind_z1=d*(i-1)+j;
        for k=1:d
            for l=1:(ind_z1-d*(k-1))
               ind_z2=d*(k-1)+l;
               Z_tilde(ind_z1,ind_z2)=(1+(i==j))*isequal(sort(intersect([i j],[k l])),sort(unique([i j])))...
                   *isequal(sort(intersect([i j],[k l])),sort(unique([k l])));
            end
        end
     end
end

% use summetry to assign values above main diag
%----------------------------------------------
Z_tilde=Z_tilde+Z_tilde'-diag(diag(Z_tilde));



