function theta=get_theta_ma1(rho)
%% get_theta_ma1
%------------------------------------------------------------------
% get Ma-parameter for MA(1) process based on 1st order 
% autocorrelation and choose invertible solution
%---------------------------------------------------------
%
%% Preparations

%input check
if (rho>1)||(rho<-1)
    error('Corr needs to be between -1 and 1!')
end

% account for max and min correlations in ma(1)
if rho>0.5
    disp('Corr to high. Setting equal to 0.5')
    rho=0.5;
elseif rho<-0.5
    disp('Corr to low. Setting equal to -0.5')
    rho=-0.5;
end
%---------------------------------------------------------
%
%% Compute Theta

% get altern solutions
theta_v=[(1+sqrt(1-4*rho^2)) (1-sqrt(1-4*rho^2))]/(2*rho);

% get invertible solution
[~,m_ind]=min(abs(theta_v));
theta=theta_v(m_ind);
