function A_i=nd_inv_3x3sym(A)
%% nd_inv_3x3
%-----------------------------------------------------------------------
% Inverts every SYMMETRIC 3x3 matrix inside (3x3xn) array A
%------------------------------------------------------------------------
%
%% Preparations

% size of 3rd dimension
n=size(A,3);

% initialize array of matrix inverses
A_i=NaN*A;

%% Loop over 3rd dimension

for i=1:n
    
    % retrieve ith matrix
    A_m=squeeze(A(:,:,i));
    
    % compute determinant using symmetry
    det_A=A_m(1,1)*A_m(2,2)*A_m(3,3)+2*A_m(1,2)*A_m(2,3)*A_m(1,3)...
        -A_m(1,3)^2*A_m(2,2)-A_m(1,1)*A_m(2,3)^2-A_m(1,2)^2*A_m(3,3);
    
    % compute adjoint
    %------------------------------------
    
    % vector of distinct elementsA
    adj_A_v=[A_m(2,2)*A_m(3,3)-A_m(2,3)^2;A_m(1,3)*A_m(2,3)-A_m(1,2)*A_m(3,3);...
        A_m(1,2)*A_m(2,3)-A_m(1,3)*A_m(2,2);A_m(1,1)*A_m(3,3)-A_m(1,3)^2;...
        A_m(1,3)*A_m(1,2)-A_m(1,1)*A_m(2,3);A_m(1,1)*A_m(2,2)-A_m(1,2)^2];
    
    % create symmetric matrix
    adj_A=tril(ones(3));
    adj_A(logical(adj_A))=adj_A_v;
    adj_A_d=diag(adj_A);
    adj_A=adj_A+adj_A';
    adj_A(logical(eye(3)))=adj_A_d;
    
    %inverse
    %-----------------------------------
    A_i(:,:,i)=adj_A/det_A;
    
end
