function [A_i, A_s, eig_s ,v_s]=nd_inv_3x3sym_sing(A)
%% nd_inv_3x3
%-----------------------------------------------------------------------
% Inverts every SYMMETRIC 3x3 matrix inside (3x3xn) array A 
% and regularizes singular matrices by retaining 1st ev
%------------------------------------------------------------------------
%
%% Preparations

% size of 3rd dimension
n=size(A,3);

% initialize array of matrix inverses
A_i=NaN*A;

% array of singular matrices vector of indices and matrix of corresp eigenvectors
A_s=[];
eig_s=[];
v_s=[];

%% Loop over 3rd dimension

for i=1:n
    
    % retrieve ith matrix
    A_m=squeeze(A(:,:,i));
    
    % compute determinant using symmetry
    det_A=A_m(1,1)*A_m(2,2)*A_m(3,3)+2*A_m(1,2)*A_m(2,3)*A_m(1,3)...
        -A_m(1,3)^2*A_m(2,2)-A_m(1,1)*A_m(2,3)^2-A_m(1,2)^2*A_m(3,3);
    
    % check for singularity
    if (det_A <= eps) || (rcond(A_m) <= eps)
        
        % singular value decomposition
         [Q S V]=svds(A_m,3);      %inv=q*s^-1 *q'
         A_s=cat(3,A_s,A_m);
         eig_s=[eig_s S];
         v_s=[v_s;i];
         
         % inversion by singular value decomposition retaining 1st ev
         A_i(:,:,i)=Q(:,1)*S(1,1)^(-1)*Q(:,1)';
         
    else  % non - singular
        
        % compute adjoint
        %------------------------------------
    
        % vector of distinct elementsA
        adj_A_v=[A_m(2,2)*A_m(3,3)-A_m(2,3)^2;A_m(1,3)*A_m(2,3)-A_m(1,2)*A_m(3,3);...
        A_m(1,2)*A_m(2,3)-A_m(1,3)*A_m(2,2);A_m(1,1)*A_m(3,3)-A_m(1,3)^2;...
        A_m(1,3)*A_m(1,2)-A_m(1,1)*A_m(2,3);A_m(1,1)*A_m(2,2)-A_m(1,2)^2];
    
        % create symmetric matrix
        adj_A=tril(ones(3));
        adj_A(logical(adj_A))=adj_A_v;
        adj_A_d=diag(adj_A);
        adj_A=adj_A+adj_A';
        adj_A(logical(eye(3)))=adj_A_d;
    
        %inverse
        %-----------------------------------
        A_i(:,:,i)=adj_A/det_A;
    
    end
    
end
