function [HAC,q] = HAC_var(y,q)
%% HAC_var
%------------------------------------------------------------
% Estimate Long-run variance based on bartlett kernel
% following Andrews
%--------------------------------------------------------------
% INPUT:
% y -> (Tx1) vector of data
% q -> bandwidth (optional)
%--------------------------------------------------------------
% OUTPUT:
% HAC-> Long-run variance estimate
% -------------------------------------------------------------------------
%
% Peter Malec, May 10, 2014
%
% -------------------------------------------------------------------------
%       
%% Preparations

%nobs
T=length(y);

% demean process
y=y-mean(y);

%bandwidth
if nargin<2
    q=max([floor(4*(T/100)^(2/9)) 1]);
else
    if abs(q-floor(q))>0
        q=floor(q);
    end
    q=max([1 q]);
end
% -------------------------------------------------------------------------
%       
%% Estimate LR variance

% compute autocovariances
AC_v=NaN*zeros(q+1,1);
for h=0:q
    AC_v(h+1)=ACov(y,h);
end

%estimate
HAC=AC_v(1)+2*AC_v(2:end)'*(1-(1:q)'/(1+q));
