function comp_kde_est(ticker1,ticker2,asseti1,asseti2,d,momt,estimt,trans,maximumv,minimumv,date_v,startd,endd,typed,cl_ind,rev_ind,sel_ind,...
    J_p,theta_h,theta_J,theta_K,K_p_thr,twost,twostc,lKb,ccorr,inpath,sourced,outpath,Q_strc)
%% comp_kde_est
%--------------------------------------------------------------
% compute kdes of spot estimates across days
%--------------------------------------------------------------
% INPUT:
% ticker1 -> ticker symbol
% asseti1 -> index of first asset (relevant only if estimt=full and momt=cov) 
% d         -> total number of assets (matters only for estimt="full")
% momt   -> moment to estimate: 'vol' or 'cov'
% estimt  -> type of estimator: 'full' or 'pair' ('cov'), 'full', 'pair' or 'uni' ('vol') 
% trans      -> type of transformation: 'log','sqrt' or 'logsqrt', else
%                   empty
% maximumv -> (n_sel_indx1) vector of maximum estimates across days and
%                           pairs/ stocks
% date_v   -> vector of trading days in matlab format
% startd    -> first trading day of interest (Matlab format)
% cl_ind    -> if ==1, data cleaned according to proc by BNHLS(2009) is used
% rev_ind    -> if ==1, only obs with price revisions are used
% sel_ind  -> vector of relevant points of estimation
% J_p-> spectral cutoff for pilot estimates of spot covariances
% theta_h   -> proportionality parameter for block length (relevant if B
%                           not specified)
% theta_J     -> proportionaliy parameter for cutoff (relevant if J
%                           or J_p not specified)
% theta_K    -> proportionality parameter for smoothing bandwidth (relevant if K
%                           or K_p not specified)
% K_p_thr    -> lower threshold for pilot smoothing bandwidth (relevant if
%                           K_p not specified): default=1
% twst     -> if >0: twostep estimation is used (estimates from first step
%                   used as pilots for second step
% twstc      -> if >0: Covariance matrices of smoothed spot (co-)volatilities
%   under the local parametric experiment   are computed using 2ndstep spot
%   covariance estimates (mattters only if 8 output arguments)
% lkB         -> if >0, shorter smoothing windows at beginning and end of
%                   day are used for spot cov estim (NOT PILOT!)
% ccorr -> if >0, correlation and variance estimates are corrected
% inpath     -> path for loading data
% sourced   -> data source
% outpath  -> path for saving
% Q_strc    -> structure containing inputs for non iid noise case
%--------------------------------------------------------------
%
% Peter Malec,  March 22 2014 
%
% -------------------------------------------------------------------------
%   
%% Preps

% Create vector of trading days in matlab date format
tdate_v=date_v(sort(find((date_v>=startd)&(date_v<=endd))));

% input check
if (~isempty(trans))&&(~isequal(momt,'vol'))
    error('Only spot VARIANCE estimates can be transformed!')
end
if (~isempty(trans))&&~ismember(trans,{'log','sqrt','logsqrt'})
    error('Possible transformations are: "log","sqrt","logsqrt"')
end

% label lKb
if lKb>0
     lKbl='_lKb';
else
     lKbl='';
end

% label ccorr
if ccorr>0
     ccorrl='_ccorr';
else
     ccorrl='';
end

%label twostep
if twost>0
     twostl='_2st';
else
     twostl='';
end

% label: estimator covariance
if twostc>0
      twostcl='_2stc';
else
      twostcl='';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

% clean?
if cl_ind==1
     cl_str='cl';            % cleaning string for output file
else
     cl_str='ncl';
end

%clean labels
theta_hl=num2str(theta_h);
theta_hl(theta_hl=='.')='';
theta_Jl=num2str(theta_J);
theta_Jl(theta_Jl=='.')='';
theta_Kl=num2str(theta_K);
theta_Kl(theta_Kl=='.')='';

% inputs for non-iid noise case
if ~isempty(Q_strc)
    Q_max=Q_strc.Q_max;
    alpha=Q_strc.alpha;
    skips=Q_strc.skips;
    alpha_l=num2str(alpha);
    alpha_l(alpha_l=='.')='';
else
    Q_max=1;
end
% -------------------------------------------------------------------------
%   
%% Collect Data

if isequal(estimt,'pair')
    
     % empty matrices for spot estimates estimates
     if isequal(momt,'cov')
           scov_mat=NaN*zeros(length(sel_ind),length(tdate_v));
     elseif isequal(momt,'vol')
         scov_mat1=NaN*zeros(length(sel_ind),length(tdate_v));
         scov_mat2=NaN*zeros(length(sel_ind),length(tdate_v));
     end
                                
 % loop over days
%-------------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);

    %name 
    basename=strcat(inpath,sourced,'_',ticker1,'_',ticker2,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,twostl,twostcl);
        
    if Q_max>1
        basename=strcat(basename,'_alpha',alpha_l,'_Q',int2str(Q_max));
        if ~isempty(skips)
            basename=strcat(basename,'_ss',int2str(skips));
        end
    end           
             
    % check for existence of file
    if isequal(exist(strcat(basename,'_scov.mat'),'file'),2);
    %------------------------

        %load    
        indat=iload(strcat(basename,'_scov.mat'),'SigmaSpot_out');    
        SigmaS=indat.SigmaSpot_out;
        
        % assign
        if isequal(momt,'cov')
            scov_mat(:,j)=SigmaS(sel_ind,2);
         elseif isequal(momt,'vol')
             scov_mat1(:,j)=SigmaS(sel_ind,1);
             scov_mat2(:,j)=SigmaS(sel_ind,3);
        end
        
        
    else
        
        disp(['Estimates for ' ticker1 ' and ' ticker2 ' for date ' datestr(tdate,'yyyy--mm--dd') ' are missing. Skip.'])                
        
    end

end

elseif isequal(estimt,'full')
    
    
     % empty matrices for spot estimates estimates
      scov_mat=NaN*zeros(length(sel_ind),length(tdate_v));
    
 % loop over days
%-------------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);

    %name 
    basename=strcat(inpath,sourced,'_',datestr(tdate,'yyyymmdd'),typed,'_d',int2str(d),'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,twostl,twostcl);
        
    if Q_max>1
        basename=strcat(basename,'_alpha',alpha_l,'_Q',int2str(Q_max));
        if ~isempty(skips)
            basename=strcat(basename,'_ss',int2str(skips));
        end
    end           
             
             
    % check for existence of file
    if isequal(exist(strcat(basename,'_scov.mat'),'file'),2);
    %------------------------

        %load    
        indat=iload(strcat(basename,'_scov.mat'),'SigmaSpot_out');   
        SigmaS=indat.SigmaSpot_out;
        
        %obtain relevant estimates and assign
        if isequal(momt,'cov')
            [SigmaSpot_out_sel,~]=retrieve_cov_el([asseti1;asseti2],SigmaS(sel_ind,:));
            scov_mat(:,j)=SigmaSpot_out_sel(:,2);
         elseif isequal(momt,'vol')
             [SigmaSpot_out_sel,~]=retrieve_cov_el_univ(asseti1,SigmaS(sel_ind,:));
             scov_mat(:,j)=SigmaSpot_out_sel;
        end
        
        
    else
        
        disp(['Estimates for date ' datestr(tdate,'yyyy--mm--dd') ' are missing. Skip.'])                
        
    end

end

% -------------------------------------------------------------------------
%
elseif (isequal(momt,'vol'))&&(isequal(estimt,'uni'))
    
     % empty matrices for spot estimates estimates
      scov_mat=NaN*zeros(length(sel_ind),length(tdate_v));
    
                                
 % loop over days
%-------------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);

    %name 
    basename=strcat(inpath,sourced,'_',ticker1,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,twostl,twostcl);
        
   if Q_max>1
        basename=strcat(basename,'_alpha',alpha_l,'_Q',int2str(Q_max));
        if ~isempty(skips)
            basename=strcat(basename,'_ss',int2str(skips));
        end
    end            
             
             
   % check for existence of file
    if isequal(exist(strcat(basename,'_scov.mat'),'file'),2);
    %------------------------

        %load    
        indat=iload(strcat(basename,'_scov.mat'),'SigmaSpot_out');    
        SigmaS=indat.SigmaSpot_out;
        
        % assign
            scov_mat(:,j)=SigmaS(sel_ind,:);
        
    else
        
        disp(['Estimates for ' ticker1 ' for date ' datestr(tdate,'yyyy--mm--dd') ' are missing. Skip.'])                
        
    end

end
    
else
    
    error('estimt needs to be either "full" or "pair". Only for volatilities, estimt can be "uni"! ')
    
end
% -------------------------------------------------------------------------
%   
%% Compute KDEs for each point of estimation 

%annualize
if (isequal(momt,'vol'))&&(isequal(estimt,'pair'))
    scov_mat1=252*scov_mat1;
    scov_mat2=252*scov_mat2;
else
    scov_mat=252*scov_mat;
end

%transformations
if isequal(momt,'vol')
    if ~isequal(estimt,'pair')
        if isequal(trans,'sqrt')
            scov_mat=sqrt(scov_mat);
        elseif isequal(trans,'log')
            scov_mat=log(scov_mat);
        elseif isequal(trans,'logsqrt')
            scov_mat=log(sqrt(scov_mat));
        end
    else
        if isequal(trans,'sqrt')
            scov_mat1=sqrt(scov_mat1);
            scov_mat2=sqrt(scov_mat2);
        elseif isequal(trans,'log')
            scov_mat1=log(scov_mat1);
            scov_mat2=log(scov_mat2);
        elseif isequal(trans,'logsqrt')
            scov_mat1=log(sqrt(scov_mat1));
            scov_mat2=log(sqrt(scov_mat2));
        end
    end
end

%clean
if isequal(momt,'cov')
    scov_mat(imag(scov_mat)~=0)=NaN;
    scov_mat(~isfinite(scov_mat))=NaN;
elseif isequal(momt,'vol')
    if ~isequal(estimt,'pair')
        scov_mat(imag(scov_mat)~=0)=NaN;
        scov_mat(~isfinite(scov_mat))=NaN;
        if (isempty(trans)||isequal(trans,'sqrt'))
              scov_mat(scov_mat<=0)=NaN;
        end
    else
        scov_mat1(imag(scov_mat1)~=0)=NaN;
        scov_mat2(imag(scov_mat2)~=0)=NaN;
        scov_mat1(~isfinite(scov_mat1))=NaN;
        scov_mat2(~isfinite(scov_mat2))=NaN;
        if (isempty(trans)||isequal(trans,'sqrt'))
              scov_mat1(scov_mat1<=0)=NaN;
              scov_mat2(scov_mat2<=0)=NaN;
        end
    end
end


% estimation points for KDE 
n=2^11;
inp_kde=NaN*zeros(length(sel_ind),n);
for i=1:length(sel_ind)
    maximum=maximumv(i); minimum=minimumv(i);
    Range=maximum-minimum;
    MIN=minimum-Range/10; MAX=maximum+Range/10;
    R=MAX-MIN; dx=R/(n-1); 
    inp_kde(i,:)=MIN+(0:dx:R);
end

% initialize
if isequal(momt,'cov')
     KDE_mat=NaN*zeros(length(sel_ind),n);
     bw_vec=NaN*zeros(length(sel_ind),1);
elseif isequal(momt,'vol')
    if isequal(estimt,'pair')
        KDE_mat1=NaN*zeros(length(sel_ind),n);
        bw_vec1=NaN*zeros(length(sel_ind),1);
        KDE_mat2=NaN*zeros(length(sel_ind),n);   
        bw_vec2=NaN*zeros(length(sel_ind),1);
    else
        KDE_mat=NaN*zeros(length(sel_ind),n);
        bw_vec=NaN*zeros(length(sel_ind),1);
    end
end


% loop across estimation points and compute KDE
for i=1:length(sel_ind)
    
    %KDE
    if isequal(momt,'cov')
        data_in=scov_mat(i,:)';
        data_in=data_in(~isnan(data_in));
        [dens,~,bw]=ksdensity(data_in,inp_kde(i,:)');
        KDE_mat(i,:)=dens(:)';
        bw_vec(i)=bw;
    elseif isequal(momt,'vol')
        if isequal(estimt,'pair')
            if isempty(trans)||isequal(trans,'sqrt')
                data_in=scov_mat1(i,:)';
                data_in=data_in(~isnan(data_in));
                [dens,~,bw]=ksdensity(data_in,inp_kde(i,:)','support','positive');
                KDE_mat1(i,:)=dens(:)';
                bw_vec1(i)=bw;
                data_in=scov_mat2(i,:)';
                data_in=data_in(~isnan(data_in));
                [dens,~,bw]=ksdensity(data_in,inp_kde(i,:)','support','positive');
                KDE_mat2(i,:)=dens(:)';
                bw_vec2(i)=bw;
            elseif isequal(trans,'log')||isequal(trans,'logsqrt')
                data_in=scov_mat1(i,:)';
                data_in=data_in(~isnan(data_in));
                [dens,~,bw]=ksdensity(data_in,inp_kde(i,:)');
                KDE_mat1(i,:)=dens(:)';
                bw_vec1(i)=bw;
                data_in=scov_mat2(i,:)';
                data_in=data_in(~isnan(data_in));
                [dens,~,bw]=ksdensity(data_in,inp_kde(i,:)');
                KDE_mat2(i,:)=dens(:)';
                bw_vec2(i)=bw;
            end
        else
            if isempty(trans)||isequal(trans,'sqrt')
                data_in=scov_mat(i,:)';
                data_in=data_in(~isnan(data_in));
                [dens,~,bw]=ksdensity(data_in,inp_kde(i,:)','support','positive');
                KDE_mat(i,:)=dens(:)';
                bw_vec(i)=bw;
            elseif isequal(trans,'log')||isequal(trans,'logsqrt')
                data_in=scov_mat(i,:)';
                data_in=data_in(~isnan(data_in));
                [dens,~,bw]=ksdensity(data_in,inp_kde(i,:)');
                KDE_mat(i,:)=dens(:)';
                bw_vec(i)=bw;
            end
        end
    end
    
end
% -------------------------------------------------------------------------
%   
%% Save Results

%collect results
if isequal(momt,'cov')
       kde_res.kde_mat=KDE_mat;
       kde_res.bw_vec=bw_vec;
    elseif isequal(momt,'vol')
        if isequal(estimt,'pair')
            kde_res.kde_mat1=KDE_mat1;
            kde_res.bw_vec1=bw_vec1;
            kde_res.kde_mat2=KDE_mat2;
            kde_res.bw_vec2=bw_vec2;
        else
            kde_res.kde_mat=KDE_mat;
            kde_res.bw_vec=bw_vec;
        end
end


%trans label
if isempty(trans)
    transl='';
else
    transl=strcat('_',trans);
end

%save
if isequal(momt,'cov')
        nout=strcat(outpath,'KDE_',momt,'_',estimt,transl,'_np',int2str(length(sel_ind)),'_',sourced,'_',ticker1,'_',ticker2,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,twostl);
elseif isequal(momt,'vol')
   if ~isequal(estimt,'pair')
        nout=strcat(outpath,'KDE_',momt,'_',estimt,transl,'_np',int2str(length(sel_ind)),'_',sourced,'_',ticker1,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,twostl);
    else
        nout=strcat(outpath,'KDE_',momt,'_',estimt,transl,'_np',int2str(length(sel_ind)),'_',sourced,'_',ticker1,'_',ticker2,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,twostl);
   end
end

if Q_max>1
        nout=strcat(nout,'_alpha',alpha_l,'_Q',int2str(Q_max));
        if ~isempty(skips)
            nout=strcat(nout,'_ss',int2str(skips));
        end
end

%save
save(nout,'kde_res');



             
             
             
             
             
             
    

