function [maximum, minimum]=find_max_min(ticker1,ticker2,asseti1,asseti2,d,momt,estimt,trans,date_v,startd,endd,typed,cl_ind,rev_ind,sel_ind,...
    J_p,theta_h,theta_J,theta_K,K_p_thr,twost,twostc,lKb,ccorr,inpath,sourced)
%% find_max_min
%--------------------------------------------------------------
% find maximum and minimum of ann. (transformed) spot 
% (co-) variance estimates across days
%--------------------------------------------------------------
% INPUT:
% ticker1 -> ticker symbol
% asseti1 -> index of first asset (relevant only if estimt=full and momt=cov) 
% d         -> total number of assets (matters only for estimt="full")
% momt   -> moment to estimate: 'vol' or 'cov'
% estimt  -> type of estimator: 'full' or 'pair' ('cov'), 'full', 'pair' or 'uni' ('vol') 
% trans      -> type of transformation: 'log','sqrt' or 'logsqrt', else
%                   empty
% date_v   -> vector of trading days in matlab format
% startd    -> first trading day of interest (Matlab format)
% cl_ind    -> if ==1, data cleaned according to proc by BNHLS(2009) is used
% rev_ind    -> if ==1, only obs with price revisions are used
% sel_ind  -> vector of relevant points of estimation
% J_p-> spectral cutoff for pilot estimates of spot covariances
% theta_h   -> proportionality parameter for block length (relevant if B
%                           not specified)
% theta_J     -> proportionaliy parameter for cutoff (relevant if J
%                           or J_p not specified)
% theta_K    -> proportionality parameter for smoothing bandwidth (relevant if K
%                           or K_p not specified)
% K_p_thr    -> lower threshold for pilot smoothing bandwidth (relevant if
%                           K_p not specified): default=1
% twst     -> if >0: twostep estimation is used (estimates from first step
%                   used as pilots for second step
% twstc      -> if >0: Covariance matrices of smoothed spot (co-)volatilities
%   under the local parametric experiment   are computed using 2ndstep spot
%   covariance estimates (mattters only if 8 output arguments)
% lkB         -> if >0, shorter smoothing windows at beginning and end of
%                   day are used for spot cov estim (NOT PILOT!)
% ccorr -> if >0, correlation and variance estimates are corrected
% inpath     -> path for loading data
% sourced   -> data source
%------------------------------------------------------------------------------------
% Output:
% maximum  -> (n_sel_ind x1) vector of maxima across days for each
%                       intraday time
% minimum   
%--------------------------------------------------------------
%
% Peter Malec,  March 22 2014 
%
% -------------------------------------------------------------------------
%   
%% Preps

% Create vector of trading days in matlab date format
tdate_v=date_v(sort(find((date_v>=startd)&(date_v<=endd))));

% input check
if (~isempty(trans))&&(~isequal(momt,'vol'))
    error('Only spot VARIANCE estimates can be transformed!')
end
if (~isempty(trans))&&~ismember(trans,{'log','sqrt','logsqrt'})
    error('Possible transformations are: "log","sqrt","logsqrt"')
end

% label lKb
if lKb>0
     lKbl='_lKb';
else
     lKbl='';
end

% label ccorr
if ccorr>0
     ccorrl='_ccorr';
else
     ccorrl='';
end

%label twostep
if twost>0
     twostl='_2st';
else
     twostl='';
end

% label: estimator covariance
if twostc>0
      twostcl='_2stc';
else
      twostcl='';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

% clean?
if cl_ind==1
     cl_str='cl';            % cleaning string for output file
else
     cl_str='ncl';
end

%clean labels
theta_hl=num2str(theta_h);
theta_hl(theta_hl=='.')='';
theta_Jl=num2str(theta_J);
theta_Jl(theta_Jl=='.')='';
theta_Kl=num2str(theta_K);
theta_Kl(theta_Kl=='.')='';
% -------------------------------------------------------------------------
%   
%% Collect Data

if isequal(estimt,'pair')
    
     % empty matrices for spot estimates estimates
     if isequal(momt,'cov')
           scov_mat=NaN*zeros(length(sel_ind),length(tdate_v));
     elseif isequal(momt,'vol')
         scov_mat1=NaN*zeros(length(sel_ind),length(tdate_v));
         scov_mat2=NaN*zeros(length(sel_ind),length(tdate_v));
     end
                                
 % loop over days
%-------------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);

    %name 
    basename=strcat(inpath,sourced,'_',ticker1,'_',ticker2,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,twostl,twostcl);
        
    % check for existence of file
    if isequal(exist(strcat(basename,'_scov.mat'),'file'),2);
    %------------------------

        %load    
        indat=iload(strcat(basename,'_scov.mat'),'SigmaSpot_out');    
        SigmaS=indat.SigmaSpot_out;
        
        % assign
        if isequal(momt,'cov')
            scov_mat(:,j)=SigmaS(sel_ind,2);
         elseif isequal(momt,'vol')
             scov_mat1(:,j)=SigmaS(sel_ind,1);
             scov_mat2(:,j)=SigmaS(sel_ind,3);
        end
        
        
    else
        
        disp(['Estimates for ' ticker1 ' and ' ticker2 ' for date ' datestr(tdate,'yyyy--mm--dd') ' are missing. Skip.'])                
        
    end

end

elseif isequal(estimt,'full')
    
    
     % empty matrices for spot estimates estimates
      scov_mat=NaN*zeros(length(sel_ind),length(tdate_v));
    
 % loop over days
%-------------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);

    %name 
    basename=strcat(inpath,sourced,'_',datestr(tdate,'yyyymmdd'),typed,'_d',int2str(d),'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,twostl,twostcl);
        
    % check for existence of file
    if isequal(exist(strcat(basename,'_scov.mat'),'file'),2);
    %------------------------

        %load    
        indat=iload(strcat(basename,'_scov.mat'),'SigmaSpot_out');   
        SigmaS=indat.SigmaSpot_out;
        
        %obtain relevant estimates and assign
        if isequal(momt,'cov')
            [SigmaSpot_out_sel,~]=retrieve_cov_el([asseti1;asseti2],SigmaS(sel_ind,:));
            scov_mat(:,j)=SigmaSpot_out_sel(:,2);
         elseif isequal(momt,'vol')
             [SigmaSpot_out_sel,~]=retrieve_cov_el_univ(asseti1,SigmaS(sel_ind,:));
             scov_mat(:,j)=SigmaSpot_out_sel;
        end
        
        
    else
        
        disp(['Estimates for date ' datestr(tdate,'yyyy--mm--dd') ' are missing. Skip.'])                
        
    end

end

% -------------------------------------------------------------------------
%
elseif (isequal(momt,'vol'))&&(isequal(estimt,'uni'))
    
     % empty matrices for spot estimates estimates
      scov_mat=NaN*zeros(length(sel_ind),length(tdate_v));
    
                                
 % loop over days
%-------------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);

    %name 
    basename=strcat(inpath,sourced,'_',ticker1,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,twostl,twostcl);
        
    % check for existence of file
    if isequal(exist(strcat(basename,'_scov.mat'),'file'),2);
    %------------------------

        %load    
        indat=iload(strcat(basename,'_scov.mat'),'SigmaSpot_out');    
        SigmaS=indat.SigmaSpot_out;
        
        % assign
            scov_mat(:,j)=SigmaS(sel_ind,:);
        
    else
        
        disp(['Estimates for ' ticker1 ' for date ' datestr(tdate,'yyyy--mm--dd') ' are missing. Skip.'])                
        
    end

end
    
else
    
    error('estimt needs to be either "full" or "pair". Only for volatilities, estimt can be "uni"! ')
    
end
% -------------------------------------------------------------------------
%   
%% Compute KDEs for each point of estimation 

% handle pair-wise vola case
if (isequal(momt,'vol'))&&(isequal(estimt,'pair'))
    scov_mat=[scov_mat1 scov_mat2];
end

%annualize
scov_mat=252*scov_mat;

%transformations
if isequal(momt,'vol')
    if isequal(trans,'sqrt')
        scov_mat=sqrt(scov_mat);
    elseif isequal(trans,'log')
        scov_mat=log(scov_mat);
    elseif isequal(trans,'logsqrt')
        scov_mat=log(sqrt(scov_mat));
    end
end

%clean
scov_mat(imag(scov_mat)~=0)=NaN;
scov_mat(~isfinite(scov_mat))=NaN;
if isequal(momt,'vol')&&(isempty(trans)||isequal(trans,'sqrt'))
              scov_mat(scov_mat<=0)=NaN;
end

% estimation points for KDE 
minimum=nanmin(scov_mat,[],2); maximum=nanmax(scov_mat,[],2);


             
             
             
    

