%% run_LLE_SPOTCOVCORR_ADAPT_EST_01062016.m
%--------------------------------------------------------------------------
% Estimate Spot Correlation using LOBSER/TAQ Data by LLE from
% m-dimensional covariance matrix or pair-wise
% using one-sided (i.e. adaptive estimator)
%--------------------------------------------------------------------------
%
%Peter Malec, June 1, 2016
%
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath =1;              

% source of data
source_d='LOBSTER';           % UPPER CASE!

% Stock
ticker_a      ={'AAPL','AMZN'}; % apr 13
% ticker_a      ={'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
%     'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','AMAT','CMCSA'}; % apr 13

% datatype
typed='midp';           % midp: midquotes, trad: trades

% indices of relevant assets
asseti=[2; 1];

% dates
tdate_v=[datenum('6 may 10') datenum('27 dec 12') datenum('23 apr 13')];

% points of estimation
input_v= linspace(1.5/6.5,1,100); %times are normalized (start at noon)
%input_v=0:0.001:1; %times are normalized

% start end end of trading (in hours)
startt=9.5;
endt=16;

% type if estimation
estimt='full'; % 'pair' or 'full'

%cleaning 
cl_ind=-1;           %if==1: cleaning is done

%revisions
rev_ind=1;     %if ==1, only obs with price revisions are used

%settings for lle
J_p=5;
theta_h=0.175;
theta_J=7;
theta_K=2;
K_p_thr=8;

% correction?
ccorr=1; % correction of variance and correlation estimates
ccorrlast=1; % last estimation step only

% less smoothing at end and beginning of day?
lKb=1;

% two step
twost=-1; % spot volas of 1st step are used as pilots for 2nd step

% covariances of estimates
twostc=1;   

% conf interval?
confi=1;   % if ci>0: conf intervals are computed

% daily estimate as horizontal line
daily=1;

% pre-specified y limits for comparison
comp_ylim=[];

% time of vertline
vertt=[datenum('14:00') datenum('14:20') datenum('13:07')] ;        % in format HH:MM:ss: if empty: no vertical line 
                        
% annotations(all following expr need to have same dimemsion)
text_pos_x=[];                   %different positions possible (if all elements in row are NaN: no labels for corresponding day)
halign_a={'left','left'};           % horizontal alignment of text (left or right)
long_ind_m=[];                   % indicator for long arrow-> arrows need same dir as above.
add_v=[]*0.00125;                           % correction (inr: 0.00125) for position of labels (positive if left, otherwise negative)


% lim correction for plot (added to upper bound) (relevant if econfi=1)
deltaY1=0;
deltaY2=0;
deltaX=0;

% plot transparent? (makes sense only if confidence intervals included...)
plot_trans=false;
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data

inpath=strcat(pathproject,'Data',filesep,source_d,filesep,'Filtered',filesep);

inpathFFF=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Add',filesep,'FFF',filesep);

addpath=strcat(pathproject,'Data',filesep,'Add',filesep);

outpath=strcat(pathproject,'Emp_AnA',filesep,'Plots',filesep);
% -------------------------------------------------------------------------
%
%% Preparations

% clean?
if cl_ind==1
    cl_str='cl';            % cleaning string for output file
else
    cl_str='ncl';
end

% label lKb
if lKb>0
     lKbl='_lKb';
else
     lKbl='';
end

% label ccorr
if ccorr>0
     ccorrl='_ccorr';
else
     ccorrl='';
end

% label ccorr
if ccorrlast>0
    ccorrlastl='_ccorrl';
else
    ccorrlastl='';
end

%label twostep
if twost>0
     twostl='_2st';
else
     twostl='';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

% daily 
if daily==1
    daily_str='_dl';
else
    daily_str='';
end

%clean labels
theta_hl=num2str(theta_h);
theta_hl(theta_hl=='.')='';
theta_Jl=num2str(theta_J);
theta_Jl(theta_Jl=='.')='';
theta_Kl=num2str(theta_K);
theta_Kl(theta_Kl=='.')='';
% -------------------------------------------------------------------------
%
%% loop over trading days
%----------------------------------------------
for ddd=1:length(tdate_v)

    % select date and display
    tdate=tdate_v(ddd);
    disp(datestr(tdate,'yyyy--mm--dd'))
% -------------------------------------------------------------------------
%
%% Estimation by Pairwise Approach

if isequal(estimt,'pair')

%load data
%--------------------------------------------------------------
%empty cell array
PRICETIME=cell(2,1);

% loop across assets
for i=1:2
    name_temp=strcat(inpath,ticker_a{asseti(i)},filesep,ticker_a{asseti(i)},'_',datestr(tdate,'yyyymmdd'),'_',typed,'_',cl_str,'.mat');
    load(name_temp);
    if isequal(typed,'trades')
        midprice=trades;
    end
    if rev_ind==1
        midprice=keep_rev(midprice,2);
    end
    PRICETIME{i}=midprice;
end

% Estimate Spot corr
%------------------------------
if confi>0
    % spot covs
    [SigmaSpot_out,block_st_out,block_end_out,J_opt_out,J_p_v_out,K_v_out,K_p_v_out,noisev_m_out,nobs_v_out,CovSigmaSpot_out]=lle_spot_cov_md_adpt_mult(input_v,PRICETIME,startt,endt,...
        1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,twostc,ccorr,ccorrlast);
        
    % load z_tilde
    name_Z=strcat(addpath,'Z_tilde_d',int2str(2),'.mat');
    if isequal(exist(name_Z,'file'),2);
        load(name_Z);
    else
        Z_tilde = constrZ_tilde(2);
    end
    
    % corr with variances of corrs
     [SpotCorr,SpotCorr_var]=comp_corr_md([2; 1],SigmaSpot_out,CovSigmaSpot_out,Z_tilde);
     
     % covariances
     [SpotCov,SpotCov_var]=retrieve_cov_el([2; 1],SigmaSpot_out,CovSigmaSpot_out,Z_tilde);
     SpotCov=252*SpotCov(:,2); 
     SpotCov_var=252^2*squeeze(SpotCov_var(2,2,:));
    
    % approximate 95% conf intervals
    ci_upper=SpotCorr+1.96*sqrt(SpotCorr_var);
    ci_lower=SpotCorr-1.96*sqrt(SpotCorr_var);
    ci_upper_cov=SpotCov+1.96*sqrt(SpotCov_var);
    ci_lower_cov=SpotCov-1.96*sqrt(SpotCov_var);
    
    
    
else
    
    % spot covs
    [SigmaSpot_out,block_st_out,block_end_out,J_opt_out,J_p_v_out,K_v_out,K_p_v_out,noisev_m_out,nobs_v_out]=lle_spot_cov_md_adpt_mult(input_v,PRICETIME,startt,endt,...
        1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,twostc,ccorr,ccorrlast);

    % corr 
    [SpotCorr,~]=comp_corr_md([2; 1],SigmaSpot_out);
    
    % covariances
     [SpotCov,~]=retrieve_cov_el([2; 1],SigmaSpot_out);
     SpotCov=252*SpotCov(:,2); 

    
end
% -------------------------------------------------------------------------
%
%% Estimation by Full Matrix Approach

elseif isequal(estimt,'full')
    
%load data
%--------------------------------------------------------------

% no stocks
m=length(ticker_a);

%empty cell array
PRICETIME=cell(m,1);

% loop across assets
for i=1:m
    name_temp=strcat(inpath,ticker_a{i},filesep,ticker_a{i},'_',datestr(tdate,'yyyymmdd'),'_',typed,'_',cl_str,'.mat');
    load(name_temp);
    if isequal(typed,'trades')
        midprice=trades;
    end
    if rev_ind==1
        midprice=keep_rev(midprice,2);
    end
    PRICETIME{i}=midprice;
end

% Estimate Spot corr
%------------------------------
if confi>0
      % spot covs
    [SigmaSpot_out,block_st_out,block_end_out,J_opt_out,J_p_v_out,K_v_out,K_p_v_out,noisev_m_out,nobs_v_out,CovSigmaSpot_out]=lle_spot_cov_md_adpt_mult(input_v,PRICETIME,startt,endt,...
        1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,twostc,ccorr,ccorrlast);
    
    % load z_tilde
    name_Z=strcat(addpath,'Z_tilde_d',int2str(m),'.mat');
    if isequal(exist(name_Z,'file'),2);
        load(name_Z);
    else
        Z_tilde = constrZ_tilde(m);
    end
    
    % corr with variances of corrs
     [SpotCorr,SpotCorr_var]=comp_corr_md(asseti,SigmaSpot_out,CovSigmaSpot_out,Z_tilde);
     
     % covariances
     [SpotCov,SpotCov_var]=retrieve_cov_el(asseti,SigmaSpot_out,CovSigmaSpot_out,Z_tilde);
     SpotCov=252*SpotCov(:,2); 
     SpotCov_var=252^2*squeeze(SpotCov_var(2,2,:));
    
    % approximate 95% conf intervals
    ci_upper=SpotCorr+1.96*sqrt(SpotCorr_var);
    ci_lower=SpotCorr-1.96*sqrt(SpotCorr_var);
    ci_upper_cov=SpotCov+1.96*sqrt(SpotCov_var);
    ci_lower_cov=SpotCov-1.96*sqrt(SpotCov_var);
    

    
else
    
% spot covs
    [SigmaSpot_out,block_st_out,block_end_out,J_opt_out,J_p_v_out,K_v_out,K_p_v_out,noisev_m_out,nobs_v_out]=lle_spot_cov_md_adpt_mult(input_v,PRICETIME,startt,endt,...
        1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,twostc,ccorr,ccorrlast);

    % corr 
    [SpotCorr,~]=comp_corr_md(asseti,SigmaSpot_out);
    
     % covariances
     [SpotCov,~]=retrieve_cov_el(asseti,SigmaSpot_out);
    SpotCov=252*SpotCov(:,2); 
    
end


end
%-------------------------------------------------------------------------
%
%% Daily estimates
if isequal(daily,1)

if isequal(estimt,'pair')

% estimate noise variance
%-------------------------------------------------
noisev=NaN*zeros(2,1);

% loop across assets
for i=1:2
        data_temp=PRICETIME{i};
        eta2=noise_cov_est(data_temp(:,2),'cov');
        if eta2<=0
           eta2=noise_cov_est(data_temp(:,2),'var');
        end
    noisev(i)=eta2;   
end
        
% Estimate Spot corr
%------------------------------
    
% integr covs
[SigmaInt_out,block_st_out,block_end_out,J_optv_out,J_p_out,K_p_out]=lle_icov_md(PRICETIME,noisev,startt,endt,...
            1,1,[],[],J_p,[],theta_h,theta_J,theta_K,K_p_thr,twost,twostc,ccorr,ccorrlast); 
        
% corr 
[IntCorr,~]=comp_corr_md([2; 1],SigmaInt_out');

% covariances
 [IntCov,~]=retrieve_cov_el([2; 1],SigmaInt_out');
 IntCov=252*IntCov(:,2); 
% -------------------------------------------------------------------------
%
%% Estimation by Full Matrix Approach

elseif isequal(estimt,'full')
    
% estimate noise variance
%-------------------------------------------------
noisev=NaN*zeros(m,1);

% loop across assets
for i=1:m
        data_temp=PRICETIME{i};
        eta2=noise_cov_est(data_temp(:,2),'cov');
        if eta2<=0
           eta2=noise_cov_est(data_temp(:,2),'var');
        end
    noisev(i)=eta2;   
end

% Estimate Spot corr
%------------------------------

% spot covs
[SigmaInt_out,block_st_out,block_end_out,J_optv_out,J_p_out,K_p_out]=lle_icov_md(PRICETIME,noisev,startt,endt,...
            1,1,[],[],J_p,[],theta_h,theta_J,theta_K,K_p_thr,twost,twostc,ccorr,ccorrlast); 

% corr 
[IntCorr,~]=comp_corr_md(asseti,SigmaInt_out');

 % covariances
 [IntCov,~]=retrieve_cov_el(asseti,SigmaInt_out');
IntCov=252*IntCov(:,2); 
    
end

end
% -------------------------------------------------------------------------
%
%% Create Plot and Save

if ~plot_trans
    
    % classic ugly plot

% ylabels
ylabs1='Correlation';
ylabs2='Covariance';

% times for plot
times_pl=(input_v*(endt-startt)+9.5)/24;
                                % perc of 24h period
                                
% create vector of labels
if ~isempty(text_pos_x)
    if sum(isnan(text_pos_x(ddd,:)))<size(text_pos_x,2)
        if (size(text_pos_x,2)~=size(halign_a,2))||(size(text_pos_x,2)~=size(long_ind_m,2))||...
            (size(long_ind_m,2)~=size(halign_a,2))
            error('text_pos_x, long_ind_m and halign_a must have same no of columns!')
        end
        text_a=cell(size(text_pos_x,2),1);
        for i=1:length(text_a)
            if ~isnan(text_pos_x(ddd,i))
                base_str=strcat('$', int2str(i),')$');
                if ~isequal(long_ind_m(ddd,i),1)
                    l_str='';
                else
                    l_str='long';
                end
                if isequal(halign_a{ddd,i},'left')
                    text_a{i}=strcat('$\',l_str,'leftarrow\left(', int2str(i),'\right)$');
                else
                    text_a{i}=strcat('$\left(', int2str(i),'\right)\',l_str,'rightarrow$');
                end
            end
        end
    else
        text_a=cell(size(text_pos_x,2),1);
    end
else
    text_a=cell(size(text_pos_x,2),1);
end
                                
% minimum and max correlation for lower limit
if confi>0
   max_q=max(ci_upper);
    max_q_y1=ceil(10*max_q)/10;
    min_q=min(ci_lower);
    min_q_y1=floor(10*min_q)/10;
    if (abs(max_q-max_q_y1)<1e-13)&&(abs(max_q-1)>1e-13)
        max_q_y1=max_q_y1+0.1;
    end
    if (abs(min_q-min_q_y1)<1e-13)&&(abs(min_q)>1e-13)
        min_q_y1=min_q_y1-0.1;
    end
end                                
                                
% transpose
SpotCorr=SpotCorr';
SpotCov=SpotCov';
if confi>0
    ci_upper=ci_upper'; 
    ci_lower=ci_lower';
    ci_upper_cov=ci_upper_cov'; 
    ci_lower_cov=ci_lower_cov';
end

% prepare plot for confidence interv
if confi>0
     % preparation plot: use for limits
    if isempty(comp_ylim)
        h2pp=plot(times_pl,[ci_lower_cov;SpotCov;ci_upper_cov]);
        ytickv2 = get(gca,'YTick');
        clf;
        close;
    end
end

%opengl software % does not run on linux
opengl('save','software') % affects next sessions only

% plot
%-----------------------------
fh=figure;
 
set(fh, 'color', 'white');

if confi>0
    [AX,h1,h2]=plotyy(times_pl,[SpotCorr;ci_upper;ci_lower],times_pl,[SpotCov;ci_upper_cov;ci_lower_cov]);
    set(h1(1),'color',rgb('black'),'linestyle','-','linewidth',1.4);
    set(h2(1),'color',rgb('darkgrey'),'linestyle','-','linewidth',1.4);
    if isequal(length(asseti),2)
        set(h1(2),'color',rgb('black'),'linestyle','--','linewidth',1.3);
        set(h1(3),'color',rgb('black'),'linestyle','--','linewidth',1.3);
        set(h2(2),'color',rgb('darkgrey'),'linestyle','--','linewidth',1.3);
        set(h2(3),'color',rgb('darkgrey'),'linestyle','--','linewidth',1.3);
    end
else
    [AX,h1,h2]=plotyy(times_pl,SpotCorr,times_pl,SpotCov);
    set(h1(1),'color',rgb('black'),'linestyle','-','linewidth',1.4);
    set(h2(1),'color',rgb('darkgrey'),'linestyle','-','linewidth',1.4);
end

%l = legend({'$\rho_t$';'$\sigma_t$'});

set(gca, 'TickDir', 'in', 'Box', 'off' ,'XMinorTick','Off','YMinorTick','Off','linewidth',1.5,...
    'XGrid','on','Ygrid','on'); % here gca means get current axis

if ~isempty(comp_ylim)
    set(AX(1),'Ylim',comp_ylim(1,:))
    set(AX(2),'Ylim',comp_ylim(2,:))
    set(AX(1),'YTick',linspace(comp_ylim(1,1),comp_ylim(1,2),5));
    set(AX(2),'YTick',linspace(comp_ylim(2,1),comp_ylim(2,2),5));
    comp_yl='_compy';
else
    comp_yl='';
    if confi>0
        set(AX(1),'Ylim',[min_q_y1,max_q_y1])
         set(AX(1),'YTick',linspace(min_q_y1,max_q_y1,5));
    else
        ytickv1 = get(AX(1),'YTick');
        set(AX(1),'Ylim',[ytickv1(1),ytickv1(end)])
         set(AX(1),'YTick',linspace(ytickv1(1),ytickv1(end),5));
        ytickv2 = get(AX(2),'YTick');
    end    
    set(AX(2),'Ylim',[ytickv2(1),ytickv2(end)])
    set(AX(2),'YTick',linspace(ytickv2(1),ytickv2(end),5));
end

set(get(AX(1),'Xlabel'),'String','\bfseries Time of Day')

set(AX(1),'XColor',rgb('black'),'YColor',rgb('black'));
set(AX(2),'XColor',rgb('black'),'YColor',rgb('black'));
               
datetick(AX(1),'x','HH:MM');
datetick(AX(2),'x','HH:MM');

set(get(AX(1),'Ylabel'),'String',ylabs1) 
set(get(AX(2),'Ylabel'),'String',ylabs2) 

% set(AX(1),'XTick',(11:0.5:16)/24);
% set(AX(2),'XTick',(11:0.5:16)/24);
set(AX(2),'XTicklabel',{});

set(get(AX(1),'Xlabel'),'interpreter','latex','FontSize',10);
set(get(AX(1),'Ylabel'),'interpreter','latex','FontSize',10);
set(get(AX(2),'Ylabel'),'interpreter','latex','FontSize',10);

% set(l,'interpreter','latex','FontSize',8);
% set(l,'Location','North','Orientation','horizontal','box','off')

set(AX(1),'Xlim',[11/24 16/24])
set(AX(2),'Xlim',[11/24 16/24])


%# vertical line
if ~isempty(vertt)
    if ~isnan(vertt(ddd))
        gridxy(vertt(ddd)-datenum('00:00'), 'LineStyle','--', 'Color',rgb('black'),'linewidth',1.3)
        %matlab.graphics.axis.decorator.Baseline('BaseValue',vertt(ddd)-datenum('00:00'), 'Parent',gca, 'Axis',0, 'Visible','on','LineStyle','--', 'Color',rgb('black'),'LineWidth',1.3);
    end
end

%text
if sum(cellfun(@isempty,text_a))<length(text_a)
    for i=1:length(text_a)
        if ~isnan(text_pos_x(ddd,i))
            x_pos=text_pos_x(ddd,i)-datenum('00:00');
            y_pos=dquant_m(find(times_pl>=x_pos,1,'first'));
                 text(x_pos+add_v(i),y_pos,text_a{i},...
            'HorizontalAlignment',halign_a{ddd,i},'interpreter','latex','FontSize',10)
        end
    end
end

parent = get(h1(1),'Parent');
set(parent,'FontSize',10,'FontWeight','demi');    
parent = get(h2(1),'Parent');
set(parent,'FontSize',10,'FontWeight','demi');    


if confi>0
    ylim_org1=get(AX(1),'Ylim');
    set(AX(1),'Ylim',[ylim_org1(1)-deltaY1 ylim_org1(2)+deltaY1]);
    ylim_org2=get(AX(2),'Ylim');
    set(AX(2),'Ylim',[ylim_org2(1)-deltaY2 ylim_org2(2)+deltaY2]);
    xlim_org=get(AX(1),'Xlim');
    set(AX(1),'Xlim',[xlim_org(1)-deltaX xlim_org(2)+deltaX]);
    set(AX(2),'Xlim',[xlim_org(1)-deltaX xlim_org(2)+deltaX]);
end

% label vert
if ~isempty(vertt)
    if ~isnan(vertt(ddd))
      vertl='_vl';
    else
      vertl='';
    end
else
    vertl='';
end


% label vert
if sum(cellfun(@isempty,text_a))<length(text_a)
      textl='_tt';
else
      textl='';
end

% label: confidence intervals
if confi>0
    confil='_confi';
    if twostc>0
        twostcl='_2stc';
    else
        twostcl='';
    end
else
    confil='';
    twostcl='';
end

% horizonal line at daily estimates
if isequal(daily,1)
        hold(AX(1))
        hh1=plot(AX(1),get(AX(1),'Xlim'),[IntCorr IntCorr] );
        set(hh1(1),'color',rgb('black'),'linestyle','-','linewidth',1.4);
        
        hold(AX(2))
        hh2=plot(AX(2),get(AX(2),'Xlim'),[IntCov IntCov] );
        set(hh2(1),'color',rgb('darkgrey'),'linestyle','-','linewidth',1.4);
        
        hold(AX(1),'off')
        hold(AX(2),'off')
end

% save plot
if isequal(estimt,'pair')
    nameout=strcat(outpath,'spot_cov_corr_adapt_2d_',source_d,'_',ticker_a{asseti(1)},'_',ticker_a{asseti(2)},'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,confil,twostcl, vertl,textl,comp_yl,...
                 daily_str);
elseif isequal(estimt,'full')
    nameout=strcat(outpath,'spot_cov_corr_adapt_md_',source_d,'_',ticker_a{asseti(1)},'_',ticker_a{asseti(2)},'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,confil,twostcl,vertl,textl,comp_yl,...
                 daily_str);
end

export_fig(nameout,'-pdf','-png');

else
    
    % transparent plot
    
    % ylabels
ylabs1='Correlation';
ylabs2='Covariance';

% times for plot
times_pl=(input_v*(endt-startt)+9.5)/24;
                                % perc of 24h period
                                
% create vector of labels
if ~isempty(text_pos_x)
    if sum(isnan(text_pos_x(ddd,:)))<size(text_pos_x,2)
        if (size(text_pos_x,2)~=size(halign_a,2))||(size(text_pos_x,2)~=size(long_ind_m,2))||...
            (size(long_ind_m,2)~=size(halign_a,2))
            error('text_pos_x, long_ind_m and halign_a must have same no of columns!')
        end
        text_a=cell(size(text_pos_x,2),1);
        for i=1:length(text_a)
            if ~isnan(text_pos_x(ddd,i))
                base_str=strcat('$', int2str(i),')$');
                if ~isequal(long_ind_m(ddd,i),1)
                    l_str='';
                else
                    l_str='long';
                end
                if isequal(halign_a{ddd,i},'left')
                    text_a{i}=strcat('$\',l_str,'leftarrow\left(', int2str(i),'\right)$');
                else
                    text_a{i}=strcat('$\left(', int2str(i),'\right)\',l_str,'rightarrow$');
                end
            end
        end
    else
        text_a=cell(size(text_pos_x,2),1);
    end
else
    text_a=cell(size(text_pos_x,2),1);
end
                                
% minimum and max correlation for lower limit
if confi>0
   max_q=max(ci_upper);
    max_q_y1=ceil(10*max_q)/10;
    min_q=min(ci_lower);
    min_q_y1=floor(10*min_q)/10;
    if (abs(max_q-max_q_y1)<1e-13)&&(abs(max_q-1)>1e-13)
        max_q_y1=max_q_y1+0.1;
    end
    if (abs(min_q-min_q_y1)<1e-13)&&(abs(min_q)>1e-13)
        min_q_y1=min_q_y1-0.1;
    end
end                                
                                
% transpose
SpotCorr=SpotCorr';
SpotCov=SpotCov';
if confi>0
    ci_upper=ci_upper'; 
    ci_lower=ci_lower';
    ci_upper_cov=ci_upper_cov'; 
    ci_lower_cov=ci_lower_cov';
end

% prepare patch plot for confidence interv
if confi>0
    px=[times_pl,fliplr(times_pl)];
    py=[ci_lower,fliplr(ci_upper)];
    pz=[ci_lower_cov,fliplr(ci_upper_cov)];
     % preparation plot: use for limits
    if isempty(comp_ylim)
        h2pp=plot(times_pl,[ci_lower_cov;SpotCov;ci_upper_cov]);
        ytickv2 = get(gca,'YTick');
        clf;
        close;
    end
end

%opengl software % does not run on linux
opengl('save','software') % affects next sessions only

% plot
%-----------------------------
fh=figure;
 
set(fh, 'color', 'white');

[AX,h1,h2]=plotyy(times_pl,SpotCorr,times_pl,SpotCov);
set(h1(1),'color',rgb('black'),'linestyle','-','linewidth',1.4);
set(h2(1),'color',rgb('darkslategrey'),'linestyle','-','linewidth',1.4);
%l = legend({'$\rho_t$';'$\sigma_t$'});

set(gca, 'TickDir', 'in', 'Box', 'off' ,'XMinorTick','Off','YMinorTick','Off','linewidth',1.5,...
    'XGrid','on','Ygrid','on'); % here gca means get current axis

if ~isempty(comp_ylim)
    set(AX(1),'Ylim',comp_ylim(1,:))
    set(AX(2),'Ylim',comp_ylim(2,:))
    set(AX(1),'YTick',linspace(comp_ylim(1,1),comp_ylim(1,2),5));
    set(AX(2),'YTick',linspace(comp_ylim(2,1),comp_ylim(2,2),5));
    comp_yl='_compy';
else
    comp_yl='';
    if confi>0
        set(AX(1),'Ylim',[min_q_y1,max_q_y1])
         set(AX(1),'YTick',linspace(min_q_y1,max_q_y1,5));
    else
        ytickv1 = get(AX(1),'YTick');
        set(AX(1),'Ylim',[ytickv1(1),ytickv1(end)])
         set(AX(1),'YTick',linspace(ytickv1(1),ytickv1(end),5));
        ytickv2 = get(AX(2),'YTick');
    end    
    set(AX(2),'Ylim',[ytickv2(1),ytickv2(end)])
    set(AX(2),'YTick',linspace(ytickv2(1),ytickv2(end),5));
end

if confi>0
    % draw on axis 1
    set(gcf, 'CurrentAxes', AX(1));
    hp1=patch(px,py,1);
    set(hp1,'FaceColor',rgb('black'),'EdgeColor','none',...
        'EdgeAlpha',0.2,'FaceAlpha',0.2)
    % draw on axis 2
    set(gcf, 'CurrentAxes', AX(2));
    hp2=patch(px,pz,1);
    set(hp2,'FaceColor',rgb('darkslategrey'),'EdgeColor','none',...
        'EdgeAlpha',0.2,'FaceAlpha',0.2); % make patch transparent
end
               
set(get(AX(1),'Xlabel'),'String','\bfseries Time of Day') 

set(AX(1),'XColor',rgb('black'),'YColor',rgb('black'));
set(AX(2),'XColor',rgb('black'),'YColor',rgb('black'));
               
datetick(AX(1),'x','HH:MM');
datetick(AX(2),'x','HH:MM');

set(get(AX(1),'Ylabel'),'String',ylabs1) 
set(get(AX(2),'Ylabel'),'String',ylabs2) 

% set(AX(1),'XTick',(11:0.5:16)/24);
% set(AX(2),'XTick',(11:0.5:16)/24);
set(AX(2),'XTicklabel',{});


set(get(AX(1),'Xlabel'),'interpreter','latex','FontSize',10);
set(get(AX(1),'Ylabel'),'interpreter','latex','FontSize',10);
set(get(AX(2),'Ylabel'),'interpreter','latex','FontSize',10);

% set(l,'interpreter','latex','FontSize',8);
% set(l,'Location','North','Orientation','horizontal','box','off')

set(AX(1),'Xlim',[11/24 16/24])
set(AX(2),'Xlim',[11/24 16/24])


%# vertical line
if ~isempty(vertt)
     if ~isnan(vertt(ddd))
        gridxy(vertt(ddd)-datenum('00:00'), 'LineStyle','--', 'Color',rgb('black'),'linewidth',1.3)
        %matlab.graphics.axis.decorator.Baseline('BaseValue',vertt(ddd)-datenum('00:00'), 'Parent',gca, 'Axis',0, 'Visible','on','LineStyle','--', 'Color',rgb('black'),'LineWidth',1.3);
    end
end

%text
if sum(cellfun(@isempty,text_a))<length(text_a)
    for i=1:length(text_a)
        if ~isnan(text_pos_x(ddd,i))
            x_pos=text_pos_x(ddd,i)-datenum('00:00');
            y_pos=dquant_m(find(times_pl>=x_pos,1,'first'));
                 text(x_pos+add_v(i),y_pos,text_a{i},...
            'HorizontalAlignment',halign_a{ddd,i},'interpreter','latex','FontSize',10)
        end
    end
end

parent = get(h1(1),'Parent');
set(parent,'FontSize',10,'FontWeight','demi');    
parent = get(h2(1),'Parent');
set(parent,'FontSize',10,'FontWeight','demi');    


if confi>0
    ylim_org1=get(AX(1),'Ylim');
    set(AX(1),'Ylim',[ylim_org1(1)-deltaY1 ylim_org1(2)+deltaY1]);
    ylim_org2=get(AX(2),'Ylim');
    set(AX(2),'Ylim',[ylim_org2(1)-deltaY2 ylim_org2(2)+deltaY2]);
    xlim_org=get(AX(1),'Xlim');
    set(AX(1),'Xlim',[xlim_org(1)-deltaX xlim_org(2)+deltaX]);
    set(AX(2),'Xlim',[xlim_org(1)-deltaX xlim_org(2)+deltaX]);
end

% label vert
if ~isempty(vertt)
    if ~isnan(vertt(ddd))
      vertl='_vl';
    else
      vertl='';
    end
else
    vertl='';
end


% label vert
if sum(cellfun(@isempty,text_a))<length(text_a)
      textl='_tt';
else
      textl='';
end

% label: confidence intervals
if confi>0
    confil='_confi';
    if twostc>0
        twostcl='_2stc';
    else
        twostcl='';
    end
else
    confil='';
    twostcl='';
end

% horizonal line at daily estimates
if isequal(daily,1)
        hold(AX(1))
        hh1=plot(AX(1),get(AX(1),'Xlim'),[IntCorr IntCorr] );
        set(hh1(1),'color',rgb('black'),'linestyle','-','linewidth',1.4);
        
        hold(AX(2))
        hh2=plot(AX(2),get(AX(2),'Xlim'),[IntCov IntCov] );
        set(hh2(1),'color',rgb('darkgrey'),'linestyle','-','linewidth',1.4);
        
        hold(AX(1),'off')
        hold(AX(2),'off')
end

% save plot
if isequal(estimt,'pair')
    nameout=strcat(outpath,'spot_cov_corr_adapt_2d_',source_d,'_',ticker_a{asseti(1)},'_',ticker_a{asseti(2)},'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,confil,twostcl, vertl,textl,comp_yl,...
                 daily_str,'_transp');
elseif isequal(estimt,'full')
    nameout=strcat(outpath,'spot_cov_corr_adapt_md_',source_d,'_',ticker_a{asseti(1)},'_',ticker_a{asseti(2)},'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,confil,twostcl,vertl,textl,comp_yl,...
                 daily_str,'_transp');
end

export_fig(nameout,'-png');
    
end
% -------------------------------------------------------------------------
%
%% end loop over trading days
end




