%% run_LLE_SPOTCOV_adapt_EST_fulls_01072015.m
%--------------------------------------------------------------------------
% Estimate Spot Covariance matrices using LOBSTER data by adaptive 
% LLE for a cross-section of NASDAQ-traded assets 
%--------------------------------------------------------------------------
%
%Peter Malec, July 1, 2015
%
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath =1;              

% source of data
source_d='LOBSTER';           % UPPER CASE!

% Stock
ticker_a      ={'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
    'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','AMAT','CMCSA'}; % apr 13

% datatype
typed='midp';           % midp: midquotes, trad: trades

% dates (entire period or spec dates)
startd=datenum('1 may 10');
endd=datenum('30 apr 14');
tdate_v=[datenum('6 may 10') datenum('27 dec 12') datenum('23 apr 13')];
%tdate_v=[datenum('29 apr 13'):datenum('30 apr 13')]';
%[datenum('1 apr 13'):datenum('5 apr 13') datenum('8 apr 13'):datenum('12 apr 13') datenum('22 apr 13') datenum('24 apr 13'):datenum('26 apr 13')]';

% type if estimation
estimt='full'; % 'pair' or 'full'

% points of estimation
input_v= linspace(1.5/6.5,1,100); %times are normalized (start at noon)
%input_v=0:0.001:1; %times are normalized

% start end end of trading (in hours)
startt=9.5;
endt=16;

%cleaning 
cl_ind=-1;           %if==1: cleaning is done

%revisions
rev_ind=1;     %if ==1, only obs with price revisions are used

%settings for lle
J_p=5;
theta_h=0.175;
theta_J=7;
theta_K=2;
K_p_thr=8;

% configuration
configl='2F';

% compute covariances
compcov=-1;

% correction?
ccorr=1; % correction of variance and correlation estimates
ccorrlast=1; % last estimation step only

% less smoothing at end and beginning of day?
lKb=1;

% two step
twost=-1; % spot volas of 1st step are used as pilots for 2nd step

% covariances of estimates
twostc=1;   
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';      
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else

    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data

inpath=strcat(pathproject,'Data',filesep,source_d,filesep,'Filtered',filesep);

inpathn=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Noise_est',filesep);

addpath=strcat(pathproject,'Data',filesep,'Add',filesep);

if ~isequal(configl,'2F')
    outpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Covs',filesep);
else
    outpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Covs_2F',filesep);
end
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days

% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days_cl_',source_d,'_m32_20100501_20140430_thrq1500_thrtr800_tthrq300_tthrtr720_cl.mat'));
date_v=t_date_v_cl;
% -------------------------------------------------------------------------
%
%% Create Vectors of Asset Pairs

%create vector of plain asset indices
ind_vec=1:length(ticker_a);

%Create [length(ticker_a)*(length(ticker_a)-1)/2 x 2] matrix containing indices of (distinct) asset pairs 
corr_ind=nchoosek(ind_vec,2);       %Binomial coefficient (n k) >>>note: 1st element will always be larger!

%split
ind_1_v=corr_ind(:,1);           
ind_2_v=corr_ind(:,2);  
% -------------------------------------------------------------------------
%
%% Create Vectors of Asset Pairs and Estimate Spot Covariance Matrices and Correlations

% Create vector of trading days in matlab date format
if isempty(tdate_v)
    tdate_v=date_v(sort(find((date_v>=startd)&(date_v<=endd))));
end


% loop over trading days
%----------------------------------------------
for j=1:length(tdate_v)

    % select date and display
    tdate=tdate_v(j);
    disp(datestr(tdate,'yyyy--mm--dd'))

    if isequal(estimt,'pair')

        %loop across asset pairs
        for i=1:length(ind_1_v) 
            spot_covm_adapt_simp_func({ticker_a{ind_1_v(i)},ticker_a{ind_2_v(i)}},tdate,typed,cl_ind,rev_ind,input_v,startt,endt,...
        J_p,theta_h,theta_J,theta_K,K_p_thr,compcov,twost,twostc,lKb,ccorr,ccorrlast,inpath,source_d,outpath)
        end

    else

            % compute
        spot_covm_adapt_simp_func(ticker_a,tdate,typed,cl_ind,rev_ind,input_v,startt,endt,...
    J_p,theta_h,theta_J,theta_K,K_p_thr,compcov,twost,twostc,lKb,ccorr,ccorrlast,inpath,source_d,outpath)
    
    end

end








