%% run_LLE_SPOTVol_ADAPT_EST_01062016.m
%--------------------------------------------------------------------------
% Estimate Spot Volatility using LOBSER/TAQ Data by LLE from
% m-dimensional covariance matrix,pair-wise or on univariate basis
% using one-sided (i.e. adaptive estimator)
%--------------------------------------------------------------------------
%
%Peter Malec, June 1, 2016
%
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear all;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath =1;              

% source of data
source_d='LOBSTER';           % UPPER CASE!

% Stock
ticker_a      ={'AAPL','AMZN'}; % apr 13
% ticker_a      ={'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
%     'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','AMAT','CMCSA'}; % apr 13

% datatype
typed='midp';           % midp: midquotes, trad: trades

% indices of relevant assets
asseti=2;
asseti_p=1;  % which corresponding asset (required for pair-wise approach)

% dates
tdate_v=[datenum('6 may 10') datenum('27 dec 12') datenum('23 apr 13')];

% points of estimation
input_v= linspace(1.5/6.5,1,100); %times are normalized (start at noon)
%input_v=0:0.001:1; %times are normalized

% start end end of trading (in hours)
startt=9.5;
endt=16;

% type if estimation
estimt='full'; % 'pair' or 'full' or 'uni'

%cleaning 
cl_ind=-1;           %if==1: cleaning is done

%revisions
rev_ind=1;     %if ==1, only obs with price revisions are used

%settings for lle
J_p=5;
theta_h=0.175;
theta_J=7;
theta_K=2;
K_p_thr=8;

% correction?
ccorr=1; % correction of variance and correlation estimates
ccorrlast=1; % last estimation step only

% less smoothing at end and beginning of day?
lKb=1;

% two step
twost=-1; % spot volas of 1st step are used as pilots for 2nd step

% covariances of estimates
twostc=1;   

% conf interval?
confi=1;   % if ci>0: conf intervals are computed

% daily estimate as horizontal line
daily=1;

% pre-specified y limits for comparison
comp_ylim=[];

% time of vertline
vertt=[datenum('14:00') datenum('14:20') datenum('13:07')] ;        % in format HH:MM:ss: if empty: no vertical line 
                        
% annotations(all following expr need to have same dimemsion)
text_pos_x=[];                   %different positions possible (if all elements in row are NaN: no labels for corresponding day)
halign_a={'left','left'};           % horizontal alignment of text (left or right)
long_ind_m=[];                   % indicator for long arrow-> arrows need same dir as above.
add_v=[]*0.00125;                           % correction (inr: 0.00125) for position of labels (positive if left, otherwise negative)


% lim correction for plot (added to upper bound) (relevant if econfi=1)
deltaY=0;
deltaX=0;

% plot transparent? (makes sense only if confidence intervals included...)
plot_trans=false;
% -------------------------------------------------------------------------
%
%% Determination of Basepath

 
if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data

inpath=strcat(pathproject,'Data',filesep,source_d,filesep,'Filtered',filesep);

inpathFFF=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Add',filesep,'FFF',filesep);

addpath=strcat(pathproject,'Data',filesep,'Add',filesep);

outpath=strcat(pathproject,'Emp_AnA',filesep,'Plots',filesep);
% -------------------------------------------------------------------------
%
%% Preparations

% clean?
if cl_ind==1
    cl_str='cl';            % cleaning string for output file
else
    cl_str='ncl';
end

% label lKb
if lKb>0
     lKbl='_lKb';
else
     lKbl='';
end

% label ccorr
if ccorr>0
     ccorrl='_ccorr';
else
     ccorrl='';
end

% label ccorr
if ccorrlast>0
    ccorrlastl='_ccorrl';
else
    ccorrlastl='';
end


%label twostep
if twost>0
     twostl='_2st';
else
     twostl='';
end


% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

% daily 
if daily==1
    daily_str='_dl';
else
    daily_str='';
end

%clean labels
theta_hl=num2str(theta_h);
theta_hl(theta_hl=='.')='';
theta_Jl=num2str(theta_J);
theta_Jl(theta_Jl=='.')='';
theta_Kl=num2str(theta_K);
theta_Kl(theta_Kl=='.')='';

% vector of indices
asseti_v=[asseti asseti_p];
% -------------------------------------------------------------------------
%
%% loop over trading days
%----------------------------------------------
for ddd=1:length(tdate_v)

    % select date and display
    tdate=tdate_v(ddd);
    disp(datestr(tdate,'yyyy--mm--dd'))
% -------------------------------------------------------------------------
%
%% Estimation by Pairwise Approach

if isequal(estimt,'pair')

%load data
%--------------------------------------------------------------

%empty cell array
PRICETIME=cell(2,1);

% loop across assets
for i=1:2
    name_temp=strcat(inpath,ticker_a{asseti_v(i)},filesep,ticker_a{asseti_v(i)},'_',datestr(tdate,'yyyymmdd'),'_',typed,'_',cl_str,'.mat');
    load(name_temp);
    if isequal(typed,'trades')
        midprice=trades;
    end
    if rev_ind==1
        midprice=keep_rev(midprice,2);
    end
    PRICETIME{i}=midprice;
end


% estimate noise variance
%-------------------------------------------------
noisev=NaN*zeros(2,1);

% loop across assets
for i=1:2
        data_temp=PRICETIME{i};
        eta2=noise_cov_est(data_temp(:,2),'cov');
        if eta2<=0
           eta2=noise_cov_est(data_temp(:,2),'var');
        end
    noisev(i)=eta2;   
end


% Estimate Spot corr
%------------------------------
if confi>0
    % spot covs
    [SigmaSpot_out,block_st_out,block_end_out,J_opt_out,J_p_out,K_out,K_p_out,noisev_m_out,nobs_v_out,CovSigmaSpot_out]=lle_spot_cov_md_adpt_mult(input_v,PRICETIME,startt,endt,...
        1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,twostc,ccorr,ccorrlast);
    
    % load z_tilde
    name_Z=strcat(addpath,'Z_tilde_d',int2str(2),'.mat');
    if isequal(exist(name_Z,'file'),2);
        load(name_Z);
    else
        Z_tilde = constrZ_tilde(2);
    end
    
    %spot vol with variance
    SpotVol=sqrt(SigmaSpot_out(:,[1 3]))*sqrt(252);
    SpotVol_var=CovSigmaSpot_out([1 end],:)'./(4*SigmaSpot_out(:,[1 3]))*252;
    
   % approximate 95% conf interval
    ci_upper=SpotVol+1.96*sqrt(SpotVol_var);
    ci_lower=SpotVol-1.96*sqrt(SpotVol_var);
    
    % minimum and max value
    max_ci=max(ci_upper);
    min_ci=min(ci_lower);
    
else
    
    % spot covs
    [SigmaSpot_out,block_st_out,block_end_out,J_opt_out,J_p_out,K_out,K_p_out,noisev_m_out,nobs_v_out]=lle_spot_cov_md_adpt_mult(input_v,PRICETIME,startt,endt,...
        1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,twostc,ccorr,ccorrlast);

    %spot vol 
    SpotVol=sqrt(SigmaSpot_out(:,[1 3]))*sqrt(252);

    
end
% -------------------------------------------------------------------------
%
%% Estimation by Full Matrix Approach

elseif isequal(estimt,'full')
    
%load data
%--------------------------------------------------------------

% no stocks
m=length(ticker_a);

%empty cell array
PRICETIME=cell(m,1);

% loop across assets
for i=1:m
    name_temp=strcat(inpath,ticker_a{i},filesep,ticker_a{i},'_',datestr(tdate,'yyyymmdd'),'_',typed,'_',cl_str,'.mat');
    load(name_temp);
    if isequal(typed,'trades')
        midprice=trades;
    end
    if rev_ind==1
        midprice=keep_rev(midprice,2);
    end
    PRICETIME{i}=midprice;
end

% estimate noise variance
%-------------------------------------------------
noisev=NaN*zeros(m,1);

% loop across assets
for i=1:m
        data_temp=PRICETIME{i};
        eta2=noise_cov_est(data_temp(:,2),'cov');
        if eta2<=0
           eta2=noise_cov_est(data_temp(:,2),'var');
        end
    noisev(i)=eta2;   
end

% Estimate Spot corr
%------------------------------
if confi>0
    % spot covs
    [SigmaSpot_out,block_st_out,block_end_out,J_opt_out,J_p_out,K_out,K_p_out,noisev_m_out,nobs_v_out,CovSigmaSpot_out]=lle_spot_cov_md_adpt_mult(input_v,PRICETIME,startt,endt,...
        1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,twostc,ccorr,ccorrlast);
    
    % load z_tilde
    name_Z=strcat(addpath,'Z_tilde_d',int2str(m),'.mat');
    if isequal(exist(name_Z,'file'),2);
        load(name_Z);
    else
        Z_tilde = constrZ_tilde(m);
    end
    
    %spot vol with variance
    SpotVol=NaN*zeros(length(input_v),length(asseti_v));
    SpotVol_var=NaN*zeros(length(input_v),length(asseti_v));
    for iii=1:length(asseti_v)
        [SigmaSpot_out_sel,CovSigmaSpot_out_sel]=retrieve_cov_el_univ(asseti_v(iii),SigmaSpot_out,CovSigmaSpot_out,Z_tilde);
        SpotVol(:,iii)=sqrt(SigmaSpot_out_sel)*sqrt(252);
        SpotVol_var(:,iii)=CovSigmaSpot_out_sel./(4*SigmaSpot_out_sel)*252;
    end
    
    % approximate 95% conf interval
    ci_upper=SpotVol+1.96*sqrt(SpotVol_var);
    ci_lower=SpotVol-1.96*sqrt(SpotVol_var);
    
    % minimum and max value
    max_ci=max(ci_upper);
    min_ci=min(ci_lower);
    
else
    
    % spot covs
    [SigmaSpot_out,block_st_out,block_end_out,J_opt_out,J_p_out,K_out,K_p_out,noisev_m_out,nobs_v_out,CovSigmaSpot_out]=lle_spot_cov_md_adpt_mult(input_v,PRICETIME,startt,endt,...
        1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,twostc,ccorr,ccorrlast);

    %spot vol with variance
     SpotVol=NaN*zeros(length(input_v),length(asseti_v));
    for iii=1:length(asseti_v)
        [SigmaSpot_out_sel,~]=retrieve_cov_el_univ(asseti_v(iii),SigmaSpot_out);
        SpotVol(:,iii)=sqrt(SigmaSpot_out_sel);
    end
    
    %spot vol 
    SpotVol=sqrt(SigmaSpot_out_sel)*sqrt(252);

    
end

% -------------------------------------------------------------------------
%
end
%-------------------------------------------------------------------------
%
%% Daily estimates

if daily==1

if isequal(estimt,'pair')

% Estimate Spot corr
%------------------------------
    
% int covs
[SigmaInt_out,block_st_out,block_end_out,J_optv_out,J_p_out,K_p_out]=lle_icov_md(PRICETIME,noisev,startt,endt,...
            1,1,[],[],J_p,[],theta_h,theta_J,theta_K,K_p_thr,twost,twostc,ccorr,ccorrlast); 

% int vol 
IntVol=sqrt(SigmaInt_out([1 3]))*sqrt(252);

% -------------------------------------------------------------------------
%
%% Estimation by Full Matrix Approach

elseif isequal(estimt,'full')
    
% Estimate Spot corr
%------------------------------
% int covs
[SigmaInt_out,block_st_out,block_end_out,J_optv_out,J_p_out,K_p_out]=lle_icov_md(PRICETIME,noisev,startt,endt,...
            1,1,[],[],J_p,[],theta_h,theta_J,theta_K,K_p_thr,twost,twostc,ccorr,ccorrlast); 

% int var 
IntVol=NaN*zeros(length(asseti_v),1);
for iii=1:length(asseti_v)
    [SigmaInt_out_sel,~]=retrieve_cov_el_univ(asseti_v(iii),SigmaInt_out');
    IntVol(iii)=sqrt(SigmaInt_out_sel)*sqrt(252);
end
% -------------------------------------------------------------------------
%
end

end
%-------------------------------------------------------------------------
%
%% Create Plot and Save

if ~plot_trans
% classic ugly plot
    
% times for plot
times_pl=(input_v*(endt-startt)+9.5)/24;
                                % perc of 24h period

% create vector of labels
if ~isempty(text_pos_x)
    if sum(isnan(text_pos_x(ddd,:)))<size(text_pos_x,2)
        if (size(text_pos_x,2)~=size(halign_a,2))||(size(text_pos_x,2)~=size(long_ind_m,2))||...
            (size(long_ind_m,2)~=size(halign_a,2))
            error('text_pos_x, long_ind_m and halign_a must have same no of columns!')
        end
        text_a=cell(size(text_pos_x,2),1);
        for i=1:length(text_a)
            if ~isnan(text_pos_x(ddd,i))
                base_str=strcat('$', int2str(i),')$');
                if ~isequal(long_ind_m(ddd,i),1)
                    l_str='';
                else
                    l_str='long';
                end
                if isequal(halign_a{ddd,i},'left')
                    text_a{i}=strcat('$\',l_str,'leftarrow\left(', int2str(i),'\right)$');
                else
                    text_a{i}=strcat('$\left(', int2str(i),'\right)\',l_str,'rightarrow$');
                end
            end
        end
    else
        text_a=cell(size(text_pos_x,2),1);
    end
else
    text_a=cell(size(text_pos_x,2),1);
end

% transpose
SpotVol=SpotVol';
if confi>0
    ci_upper=ci_upper'; 
    ci_lower=ci_lower';
end
            
% prepare patch plot for confidence interv
if confi>0
    % preparation plot: use for limits
    if isempty(comp_ylim)
        hpp=plot(times_pl,[ci_lower(1,:);SpotVol(1,:);ci_upper(1,:);...
            ci_lower(2,:);SpotVol(2,:);ci_upper(2,:)]);
        ytickv = get(gca,'YTick');
        clf;
        close;
    end
end                                

%opengl software % does not run on linux
opengl('save','software') % affects next sessions only

% plot
%-----------------------------
fh=figure;
 
set(fh, 'color', 'white');

if confi>0
    h=plot(times_pl,[SpotVol;ci_lower;ci_upper]);
    set(h(1),'color',rgb('black'),'linestyle','-','linewidth',1.4);
    set(h(2),'color',rgb('darkgrey'),'linestyle','-','linewidth',1.4);
    if isequal(length(asseti_v),2)
        set(h(3),'color',rgb('black'),'linestyle','--','linewidth',1.3);
        set(h(4),'color',rgb('darkgrey'),'linestyle','--','linewidth',1.3);
        set(h(5),'color',rgb('black'),'linestyle','--','linewidth',1.3);
        set(h(6),'color',rgb('darkgrey'),'linestyle','--','linewidth',1.3);
    end
else
    h=plot(times_pl,SpotVol);
    set(h(1),'color',rgb('black'),'linestyle','-','linewidth',1.4);
    set(h(2),'color',rgb('darkgrey'),'linestyle','-','linewidth',1.4);
end

set(gca, 'TickDir', 'in', 'Box', 'off' ,'XMinorTick','Off','YMinorTick','Off','linewidth',1.5,...
    'XGrid','on','Ygrid','on'); % here gca means get current axis

if ~isempty(comp_ylim)
    set(gca,'Ylim',comp_ylim)
    set(gca,'YTick',linspace(comp_ylim(1),comp_ylim(2),5));
    comp_yl='_compy';
else
    comp_yl='';
    if confi<=0
        ytickv = get(gca,'YTick');
    end    
    set(gca,'Ylim',[ytickv(1),ytickv(end)])
    set(gca,'YTick',linspace(ytickv(1),ytickv(end),5));
end

datetick('x','HH:MM');

xl = xlabel('\bfseries Time of Day');
yl = ylabel('\bfseries Spot Volatility');
   
set(xl,'interpreter','latex','FontSize',10);
set(yl,'interpreter','latex','FontSize',10);

xlim([11/24 16/24])

parent = get(h(1),'Parent');
set(parent,'FontSize',10,'FontWeight','demi');    


%# vertical line
if ~isempty(vertt)
    if ~isnan(vertt(ddd))
    gridxy(vertt(ddd)-datenum('00:00'), 'LineStyle','--', 'Color',rgb('black'),'linewidth',1.3)
        %matlab.graphics.axis.decorator.Baseline('BaseValue',vertt(ddd)-datenum('00:00'), 'Parent',gca, 'Axis',0, 'Visible','on','LineStyle','--', 'Color',rgb('black'),'LineWidth',1.3);
    end
end

%text
if sum(cellfun(@isempty,text_a))<length(text_a)
    for i=1:length(text_a)
        if ~isnan(text_pos_x(ddd,i))
            x_pos=text_pos_x(ddd,i)-datenum('00:00');
            y_pos=dquant_m(find(times_pl>=x_pos,1,'first'));
                 text(x_pos+add_v(i),y_pos,text_a{i},...
            'HorizontalAlignment',halign_a{ddd,i},'interpreter','latex','FontSize',10)
        end
    end
end

if confi>0
    ylim_org=get(gca,'Ylim');
    set(gca,'Ylim',[ylim_org(1)-deltaY ylim_org(2)+deltaY]);
    xlim_org=get(gca,'Xlim');
    set(gca,'Xlim',[xlim_org(1)-deltaX xlim_org(2)+deltaX]);
end

% label vert
if ~isempty(vertt)
    if ~isnan(vertt(ddd))
      vertl='_vl';
    else
      vertl='';
    end
else
    vertl='';
end


% label vert
if sum(cellfun(@isempty,text_a))<length(text_a)
      textl='_tt';
else
      textl='';
end

% label: confidence intervals
if confi>0
    confil='_confi';
    if twostc>0
        twostcl='_2stc';
    else
        twostcl='';
    end
else
    confil='';
    twostcl='';
end

% horizonal line 
if isequal(daily,1)
%     hy = graph2d.constantline(outvd, 'color',rgb('black'),'linestyle','-','linewidth',1.4);
%     changedependvar(hy,'y');
    hold on
    hy=plot(xlim', [IntVol(1) IntVol(1)]);              % Plot horz Line
    set(hy,'color',rgb('black'),'linestyle','-','linewidth',1.4);
    if isequal(length(asseti_v),2)
        hy2=plot(xlim', [IntVol(2) IntVol(2)]);              % Plot horz Line
        set(hy2,'color',rgb('darkgrey'),'linestyle','-','linewidth',1.4);
    end
    hold off
end

% save plot
if isequal(estimt,'pair')
    nameout=strcat(outpath,'spot_vol_2d_',source_d,'_',ticker_a{asseti},'_',ticker_a{asseti_p},'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,confil,twostcl,vertl,textl,comp_yl,...
                 daily_str);
elseif isequal(estimt,'full')
    nameout=strcat(outpath,'spot_vol_md_',source_d,'_',ticker_a{asseti},'_d',int2str(length(ticker_a)),'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,confil,twostcl,vertl,textl,comp_yl,...
                 daily_str);
elseif isequal(estimt,'uni')
    nameout=strcat(outpath,'spot_vol_1d_',source_d,'_',ticker_a{asseti},'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,confil,twostcl,vertl,textl,comp_yl,...
                 daily_str);             
end

export_fig(nameout,'-pdf','-png');

else
    % transparent plot
    % times for plot
times_pl=(input_v*(endt-startt)+9.5)/24;
                                % perc of 24h period

% create vector of labels
if ~isempty(text_pos_x)
    if sum(isnan(text_pos_x(ddd,:)))<size(text_pos_x,2)
        if (size(text_pos_x,2)~=size(halign_a,2))||(size(text_pos_x,2)~=size(long_ind_m,2))||...
            (size(long_ind_m,2)~=size(halign_a,2))
            error('text_pos_x, long_ind_m and halign_a must have same no of columns!')
        end
        text_a=cell(size(text_pos_x,2),1);
        for i=1:length(text_a)
            if ~isnan(text_pos_x(ddd,i))
                base_str=strcat('$', int2str(i),')$');
                if ~isequal(long_ind_m(ddd,i),1)
                    l_str='';
                else
                    l_str='long';
                end
                if isequal(halign_a{ddd,i},'left')
                    text_a{i}=strcat('$\',l_str,'leftarrow\left(', int2str(i),'\right)$');
                else
                    text_a{i}=strcat('$\left(', int2str(i),'\right)\',l_str,'rightarrow$');
                end
            end
        end
    else
        text_a=cell(size(text_pos_x,2),1);
    end
else
    text_a=cell(size(text_pos_x,2),1);
end

% transpose
SpotVol=SpotVol';
if confi>0
    ci_upper=ci_upper'; 
    ci_lower=ci_lower';
end
            
% prepare patch plot for confidence interv
if confi>0
    px=[times_pl,fliplr(times_pl)];
    py1=[ci_lower(1,:),fliplr(ci_upper(1,:))];
    py2=[ci_lower(2,:),fliplr(ci_upper(2,:))];
    % preparation plot: use for limits
    if isempty(comp_ylim)
        hpp=plot(times_pl,[ci_lower(1,:);SpotVol(1,:);ci_upper(1,:);...
            ci_lower(2,:);SpotVol(2,:);ci_upper(2,:)]);
        ytickv = get(gca,'YTick');
        clf;
        close;
    end
end                                

%opengl software % does not run on linux
opengl('save','software') % affects next sessions only

% plot
%-----------------------------
fh=figure;
 
set(fh, 'color', 'white');

h=plot(times_pl,SpotVol');

set(h(1),'color',rgb('black'),'linestyle','-','linewidth',1.4);
set(h(2),'color',rgb('darkslategrey'),'linestyle','-','linewidth',1.4);

set(gca, 'TickDir', 'in', 'Box', 'off' ,'XMinorTick','Off','YMinorTick','Off','linewidth',1.5,...
    'XGrid','on','Ygrid','on'); % here gca means get current axis

if ~isempty(comp_ylim)
    set(gca,'Ylim',comp_ylim)
    set(gca,'YTick',linspace(comp_ylim(1),comp_ylim(2),5));
    comp_yl='_compy';
else
    comp_yl='';
    if confi<=0
        ytickv = get(gca,'YTick');
    end    
    set(gca,'Ylim',[ytickv(1),ytickv(end)])
    set(gca,'YTick',linspace(ytickv(1),ytickv(end),5));
end

if confi>0
    % draw on axis 1
    set(gcf, 'CurrentAxes', gca);
    hp1=patch(px,py1,1);
    hp2=patch(px,py2,1);
    set(hp1,'FaceColor',rgb('black'),'EdgeColor','none',...
        'EdgeAlpha',0.2,'FaceAlpha',0.2)
    set(hp2,'FaceColor',rgb('darkslategrey'),'EdgeColor','none',...
        'EdgeAlpha',0.2,'FaceAlpha',0.2)
end

datetick('x','HH:MM');

xl = xlabel('\bfseries Time of Day');
yl = ylabel('\bfseries Spot Volatility');
   
set(xl,'interpreter','latex','FontSize',10);
set(yl,'interpreter','latex','FontSize',10);

xlim([11/24 16/24])

parent = get(h(1),'Parent');
set(parent,'FontSize',10,'FontWeight','demi');    


%# vertical line
if ~isempty(vertt)
    if ~isnan(vertt(ddd))
        gridxy(vertt(ddd)-datenum('00:00'), 'LineStyle','--', 'Color',rgb('black'),'linewidth',1.3)
        %matlab.graphics.axis.decorator.Baseline('BaseValue',vertt(ddd)-datenum('00:00'), 'Parent',gca, 'Axis',0, 'Visible','on','LineStyle','--', 'Color',rgb('black'),'LineWidth',1.3);
    end
end

%text
if sum(cellfun(@isempty,text_a))<length(text_a)
    for i=1:length(text_a)
        if ~isnan(text_pos_x(ddd,i))
            x_pos=text_pos_x(ddd,i)-datenum('00:00');
            y_pos=dquant_m(find(times_pl>=x_pos,1,'first'));
                 text(x_pos+add_v(i),y_pos,text_a{i},...
            'HorizontalAlignment',halign_a{ddd,i},'interpreter','latex','FontSize',10)
        end
    end
end

if confi>0
    ylim_org=get(gca,'Ylim');
    set(gca,'Ylim',[ylim_org(1)-deltaY ylim_org(2)+deltaY]);
    xlim_org=get(gca,'Xlim');
    set(gca,'Xlim',[xlim_org(1)-deltaX xlim_org(2)+deltaX]);
end

% label vert
if ~isempty(vertt)
    if ~isnan(vertt(ddd))
      vertl='_vl';
    else
      vertl='';
    end
else
    vertl='';
end

% label vert
if sum(cellfun(@isempty,text_a))<length(text_a)
      textl='_tt';
else
      textl='';
end

% label: confidence intervals
if confi>0
    confil='_confi';
    if twostc>0
        twostcl='_2stc';
    else
        twostcl='';
    end
else
    confil='';
    twostcl='';
end

% horizonal line 
if isequal(daily,1)
%     hy = graph2d.constantline(outvd, 'color',rgb('black'),'linestyle','-','linewidth',1.4);
%     changedependvar(hy,'y');
    hold on
    hy=plot(xlim', [IntVol(1) IntVol(1)]);              % Plot horz Line
    set(hy,'color',rgb('black'),'linestyle','-','linewidth',1.4);
    if isequal(length(asseti_v),2)
        hy2=plot(xlim', [IntVol(2) IntVol(2)]);              % Plot horz Line
        set(hy2,'color',rgb('darkgrey'),'linestyle','-','linewidth',1.4);
    end
    hold off
end

% save plot
if isequal(estimt,'pair')
    nameout=strcat(outpath,'spot_vol_2d_',source_d,'_',ticker_a{asseti},'_',ticker_a{asseti_p},'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,confil,twostcl,vertl,textl,comp_yl,...
                 daily_str,'_transp');
elseif isequal(estimt,'full')
    nameout=strcat(outpath,'spot_vol_md_',source_d,'_',ticker_a{asseti},'_d',int2str(length(ticker_a)),'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,confil,twostcl,vertl,textl,comp_yl,...
                 daily_str,'_transp');
end

export_fig(nameout,'-png');

end
% -------------------------------------------------------------------------
%
%% end loop over trading days
end

