%% run_comp_Desc_29042014.m
%--------------------------------------------------------------------------
% creates table containing no of obs, perc of nonzero returns, average
% duration and noise-to-signal-ratio per obs following Oomen (2006)
% averaged over days
%--------------------------------------------------------------------------
%
% Peter Malec, April 29, 2014
%
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear all;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath =1;              

% source of data
source_d='LOBSTER';           % UPPER CASE!

% Stock
ticker_a      ={'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
    'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','AMAT','CMCSA'}; % apr 13

% datatype
typed='midp';           % midp: midquotes, trad: trades

% dates (entire period or spec dates)
startd=datenum('1 may 10');
endd=datenum('30 apr 14');
tdate_v=[];
%tdate_v=[datenum('29 apr 13'):datenum('30 apr 13')]';
%[datenum('1 apr 13'):datenum('5 apr 13') datenum('8 apr 13'):datenum('12 apr 13') datenum('22 apr 13') datenum('24 apr 13'):datenum('26 apr 13')]';

%cleaning 
cl_ind=-1;           %if==1: cleaning is done

%revisions
rev_ind=-1;     %if ==1, only obs with price revisions are used: set rev_ind to -1 even for midp. 
                                                                                                % noise estimates are computed based on revisions anyway
% frequency for rv (in seconds)
freqrv=300;

% no of subsamples
nss=10;

%---------------------------------------------------------
% settings for noise level estimation
%---------------------------------------------------------
%sign level for test
alpha=0.05;

%maximum order of dependence
Q_max=50;  %if Q_max=1: iid noise assumed

% skip sampling frequency in seconds 
skips=300;
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data

inpathd=strcat(pathproject,'Data',filesep,source_d,filesep,'Filtered',filesep);

inpathrv=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'RV',filesep);

inpath_noise=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Noise_est',filesep);

nobspath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Add',filesep,'N_obs_LOBSTER',filesep);

difftpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Add',filesep,'Max_tdiff_LOBSTER',filesep);

addpath=strcat(pathproject,'Data',filesep,'Add',filesep);

outpath=strcat(pathproject,'Emp_AnA',filesep,'Tables',filesep);

outpathres=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Averages',filesep);
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days

% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days_cl_',source_d,'_m32_20100501_20140430_thrq1500_thrtr800_tthrq300_tthrtr720_cl.mat'));
date_v=t_date_v_cl;
% -------------------------------------------------------------------------
%
%% Preparations

% clean?
if cl_ind==1
    cl_str='cl';            % cleaning string for output file
else
    cl_str='ncl';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

if Q_max>1
    % alpha_label
    alpha_l=num2str(alpha);
    alpha_l(alpha_l=='.')='';
    
    if ~isempty(skips)
        if ~isempty(nss)
            basename=strcat('d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,rev_str,'_freq',int2str(freqrv),'_nss',int2str(nss),'_alpha',alpha_l,'_Q',int2str(Q_max),'_ss',int2str(skips));
        else
            basename=strcat('d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,rev_str,'_freq',int2str(freqrv),'_alpha',alpha_l,'_Q',int2str(Q_max),'_ss',int2str(skips));
        end
    else
        if ~isempty(nss)
            basename=strcat('d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,rev_str,'_freq',int2str(freqrv),'_nss',int2str(nss),'_alpha',alpha_l,'_Q',int2str(Q_max));
        else
            basename=strcat('d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,rev_str,'_freq',int2str(freqrv),'_alpha',alpha_l,'_Q',int2str(Q_max));
        end
    end
    
else

    if ~isempty(nss)
        basename=strcat('d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,rev_str,'_freq',int2str(freqrv),'_nss',int2str(nss));
    else
    basename=strcat('d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,rev_str,'_freq',int2str(freqrv));
    end

end

if ~isequal(typed,'midp')
    basenamel=basename;
else
    if Q_max>1
        if ~isempty(skips)
            if ~isempty(nss)
                basenamel=strcat('d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
                typed,'_',cl_str,'_rev','_freq',int2str(freqrv),'_nss',int2str(nss),'_alpha',alpha_l,'_Q',int2str(Q_max),'_ss',int2str(skips));
            else
                basenamel=strcat('d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
                typed,'_',cl_str,'_rev','_freq',int2str(freqrv),'_alpha',alpha_l,'_Q',int2str(Q_max),'_ss',int2str(skips));
            end
        else
            if ~isempty(nss)
                basenamel=strcat('d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
                typed,'_',cl_str,'_rev','_freq',int2str(freqrv),'_nss',int2str(nss),'_alpha',alpha_l,'_Q',int2str(Q_max));
            else
                basenamel=strcat('d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
                typed,'_',cl_str,'_rev','_freq',int2str(freqrv),'_alpha',alpha_l,'_Q',int2str(Q_max));
            end
        end
    else
        if ~isempty(nss)
            basenamel=strcat('d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
                typed,'_',cl_str,'_rev','_freq',int2str(freqrv),'_nss',int2str(nss));
        else
        basenamel=strcat('d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,'_rev','_freq',int2str(freqrv));
        end
    end
end

% no stocks
m=length(ticker_a);

% Create vector of trading days in matlab date format
if isempty(tdate_v)
    tdate_v=date_v(sort(find((date_v>=startd)&(date_v<=endd))));
end

%
%-----------------------------------------------------------------------
%
%% check for existence of file

% name pf previosuly saved results
nameout_res=strcat(outpathres,'NtS_',basenamel,'.mat');

index=isequal(exist(nameout_res,'file'),2);
% -------------------------------------------------------------------------
%
if ~index
% -------------------------------------------------------------------------
%
%% Compute Avg. NtS for each Stock

%empty matrix
nts_mat=NaN*zeros(length(tdate_v),m);

if ~isequal(typed,'midp')
    rev_indnl=rev_ind;
else
    rev_indnl=1;
end

% loop over trading days
%----------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);
    disp(datestr(tdate,'yyyy--mm--dd'))
    
    %empty vector
    nts_vec=NaN*zeros(m,1);
    
    %loop across assets
   parfor i=1:m
        nts_vec(i)=comp_nts_per_obs(inpathd,inpathrv,inpath_noise,ticker_a{i},tdate,source_d,typed,cl_ind,rev_indnl,freqrv,nss,Q_max,alpha,skips);
   end
   
   %assign
   nts_mat(j,:)=nts_vec';
   
end

%save
save(nameout_res,'nts_mat');
% -------------------------------------------------------------------------
%
%% Use Old Results

else
    
    %load
    load(nameout_res);
   
end
% -------------------------------------------------------------------------
%
%% check for existence of file

% name pf previosuly saved results
nameout_res2=strcat(outpathres,'eta_',basenamel,'.mat');

index2=isequal(exist(nameout_res2,'file'),2);
% -------------------------------------------------------------------------
%
if ~index2
% -------------------------------------------------------------------------
%
%% Get Noise Estimates


%empty matrix
noise_mat=NaN*zeros(length(tdate_v),m);

if ~isequal(typed,'midp')
    rev_indnl=rev_ind;
else
    rev_indnl=1;
end

% loop over trading days
%----------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);
    disp(datestr(tdate,'yyyy--mm--dd'))
    
    %empty vector
    noise_vec=NaN*zeros(m,1);
    
    %loop across assets
   parfor i=1:m
        noise_vec(i)=getnoise(inpath_noise,ticker_a{i},tdate,source_d,typed,cl_ind,rev_indnl,Q_max,alpha,skips);
   end
   
   %assign
   noise_mat(j,:)=noise_vec';
   
end

%save
save(nameout_res2,'noise_mat');
% -------------------------------------------------------------------------
%
%% Use Old Results

else
    
    %load
    load(nameout_res2);
   
end
% -------------------------------------------------------------------------
%
%% check for existence of file

if Q_max>1
    
if ~isequal(typed,'midp')
    rev_strnl=rev_str;
else
    rev_strnl='_rev';
end
    
if ~isempty(skips)
       basenamen=strcat('R_d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,rev_strnl,'_alpha',alpha_l,'_Q',int2str(Q_max),'_ss',int2str(skips));
else
       basenamen=strcat('R_d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,rev_strnl,'_alpha',alpha_l,'_Q',int2str(Q_max));
end

% name pf previosuly saved results
nameout_res3=strcat(outpathres,basenamen,'.mat');

index3=isequal(exist(nameout_res3,'file'),2);
% -------------------------------------------------------------------------
%
if ~index3
% -------------------------------------------------------------------------
%
%% Get order of serial dependence

%get R matrix
R_mat=NaN*zeros(length(tdate_v),m);

% loop across assets
 for k=1:m
    
% tickers
ticker=ticker_a{k};
disp(ticker)
    
% initialize
R_v=NaN*zeros(length(tdate_v),1);
   
% loop over days
%-------------------------------------------------
    
parfor j=1:length(tdate_v)
    
    % select date
    tdate=tdate_v(j);
    

    %name 
    if ~isempty(skips)
       basenameR=strcat(inpath_noise,ticker,filesep,'noise_est_',ticker,'_',source_d,'_',datestr(tdate,'yyyymmdd'),typed,cl_str,rev_strnl,'_alpha',alpha_l,'_Q',int2str(Q_max),'_ss',int2str(skips));
    else
        basenameR=strcat(inpath_noise,ticker,filesep,'noise_est_',ticker,'_',source_d,'_',datestr(tdate,'yyyymmdd'),typed,cl_str,rev_strnl,'_alpha',alpha_l,'_Q',int2str(Q_max));
    end
        
    % check for existence of file
    if isequal(exist(strcat(basenameR,'.mat'),'file'),2);
    %------------------------

        %load    
        indat=iload(strcat(basenameR,'_add_res.mat'),'add_res');    
        add_res=indat.add_res;
        
        % assign
        R_v(j)=length(add_res.stat_val_vec)-1;
        
    else
        
        disp([' ACF Estimates for ' ticker  ' are missing. Skip.'])
        
    end

end

%assign
R_mat(:,k)=R_v;
 end
 
 %save
save(nameout_res3,'R_mat');
% -------------------------------------------------------------------------
%
%% Use Old Results

else
    
    %load
    load(nameout_res3);
   
end

%---------------------------------------------------------------------------
end
% -------------------------------------------------------------------------
%
%% Get Remaining Quantities

% empty matrices
nobs_mat=NaN*zeros(length(tdate_v),m);
if ~isequal(rev_ind,1)
    pernzer_mat=NaN*zeros(length(tdate_v),m);
    avgddiffpnz_mat=NaN*zeros(length(tdate_v),m);
end
avgddifft_mat=NaN*zeros(length(tdate_v),m);

% loop across assets and collect
for i=1:m
    ticker=ticker_a{i};
    load(strcat(nobspath,ticker,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),'_',typed,'_',cl_str,rev_str));
    nobs_mat(:,i)=n_obs_mat2(:,1);
    if ~isequal(rev_ind,1)
        pernzer_mat(:,i)=n_obs_mat2(:,2);
    end
    load(strcat(difftpath,ticker,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),'_',typed,'_',cl_str,rev_str));
    avgddifft_mat(:,i)=difft_vec;
    if ~isequal(rev_ind,1)
        load(strcat(difftpath,ticker,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),'_',typed,'_',cl_str,'_rev'));
        avgddiffpnz_mat(:,i)=difft_vec;
    end
end
% -------------------------------------------------------------------------
%
%% Create Table

%compute averages
n_obs=nanmean(nobs_mat)';
avgddifft=nanmean(avgddifft_mat)';
if ~isequal(rev_ind,1)
    pernzer=nanmean(pernzer_mat)';
    avgddiffpnz=nanmean(avgddiffpnz_mat)';
end
noise=nanmean(noise_mat)';
nts=nanmean(nts_mat)';
if ~isequal(rev_ind,1)
    res_out=[n_obs avgddifft (pernzer*100) avgddiffpnz (noise*10^6) nts];
else
    res_out=[n_obs avgddifft (noise*10^6) nts];
end
if Q_max>1
    % cleaning of outliers
 %   R_mat(R_mat==(Q_max-1))=NaN;
    R=nanmean(R_mat)';
    res_out=[res_out R];
end

% compute global means
res_out=[res_out;nanmean(res_out)];


% create table with different horizons stacked vertically
outname=strcat(outpath,'Summ_',basename,'.txt');

if ~isequal(rev_ind,1)
    if Q_max>1
        horz_lab={'$\overline{n}$','$\overline{\Delta t}$','$\%_{\left(\Delta Y>0\right)}$','$\overline{\Delta t_{\left(\Delta Y>0\right)}}$','$\overline{\sqrt{\hat\eta}}$','$\overline{\hat\xi}$','$\overline{\hat R}$'};
    else
        horz_lab={'$\overline{n}$','$\overline{\Delta t}$','$\%_{\left(\Delta Y>0\right)}$','$\overline{\Delta t_{\left(\Delta Y>0\right)}}$','$\overline{\sqrt{\hat\eta}}$','$\overline{\hat\xi}$'};
    end
else
    if Q_max>1
        horz_lab={'$\overline{n}$','$\overline{\Delta t}$','$\overline{\sqrt{\hat\eta}}$','$\overline{\hat\xi}$','$\overline{\hat R}$'};
    else
        horz_lab={'$\overline{n}$','$\overline{\Delta t}$','$\overline{\sqrt{\hat\eta}}$','$\overline{\hat\xi}$'};
    end
end

% vertical labels
vert_lab=[ticker_a';'Avg.'];

latextable_my(res_out,'Vert',vert_lab,'Horiz',horz_lab,'Hline',[0,1,NaN,(size(res_out,1)-1)],'format','%3.3f','name',outname);








