%% run_comp_Med_Avg_MRK_21042016.m
%--------------------------------------------------------------------------
% Compute median of TS average of MRK correlation
% estimates
%--------------------------------------------------------------------------
%
% Peter Malec, April 21, 2016
%
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear all;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath =1;              

% source of data
source_d='LOBSTER';           % UPPER CASE!

% Stock
ticker_a      ={'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
    'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','AMAT','CMCSA'}; % apr 13

% datatype
typed='midp';           % midp: midquotes, trad: trades

% dates (entire period or spec dates)
startd=datenum('1 may 10');
endd=datenum('30 apr 14');
tdate_v=[];
%tdate_v=[datenum('29 apr 13'):datenum('30 apr 13')]';
%[datenum('1 apr 13'):datenum('5 apr 13') datenum('8 apr 13'):datenum('12 apr 13') datenum('22 apr 13') datenum('24 apr 13'):datenum('26 apr 13')]';

%cleaning 
cl_ind=-1;           %if==1: cleaning is done

%revisions
rev_ind=1;     %if ==1, only obs with price revisions are used
% -------------------------------------------------------------------------
%
%% Determination of Basepath

if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end

% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data

inpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'MRK',filesep);

addpath=strcat(pathproject,'Data',filesep,'Add',filesep);

outpath=strcat(pathproject,'Emp_AnA',filesep,'Tables',filesep);

outpathres=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Averages',filesep);
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days

% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days_cl_',source_d,'_m32_20100501_20140430_thrq1500_thrtr800_tthrq300_tthrtr720_cl.mat'));
date_v=t_date_v_cl;
% -------------------------------------------------------------------------
%
%% Estimate Spot Covariance Matrices 

% Create vector of trading days in matlab date format
if isempty(tdate_v)
    tdate_v=date_v(sort(find((date_v>=startd)&(date_v<=endd))));
end

% no assets
m=length(ticker_a);


% clean?
if cl_ind==1
    cl_str='cl';            % cleaning string for output file
else
    cl_str='ncl';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end


%basename
baseout=strcat(source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),typed,'_d',int2str(m),'_',cl_str,rev_str);

% name pf previosuly saved results
nameout_res=strcat(outpathres,baseout,'.mat');
index=isequal(exist(nameout_res,'file'),2);

if (~index)
% -------------------------------------------------------------------------
%
%% Start Loop over days 

% initialize
corr_m=NaN*zeros(length(tdate_v),m*(m-1)/2);

% loop over days
%-------------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);
    disp(datestr(tdate,'yyyy--mm--dd'))
    
     %name 
    basename=strcat(inpath,source_d,'_',datestr(tdate,'yyyymmdd'),typed,'_d',int2str(m),'_',cl_str,rev_str);

    % check for existence of file
    if isequal(exist(strcat(basename,'_MRK.mat'),'file'),2);
    %------------------------

        %load    
        load(strcat(basename,'_MRK.mat'));    
        
        % compute correlation matrix
        rmk_corr=diag(diag(rmk).^(-.5))*rmk*diag(diag(rmk).^(-.5));

         % select upper off-diagonal elements and assign
         corr_m(j,:)=rmk_corr(logical(triu(ones(m))-eye(m)));

     else

            disp(['Estimates for day ' datestr(tdate,'yyyymmdd') ' are missing. Skip.'])

    end

% end loop over days
%-------------------------------------------------
    
end


% -------------------------------------------------------------------------
%
%% Compute average correlations and save results

% what to to return
outv=nanmean(corr_m);

%save 
save(nameout_res,'outv');
% -------------------------------------------------------------------------
%
%% Use Old Results
else
    
    load(nameout_res);
    
end
% -------------------------------------------------------------------------
%
%% Create Table

% compute quantiles
quant_m=quantile(outv,(.25:.25:.75));
quant_m_dec=quantile(outv,(0:.1:1));

% create table with different horizons stacked vertically
outname=strcat(outpath,'Corr_MRK_',baseout,'.txt');

horz_lab=[{'$p_{0.25}$','$p_{0.5}$','$p_{0.75}$'},...
    {'$p_{0}$','$p_{0.1}$','$p_{0.2}$','$p_{0.3}$','$p_{0.4}$','$p_{0.5}$','$p_{0.6}$','$p_{0.7}$','$p_{0.8}$','$p_{0.9}$','$p_{1}$'}];

latextable_my([quant_m, quant_m_dec],'Vert',{},'Horiz',horz_lab,'Hline',[0,1,NaN],'format','%3.3f','name',outname);
