%% run_comp_nobs_pernzero_2942014.m
%--------------------------------------------------------------------------
% Compute no of obs and perc of nonzero returns ACross all stocks
%--------------------------------------------------------------------------
%
% Peter Malec, APril 29, 2014
%
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear all;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath =1;              

% source of data
source_d='LOBSTER';           % UPPER CASE!

% Stock
ticker_a      ={'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
    'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','AMAT','CMCSA'}; % apr 13

% datatype
typed='midp';           % midp: midquotes, trad: trades

% dates (entire period or spec dates)
startd=datenum('1 may 10');
endd=datenum('30 apr 14');
tdate_v=[];
%tdate_v=[datenum('29 apr 13'):datenum('30 apr 13')]';
%[datenum('1 apr 13'):datenum('5 apr 13') datenum('8 apr 13'):datenum('12 apr 13') datenum('22 apr 13') datenum('24 apr 13'):datenum('26 apr 13')]';

%cleaning 
cl_ind=-1;           %if==1: cleaning is done

%revisions
rev_ind=-1;     %if ==1, only obs with price revisions are used
% -------------------------------------------------------------------------
%
%% Determination of Basepath

if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data

inpath=strcat(pathproject,'Data',filesep,source_d,filesep,'Filtered',filesep);

addpath=strcat(pathproject,'Data',filesep,'Add',filesep);

outpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Add',filesep,'N_obs_LOBSTER',filesep);
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days

% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days_cl_',source_d,'_m32_20100501_20140430_thrq1500_thrtr800_tthrq300_tthrtr720_cl.mat'));
date_v=t_date_v_cl;
% -------------------------------------------------------------------------
%
%% Preparations

% clean?
if cl_ind==1
    cl_str='cl';            % cleaning string for output file
else
    cl_str='ncl';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end
% -------------------------------------------------------------------------
%
%% Check Number of Observations

% no stocks
m=length(ticker_a);

% Create vector of trading days in matlab date format
if isempty(tdate_v)
    tdate_v=date_v(sort(find((date_v>=startd)&(date_v<=endd))));
end


%loop across assets
%----------------------------------------------
for i=1:m
    
    ticker=ticker_a{i};
    
    % empy matrix
    n_obs_mat2=NaN*zeros(length(tdate_v),2);

    % loop over trading days
    parfor j=1:length(tdate_v)
    
         % select date and display
          tdate=tdate_v(j);
          disp([ticker ':' datestr(tdate,'yyyy--mm--dd')])
    
        %compute
        [n_obs,prec_nzero]=comp_n_obs(inpath,ticker,tdate,typed,cl_str,rev_ind);
        n_obs_mat2(j,:)=[n_obs prec_nzero];
   
   end
   
    %save 
    name_out=strcat(outpath,ticker,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),'_',typed,'_',cl_str,rev_str,'.mat');
    save(name_out,'n_obs_mat2')

end








