%% run_comp_nobs_persec_21042016.m
%--------------------------------------------------------------------------
% compute average number of observation per second
% and create table
%--------------------------------------------------------------------------
%
% Peter Malec, April 21, 2016
%
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear all;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath =1;              

% source of data
source_d='LOBSTER';           % UPPER CASE!

% Stock
ticker_a      ={'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
    'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','AMAT','CMCSA'}; % apr 13

% datatype
typed='midp';           % midp: midquotes, trad: trades

% dates (entire period or spec dates)
startd=datenum('1 may 10');
endd=datenum('30 apr 14');
tdate_v=[];
%tdate_v=[datenum('29 apr 13'):datenum('30 apr 13')]';
%[datenum('1 apr 13'):datenum('5 apr 13') datenum('8 apr 13'):datenum('12 apr 13') datenum('22 apr 13') datenum('24 apr 13'):datenum('26 apr 13')]';

%cleaning 
cl_ind=-1;           %if==1: cleaning is done

%revisions
rev_ind=1;     %if ==1, only obs with price revisions are used: set rev_ind to -1 even for midp. 
                                                                                                % noise estimates are computed based on revisions anyway
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data

nobspath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Add',filesep,'N_obs_LOBSTER',filesep);

addpath=strcat(pathproject,'Data',filesep,'Add',filesep);

outpath=strcat(pathproject,'Emp_AnA',filesep,'Tables',filesep);

outpathres=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Averages',filesep);
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days

% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days_cl_',source_d,'_m32_20100501_20140430_thrq1500_thrtr800_tthrq300_tthrtr720_cl.mat'));
date_v=t_date_v_cl;
% -------------------------------------------------------------------------
%
%% Preparations

% clean?
if cl_ind==1
    cl_str='cl';            % cleaning string for output file
else
    cl_str='ncl';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

basename=strcat('d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
typed,'_',cl_str,rev_str);

% no stocks
m=length(ticker_a);

% Create vector of trading days in matlab date format
if isempty(tdate_v)
    tdate_v=date_v(sort(find((date_v>=startd)&(date_v<=endd))));
end
%
%-----------------------------------------------------------------------
%
%% check for existence of files

% name pf previosuly saved results
nameout_res=strcat(outpathres,basename,'.mat');

index=isequal(exist(nameout_res,'file'),2);
% -------------------------------------------------------------------------
%
if ~index
%% Get Remaining Quantities

% empty matrices
nobs_mat=NaN*zeros(length(tdate_v),m);

% loop across assets and collect
for i=1:m
    ticker=ticker_a{i};
    load(strcat(nobspath,ticker,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),'_',typed,'_',cl_str,rev_str));
    nobs_mat(:,i)=n_obs_mat2(:,1);
end

%save
save(nameout_res,'nobs_mat');
% -------------------------------------------------------------------------
%
%% Use Old Results

else
    
    %load
    load(nameout_res);
   
end
% -------------------------------------------------------------------------
%
%% Create Table

%compute averages nobs per sec across days
intens_est=nanmean(nobs_mat)'/23400;

% compute quantiles
quant_m=quantile(intens_est,(0:.25:1));
quant_m_dec=quantile(intens_est,(0:.1:1));

% create table with different horizons stacked vertically
outname=strcat(outpath,'IntensEst_',basename,'.txt');

horz_lab={'$\hat \lambda$'};

vert_lab=[ticker_a {'$p_{0}$','$p_{0.25}$','$p_{0.5}$','$p_{0.75}$','$p_{1}$'} ...
    {'$p_{0}$','$p_{0.1}$','$p_{0.2}$','$p_{0.3}$','$p_{0.4}$','$p_{0.5}$','$p_{0.6}$','$p_{0.7}$','$p_{0.8}$','$p_{0.9}$','$p_{1}$'}];

latextable_my([intens_est;quant_m';quant_m_dec'],'Vert',vert_lab,'Horiz',horz_lab,'Hline',[0,1,NaN],'format','%3.3f','name',outname);



