%% run_comp_nts_per_obs_07042014.m
%--------------------------------------------------------------------------
% compute noise-to-signal-ratio per obs following Oomen (2006)
% average over days
%--------------------------------------------------------------------------
%
% Peter Malec, Apirl 7, 2014
%
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear all;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath =1;              

% source of data
source_d='LOBSTER';           % UPPER CASE!

% Stock
ticker_a      ={'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
    'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','AMAT','CMCSA'}; % apr 13

% datatype
typed='midp';           % midp: midquotes, trad: trades

% dates (entire period or spec dates)
startd=datenum('1 may 10');
endd=datenum('30 apr 14');
tdate_v=[];
%tdate_v=[datenum('29 apr 13'):datenum('30 apr 13')]';
%[datenum('1 apr 13'):datenum('5 apr 13') datenum('8 apr 13'):datenum('12 apr 13') datenum('22 apr 13') datenum('24 apr 13'):datenum('26 apr 13')]';

%cleaning 
cl_ind=-1;           %if==1: cleaning is done

%revisions
rev_ind=1;     %if ==1, only obs with price revisions are used

% frequency for rv (in seconds)
freqrv=300;

% no of subsamples
nss=10;

% total quantile (across stocks and days??)
totq=-1;
%---------------------------------------------------------
% settings for noise level estimation
%---------------------------------------------------------
%sign level for test
alpha=0.05;

%maximum order of dependence
Q_max=50;  %if Q_max=1: iid noise assumed

% skip sampling frequency in seconds 
skips=300;
% -------------------------------------------------------------------------
%
%% Determination of Basepath

if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data

inpathd=strcat(pathproject,'Data',filesep,source_d,filesep,'Filtered',filesep);

inpathrv=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'RV',filesep);

inpath_noise=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Noise_est',filesep);

addpath=strcat(pathproject,'Data',filesep,'Add',filesep);

outpath=strcat(pathproject,'Emp_AnA',filesep,'Tables',filesep);

outpathres=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Averages',filesep);
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days

% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days_cl_',source_d,'_m32_20100501_20140430_thrq1500_thrtr800_tthrq300_tthrtr720_cl.mat'));
date_v=t_date_v_cl;
% -------------------------------------------------------------------------
%
%% Preparations

% clean?
if cl_ind==1
    cl_str='cl';            % cleaning string for output file
else
    cl_str='ncl';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

if Q_max>1
    % alpha_label
    alpha_l=num2str(alpha);
    alpha_l(alpha_l=='.')='';
    
    if ~isempty(skips)
        if ~isempty(nss)
            basename=strcat('NtS_d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,rev_str,'_freq',int2str(freqrv),'_nss',int2str(nss),'_alpha',alpha_l,'_Q',int2str(Q_max),'_ss',int2str(skips));
        else
            basename=strcat('NtS_d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,rev_str,'_freq',int2str(freqrv),'_alpha',alpha_l,'_Q',int2str(Q_max),'_ss',int2str(skips));
        end
    else
        if ~isempty(nss)
            basename=strcat('NtS_d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,rev_str,'_freq',int2str(freqrv),'_nss',int2str(nss),'_alpha',alpha_l,'_Q',int2str(Q_max));
        else
            basename=strcat('NtS_d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,rev_str,'_freq',int2str(freqrv),'_alpha',alpha_l,'_Q',int2str(Q_max));
        end
    end
    
else

    if ~isempty(nss)
        basename=strcat('NtS_d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,rev_str,'_freq',int2str(freqrv),'_nss',int2str(nss));
    else
    basename=strcat('NtS_d',int2str(length(ticker_a)),'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,rev_str,'_freq',int2str(freqrv));
    end

end
%
%-----------------------------------------------------------------------
%% check for existence of files

% name pf previosuly saved results
nameout_res=strcat(outpathres,basename,'.mat');

index=isequal(exist(nameout_res,'file'),2);
% -------------------------------------------------------------------------
%
if ~index
% -------------------------------------------------------------------------
%
%% Compute Avg. NtS for each Stock

% no stocks
m=length(ticker_a);

% Create vector of trading days in matlab date format
if isempty(tdate_v)
    tdate_v=date_v(sort(find((date_v>=startd)&(date_v<=endd))));
end

%empty matrix
nts_mat=NaN*zeros(length(tdate_v),m);

% loop over trading days
%----------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);
    disp(datestr(tdate,'yyyy--mm--dd'))
    
    %empty vector
    nts_vec=NaN*zeros(m,1);
    
    %loop across assets
   parfor i=1:m
        nts_vec(i)=comp_nts_per_obs(inpathd,inpathrv,inpath_noise,ticker_a{i},tdate,source_d,typed,cl_ind,rev_ind,freqrv,nss,Q_max,alpha,skips);
   end
   
   %assign
   nts_mat(j,:)=nts_vec';
   
end

%save
save(nameout_res,'nts_mat');
% -------------------------------------------------------------------------
%
%% Use Old Results

else
    
    %load
    load(nameout_res);
   
end
% -------------------------------------------------------------------------
%
%% Create Table

%compute average
res_out=nanmean(nts_mat);

% compute quantiles
if ~isequal(totq,1)
    res_outq=quantile(res_out,[0.25 0.5 0.75]);
    res_outq_dec=quantile(res_out,(0:.1:1));
    totql='';
else
    res_outq=quantile(nts_mat(:),[0.25 0.5 0.75]);
    res_outq_dec=quantile(nts_mat(:),(0:.1:1));
    totql='_tot';
end

% create table with different horizons stacked vertically
outname=strcat(outpath,basename,totql,'.txt');

horz_lab={'$\sqrt{N\eta/\hat IV}$'};

latextable_my([res_out';res_outq';res_outq_dec'] ,'Vert',[ticker_a {'$q_{0.25}$','$q_{0.5}$','$q_{0.75}$'} ...
    {'$p_{0}$','$p_{0.1}$','$p_{0.2}$','$p_{0.3}$','$p_{0.4}$','$p_{0.5}$','$p_{0.6}$','$p_{0.7}$','$p_{0.8}$','$p_{0.9}$','$p_{1}$'}]','Horiz',horz_lab,'Hline',[0,1,NaN],'format','%3.3f','name',outname);








