%% run_create_tdays_fin_LOBSTER_2722014.m
%--------------------------------------------------------------------------
% Create "Final" Trading Days: Days featuring at least certain number 
% of observations and durations not too long
%--------------------------------------------------------------------------
%
% Peter Malec, February 27, 2014
%
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear all;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath =-1;              

% source of data
source_d='LOBSTER';           % UPPER CASE!

% number of stocks
m=32;

%thresholds
thr_qu=1500;
thr_tr=800;
tthr_qu=300;   % in sec
tthr_tr=720;

% dates (entire period or spec dates)
startd=datenum('1 may 10');
endd=datenum('31 dec 13');
tdate_v=[];
%tdate_v=[datenum('29 apr 13'):datenum('30 apr 13')]';
%[datenum('1 apr 13'):datenum('5 apr 13') datenum('8 apr 13'):datenum('12 apr 13') datenum('22 apr 13') datenum('24 apr 13'):datenum('26 apr 13')]';

%cleaning 
cl_ind=1;           %if==1: cleaning is done

%revisions
rev_ind=-1;     %if ==1, only obs with price revisions are used
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = 'D:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==2
    
    pathproject = 'D:\\WORK\\Spot_corr\\MATLAB\\';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data

inpath=strcat(pathproject,'Emp_AnA\Estimates\\Add\\N_obs_LOBSTER\\');

inpath2=strcat(pathproject,'Emp_AnA\Estimates\\Add\\Max_tdiff_LOBSTER\\');

addpath=strcat(pathproject,'Data\\Add\\');

outpath=strcat(pathproject,'Data\\Add\\');
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days

% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days.mat')); 
% -------------------------------------------------------------------------
%
%% Preparations

% clean?
if cl_ind==1
    cl_str='cl';            % cleaning string for output file
else
    cl_str='ncl';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end
% -------------------------------------------------------------------------
%
%% Create "Cleaned" Trading Days

% Create vector of trading days in matlab date format
if isempty(tdate_v)
    tdate_v=date_v(sort(find((date_v>=startd)&(date_v<=endd))));
end

% initialize vector of "cleaned" trading days
t_date_v_cl=[];

% loop over trading days
%----------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);
    disp(datestr(tdate,'yyyy--mm--dd'))
    
    % load minimum number of obs and max duration
    load(strcat(inpath,'m',int2str(m),'_',datestr(tdate,'yyyymmdd'),'_midp_',cl_str,rev_str,'.mat'));
    n_obs_qu=min_n_obs;
    load(strcat(inpath,'m',int2str(m),'_',datestr(tdate,'yyyymmdd'),'_trades_ncl.mat'));
    n_obs_tr=min_n_obs;
    load(strcat(inpath2,'m',int2str(m),'_',datestr(tdate,'yyyymmdd'),'_midp_',cl_str,rev_str,'.mat'));
    max_tdiff_qu=max_max_difft;
    load(strcat(inpath2,'m',int2str(m),'_',datestr(tdate,'yyyymmdd'),'_trades_ncl.mat'));
    max_tdiff_tr=max_max_difft;
    
    % check if nobs above or below threshold
    if (n_obs_qu>=thr_qu)&&(n_obs_tr>=thr_tr)
        if (max_tdiff_qu<=tthr_qu)&&(max_tdiff_tr<=tthr_tr)
            t_date_v_cl=[t_date_v_cl;tdate];
        else
            disp('Too long durations')
        end
    else
        disp('Too few observations')
    end
   
end

%save 
name_out=strcat(outpath,'trading_days_cl_LOBSTER_','m',int2str(m),'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),'_thrq',int2str(thr_qu),'_thrtr',int2str(thr_tr),'_tthrq',int2str(tthr_qu),'_tthrtr',int2str(tthr_tr),'_',cl_str,rev_str,'.mat');
save(name_out,'t_date_v_cl')






