%% run_desc_LMM_inputs_15072014.m
%--------------------------------------------------------------------------
% Computes quantiles etc. of number of cross-sectional averages (unless
% estimation method is "full") of 
% Blocks, spectral cutoff and smoothing
% bandwidth (defined as in latest version of the paper)
%--------------------------------------------------------------------------
%
%Peter Malec, July 15,2014
%
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear all;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath =1;              

% source of data
sourced='LOBSTER';           % UPPER CASE!

% Stock
ticker_a      ={'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
    'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','AMAT','CMCSA'}; % apr 13

% datatype
typed='midp';           % midp: midquotes, trad: trades

% dates (entire period or spec dates)
startd=datenum('1 may 10');
endd=datenum('30 apr 14');
tdate_v=[];
%tdate_v=[datenum('29 apr 13'):datenum('30 apr 13')]';
%[datenum('1 apr 13'):datenum('5 apr 13') datenum('8 apr 13'):datenum('12 apr 13') datenum('22 apr 13') datenum('24 apr 13'):datenum('26 apr 13')]';

% type if estimation
estimt='full'; % 'pair' or 'full' or 'uni'

%cleaning 
cl_ind=-1;           %if==1: cleaning is done

%revisions
rev_ind=1;     %if ==1, only obs with price revisions are used

%settings for lle
J_p=5;
theta_h=0.175;
theta_J=7;
theta_K=2;
K_p_thr=8;

% configuration
configl='2F';

% correction?
ccorr=1; % correction of variance and correlation estimates
ccorrlast=1; % last estimation step only

% less smoothing at end and beginning of day?
lKb=1;

% two step
twost=-1; % spot volas of 1st step are used as pilots for 2nd step

% covariances of estimates
twostc=1;   
%-------------------non iid noise---------------------------------
%sign level for test
alpha=0.05;

%maximum order of dependence
Q_max=50;  %if Q_max=0: iid noise assumed

% skip sampling frequency in seconds 
skips=300;
% -------------------------------------------------------------------------
%
%% Determination of Basepath

if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data

if ~isequal(estimt,'uni')
    if ~isequal(configl,'2F')
        inpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Covs',filesep);
    else
        inpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Covs_2F',filesep);
    end
else
    if ~isequal(configl,'2F')
        inpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Vars',filesep);
    else
        inpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Vars_2F',filesep);
    end
end

addpath=strcat(pathproject,'Data',filesep,'Add',filesep);

outpath=strcat(pathproject,'Emp_AnA',filesep,'Tables',filesep);

outpathres=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Averages',filesep);
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days

% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days_cl_',sourced,'_m32_20100501_20140430_thrq1500_thrtr800_tthrq300_tthrtr720_cl.mat'));
date_v=t_date_v_cl;
% -------------------------------------------------------------------------
%
%% labels

% clean?
if cl_ind==1
    cl_str='cl';            % cleaning string for output file
else
    cl_str='ncl';
end

% label lKb
if lKb>0
     lKbl='_lKb';
else
     lKbl='';
end

% label ccorr
if ccorr>0
     ccorrl='_ccorr';
else
     ccorrl='';
end

% label ccorr
if ccorrlast>0
    ccorrlastl='_ccorrl';
else
    ccorrlastl='';
end

%label twostep
if twost>0
     twostl='_2st';
else
     twostl='';
end

% label: estimator covariance
if twostc>0
      twostcl='_2stc';
else
      twostcl='';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

%clean labels
theta_hl=num2str(theta_h);
theta_hl(theta_hl=='.')='';
theta_Jl=num2str(theta_J);
theta_Jl(theta_Jl=='.')='';
theta_Kl=num2str(theta_K);
theta_Kl(theta_Kl=='.')='';
alpha_l=num2str(alpha);
alpha_l(alpha_l=='.')='';


% outname base
if isequal(estimt,'pair')
    baseout=strcat('Desc_LMM_inp_2d_m',int2str(length(ticker_a)),sourced,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl);
elseif isequal(estimt,'full')
     baseout=strcat('Desc_LMM_inp_md_m',int2str(length(ticker_a)),sourced,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl);
elseif isequal(estimt,'uni')
     baseout=strcat('Desc_LMM_inp_1d_m',int2str(length(ticker_a)),sourced,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl);             
end

if Q_max>1
        baseout=strcat(baseout,'_alpha',alpha_l,'_Q',int2str(Q_max));
        if ~isempty(skips)
            baseout=strcat(baseout,'_ss',int2str(skips));
        end
end
% -------------------------------------------------------------------------
%
%% check for existence of files

% name pf previosuly saved results
nameout_res=strcat(outpathres,baseout,'.mat');

index=isequal(exist(nameout_res,'file'),2);

if ~index
% -------------------------------------------------------------------------
%
%% Create Vectors of Asset Pairs

%create vector of plain asset indices
ind_vec=1:length(ticker_a);

%Create [length(ticker_a)*(length(ticker_a)-1)/2 x 2] matrix containing indices of (distinct) asset pairs 
corr_ind=nchoosek(ind_vec,2);       %Binomial coefficient (n k) >>>note: 1st element will always be larger!

%split
ind_1_v=corr_ind(:,1);           
ind_2_v=corr_ind(:,2);  
% -------------------------------------------------------------------------
%
%% Start Loop over days 

% Create vector of trading days in matlab date format
if isempty(tdate_v)
    tdate_v=date_v(sort(find((date_v>=startd)&(date_v<=endd))));
end


% initialize
if isequal(estimt,'pair')
    B_mat=NaN*zeros(length(tdate_v),length(ind_1_v));
    J_mat=NaN*zeros(length(tdate_v),length(ind_1_v));
    K_mat=NaN*zeros(length(tdate_v),length(ind_1_v));
elseif isequal(estimt,'uni')
     B_mat=NaN*zeros(length(tdate_v),length(ticker_a));
    J_mat=NaN*zeros(length(tdate_v),length(ticker_a));
    K_mat=NaN*zeros(length(tdate_v),length(ticker_a));
elseif isequal(estimt,'full')
     B_mat=NaN*zeros(length(tdate_v),1);
    J_mat=NaN*zeros(length(tdate_v),1);
    K_mat=NaN*zeros(length(tdate_v),1);
 else
    error('estimt needs to be pair, uni or full!!!')
end

% loop over days
%-------------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);
    disp(datestr(tdate,'yyyy--mm--dd'))
    
    
% pair-wise estimation
%---------------------------------------------------------
if isequal(estimt,'pair')
    
% loop across paris
parfor i=1:length(ind_1_v)
    
    % tickers
    ticker1=ticker_a{ind_1_v(i)};
    ticker2=ticker_a{ind_2_v(i)};

    %name 
    basename=strcat(inpath,sourced,'_',ticker1,'_',ticker2,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,twostcl);
             
    if Q_max>1
        basename=strcat(basename,'_alpha',alpha_l,'_Q',int2str(Q_max));
        if ~isempty(skips)
            basename=strcat(basename,'_ss',int2str(skips));
        end
    end                    
        
    % check for existence of file
    if isequal(exist(strcat(basename,'_LMM_conf.mat'),'file'),2);
    %------------------------

        %load    
        indat=iload(strcat(basename,'_LMM_conf.mat'),'LMM_conf');    
        LMM_confp=indat.LMM_conf.gen;

        % assign
        B_mat(j,i)=LMM_confp(1);
        J_mat(j,i)=LMM_confp(2);
        K_mat(j,i)=LMM_confp(4);
        
    else
        
        disp(['Estimates for ' ticker1 ' and ' ticker2 ' are missing. Skip.'])
        
    end

end

% pair-wise estimation
%---------------------------------------------------------
elseif isequal(estimt,'uni')
    
% loop across paris
parfor i=1:length(ticker_a)
    
    % tickers
    ticker=ticker_a{i};

    %name 
    basename=strcat(inpath,sourced,'_',ticker,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,twostcl);
             
    if Q_max>1
        basename=strcat(basename,'_alpha',alpha_l,'_Q',int2str(Q_max));
        if ~isempty(skips)
            basename=strcat(basename,'_ss',int2str(skips));
        end
    end                    
        
    % check for existence of file
    if isequal(exist(strcat(basename,'_LMM_conf.mat'),'file'),2);
    %------------------------

        %load    
        indat=iload(strcat(basename,'_LMM_conf.mat'),'LMM_conf');    
        LMM_confp=indat.LMM_conf.gen;

        % assign
        B_mat(j,i)=LMM_confp(1);
        J_mat(j,i)=LMM_confp(2);
        K_mat(j,i)=LMM_confp(4);
        
    else
        
        disp(['Estimate for ' ticker ' is missing. Skip.'])
        
    end

end

%   Full Covariance matrix estimation
%------------------------------------------------------
elseif isequal(estimt,'full')
    
%name 
basename=strcat(inpath,sourced,'_',datestr(tdate,'yyyymmdd'),typed,'_d',int2str(length(ticker_a)),'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,twostcl);
             
             
if Q_max>1
        basename=strcat(basename,'_alpha',alpha_l,'_Q',int2str(Q_max));
        if ~isempty(skips)
            basename=strcat(basename,'_ss',int2str(skips));
        end
end                        
             
% check for existence of file
if isequal(exist(strcat(basename,'_LMM_conf.mat'),'file'),2);
%------------------------
    
    %load    
    load(strcat(basename,'_LMM_conf.mat'));    
    LMM_conf=LMM_conf.gen;
    
    % assign
        B_mat(j)=LMM_conf(1);
        J_mat(j)=LMM_conf(2);
        K_mat(j)=LMM_conf(4);
    

 else
        
        disp(['Estimates for day ' datestr(tdate,'yyyymmdd') ' are missing. Skip.'])
        
end
    
    
end

% end loop over days
%-------------------------------------------------
end
% -------------------------------------------------------------------------
%
%% Compute averages and save results

if isequal(estimt,'pair')||isequal(estimt,'uni')
    res_out=[nanmean(B_mat,2) nanmean(J_mat,2) nanmean(K_mat/2,2)];
else
    res_out=[B_mat J_mat K_mat/2];
end

save(nameout_res,'res_out');
% -------------------------------------------------------------------------
%
%% Use Old Results
else
    
    load(nameout_res);

end
% -------------------------------------------------------------------------
%
%% Create Table

% create table with different horizons stacked vertically
outname=strcat(outpath,baseout,'.txt');

% compute statistics by year and full
res_out_out=NaN*zeros(15,4);
res_out_out(1:3,:)=[quantile(res_out,0.05,1)' nanmean(res_out,1)' ...
    quantile(res_out,0.95,1)' nanstd(res_out,1,1)'];
tdate_ind=sort(find((date_v>=datenum('1 may 10'))&(date_v<=datenum('30 apr 11'))));
res_out_out(4:6,:)=[quantile(res_out(tdate_ind,:),0.05,1)' nanmean(res_out(tdate_ind,:),1)' ...
    quantile(res_out(tdate_ind,:),0.95,1)' nanstd(res_out(tdate_ind,:),1,1)'];
tdate_ind=sort(find((date_v>=datenum('1 may 11'))&(date_v<=datenum('30 apr 12'))));
res_out_out(7:9,:)=[quantile(res_out(tdate_ind,:),0.05,1)' nanmean(res_out(tdate_ind,:),1)' ...
    quantile(res_out(tdate_ind,:),0.95,1)' nanstd(res_out(tdate_ind,:),1,1)'];
tdate_ind=sort(find((date_v>=datenum('1 may 12'))&(date_v<=datenum('30 apr 13'))));
res_out_out(10:12,:)=[quantile(res_out(tdate_ind,:),0.05,1)' nanmean(res_out(tdate_ind,:),1)' ...
    quantile(res_out(tdate_ind,:),0.95,1)' nanstd(res_out(tdate_ind,:),1,1)'];
tdate_ind=sort(find((date_v>=datenum('1 may 13'))&(date_v<=datenum('30 apr 14'))));
res_out_out(13:15,:)=[quantile(res_out(tdate_ind,:),0.05,1)' nanmean(res_out(tdate_ind,:),1)' ...
    quantile(res_out(tdate_ind,:),0.95,1)' nanstd(res_out(tdate_ind,:),1,1)'];

% needs to be adjusted as above
% res_out_out(1:4,:)=[quantile(res_out,0.1,1); median(res_out,1); ...
%     quantile(res_out,0.9,1) ;median(abs(res_out-repmat(median(res_out,1),size(res_out,1),1)),1)];
% tdate_ind=sort(find((date_v>=datenum('1 may 10'))&(date_v<=datenum('30 apr 11'))));
% res_out_out(5:8,:)=[quantile(res_out(tdate_ind,:),0.1,1); median(res_out(tdate_ind,:),1); ...
%     quantile(res_out(tdate_ind,:),0.9,1) ;median(abs(res_out(tdate_ind,:)-repmat(median(res_out(tdate_ind,:),1),size(res_out(tdate_ind,:),1),1)),1)];
% tdate_ind=sort(find((date_v>=datenum('1 may 11'))&(date_v<=datenum('30 apr 12'))));
% res_out_out(9:12,:)=[quantile(res_out(tdate_ind,:),0.1,1); median(res_out(tdate_ind,:),1); ...
%     quantile(res_out(tdate_ind,:),0.9,1) ;median(abs(res_out(tdate_ind,:)-repmat(median(res_out(tdate_ind,:),1),size(res_out(tdate_ind,:),1),1)),1)];
% tdate_ind=sort(find((date_v>=datenum('1 may 12'))&(date_v<=datenum('30 apr 13'))));
% res_out_out(13:16,:)=[quantile(res_out(tdate_ind,:),0.1,1); median(res_out(tdate_ind,:),1); ...
%     quantile(res_out(tdate_ind,:),0.9,1) ;median(abs(res_out(tdate_ind,:)-repmat(median(res_out(tdate_ind,:),1),size(res_out(tdate_ind,:),1),1)),1)];
% tdate_ind=sort(find((date_v>=datenum('1 may 13'))&(date_v<=datenum('30 apr 14'))));
% res_out_out(17:20,:)=[quantile(res_out(tdate_ind,:),0.1,1); median(res_out(tdate_ind,:),1); ...
%     quantile(res_out(tdate_ind,:),0.9,1) ;median(abs(res_out(tdate_ind,:)-repmat(median(res_out(tdate_ind,:),1),size(res_out(tdate_ind,:),1),1)),1)];


vert_lab=repmat({'$\lceil h_n^{-1} \rceil$';'$J_n$';'$K_n$'},5,1);
horz_lab={'$q_{0.05}$','Mean','$q_{0.95}$','Std.'};

% horz_lab=repmat({'$q_{0.1}$','Med','$q_{0.9}$','MAD'},1,5);


latextable_my(res_out_out,'Vert',vert_lab,'Horiz',horz_lab,'Hline',[0,1,4,7,10,13,16,NaN],'format','%3.3f','name',outname);




