%% run_est_seas_ret_07042014.m
%--------------------------------------------------------------------------
% estimate intraday seasonality from plain returns. daily vola
% estimate is subsampled 5min-RV.
%--------------------------------------------------------------------------
%
% Peter Malec, April 7, 2014
%
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear all;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath =1;              

% source of data
source_d='LOBSTER';           % UPPER CASE!

% Stock
ticker_a      ={'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
    'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','AMAT','CMCSA'}; % apr 13

% datatype
typed='midp';           % midp: midquotes, trad: trades

% dates (entire period or spec dates)
startd=datenum('1 may 10');
endd=datenum('30 apr 14');
tdate_v=[];
%tdate_v=[datenum('29 apr 13'):datenum('30 apr 13')]';
%[datenum('1 apr 13'):datenum('5 apr 13') datenum('8 apr 13'):datenum('12 apr 13') datenum('22 apr 13') datenum('24 apr 13'):datenum('26 apr 13')]';

% start end end of trading (in hours)
startt=9.5;
endt=16;

% Order of Fourier Form
maxD=20;

% spec of fourier form
spec=1; %=0 -> no polynomial and intercept, =1  ->polynomial, but no intercept, = 2   -> intercept, but no polynomial  =3  -> intercept and polynomial

%cleaning 
cl_ind=-1;           %if==1: cleaning is done

%revisions
rev_ind=1;     %if ==1, only obs with price revisions are used

% frequency for sampling (in seconds)
freqs=300;

% frequency for rv (in seconds)
freqrv=300;

% no of subsamples
nss=10;
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data

inpathd=strcat(pathproject,'Data',filesep,source_d,filesep,'Filtered',filesep);

inpathrv=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'RV',filesep);

addpath=strcat(pathproject,'Data',filesep,'Add',filesep);

outpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'FFF_Ret',filesep);
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days

% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days_cl_',source_d,'_m32_20100501_20140430_thrq1500_thrtr800_tthrq300_tthrtr720_cl.mat'));
date_v=t_date_v_cl;
% -------------------------------------------------------------------------
%
%% Estimate Spot Covariance Matrices 

% Create vector of trading days in matlab date format
if isempty(tdate_v)
    tdate_v=date_v(sort(find((date_v>=startd)&(date_v<=endd))));
end

% loop over assets
%----------------------------------------------
parfor i=1:length(ticker_a)
    
    ticker=ticker_a{i};

    est_seas_ret_func(ticker,tdate_v,typed,cl_ind,rev_ind,...
    freqrv,nss,freqs,startt,endt,maxD,spec,inpathd,inpathrv,source_d,outpath)

end


   


