%% run_plot_avg_spotvol_31052016.m
%--------------------------------------------------------------------------
% Plot across-day-averages of Spot volatility Estimates
%--------------------------------------------------------------------------
%
%Peter Malec, May 31,2016
%
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath =1;              

% source of data
sourced='LOBSTER';           % UPPER CASE!

% Stock
ticker_a      ={'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
    'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','AMAT','CMCSA'}; % apr 13

% index
asseti=[11; 1];

% datatype
typed='midp';           % midp: midquotes, trad: trades

% dates (entire period or spec dates)
startd_v=datenum('1 may 10');%[datenum('1 may 10') datenum('1 may 11') datenum('1 may 12') datenum('1 may 13')];
endd_v=datenum('30 apr 14');%[datenum('30 apr 11') datenum('30 apr 12') datenum('30 apr 13') datenum('30 apr 14')];

% points of estimation
input_v=0:0.001:1; %times are normalized

% start end end of trading (in hours)
startt=9.5;
endt=16;

% type if estimation
estimt='full'; % 'full' or uni

%cleaning 
cl_ind=-1;           %if==1: cleaning is done

%revisions
rev_ind=1;     %if ==1, only obs with price revisions are used

%settings for lle
J_p=5;
theta_h=0.175;
theta_J=7;
theta_K=2;
K_p_thr=8;

% configuration
configl='2F';

% correction?
ccorr=1; % correction of variance and correlation estimates
ccorrlast=1; % last estimation step only

% less smoothing at end and beginning of day?
lKb=1;

% two step
twost=-1; % spot volas of 1st step are used as pilots for 2nd step

% covariances of estimates
twostc=1;   

% daily estimate as horizontal line
daily=1;

% pre-specified y limits for comparison
comp_ylim=[];

% exclude flash crash
fcex=1;

% exclude 08/09/11
a911ex=1;

% exclude all FOMC announcement days
FOMCex=1;

% consider ONLY FOMC days
FOMConly=false;
%-------------------non iid noise---------------------------------
%sign level for test
alpha=0.05;

%maximum order of dependence
Q_max=50;  %if Q_max=0: iid noise assumed

% skip sampling frequency in seconds 
skips=300;
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data

if ~isequal(estimt,'uni')
    if ~isequal(configl,'2F')
            inpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Covs',filesep);
    else
            inpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Covs_2F',filesep);
    end

    if ~isequal(configl,'2F')
        inpathint=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'ICovs',filesep);
    else
        inpathint=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'ICovs_2F',filesep);
    end

else
    if ~isequal(configl,'2F')
        inpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Vars',filesep);
    else
        inpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Vars_2F',filesep);
    end
    
    if ~isequal(configl,'2F')
        inpathint=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'IVars',filesep);
    else
        inpathint=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'IVars_2F',filesep);
    end

end

addpath=strcat(pathproject,'Data',filesep,'Add',filesep);

outpath=strcat(pathproject,'Emp_AnA',filesep,'Plots',filesep);

outpathres=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Averages',filesep);
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days

% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days_cl_',sourced,'_m32_20100501_20140430_thrq1500_thrtr800_tthrq300_tthrtr720_cl.mat'));
date_v=t_date_v_cl;

% load vector of FOMC announcement days
load(strcat(addpath,'FOMC_days.mat'));
% -------------------------------------------------------------------------
%
%% labels

% clean?
if cl_ind==1
    cl_str='cl';            % cleaning string for output file
else
    cl_str='ncl';
end

% label lKb
if lKb>0
     lKbl='_lKb';
else
     lKbl='';
end

% label ccorr
if ccorr>0
     ccorrl='_ccorr';
else
     ccorrl='';
end

% label ccorr
if ccorrlast>0
    ccorrlastl='_ccorrl';
else
    ccorrlastl='';
end

%label twostep
if twost>0
     twostl='_2st';
else
     twostl='';
end

% label: estimator covariance
if twostc>0
      twostcl='_2stc';
else
      twostcl='';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

% daily 
if daily==1
    daily_str='_dl';
else
    daily_str='';
end

% exclude twitter flash crash
if fcex==1
    fcex_str='_fcex';
else
    fcex_str='';
end

% exclude 08/09/11
if a911ex==1;
    a911ex_str='_a911ex';
else
    a911ex_str='';
end

% exclude all FOMC announcement days
if FOMCex==1;
    FOMCex_str='_FOMCex';
else
    FOMCex_str='';
end

% FOMC only
if FOMConly
    FOMCex_str='FOMCon';
end

%clean labels
theta_hl=num2str(theta_h);
theta_hl(theta_hl=='.')='';
theta_Jl=num2str(theta_J);
theta_Jl(theta_Jl=='.')='';
theta_Kl=num2str(theta_K);
theta_Kl(theta_Kl=='.')='';
 % alpha_label
alpha_l=num2str(alpha);
alpha_l(alpha_l=='.')='';

% -------------------------------------------------------------------------
%
%% Loop over start and end days

for dd=1:length(startd_v)
    
% select
startd=startd_v(dd);
endd=endd_v(dd);

% outname base
if isequal(estimt,'full')
     baseout=strcat('avg_spot_vol_md_m',int2str(length(ticker_a)),'_',ticker_a{asseti},sourced,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),typed,'_',cl_str,rev_str,...
             '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,fcex_str,a911ex_str,FOMCex_str);   
elseif isequal(estimt,'uni')
     baseout=strcat('avg_spot_vol_1d_m',int2str(length(ticker_a)),'_',ticker_a{asseti},sourced,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),typed,'_',cl_str,rev_str,...
             '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,fcex_str,a911ex_str,FOMCex_str);         
end

if Q_max>1
    baseout=strcat(baseout,'_alpha',alpha_l,'_Q',int2str(Q_max));
    if ~isempty(skips)
        baseout=strcat(baseout,'_ss',int2str(skips));
    end
end


% times for plot
times_pl=(input_v*(endt-startt)+9.5)/24;
                                % perc of 24h period
% -------------------------------------------------------------------------
%
%% check for existence of files

% name pf previosuly saved results
nameout_res=strcat(outpathres,baseout,'.mat');
index=isequal(exist(nameout_res,'file'),2);

baseout_int=strcat('i_',baseout);
nameout_res_int=strcat(outpathres,baseout_int,'.mat');
index_int=isequal(exist(nameout_res_int,'file'),2);

if (~index)||(~index_int)
% -------------------------------------------------------------------------
%
%% Start Loop over days 

% Create vector of trading days in matlab date format
tdate_v=date_v(sort(find((date_v>=startd)&(date_v<=endd))));

% consider ONLY FOMC announcement days
if ~FOMConly
    % exclude all FOMC announcement days
    if FOMCex==1;
       tdate_v=setdiff(tdate_v,ann_vec);%retain trading days that are not announcements
    end
else
    tdate_v=intersect(tdate_v,ann_vec);
end

% exclude twitter flash crash
if fcex==1
    tdate_v(tdate_v==datenum('6 may 10'))=[];
end

% exclude 08/09/11
if a911ex==1;
    tdate_v(tdate_v==datenum('9 aug 11'))=[];
end

end

if (~index)


% initialize
vol_a=NaN*zeros(length(input_v),length(asseti),length(tdate_v));

                                
% loop over days
%-------------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);
    disp(datestr(tdate,'yyyy--mm--dd'))
    
    
% pair-wise estimation
%---------------------------------------------------------
%   Full Covariance matrix estimation
%------------------------------------------------------
if isequal(estimt,'full')
    
%name 
basename=strcat(inpath,sourced,'_',datestr(tdate,'yyyymmdd'),typed,'_d',int2str(length(ticker_a)),'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,twostcl);
             
if Q_max>1
        basename=strcat(basename,'_alpha',alpha_l,'_Q',int2str(Q_max));
        if ~isempty(skips)
            basename=strcat(basename,'_ss',int2str(skips));
        end
end             
             
             
% check for existence of file
if isequal(exist(strcat(basename,'_scov.mat'),'file'),2);
%------------------------
    
    %load    
    load(strcat(basename,'_scov.mat'));    
    
    for i=1:length(asseti)
    
        [SigmaSpot_out_sel,~]=retrieve_cov_el_univ(asseti(i),SigmaSpot_out);

        % assign
        vol_a(:,i,j)=SigmaSpot_out_sel;
        
    end

 else
        
        disp(['Estimates for day ' datestr(tdate,'yyyymmdd') ' are missing. Skip.'])
        
end

% pair-wise estimation
%---------------------------------------------------------
elseif isequal(estimt,'uni')
    
for i=1:length(asseti)    
    
    % tickers
    ticker=ticker_a{asseti(i)};

    %name 
    basename=strcat(inpath,sourced,'_',ticker,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,twostcl);

    if Q_max>1
        basename=strcat(basename,'_alpha',alpha_l,'_Q',int2str(Q_max));
        if ~isempty(skips)
            basename=strcat(basename,'_ss',int2str(skips));
        end
    end             


    % check for existence of file
    if isequal(exist(strcat(basename,'_scov.mat'),'file'),2);
    %------------------------

        %load    
        indat=iload(strcat(basename,'_scov.mat'),'SigmaSpot_out');    
        SigmaSs=indat.SigmaSpot_out;

        % assign
        vol_a(:,i,j)=SigmaSs;

    else

        disp(['Estimates for ' ticker ' are missing. Skip.'])

    end

end

end

% end loop over days
%-------------------------------------------------
end
% -------------------------------------------------------------------------
%
%% Compute average correlations and save results

% computed stds
vol_a(vol_a<0)=NaN;
vol_a=sqrt(vol_a);

% annualize volas 
vol_a=sqrt(252)*vol_a;

% what to plot
outv=nanmean(vol_a,3);
     
%save 
save(nameout_res,'outv');
% -------------------------------------------------------------------------
%
%% Use Old Results
else
    
    load(nameout_res);

end
% -------------------------------------------------------------------------
%
%% Daily Estimates
if daily==1
    
if (~index_int)    
    
% initialize
ivol_a=NaN*zeros(length(asseti),length(tdate_v));

% loop over days
%-------------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);
    disp(datestr(tdate,'yyyy--mm--dd'))
    
    
% pair-wise estimation
%---------------------------------------------------------
%   Full Covariance matrix estimation
%------------------------------------------------------
if isequal(estimt,'full')
    
%name 
basename=strcat(inpathint,sourced,'_',datestr(tdate,'yyyymmdd'),typed,'_d',int2str(length(ticker_a)),'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),ccorrl,ccorrlastl,twostl,twostcl);

if Q_max>1
    basename=strcat(basename,'_alpha',alpha_l,'_Q',int2str(Q_max));
    if ~isempty(skips)
        basename=strcat(basename,'_ss',int2str(skips));
    end
end             
             
% check for existence of file
if isequal(exist(strcat(basename,'_icov.mat'),'file'),2);
%------------------------
    
    %load    
    load(strcat(basename,'_icov.mat'));    
    
    % loop across paris
    for i=1:length(asseti)
    
        [SigmaSpot_out_sel,~]=retrieve_cov_el_univ(asseti(i),SigmaInt_out');
    
        % assign
        ivol_a(i,j)=SigmaSpot_out_sel;
        
    end
    

 else
        
        disp(['Integrated Estimates for day ' datestr(tdate,'yyyymmdd') ' are missing. Skip.'])
        
end

% pair-wise estimation
%---------------------------------------------------------
elseif isequal(estimt,'uni')
    
% loop across paris
for i=1:length(asseti)
    
    % tickers
    ticker=ticker_a{asseti(i)};

    %name 
    basename=strcat(inpathint,sourced,'_',ticker,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,twostcl);
        
    if Q_max>1
        basename=strcat(basename,'_alpha',alpha_l,'_Q',int2str(Q_max));
        if ~isempty(skips)
            basename=strcat(basename,'_ss',int2str(skips));
        end
    end             
             
             
    % check for existence of file
    if isequal(exist(strcat(basename,'_icov.mat'),'file'),2);
    %------------------------

        %load    
        indat=iload(strcat(basename,'_icov.mat'),'SigmaSpot_out');    
        SigmaSs=indat.SigmaSpot_out;
        
        % assign
        ivol_a(i,j)=SigmaSs;
        
    else
        
        disp(['Estimates for ' ticker ' are missing. Skip.'])
        
    end
    
    
end

end

% end loop over days
%-------------------------------------------------
end

% -------------------------------------------------------------------------
%
%% Compute average correlations and save results

% computed stds
ivol_a(ivol_a<0)=NaN;
ivol_a=sqrt(ivol_a);

% annualize volas 
ivol_a=sqrt(252)*ivol_a;

outvd=nanmean(ivol_a,2);

%save 
save(nameout_res_int,'outvd');
% -------------------------------------------------------------------------
%
%% Use Old Results
else
    
    load(nameout_res_int);
    
end

end
% -------------------------------------------------------------------------
%
%% Plot 



%opengl software % does not run on linux
opengl('save','software') % affects next sessions only

% plot
%-----------------------------
fh=figure;
 
set(fh, 'color', 'white');

h=plot(times_pl,outv);

set(h(1),'color',rgb('black'),'linestyle','-','linewidth',1.3);
if isequal(length(asseti),2)
    set(h(2),'color',rgb('darkgrey'),'linestyle','-','linewidth',1.3);
end

set(gca, 'TickDir', 'in', 'Box', 'off' ,'XMinorTick','Off','YMinorTick','Off','linewidth',1.5,...
    'XGrid','on','Ygrid','on'); % here gca means get current axis

if ~isempty(comp_ylim)
    set(gca,'Ylim',comp_ylim)
    set(gca,'YTick',linspace(comp_ylim(1),comp_ylim(2),5));
    comp_yl='_compy';
else
    comp_yl='';
    ytickv = get(gca,'YTick');
    set(gca,'Ylim',[ytickv(1),ytickv(end)])
    set(gca,'YTick',linspace(ytickv(1),ytickv(end),5));
end

datetick('x','HH:MM');

xl = xlabel('\bfseries Time of Day');
yl = ylabel('\bfseries Avg. Spot Volatility');
   
set(xl,'interpreter','latex','FontSize',8);
set(yl,'interpreter','latex','FontSize',8);

xlim([9.5/24 16/24])

parent = get(h(1),'Parent');
set(parent,'FontSize',9,'FontWeight','demi');    

% horizonal line 
if isequal(daily,1)
%     hy = graph2d.constantline(outvd, 'color',rgb('black'),'linestyle','-','linewidth',1.4);
%     changedependvar(hy,'y');
    hold on
    hy=plot(xlim, [outvd(1) outvd(1)]);              % Plot horz Line
    set(hy,'color',rgb('black'),'linestyle','-','linewidth',1.4);
    hold off
    if isequal(length(asseti),2)
        hold on
        hy2=plot(xlim, [outvd(2) outvd(2)]);              % Plot horz Line
        set(hy2,'color',rgb('black'),'linestyle','--','linewidth',1.4);
        hold off
    end
end

% save plot
nameout=strcat(outpath,baseout,comp_yl,daily_str);
        
export_fig(nameout,'-pdf');
% 
% -------------------------------------------------------------------------
%
%% End loop over start and end days

end

