%% run_plot_ddist_std_spotcorr_03072014.m
%--------------------------------------------------------------------------
% Plot Cross-sectional deciles of across-day-standard deviations of Spot Correlation Estimates
%--------------------------------------------------------------------------
%
%Peter Malec, July 3,2014
%
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath =1;              

% source of data
sourced='LOBSTER';           % UPPER CASE!

% Stock
ticker_a      ={'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
    'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','AMAT','CMCSA'}; % apr 13

% asset to focus on 
ind_sel=[];  % focus on correlations with this asset (if empty no focus)

% datatype
typed='midp';           % midp: midquotes, trad: trades

% dates (entire period or spec dates)
startd_v=datenum('1 may 10');%[datenum('1 may 10') datenum('1 may 11') datenum('1 may 12') datenum('1 may 13')];
endd_v=datenum('30 apr 14');%[datenum('30 apr 11') datenum('30 apr 12') datenum('30 apr 13') datenum('30 apr 14')];

% points of estimation
input_v=0:0.001:1; %times are normalized

% absolute
absi=-1;

% start end end of trading (in hours)
startt=9.5;
endt=16;

% type if estimation
estimt='full'; % 'pair' or 'full'

%cleaning 
cl_ind=-1;           %if==1: cleaning is done

%revisions
rev_ind=1;     %if ==1, only obs with price revisions are used

%settings for lle
J_p=5;
theta_h=0.175;
theta_J=7;
theta_K=2;
K_p_thr=8;

% configuration
configl='2F';

% correction?
ccorr=1; % correction of variance and correlation estimates
ccorrlast=1; % last estimation step only

% less smoothing at end and beginning of day?
lKb=1;

% two step
twost=-1; % spot volas of 1st step are used as pilots for 2nd step

% covariances of estimates
twostc=1;   

% pre-specified y limits for comparison
comp_ylim=[];

% exclude flash crash
fcex=1;

% exclude 08/09/11
a911ex=1;

% exclude all FOMC announcement days
FOMCex=1;

% consider ONLY FOMC days
FOMConly=false;
%-------------------non iid noise---------------------------------
%sign level for test
alpha=0.05;

%maximum order of dependence
Q_max=50;  %if Q_max=0: iid noise assumed

% skip sampling frequency in seconds 
skips=300;
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data

if ~isequal(configl,'2F')
        inpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Covs',filesep);
else
        inpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Covs_2F',filesep);
end

addpath=strcat(pathproject,'Data',filesep,'Add',filesep);

outpath=strcat(pathproject,'Emp_AnA',filesep,'Plots',filesep);

outpathres=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Averages',filesep);
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days

% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days_cl_',sourced,'_m32_20100501_20140430_thrq1500_thrtr800_tthrq300_tthrtr720_cl.mat'));
date_v=t_date_v_cl;

% load vector of FOMC announcement days
load(strcat(addpath,'FOMC_days.mat'));
% -------------------------------------------------------------------------
%
%% labels

% clean?
if cl_ind==1
    cl_str='cl';            % cleaning string for output file
else
    cl_str='ncl';
end

% label lKb
if lKb>0
     lKbl='_lKb';
else
     lKbl='';
end

% label ccorr
if ccorr>0
     ccorrl='_ccorr';
else
     ccorrl='';
end

% label ccorr
if ccorrlast>0
    ccorrlastl='_ccorrl';
else
    ccorrlastl='';
end

%label twostep
if twost>0
     twostl='_2st';
else
     twostl='';
end

% label: estimator covariance
if twostc>0
      twostcl='_2stc';
else
      twostcl='';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

% exclude twitter flash crash
if fcex==1
    fcex_str='_fcex';
else
    fcex_str='';
end

% exclude 08/09/11
if a911ex==1;
    a911ex_str='_a911ex';
else
    a911ex_str='';
end

% exclude all FOMC announcement days
if FOMCex==1;
    FOMCex_str='_FOMCex';
else
    FOMCex_str='';
end

% FOMC only
if FOMConly
    FOMCex_str='FOMCon';
end

%clean labels
theta_hl=num2str(theta_h);
theta_hl(theta_hl=='.')='';
theta_Jl=num2str(theta_J);
theta_Jl(theta_Jl=='.')='';
theta_Kl=num2str(theta_K);
theta_Kl(theta_Kl=='.')='';

% alpha_label
alpha_l=num2str(alpha);
 alpha_l(alpha_l=='.')='';
 
% label absolute
if absi>0
      absil='dmed_std_abs';
else
      absil='dmed_std';
end 

% -------------------------------------------------------------------------
%
%% Loop over start and end days

for dd=1:length(startd_v)
    
% select
startd=startd_v(dd);
endd=endd_v(dd); 


% outname base
if ~isempty(ind_sel)
    if isequal(estimt,'pair')
        baseout=strcat(absil,'_spot_corr_2d_m',int2str(length(ticker_a)),'_',ticker_a{ind_sel},'_',sourced,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,fcex_str,a911ex_str,FOMCex_str);
    elseif isequal(estimt,'full')
        baseout=strcat(absil,'_spot_corr_md_m',int2str(length(ticker_a)),'_',ticker_a{ind_sel},'_',sourced,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,fcex_str,a911ex_str,FOMCex_str);
    end
else 
    if isequal(estimt,'pair')
        baseout=strcat(absil,'_spot_corr_2d_m',int2str(length(ticker_a)),sourced,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,fcex_str,a911ex_str,FOMCex_str);
    elseif isequal(estimt,'full')
        baseout=strcat(absil,'_spot_corr_md_m',int2str(length(ticker_a)),sourced,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,fcex_str,a911ex_str,FOMCex_str);
    end
end

if Q_max>1
    baseout=strcat(baseout,'_alpha',alpha_l,'_Q',int2str(Q_max));
    if ~isempty(skips)
        baseout=strcat(baseout,'_ss',int2str(skips));
    end
end

% times for plot
times_pl=(input_v*(endt-startt)+9.5)/24;
                                % perc of 24h period
% -------------------------------------------------------------------------
%
%% check for existence of files

% name pf previosuly saved results
nameout_res=strcat(outpathres,baseout,'.mat');

index=isequal(exist(nameout_res,'file'),2);

if ~index
% -------------------------------------------------------------------------
%
%% Create Vectors of Asset Pairs

%create vector of plain asset indices
ind_vec=1:length(ticker_a);

%Create [length(ticker_a)*(length(ticker_a)-1)/2 x 2] matrix containing indices of (distinct) asset pairs 
corr_ind_org=nchoosek(ind_vec,2);       %Binomial coefficient (n k) >>>note: 1st element will always be larger!

%split
ind_1_v_org=corr_ind_org(:,1);           
ind_2_v_org=corr_ind_org(:,2);  

% select relevant pairs
if ~isempty(ind_sel)
    ind_1_ind=ind_1_v_org==ind_sel;
    ind_2_ind=ind_2_v_org==ind_sel;
    corr_ind=corr_ind_org(logical(ind_1_ind+ind_2_ind),:);
    ind_1_v=corr_ind(:,1);           
    ind_2_v=corr_ind(:,2);  
else
    corr_ind=corr_ind_org;
    ind_1_v=corr_ind(:,1);           
    ind_2_v=corr_ind(:,2);  
end
% -------------------------------------------------------------------------
%
%% Start Loop over days 

% Create vector of trading days in matlab date format
tdate_v=date_v(sort(find((date_v>=startd)&(date_v<=endd))));

% consider ONLY FOMC announcement days
if ~FOMConly
    % exclude all FOMC announcement days
    if FOMCex==1;
       tdate_v=setdiff(tdate_v,ann_vec);%retain trading days that are not announcements
    end
else
    tdate_v=intersect(tdate_v,ann_vec);
end

% exclude twitter flash crash
if fcex==1
    tdate_v(tdate_v==datenum('6 may 10'))=[];
end

% exclude 08/09/11
if a911ex==1;
    tdate_v(tdate_v==datenum('9 aug 11'))=[];
end

% initialize
corr_a=NaN*zeros(length(input_v),length(ind_1_v),length(tdate_v));

% loop over days
%-------------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);
    disp(datestr(tdate,'yyyy--mm--dd'))
    
    
% pair-wise estimation
%---------------------------------------------------------
if isequal(estimt,'pair')
    
% loop across paris
parfor i=1:length(ind_1_v)
    
    % tickers
    ticker1=ticker_a{ind_1_v(i)};
    ticker2=ticker_a{ind_2_v(i)};

    %name 
    basename=strcat(inpath,sourced,'_',ticker1,'_',ticker2,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,twostcl);
        
    if Q_max>1
        basename=strcat(basename,'_alpha',alpha_l,'_Q',int2str(Q_max));
        if ~isempty(skips)
            basename=strcat(basename,'_ss',int2str(skips));
        end
    end             
             
             
    % check for existence of file
    if isequal(exist(strcat(basename,'_scov.mat'),'file'),2);
    %------------------------

        %load    
        indat=iload(strcat(basename,'_scov.mat'),'SigmaSpot_out');    
        SigmaS=indat.SigmaSpot_out;
        
        % compute correlations
        [scorr_out,~]=comp_corr_md([2; 1],SigmaS);
        
        % assign
        corr_a(:,i,j)=scorr_out;
        
    else
        
        disp(['Estimates for ' ticker1 ' and ' ticker2 ' are missing. Skip.'])
        
    end

end

%   Full Covariance matrix estimation
%------------------------------------------------------
elseif isequal(estimt,'full')
    
%name 
basename=strcat(inpath,sourced,'_',datestr(tdate,'yyyymmdd'),typed,'_d',int2str(length(ticker_a)),'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,twostcl);

if Q_max>1
    basename=strcat(basename,'_alpha',alpha_l,'_Q',int2str(Q_max));
    if ~isempty(skips)
        basename=strcat(basename,'_ss',int2str(skips));
    end
end             
             
% check for existence of file
if isequal(exist(strcat(basename,'_scov.mat'),'file'),2);
%------------------------
    
    %load    
    load(strcat(basename,'_scov.mat'));    
    
    % loop across paris
    for i=1:length(ind_1_v)
    
        % compute correlations
        [scorr_out,~]=comp_corr_md([ind_1_v(i);ind_2_v(i)],SigmaSpot_out);
        
        % assign
        corr_a(:,i,j)=scorr_out;
        
    end
    

 else
        
        disp(['Estimates for day ' datestr(tdate,'yyyymmdd') ' are missing. Skip.'])
        
end
    
    
end

% end loop over days
%-------------------------------------------------
end
% -------------------------------------------------------------------------
%
%% Compute average correlations and save results

% what to plot
if absi>0
    outv=nanstd(abs(corr_a),1,3);
else
    outv=nanstd(corr_a,1,3);
end


% compute quantiles
quant_m=quantile(outv,(0.1:0.1:1),2) ;


%save 
save(nameout_res,'quant_m');
% -------------------------------------------------------------------------
%
%% Use Old Results
else
    
    load(nameout_res);

end
% -------------------------------------------------------------------------
%
%% Plot 

% differences as area plots sum of columns
dquant_m=[quant_m(:,1) diff(quant_m,1,2)]; 

%prepare ylabel
 ylabs='Standard Deviation Deciles';


% plot
%-----------------------------
fh=figure;
 
set(fh, 'color', 'white');

h = area(times_pl,dquant_m);

datetick('x','HH:MM');

xl = xlabel('\bfseries Time of Day');
yl = ylabel(['\bfseries ' ylabs]);
% l = legend(legend_a);
    
set(gca,'Layer','top', 'TickDir', 'in', 'Box', 'off' ,'XMinorTick','Off','YMinorTick','Off','linewidth',1.5,...
    'XGrid','on','Ygrid','on','GridColor',rgb('black'),'GridLineStyle',':','GridColorMode','manual','GridAlpha',.5); % here gca means get current axis

set(h,'linestyle','-','linewidth',1.3);
ytickv = get(gca,'YTick');
set(h,'BaseValue',ytickv(1))
colormap autumn

set(xl,'interpreter','latex','FontSize',10);
set(yl,'interpreter','latex','FontSize',10);
% set(l,'interpreter','latex','FontSize',10);
% set(l,'Location','Northwest','Orientation','vertical','box','off')

if ~isempty(comp_ylim)
    set(gca,'Ylim',comp_ylim)
    set(gca,'YTick',linspace(comp_ylim(1),comp_ylim(2),5));
    comp_yl='_compy';
else
    comp_yl='';
    ytickv = get(gca,'YTick');
    set(gca,'YTick',linspace(ytickv(1),ytickv(end),5));
end

xlim([9.5/24 16/24])
 
parent = get(h(1),'Parent');
set(parent,'FontSize',10,'FontWeight','demi');    

set(gca,'Box', 'off')


% save plot
export_fig(strcat(outpath,baseout,comp_yl),'-pdf');

% savefig(nameout,'pdf','-fonts');
% savefig(nameout,'eps','-fonts');
% savefig(nameout,'jpeg','-fonts');

% -------------------------------------------------------------------------
%
%% End loop over start and end days

end
