%% run_plot_dist_adapt_spotcov_02072015.m
%--------------------------------------------------------------------------
% Plot Cross Sectional Distribution (quantiles) of Spot Covariance Estimates
% based on adaptive version of estimator
%--------------------------------------------------------------------------
%
%Peter Malec, July 2, 2015
%
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath =1;              

% source of data
sourced='LOBSTER';           % UPPER CASE!

% Stock
ticker_a      ={'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
    'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','AMAT','CMCSA'}; % apr 13

% asset to focus on 
ind_sel=[];  % focus on correlations with this asset (if empty no focus)

% datatype
typed='midp';           % midp: midquotes, trad: trades

% dates (entire period or spec dates)
startd=datenum('1 may 10');
endd=datenum('30 apr 14');
tdate_v=[datenum('6 may 10')];
%tdate_v=[datenum('29 apr 13'):datenum('30 apr 13')]';
%[datenum('1 apr 13'):datenum('5 apr 13') datenum('8 apr 13'):datenum('12 apr 13') datenum('22 apr 13') datenum('24 apr 13'):datenum('26 apr 13')]';

% points of estimation
input_v= linspace(1.5/6.5,1,100); %times are normalized (start at noon)
%input_v=0:0.001:1; %times are normalized

% absolute
absi=-1;

% start end end of trading (in hours)
startt=9.5;
endt=16;

% type if estimation
estimt='full'; % 'pair' or 'full'

%cleaning 
cl_ind=-1;           %if==1: cleaning is done

%revisions
rev_ind=1;     %if ==1, only obs with price revisions are used

%settings for lle
J_p=5;
theta_h=0.175;
theta_J=7;
theta_K=2;
K_p_thr=8;

% configuration
configl='2F';

% correction?
ccorr=1; % correction of variance and correlation estimates
ccorrlast=1; % last estimation step only

% less smoothing at end and beginning of day?
lKb=1;

% two step
twost=-1; % spot volas of 1st step are used as pilots for 2nd step

% covariances of estimates
twostc=1;   

% daily estimate as horizontal line
daily=1;

% pre-specified y limits for comparison
comp_ylim=[0 1];

% time of vertline
vertt=[datenum('14:00')] ;        % in format HH:MM:ss: if empty: no vertical line 
%vertt=[datenum('14:00') datenum('14:20') datenum('13:07')] ;        % in format HH:MM:ss: if empty: no vertical line                         

% annotations(all following expr need to have same dimemsion)
text_pos_x=[];                   %different positions possible (if all elements in row are NaN: no labels for corresponding day)
halign_a={};           % horizontal alignment of text (left or right)
long_ind_m=[];                   % indicator for long arrow-> arrows need same dir as above.
add_v=[]*0.00125;                           % correction (inr: 0.00125) for position of labels (positive if left, otherwise negative)
%-------------------non iid noise---------------------------------
%sign level for test
alpha=0.05;

%maximum order of dependence
Q_max=50;  %if Q_max=0: iid noise assumed

% skip sampling frequency in seconds 
skips=300;
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data

if ~isequal(configl,'2F')
        inpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Covs',filesep);
else
        inpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Covs_2F',filesep);
end

if ~isequal(configl,'2F')
    inpathint=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'ICovs',filesep);
else
    inpathint=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'ICovs_2F',filesep);
end

addpath=strcat(pathproject,'Data',filesep,'Add',filesep);

outpath=strcat(pathproject,'Emp_AnA',filesep,'Plots',filesep);

outpathres=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Averages',filesep);
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days

% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days_cl_',sourced,'_m32_20100501_20140430_thrq1500_thrtr800_tthrq300_tthrtr720_cl.mat'));
date_v=t_date_v_cl;
% -------------------------------------------------------------------------
%
%% labels

% clean?
if cl_ind==1
    cl_str='cl';            % cleaning string for output file
else
    cl_str='ncl';
end

% label lKb
if lKb>0
     lKbl='_lKb';
else
     lKbl='';
end

% label ccorr
if ccorr>0
     ccorrl='_ccorr';
else
     ccorrl='';
end

% label ccorr
if ccorrlast>0
    ccorrlastl='_ccorrl';
else
    ccorrlastl='';
end

%label twostep
if twost>0
     twostl='_2st';
else
     twostl='';
end

% label: estimator covariance
if twostc>0
      twostcl='_2stc';
else
      twostcl='';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

% daily 
if daily==1
    daily_str='_dl';
else
    daily_str='';
end

%clean labels
theta_hl=num2str(theta_h);
theta_hl(theta_hl=='.')='';
theta_Jl=num2str(theta_J);
theta_Jl(theta_Jl=='.')='';
theta_Kl=num2str(theta_K);
theta_Kl(theta_Kl=='.')='';

% label absolute
if absi>0
      absil='med_abs';
else
      absil='med';
end

% alpha_label
alpha_l=num2str(alpha);
 alpha_l(alpha_l=='.')='';
% -------------------------------------------------------------------------
%
%% Create Vectors of Asset Pairs

%create vector of plain asset indices
ind_vec=1:length(ticker_a);

%Create [length(ticker_a)*(length(ticker_a)-1)/2 x 2] matrix containing indices of (distinct) asset pairs 
corr_ind_org=nchoosek(ind_vec,2);       %Binomial coefficient (n k) >>>note: 1st element will always be larger!

%split
ind_1_v_org=corr_ind_org(:,1);           
ind_2_v_org=corr_ind_org(:,2);  

% select relevant pairs
if ~isempty(ind_sel)
    ind_1_ind=ind_1_v_org==ind_sel;
    ind_2_ind=ind_2_v_org==ind_sel;
    corr_ind=corr_ind_org(logical(ind_1_ind+ind_2_ind),:);
    ind_1_v=corr_ind(:,1);           
    ind_2_v=corr_ind(:,2);  
else
    corr_ind=corr_ind_org;
    ind_1_v=corr_ind(:,1);           
    ind_2_v=corr_ind(:,2);  
end
% -------------------------------------------------------------------------
%
%% Start Loop over days 

% Create vector of trading days in matlab date format
if isempty(tdate_v)
    tdate_v=date_v(sort(find((date_v>=startd)&(date_v<=endd))));
end

% times for plot
times_pl=(input_v*(endt-startt)+9.5)/24;
                                % perc of 24h period
% loop
%-------------------------------------------------
for j=1:length(tdate_v)
    
    % select date and display
    tdate=tdate_v(j);
    disp(datestr(tdate,'yyyy--mm--dd'))
    
    % clear old values
    clear corr_m;
    clear outv;
    
%% collect pairwise correlation estimates

% initialize
cov_m=NaN*zeros(length(input_v),length(ind_1_v));


% pair-wise estimation
%---------------------------------------------------------
if isequal(estimt,'pair')

% loop across paris
for i=1:length(ind_1_v)
    
    % tickers
    ticker1=ticker_a{ind_1_v(i)};
    ticker2=ticker_a{ind_2_v(i)};

    %name 
    basename=strcat(inpath,sourced,'_',ticker1,'_',ticker2,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,twostcl);
        
    % check for existence of file
    if isequal(exist(strcat(basename,'_scov_adapt.mat'),'file'),2);
    %------------------------

        %load    
        load(strcat(basename,'_scov_adapt.mat'));    
        
        % assign
        cov_m(:,i)=SigmaSpot_out(:,2);
        
        
    else
        
        disp(['Estimates for ' ticker1 ' and ' ticker2 ' are missing. Skip.'])
        
    end

end

%   Full Covariance matrix estimation
%------------------------------------------------------
elseif isequal(estimt,'full')
    
%name 
basename=strcat(inpath,sourced,'_',datestr(tdate,'yyyymmdd'),typed,'_d',int2str(length(ticker_a)),'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,twostcl);
                          
% check for existence of file
if isequal(exist(strcat(basename,'_scov_adapt.mat'),'file'),2);
%------------------------
    
    %load    
    load(strcat(basename,'_scov_adapt.mat'));    
    
    % loop across paris
    for i=1:length(ind_1_v)
    
        %retrieve covariance elements
        [SigmaSpot_out_sel,~]=retrieve_cov_el([ind_1_v(i);ind_2_v(i)],SigmaSpot_out);
    
        % assign
        cov_m(:,i)=SigmaSpot_out_sel(:,2);
        
    end
    

 else
        
        disp(['Estimates for day ' datestr(tdate,'yyyymmdd') ' are missing. Skip.'])
        
end
    
end

% annualize covariances
cov_m=252*cov_m;
% -------------------------------------------------------------------------
%
%% Daily

if daily==1

% initialize
icov_m=NaN*zeros(1,length(ind_1_v));

% pair-wise estimation
%---------------------------------------------------------
if isequal(estimt,'pair')
    
% loop across paris
parfor i=1:length(ind_1_v)
    
    % tickers
    ticker1=ticker_a{ind_1_v(i)};
    ticker2=ticker_a{ind_2_v(i)};
    
    %name 
    basename=strcat(inpathint,sourced,'_',ticker1,'_',ticker2,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),ccorrl,ccorrlastl,twostl,twostcl);
        
    if Q_max>1
        basename=strcat(basename,'_alpha',alpha_l,'_Q',int2str(Q_max));
        if ~isempty(skips)
            basename=strcat(basename,'_ss',int2str(skips));
        end
    end             
             
             
    % check for existence of file
    if isequal(exist(strcat(basename,'_icov.mat'),'file'),2);
    %------------------------

        %load    
        indat=iload(strcat(basename,'_icov.mat'),'SigmaInt_out');    
        SigmaI=indat.SigmaInt_out;
        
        % assign
        icov_m(i)=SigmaI(2);
        
    else
        
        disp(['Integrated Estimates for ' ticker1 ' and ' ticker2 ' are missing. Skip.'])
        
    end

end

%   Full Covariance matrix estimation
%------------------------------------------------------
elseif isequal(estimt,'full')
    
%name 
basename=strcat(inpathint,sourced,'_',datestr(tdate,'yyyymmdd'),typed,'_d',int2str(length(ticker_a)),'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),ccorrl,ccorrlastl,twostl,twostcl);

if Q_max>1
    basename=strcat(basename,'_alpha',alpha_l,'_Q',int2str(Q_max));
    if ~isempty(skips)
        basename=strcat(basename,'_ss',int2str(skips));
    end
end             
             
% check for existence of file
if isequal(exist(strcat(basename,'_icov.mat'),'file'),2);
%------------------------
    
    %load    
    load(strcat(basename,'_icov.mat'));    
    
    % loop across paris
    for i=1:length(ind_1_v)
        
        %retrieve covariance elements
        [SigmaSpot_out_sel,~]=retrieve_cov_el([ind_1_v(i);ind_2_v(i)],SigmaInt_out');
    
        % assign
        icov_m(i)=SigmaSpot_out_sel(:,2);

    end
    

 else
        
        disp(['Integrated Estimates for day ' datestr(tdate,'yyyymmdd') ' are missing. Skip.'])
        
end
    
    
end

% annualize covariances
icov_m=252*icov_m;

if absi>0
     outvd=abs(icov_m);
else
     outvd=icov_m;
end
outvd=nanmedian(outvd);

end
% -------------------------------------------------------------------------
%
%% Plot average correlations


% what to plot
if absi>0
    outv=abs(cov_m);
    ylabs='Abs. Covariance Deciles';
else
    outv=cov_m;
     ylabs='Covariance Deciles';
end

% compute quantiles
quant_m=quantile(outv,(0.1:0.1:1),2) ;

% differences as area plots sum of columns
dquant_m=[quant_m(:,1) diff(quant_m,1,2)]; 

% minimum and max correlation for lower limit
% max_q=max(quant_m(:,end));
% max_q_y=ceil(10*max_q)/10;
% min_q=min(quant_m(:,1));
% min_q_y=floor(10*min_q)/10;
% if (abs(max_q-max_q_y)<1e-13)&&(abs(max_q-1)>1e-13)
%     max_q_y=max_q_y+0.1;
% end
% if (abs(min_q-min_q_y)<1e-13)&&(abs(min_q-basev)>1e-13)
%     min_q_y=min_q_y-0.1;
% end

% % legend labels
% legend_a=cell(10,1);
% for k=1:length(legend_a)
% legend_a{k}=num2str(0.1*k);
% end

% create vector of labels
if ~isempty(text_pos_x)
    if sum(isnan(text_pos_x(j,:)))<size(text_pos_x,2)
        if (size(text_pos_x,2)~=size(halign_a,2))||(size(text_pos_x,2)~=size(long_ind_m,2))||...
            (size(long_ind_m,2)~=size(halign_a,2))
            error('text_pos_x, long_ind_m and halign_a must have same no of columns!')
        end
        text_a=cell(size(text_pos_x,2),1);
        for i=1:length(text_a)
            if ~isnan(text_pos_x(j,i))
                base_str=strcat('$', int2str(i),')$');
                if ~isequal(long_ind_m(j,i),1)
                    l_str='';
                else
                    l_str='long';
                end
                if isequal(halign_a{j,i},'left')
                    text_a{i}=strcat('$\',l_str,'leftarrow\left(', int2str(i),'\right)$');
                else
                    text_a{i}=strcat('$\left(', int2str(i),'\right)\',l_str,'rightarrow$');
                end
            end
        end
    else
        text_a=cell(size(text_pos_x,2),1);
    end
else
    text_a=cell(size(text_pos_x,2),1);
end
    
% plot
%-----------------------------
fh=figure;
 
set(fh, 'color', 'white');

h = area(times_pl,dquant_m);

datetick('x','HH:MM');

xl = xlabel('\bfseries Time of Day');
yl = ylabel(['\bfseries ' ylabs]);
% l = legend(legend_a);
    
set(gca,'Layer','top', 'TickDir', 'in', 'Box', 'off' ,'XMinorTick','Off','YMinorTick','Off','linewidth',1.5,...
    'XGrid','on','Ygrid','on','GridColor',rgb('black'),'GridLineStyle',':','GridColorMode','manual','GridAlpha',.5); % here gca means get current axis

set(h,'linestyle','-','linewidth',1.3);
ytickv = get(gca,'YTick');
set(h,'BaseValue',ytickv(1))
colormap autumn

set(xl,'interpreter','latex','FontSize',10);
set(yl,'interpreter','latex','FontSize',10);
% set(l,'interpreter','latex','FontSize',10);
% set(l,'Location','Northwest','Orientation','vertical','box','off')

if ~isempty(comp_ylim)
    set(gca,'Ylim',comp_ylim)
    set(gca,'YTick',linspace(comp_ylim(1),comp_ylim(2),5));
    comp_yl='_compy';
else
    comp_yl='';
    ytickv = get(gca,'YTick');
    set(gca,'YTick',linspace(ytickv(1),ytickv(end),5));
end

xlim([11/24 16/24])
 
parent = get(h(1),'Parent');
set(parent,'FontSize',10,'FontWeight','demi');    

set(gca,'Box', 'off')

%# vertical line
if ~isempty(vertt)
    if ~isnan(vertt(j))
%         hx = graph2d.constantline(vertt(j)-datenum('00:00'), 'LineStyle','--', 'Color',rgb('black'),'linewidth',1.3);
%         changedependvar(hx,'x');
        matlab.graphics.axis.decorator.Baseline('BaseValue',vertt(j)-datenum('00:00'), 'Parent',gca, 'Axis',0, 'Visible','on','LineStyle','--', 'Color',rgb('black'),'LineWidth',1.3);
    end
end

%text
if sum(cellfun(@isempty,text_a))<length(text_a)
    for i=1:length(text_a)
        if ~isnan(text_pos_x(j,i))
            x_pos=text_pos_x(j,i)-datenum('00:00');
            y_pos=dquant_m(find(times_pl>=x_pos,1,'first'));
                 text(x_pos+add_v(i),y_pos,text_a{i},...
            'HorizontalAlignment',halign_a{j,i},'interpreter','latex','FontSize',10)
        end
    end
end

% label vert
if ~isempty(vertt)
    if ~isnan(vertt(j))
      vertl='_vl';
    else
      vertl='';
    end
else
    vertl='';
end


% label vert
if sum(cellfun(@isempty,text_a))<length(text_a)
      textl='_tt';
else
      textl='';
end

% horizonal line at daily median
if isequal(daily,1)
%     hy = graph2d.constantline(outvd, 'color',rgb('black'),'linestyle','-','linewidth',1.4);
%     changedependvar(hy,'y');
        hold on
        hy=plot(xlim, [outvd outvd]);              % Plot horz Line
        set(hy,'color',rgb('black'),'linestyle','-','linewidth',1.4);
        hold off
end
 
parent = get(h(1),'Parent');
set(parent,'FontSize',10,'FontWeight','demi');    

set(gca,'Box', 'off')

% save plot
if ~isempty(ind_sel)
    if isequal(estimt,'pair')
        nameout=strcat(outpath,absil,'_spot_cov_adapt_2d_m',int2str(length(ticker_a)),'_',ticker_a{ind_sel},'_',sourced,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,vertl,textl,comp_yl,daily_str);
    elseif isequal(estimt,'full')
        nameout=strcat(outpath,absil,'_spot_cov_adapt_md_m',int2str(length(ticker_a)),'_',ticker_a{ind_sel},'_',sourced,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,vertl,textl,comp_yl,daily_str);
    end
else
    if isequal(estimt,'pair')
        nameout=strcat(outpath,absil,'_spot_cov_adapt_2d_m',int2str(length(ticker_a)),'_',sourced,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,vertl,textl,comp_yl,daily_str);
    elseif isequal(estimt,'full')
        nameout=strcat(outpath,absil,'_spot_cov_adapt_md_m',int2str(length(ticker_a)),'_',sourced,'_',datestr(tdate,'yyyymmdd'),typed,'_',cl_str,rev_str,...
                 '_th',theta_hl,'tJ',theta_Jl,'tK',theta_Kl,'J_p',int2str(J_p),'K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,vertl,textl,comp_yl,daily_str);
    end
end

if Q_max>1
        nameout=strcat(nameout,'_alpha',alpha_l,'_Q',int2str(Q_max));
        if ~isempty(skips)
            nameout=strcat(nameout,'_ss',int2str(skips));
        end
end
    
        
export_fig(nameout,'-pdf');
% savefig(nameout,'pdf','-fonts');
% savefig(nameout,'eps','-fonts');
% savefig(nameout,'jpeg','-fonts');

% -------------------------------------------------------------------------
%
%% end loop over days
end


