%% run_plot_seas_ret_07052014.m
%--------------------------------------------------------------------------
% plot intraday seasonality based on plain returns. daily vola
% estimate is subsampled 5min-RV.
%--------------------------------------------------------------------------
%
% Peter Malec, May 7, 2014
%
% -------------------------------------------------------------------------
%
%% Define INPUTS


% Clear system
clear all;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath =1;              

% source of data
source_d='LOBSTER';           % UPPER CASE!

% Stock
ticker_a     ={'AAPL','MSFT','GOOG','CSCO','ORCL','INTC','QCOM','AMGN','TEVA','GILD','AMZN','EBAY','NWSA',...
    'DTV','CELG','INFY','YHOO','COST','SPLS','SBUX','ADP','ESRX','ADBE','FSLR','BIIB','SYMC','JNPR','BRCM','AMAT','CMCSA'}; % apr 13

% datatype
typed='midp';           % midp: midquotes, trad: trades

% dates (entire period or spec dates)
startd=datenum('1 may 10');
endd=datenum('30 apr 14');
tdate_v=[];
%tdate_v=[datenum('29 apr 13'):datenum('30 apr 13')]';
%[datenum('1 apr 13'):datenum('5 apr 13') datenum('8 apr 13'):datenum('12 apr 13') datenum('22 apr 13') datenum('24 apr 13'):datenum('26 apr 13')]';

% dates for FFF
startdFFF=datenum('3 may 10');
enddFFF=datenum('30 apr 14');

% points of estimation
input_v=0:0.001:1; %times are normalized

% start end end of trading (in hours)
startt=9.5;
endt=16;

% Order of Fourier Form
maxD=20;

% spec of fourier form
spec=1; %=0 -> no polynomial and intercept, =1  ->polynomial, but no intercept, = 2   -> intercept, but no polynomial  =3  -> intercept and polynomial

%cleaning 
cl_ind=-1;           %if==1: cleaning is done

%revisions
rev_ind=1;     %if ==1, only obs with price revisions are used

% frequency for sampling (in seconds)
freqs=300;

% frequency for rv (in seconds)
freqrv=300;

% no of subsamples
nss=10;

% aggregate according to two liqu groups
liqugroup=5; % 1,2 or 3,4,5 (3 groups) if [], pool all assets

%save plot?
savep=-1;
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath and Path for additional Data

inpath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'FFF_Ret',filesep);
nobspath=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'Add',filesep,'N_obs_LOBSTER',filesep);
addpath=strcat(pathproject,'Data',filesep,'Add',filesep);
outpath=strcat(pathproject,'Emp_AnA',filesep,'Plots',filesep);
% -------------------------------------------------------------------------
%
%% Load Vector of Trading Days

% Create vector of trading days in matlab date format
load(strcat(addpath,'trading_days_cl_',source_d,'_m32_20100501_20140430_thrq1500_thrtr800_tthrq300_tthrtr720_cl.mat'));
date_v=t_date_v_cl;
% -------------------------------------------------------------------------
%
%% labels

% clean?
if cl_ind==1
    cl_str='cl';            % cleaning string for output file
else
    cl_str='ncl';
end

% revisions?
if rev_ind==1
     rev_str='_rev';            
else
     rev_str='';     
end

% times for plot
times_pl=(input_v*(endt-startt)+9.5)/24;
                                % perc of 24h period

% dimension
m=length(ticker_a);

% Create vector of trading days in matlab date format
if isempty(tdate_v)
    tdate_v=date_v(sort(find((date_v>=startd)&(date_v<=endd))));
end
% -------------------------------------------------------------------------
%
%% find two liquidity groups if necessary
if ~isempty(liqugroup)
    
    nobs_mat=NaN*zeros(length(tdate_v),m);
    
    % loop across assets and collect
    for i=1:m
        ticker=ticker_a{i};
        load(strcat(nobspath,ticker,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),'_',typed,'_',cl_str,rev_str));
        nobs_mat(:,i)=n_obs_mat2(:,1);
    end
    
    % sort 
    [~,I]=sort(nanmean(nobs_mat),'descend');
    
    % select tickers
    if isequal(liqugroup,1)
        ticker_a=ticker_a(I(1:floor(length(ticker_a)/2)));
    elseif isequal(liqugroup,2)
        ticker_a=ticker_a(I((floor(length(ticker_a)/2)+1):end));
   elseif isequal(liqugroup,3)
        ticker_a=ticker_a(I(1:floor(length(ticker_a)/3)));
   elseif isequal(liqugroup,4)
        ticker_a=ticker_a(I((floor(length(ticker_a)/3)+1):(floor(length(ticker_a)/3)*2)));     
   elseif isequal(liqugroup,5)
        ticker_a=ticker_a(I((floor(length(ticker_a)/3)*2+1):end));          
    else
        error('liqugriup must be either 1,2 or 3,4,5!')
    end
    
    %label
    liquiLab=strcat('_L',int2str(liqugroup));
    
else
    %label
    liquiLab='';
    
end

% -------------------------------------------------------------------------
%
%% check existence of FFF estimate

%load estimates
%-----------------------------------------------------
if ~isempty(nss)
        basename_FFF=strcat('FFF_maxD',int2str(maxD),'_spec',int2str(spec),'_m',int2str(length(ticker_a)),liquiLab,'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
            typed,'_',cl_str,rev_str,...
                '_freqs',int2str(freqs),'_freq',int2str(freqrv),'_nss',int2str(nss));
else
    basename_FFF=strcat('FFF_maxD',int2str(maxD),'_spec',int2str(spec),'_m',int2str(length(ticker_a)),liquiLab,'_',source_d,'_',datestr(startd,'yyyymmdd'),'_',datestr(endd,'yyyymmdd'),...
       typed,'_',cl_str,rev_str,...
                '_freqs',int2str(freqs),'_freq',int2str(freqrv));
end

index=isequal(exist(strcat(inpath,basename_FFF,'.mat'),'file'),2);

if ~index
% -------------------------------------------------------------------------
%
%% Compute FFF

% number of parameters
switch spec
    case 0
        np=2*maxD;
    case 1
        np=2*maxD+2;
     case 2
         np=2*maxD+1;
    otherwise
        np=2*maxD+3;
end


% initialize parameter matrix
param_mat=zeros(length(ticker_a),np);

% loop over assets and collect parameters
%----------------------------------------------
for i=1:length(ticker_a)
    
    ticker=ticker_a{i};

    %load estimates
    %-----------------------------------------------------
    if ~isempty(nss)
        basename=strcat('FFF_maxD',int2str(maxD),'_spec',int2str(spec),source_d,'_',ticker,'_',datestr(startdFFF,'yyyymmdd'),'_',datestr(enddFFF,'yyyymmdd'),...
            typed,'_',cl_str,rev_str,...
                '_freqs',int2str(freqs),'_freq',int2str(freqrv),'_nss',int2str(nss));
    else
    basename=strcat('FFF_maxD',int2str(maxD),'_spec',int2str(spec),source_d,'_',ticker,'_',datestr(startdFFF,'yyyymmdd'),'_',datestr(enddFFF,'yyyymmdd'),...
       typed,'_',cl_str,rev_str,...
                '_freqs',int2str(freqs),'_freq',int2str(freqrv));
    end
    load(strcat(inpath,basename))     
    
    %assigns parameter estimates
    param_mat(i,1:length(FF_res.theta_FF))=FF_res.theta_FF(:)';

end

%median parameters
theta_FF_med=nanmedian(param_mat)';

%save
save(strcat(inpath,basename_FFF),'theta_FF_med')     

else
%% load values

load(strcat(inpath,basename_FFF))    
    
end   
% -------------------------------------------------------------------------
%
%% Plot

% compute FFF using median parameters
sigma2=vola_fourier_gen(times_pl',theta_FF_med,spec);


ylabs='Volatility Seas. Factor';


% plot
%-----------------------------
fh=figure;
 
set(fh, 'color', 'white');


h1=plot(times_pl',sqrt(sigma2));

set(h1(1),'color',rgb('black'),'linestyle','-','linewidth',1.3);


datetick('x','HH:MM');

xl = xlabel('\bfseries Time of Day');
yl = ylabel(['\bfseries ' ylabs]);

set(gca, 'TickDir', 'in', 'Box', 'on' ,'XMinorTick','Off','YMinorTick','Off','linewidth',1.5,...
    'XGrid','off','Ygrid','off','XTick',(9:1:16)/24); % here gca means get current axis
    
set(xl,'interpreter','latex','FontSize',10);
set(yl,'interpreter','latex','FontSize',10);

xlim([9.5/24 16/24]) 

parent = get(h1(1),'Parent');
set(parent,'FontSize',10,'FontWeight','demi');    


% save plot
if savep==1
    nameout=strcat(outpath,basename_FFF);
    export_fig(nameout,'-pdf'); 
end




