%% run_plot_sim_eval_svol_grid_kern_21052016.m
%--------------------------------------------------------------------------
% plots (normalized) RMISEs, bias or variances for 
% estimates of spot variances using lmm for
%          *simple multivatiate factor model as in 
%               Barndorff-Nielsen, Hansen, Lunde & Shephard (2011, JE)
%               based on equicorrelation structure for signal 
%           * 2-factor stochastic volatility following Chernov et al. (2003, JE)
%           * intraday seasonality
 %           *dillluted by microstructure noise
  %           * smoothing final estimates using kernel weights
 % for grid of two thetas, while other theta fixed
%--------------------------------------------------------------------------
%
% Peter Malec, May 21, 2016
%
% -------------------------------------------------------------------------------------------------
%
%% Define INPUTS

% Clear system
clear all;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath = 1;                    

%# number of simulation steps within a day
steps=23400*5;      

%# number of seconds within trading day
nsec_trad=23400;

% dimension
m=15;

% # of replications
repl=1000;    

% bias or emse
meas='fb';

% diurnal component
diurn=1; %if >0: deterministic diurnal component

% incorporate jumps ?
doJumps=false;

%burnin second factor
Nin=1e6;  

% points of estimation
input_v=0:0.01:1; %times are normalized

% theta grids
theta_h_v=0.025:0.025:0.25;
theta_J_v=1:1:10;
theta_K_v=1.2:0.4:4.8; 
%theta_K_v=0.4:0.4:4; 
%theta_J_v=0.5:0.5:5;

%remaining settings for lle
J_p=5;
K_p_thr=1;

% implementation of kernel-based estimator
J_p_kern=5;
theta_h_kern=0.175;
theta_J_kern=7;
theta_K_v_kern=.006:.001:.015;
K_p_thr_kern=0;%.25;
kern='GAUSS';

% correction?
ccorr=1; % correction of variance and correlation estimates
ccorrlast=1; % last estimation step only

% less smoothing at end and beginning of day?
lKb=1;

% two step
twost=-1; % spot volas of 1st step are used as pilots for 2nd step
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath 

inpath=strcat(pathproject,'Sim',filesep,'Sim_d',int2str(m),filesep);

outpath=strcat(pathproject,'Sim',filesep,'Plots',filesep);

outpathres=strcat(pathproject,'Sim',filesep,'Averages',filesep);
% -------------------------------------------------------------------------
%
%% Labels

% label lKb
if lKb>0
     lKbl='_lKb';
else
     lKbl='';
end

% label ccorr
if ccorr>0
     ccorrl='_ccorr';
else
     ccorrl='';
end

% label ccorrlast
if ccorrlast<=0
     ccorrlastl='_nccorrl';
else
     ccorrlastl='';
end

%label twostep
if twost>0
     twostl='_2st';
else
     twostl='';
end

%seasonality
if diurn>0
    diurnl='';
else
     diurnl='ndiurn_';
end
% -------------------------------------------------------------------------
%
%% Define inputs

% square root of equicorrelation
rhotild=sqrt(0.312);   % 0.312 (q_{0.5})

 % 1st order Acorr of MA 1noise
 nrho=0.441*ones(m,1);  

% ma param?
if ~isempty(nrho)
    nrho_l=strcat('_marh', num2str(nrho(1),'%tx'));
else
    nrho_l='';
end

% jump configuration
if doJumps
    J_time=0.6;
    J_size_fac=5;
    J_prob=0.75;
end

% -------------------------------------------------------------------------
%
%% check for existence of files

%basename
thml=num2str(theta_h_v(1),'%2.2f');
thml(thml=='.')='';
tKml=num2str(theta_K_v(1),'%2.2f');
tKml(tKml=='.')='';
rhotl=num2str(rhotild,'%2.2f');
rhotl(rhotl=='.')='';

thkernl=num2str(theta_h_kern,'%2.3f');
thkernl(thkernl=='.')='';
tKkernml=num2str(theta_K_v_kern(1),'%2.3f');
tKkernml(tKkernml=='.')='';
K_p_thr_kernl=num2str(K_p_thr_kern,'%2.2f');
    K_p_thr_kernl(K_p_thr_kernl=='.')='';


basename=strcat('inp_',int2str(length(input_v)),'_thm',thml,'_thv',int2str(length(theta_h_v)),...
    '_tJm',int2str(theta_J_v(1)),'_tJv',int2str(length(theta_J_v)),'_tKm',tKml,...
                '_tKv',int2str(length(theta_K_v)),'_J_p',int2str(J_p),'_K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,...
                '_',diurnl,'_',rhotl,nrho_l,'_d',int2str(m),'_st',num2str(steps),'_nsec',num2str(nsec_trad),'_nin',num2str(Nin));

basename_kern=strcat('inp_',int2str(length(input_v)),'_',upper(kern),'_th',thkernl,...
        '_tJ',int2str(theta_J_kern),'_tKm',tKkernml,...
                    '_tKv',int2str(length(theta_K_v_kern)),'_J_p',int2str(J_p_kern),'_K_pt',K_p_thr_kernl,ccorrl,ccorrlastl,twostl,...
                    '_',diurnl,'_',rhotl,nrho_l,'_d',int2str(m),'_st',num2str(steps),'_nsec',num2str(nsec_trad),'_nin',num2str(Nin));            
                        
if doJumps
    jptl=num2str(J_time,'%2.2f');
    jptl(jptl=='.')='';
    jpsl=num2str(J_size_fac,'%2.2f');
    jpsl(jpsl=='.')='';
    jppl=num2str(J_prob,'%2.2f');
    jppl(jppl=='.')='';
    basename=strcat(basename,'_jpt',jptl,'_jps',jpsl,'_jpp',jppl);
    basename_kern=strcat(basename_kern,'_jpt',jptl,'_jps',jpsl,'_jpp',jppl);
end

% name pf previosuly saved results
nameout_res=strcat(outpathres,meas,'_svol_fact_',basename_kern,'_reps',num2str(repl),'.mat');

index=isequal(exist(nameout_res,'file'),2);

if ~index
% -------------------------------------------------------------------------
%            
%% Collect Results across Monte Carlo Loops            
            
% intialize array for results
res_arr=NaN*zeros(m*(m+1)/2,length(theta_K_v_kern),repl);

% loop over dgps, simulate and compute estimates
%--------------------------------------------------------------------
parfor j=1:repl                                       
         
            %Status
            display([ 'Replication: ' int2str(j)]);
            
            %load
            xx=iload(strcat(inpath,basename_kern,'_r',num2str(j)),'x');
            res_arr(:,:,j)=xx.x;
         
end

% load matrix of true integrated variances 
load(strcat(inpath,basename,'_reps',num2str(repl),'_isigma2.mat'))

%expand matrix of true integrated variances 
isigma2_arr=permute(isigma2_mat,[2 3 1]);
isigma2_arr=isigma2_arr(:,ones(length(theta_K_v_kern),1),:);
% -------------------------------------------------------------------------
%    
%% compute measure

% compute
switch meas
        case 'rmse'
                outarr=sqrt(squeeze(nanmean((res_arr./isigma2_arr-1).^2,3)));
        case 'fb'
                outarr=squeeze(nanmean((res_arr./isigma2_arr-1).^2,3));
        case 'std'
                outarr=squeeze(nanstd(res_arr./isigma2_arr,1,3));
        case  'bias'
                outarr=abs(squeeze(nanmean(res_arr./isigma2_arr-1,3)));
        otherwise
                  error('Input "rmse", "std" or "bias"!')  
end

% delete huge array
clear res_arr;
clear isigma2_arr;

%save 
save(nameout_res,'outarr');
% -------------------------------------------------------------------------
%
%% Use Old Results
else
    
    load(nameout_res);

end
% -------------------------------------------------------------------------
% 
%% Select variables for plot

 % average results over elements of matrix
 outarr=squeeze(nanmean(outarr,1));
 
 %do stuff for frobenius norm 
 if isequal(meas,'fb')
    outarr=sqrt(outarr);
 end
% -------------------------------------------------------------------------
%
%% Plot 

%x- and y-variable
xvar=theta_K_v_kern;

%prepare ylabel
ylabs=upper(meas);

fh=figure;
 
set(fh, 'color', 'white');

h=plot(xvar,100*outarr);

set(h(1),'color',rgb('black'),'linestyle','-','linewidth',1.3);

xl = xlabel(['\bfseries ' strcat('$\theta_K$')]);
yl = zlabel(['\bfseries ' ylabs]);
    
xlim([xvar(1) xvar(end)])

xtickv = get(gca,'XTick');
set(gca,'XTick',linspace(xtickv(1),xtickv(end),5));

set(gca, 'TickDir', 'in','linewidth',1.3); % here gca means get current axis
    
set(xl,'interpreter','latex','FontSize',14);
set(yl,'interpreter','latex','FontSize',14);

parent = get(h(1),'Parent');
set(parent,'FontSize',10,'FontWeight','demi');    


% save plot
nameout=strcat(outpath,meas,'_svol_fact_',basename_kern ,'_reps',num2str(repl));

export_fig(nameout,'-pdf');

% savefig(nameout,'pdf','-fonts');
% savefig(nameout,'eps','-fonts');
% savefig(nameout,'jpeg','-fonts');
%  

    
