%% run_sim_eval_factor_svol_2f_kern_17052016.m
%--------------------------------------------------------------------------
% Evaluates  (normalized) RMISEs, bias or variances for 
% estimates of spot variances using lmm for
%          *simple multivatiate factor model as in 
%               Barndorff-Nielsen, Hansen, Lunde & Shephard (2011, JE)
%               based on equicorrelation structure for signal 
%           * 2-factor stochastic volatility following Chernov et al. (2003, JE)
%           * intraday seasonality
 %           *dillluted by microstructure noise
 %           * smoothing final estimates using kernel weights
%--------------------------------------------------------------------------
%
% Peter Malec, May 17, 2016
%
% -------------------------------------------------------------------------------------------------
%
%% Define INPUTS

% Clear system
clear all;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath = 1;                    

%# number of simulation steps within a day
steps=23400*5;      

%# number of seconds within trading day
nsec_trad=23400;

% dimension
m=15;

% # of replications
repl=1000;    

% bias or emse
meas='fb';

% diurnal component
diurn=1; %if >0: deterministic diurnal component

% incorporate jumps ?
doJumps=true;

%burnin second factor
Nin=1e6;  

% points of estimation
input_v=0:0.01:1; %times are normalized

% theta grids
theta_h_v=0.025:0.025:0.25;
theta_J_v=1:1:10;
theta_K_v=1.2:0.4:4.8; 
%theta_K_v=0.4:0.4:4; 
%theta_J_v=0.5:0.5:5;

%remaining settings for lle
J_p=5;
K_p_thr=1;

% implementation of kernel-based estimator
J_p_kern=5;
theta_h_kern=0.175;%0.175;
theta_J_kern=6;%7;
theta_K_v_kern=.005:.005:.05;
K_p_thr_kern=0;%.25;
kern='GAUSS';

% correction?
ccorr=1; % correction of variance and correlation estimates
ccorrlast=-1; % last estimation step only

% less smoothing at end and beginning of day?
lKb=1;

% two step
twost=-1; % spot volas of 1st step are used as pilots for 2nd step

% check psd
doCheckPSD=true;

% separate results for var and cov
doSepVarCov=true;%true; DO THAT ONLY IF m>1 !!!!!!!!!!
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath 

inpath=strcat(pathproject,'Sim',filesep,'Sim_d',int2str(m),filesep);
 
outpath=strcat(pathproject,'Sim',filesep,'Tables',filesep);

outpathres=strcat(pathproject,'Sim',filesep,'Averages',filesep);
% -------------------------------------------------------------------------
%
%% Define inputs

% square root of equicorrelation
rhotild=sqrt(0.312);   % 0.312 (q_{0.5})

 % 1st order Acorr of MA 1noise
 nrho=0.441*ones(m,1);  

% ma param?
if ~isempty(nrho)
    nrho_l=strcat('_marh', num2str(nrho(1),'%tx'));
else
    nrho_l='';
end

% jump configuration
if doJumps
    J_time=0.6;
    J_size_fac=5;
    J_prob=0.75;
end
% -------------------------------------------------------------------------
%
%% Labels

% label lKb
if lKb>0
     lKbl='_lKb';
else
     lKbl='';
end


% label ccorr
if ccorr>0
     ccorrl='_ccorr';
else
     ccorrl='';
end

% label ccorrlast
if ccorrlast<=0
     ccorrlastl='_nccorrl';
else
     ccorrlastl='';
end

%label twostep
if twost>0
     twostl='_2st';
else
     twostl='';
end

%seasonality
if diurn>0
    diurnl='';
else
     diurnl='ndiurn_';
end
% -------------------------------------------------------------------------
%
%% check for existence of files

%basename
thml=num2str(theta_h_v(1),'%2.2f');
thml(thml=='.')='';
tKml=num2str(theta_K_v(1),'%2.2f');
tKml(tKml=='.')='';
rhotl=num2str(rhotild,'%2.2f');
rhotl(rhotl=='.')='';

thkernl=num2str(theta_h_kern,'%2.3f');
thkernl(thkernl=='.')='';
tKkernml=num2str(theta_K_v_kern(1),'%2.3f');
tKkernml(tKkernml=='.')='';
K_p_thr_kernl=num2str(K_p_thr_kern,'%2.2f');
    K_p_thr_kernl(K_p_thr_kernl=='.')='';

basename=strcat('inp_',int2str(length(input_v)),'_thm',thml,'_thv',int2str(length(theta_h_v)),...
    '_tJm',int2str(theta_J_v(1)),'_tJv',int2str(length(theta_J_v)),'_tKm',tKml,...
                '_tKv',int2str(length(theta_K_v)),'_J_p',int2str(J_p),'_K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,...
                '_',diurnl,'_',rhotl,nrho_l,'_d',int2str(m),'_st',num2str(steps),'_nsec',num2str(nsec_trad),'_nin',num2str(Nin));
            
basename_kern=strcat('inp_',int2str(length(input_v)),'_',upper(kern),'_th',thkernl,...
        '_tJ',int2str(theta_J_kern),'_tKm',tKkernml,...
                    '_tKv',int2str(length(theta_K_v_kern)),'_J_p',int2str(J_p_kern),'_K_pt',K_p_thr_kernl,ccorrl,ccorrlastl,twostl,...
                    '_',diurnl,'_',rhotl,nrho_l,'_d',int2str(m),'_st',num2str(steps),'_nsec',num2str(nsec_trad),'_nin',num2str(Nin));            

if doJumps
    jptl=num2str(J_time,'%2.2f');
    jptl(jptl=='.')='';
    jpsl=num2str(J_size_fac,'%2.2f');
    jpsl(jpsl=='.')='';
    jppl=num2str(J_prob,'%2.2f');
    jppl(jppl=='.')='';
    basename=strcat(basename,'_jpt',jptl,'_jps',jpsl,'_jpp',jppl);
    basename_kern=strcat(basename_kern,'_jpt',jptl,'_jps',jpsl,'_jpp',jppl);
end
                                
% name pf previosuly saved results
nameout_res=strcat(outpathres,meas,'_svol_fact_',basename_kern,'_reps',num2str(repl),'.mat');

index=isequal(exist(nameout_res,'file'),2);

if ~index
% -------------------------------------------------------------------------
%            
%% Collect Results across Monte Carlo Loops            
            
% intialize array for results
res_arr=NaN*zeros(m*(m+1)/2,length(theta_K_v_kern),repl);

% loop over dgps, simulate and compute estimates
%--------------------------------------------------------------------
parfor j=1:repl                                       
         
            %Status
            display([ 'Replication: ' int2str(j)]);
            
            %load
            xx=iload(strcat(inpath,basename_kern,'_r',num2str(j)),'x');
            res_arr(:,:,j)=xx.x;
         
end

% load matrix of true integrated variances 
load(strcat(inpath,basename,'_reps',num2str(repl),'_isigma2.mat'))

%expand matrix of true integrated variances 
isigma2_arr=permute(isigma2_mat,[2 3 1]);
isigma2_arr=isigma2_arr(:,ones(length(theta_K_v_kern),1),:);
% -------------------------------------------------------------------------
%    
%% compute measure

% compute
switch meas
        case 'rmse'
                outarr=sqrt(squeeze(nanmean((res_arr./isigma2_arr-1).^2,3)));
        case 'fb'
                outarr=squeeze(nanmean((res_arr./isigma2_arr-1).^2,3));
        case 'std'
                outarr=squeeze(nanstd(res_arr./isigma2_arr,1,3));
        case  'bias'
                outarr=abs(squeeze(nanmean(res_arr./isigma2_arr-1,3)));
        otherwise
                  error('Input "rmse", "std" or "bias"!')  
end

% delete huge array
clear res_arr;
clear isigma2_arr;

%save 
save(nameout_res,'outarr');
% -------------------------------------------------------------------------
%
%% Use Old Results
else
    
    load(nameout_res);

end
% -------------------------------------------------------------------------
%
%% check frequency of PSD-Estimates

if doCheckPSD
%-------------------
    
% name pf previosuly saved results
nameout_res_psd=strcat(outpathres,meas,'_svol_fact_psd_',basename_kern,'_reps',num2str(repl),'.mat');

index2=isequal(exist(nameout_res_psd,'file'),2);

if ~index2
% -------------------------------------------------------------------------
%            
%% Collect Results across Monte Carlo Loops            
            
% intialize array for results
res_arr_psd=NaN*zeros(m*(m+1)/2,length(theta_K_v_kern),repl);

% loop over dgps, simulate and compute estimates
%--------------------------------------------------------------------
parfor j=1:repl                                       
         
            %Status
            display([ 'Replication: ' int2str(j)]);
            
            %load
            xx=iload(strcat(inpath,basename_kern,'_r',num2str(j)),'x');
            res_arr_psd(:,:,j)=xx.x;
         
end
% -------------------------------------------------------------------------
%    
%% compute measure

% convert stacked matrices in 1st dimension back
res_arr_psd=ivech3d(res_arr_psd,m);

% check of given matrices are psd
outarrPSD=NaN*zeros(length(theta_K_v_kern),repl);

for kkk=1:length(theta_K_v_kern)
    for lll=1:repl
           [~,tempind]=chol(squeeze(res_arr_psd(:,:,kkk,lll)));
           outarrPSD(kkk,lll)=isequal(tempind,0);
    end
end

% compute percentage of psd cases
outarrPSD=squeeze(nanmean(outarrPSD,2));

% delete huge array
clear res_arr_psd;

%save 
save(nameout_res_psd,'outarrPSD');
% -------------------------------------------------------------------------
%
%% Use Old Results
else
    
    load(nameout_res_psd);

end

end
% -------------------------------------------------------------------------
% 
%% separate results for variances and covariances

if doSepVarCov
%-------------------

% check measure
if isequal(meas,'fb')
    meas_sep='rmse';
else
    meas_sep=meas;
end
    
% name pf previosuly saved results
nameout_res_sep=strcat(outpathres,meas,'_svol_fact_sep_',basename_kern,'_reps',num2str(repl),'.mat');

index3=isequal(exist(nameout_res_sep,'file'),2);

if ~index3
% -------------------------------------------------------------------------
%            
%% Collect Results across Monte Carlo Loops            
            
% intialize array for results
res_arr_sep=NaN*zeros(m*(m+1)/2,length(theta_K_v_kern),repl);

% loop over dgps, simulate and compute estimates
%--------------------------------------------------------------------
parfor j=1:repl                                       
         
            %Status
            display([ 'Replication: ' int2str(j)]);
            
            %load
            xx=iload(strcat(inpath,basename_kern,'_r',num2str(j)),'x');
            res_arr_sep(:,:,j)=xx.x;
         
end

% load matrix of true integrated variances 
load(strcat(inpath,basename,'_reps',num2str(repl),'_isigma2.mat'))

%expand matrix of true integrated variances and covariances 
isigma2_arr=ivech2d(isigma2_mat',m);   
isigma2_arr_var=reshape(isigma2_arr(logical(repmat(eye(m),1,1,repl))),m,repl);
isigma2_arr_cov=reshape(isigma2_arr(logical(repmat(tril(ones(m))-eye(m),1,1,repl))),m*(m-1)/2,repl);

isigma2_arr_var=permute(isigma2_arr_var,[1 3 2]);
isigma2_arr_cov=permute(isigma2_arr_cov,[1 3 2]);

isigma2_arr_var=isigma2_arr_var(:,ones(length(theta_K_v_kern),1),:);
isigma2_arr_cov=isigma2_arr_cov(:,ones(length(theta_K_v_kern),1),:);
% -------------------------------------------------------------------------
%    
%% compute measure

% convert stacked matrices in 1st dimension back
res_arr_sep=ivech3d(res_arr_sep,m);

%select variances and covariances
res_arr_var=reshape(res_arr_sep(logical(repmat(eye(m),1,1,length(theta_K_v_kern),repl))),...
    m,length(theta_K_v_kern),repl);
res_arr_cov=reshape(res_arr_sep(logical(repmat(tril(ones(m))-eye(m),1,1,length(theta_K_v_kern),repl))),...
    m*(m-1)/2,length(theta_K_v_kern),repl);

% compute
switch meas_sep
        case 'rmse'
                outarr_var=sqrt(squeeze(nanmean((res_arr_var./isigma2_arr_var-1).^2,3)));
                outarr_cov=sqrt(squeeze(nanmean((res_arr_cov./isigma2_arr_cov-1).^2,3)));
        case 'std'
                outarr_var=squeeze(nanstd(res_arr_var./isigma2_arr_var,1,3));
                outarr_cov=squeeze(nanstd(res_arr_cov./isigma2_arr_cov,1,3));
        case  'bias'
                outarr_var=abs(squeeze(nanmean(res_arr_var./isigma2_arr_var-1,3)));
                outarr_cov=abs(squeeze(nanmean(res_arr_cov./isigma2_arr_cov-1,3)));
        otherwise
                  error('Input "rmse", "std" or "bias"!')  
end

% delete huge array
clear res_arr_sep;
clear res_arr_var;
clear res_arr_cov;
clear isigma2_arr;
clear isigma2_arr_var;
clear isigma2_arr_cov;

%save 
save(nameout_res_sep,'outarr_var','outarr_cov');
% -------------------------------------------------------------------------
%
%% Use Old Results
else
    
    load(nameout_res_sep);

end

end
% -------------------------------------------------------------------------
% 
 %% Output
 
 % average results over elements of matrix
 outarr=squeeze(nanmean(outarr,1));
 
 %do stuff for frobenius norm 
 if isequal(meas,'fb')
    outarr=sqrt(outarr);
 end
 
 % add theta_h and theta_J values
 outmat=[theta_K_v_kern' 100*outarr'];

% create table with different horizons stacked vertically
nameout_tab=strcat(outpath,meas,'_svol_fact',basename_kern,'_reps',num2str(repl),'.txt');
latextable_my(outmat,'Vert',[],'Horiz',[{'K'} {meas} ],'Hline',[],'format','%3.3f','name',nameout_tab);


%
%--------------------------------------------------------------------------------------------------------------------------------
%

% get "optimal" values for theta's
[out_opt,ind_K]=min(100*outarr);
theta_K_opt=theta_K_v_kern(ind_K);

% get "extreme" results 
ResComp=NaN*zeros(2,4);

ResComp(1,:)=[theta_h_kern theta_J_kern theta_K_v_kern(1) 100*outarr(1)];
ResComp(2,:)=[theta_h_kern theta_J_kern theta_K_v_kern(end)  100*outarr(end)];

% get results on psd property
if doCheckPSD
    
    % for optimal inputs      
    optPSD=100*outarrPSD(ind_K);    
    
    % for other results
    addResComp=NaN*zeros(2,1);
    addResComp(1)=100*outarrPSD(1);
    addResComp(2)=100*outarrPSD(2);
  
    ResComp=[ResComp addResComp];
    
    % extend output
    outtable=[theta_h_kern theta_J_kern theta_K_opt out_opt optPSD; ResComp];

    % labels for table
    horz_lab={'$\theta_h$','$\theta_J$','$\theta_K$',strcat('$',upper(meas),'_n$'),strcat('$ \% PSD $')};
    
    % outname
    nameout_tab_opt=strcat(outpath,meas,'_op_svol_',basename_kern,'_reps',num2str(repl),'_PSD','.txt');
  
else
    
    outtable=[theta_h_kern theta_J_kern theta_K_opt out_opt; ResComp];
    
    % labels for table
    horz_lab={'$\theta_h$','$\theta_J$','$\theta_K$',strcat('$',upper(meas),'_n$')};
    
      % outname
    nameout_tab_opt=strcat(outpath,meas,'_op_svol_',basename_kern,'_reps',num2str(repl),'.txt');

end


% create table 
latextable_my(outtable,'Vert',[{'Opt'}, repmat({' '},1,size(ResComp,1))],'Horiz',horz_lab,'Hline',[0,1,NaN],'format','%3.3f','name',nameout_tab_opt);
% -------------------------------------------------------------------------
% 
 %% Separate Output

 
 if doSepVarCov
    
     % average results over elements of matrix
     outarr_var=squeeze(nanmean(outarr_var,1));
     if m>2
        outarr_cov=squeeze(nanmean(outarr_cov,1));
     else
         outarr_cov=squeeze(outarr_cov);
     end
     
     % get "optimal" values for theta's
    [out_opt_var,ind_K_var]=min(100*outarr_var);
    theta_K_opt_var=theta_K_v_kern(ind_K_var);
     
    % get "optimal" values for theta's
    [out_opt_cov,ind_K_cov]=min(100*outarr_cov);
    theta_K_opt_cov=theta_K_v_kern(ind_K_cov);

    % get "extreme" results 
    ResComp_var=NaN*zeros(2,4);
    ResComp_cov=NaN*zeros(2,4);

    ResComp_var(1,:)=[theta_h_kern theta_J_kern theta_K_v_kern(1) 100*outarr_var(1)];
    ResComp_var(2,:)=[theta_h_kern theta_J_kern theta_K_v_kern(end)  100*outarr_var(end)];
    ResComp_cov(1,:)=[theta_h_kern theta_J_kern theta_K_v_kern(1) 100*outarr_cov(1)];
    ResComp_cov(2,:)=[theta_h_kern theta_J_kern theta_K_v_kern(end)  100*outarr_cov(end)];
     
     % for global optimal inputs      
    opt_var=100*outarr_var(ind_K);    
    opt_cov=100*outarr_cov(ind_K);    
    
    % output table
    outtable_var=[theta_h_kern theta_J_kern theta_K_opt_var out_opt_var; ...
        theta_h_kern theta_J_kern theta_K_opt opt_var; ResComp_var];
    outtable_cov=[theta_h_kern theta_J_kern theta_K_opt_cov out_opt_cov; ...
        theta_h_kern theta_J_kern theta_K_opt opt_cov; ResComp_cov];
    
    % labels for table
    horz_lab={'$\theta_h$','$\theta_J$','$\theta_K$',strcat('$',upper(meas),'_n$')};
    
      % outname
    nameout_tab_opt_var=strcat(outpath,meas_sep,'_op_var_svol_',basename_kern,'_reps',num2str(repl),'.txt');
    nameout_tab_opt_cov=strcat(outpath,meas_sep,'_op_cov_svol_',basename_kern,'_reps',num2str(repl),'.txt');
    
    % create table 
    latextable_my(outtable_var,'Vert',[{'Opt'},{'Opt*'}, repmat({' '},1,size(ResComp,1))],'Horiz',horz_lab,'Hline',[0,1,NaN],'format','%3.3f','name',nameout_tab_opt_var);
    latextable_my(outtable_cov,'Vert',[{'Opt'},{'Opt*'}, repmat({' '},1,size(ResComp,1))],'Horiz',horz_lab,'Hline',[0,1,NaN],'format','%3.3f','name',nameout_tab_opt_cov);
     
 end


    
