%% run_sim_factor_svol_2f_26042016.m
%--------------------------------------------------------------------------
% estimates spot variance using lmm for
%          *simple multivatiate factor model as in 
%               Barndorff-Nielsen, Hansen, Lunde & Shephard (2011, JE)
%               based on equicorrelation structure for signal 
%           * 2-factor stochastic volatility following Chernov et al. (2003, JE)
%           * intraday seasonality
 %           *dillluted by microstructure noise
%--------------------------------------------------------------------------
%
% Peter Malec, April 26, 2016
%
% -------------------------------------------------------------------------------------------------
%
%% Define INPUTS

% Clear system
clear all;
clc;

% add procs
myaddToPath;

% running on Camgrid?
onCam=true;%true;

% Choose basepath
basepath = 1;                    

% seed value
seedv=12345678;

%# number of simulation steps within a day
steps=23400*5;      

%# number of seconds within trading day
nsec_trad=23400;

% # of replications
repl=1000;%3000;    

% dimension
m=15;

%burnin second factor
Nin=1e6;  

% diurnal component
diurn=1; %if >0: deterministic diurnal component

% incorporate jumps ?
doJumps=false;

% points of estimation
input_v=0:0.01:1; %times are normalized

% theta grids
theta_h_v=0.025:0.025:0.25;
theta_J_v=1:1:10;
theta_K_v=1.2:0.4:4.8; 
%theta_K_v=0.4:0.4:4; 
%theta_J_v=0.5:0.5:5;

%remaining settings for lle
J_p=5;
K_p_thr=1;

% correction?
ccorr=1; % correction of variance and correlation estimates
ccorrlast=1; % last estimation step only

% less smoothing at end and beginning of day?
lKb=1;

% two step
twost=-1; % spot volas of 1st step are used as pilots for 2nd step

% do "normal" estimator
doNorm=true;

% do kernel-based estimator
doKern=false;

% implementation of kernel-based estimator
J_p_kern=5;
theta_h_kern=0.15;%0.175;
theta_J_kern=6;%7;
theta_K_v_kern=.005:.005:.05;
K_p_thr_kern=0;%.25;
kern='GAUSS';
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% setup parpool

if onCam
    maxNumCompThreads(16);
    parpool(16)
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath 

if ~onCam
    inpathFFF=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'FFF_Ret',filesep);
    outpath=strcat(pathproject,'Sim',filesep,'Sim_d',int2str(m),filesep);
else
    inpathFFF=strcat('FFF_Ret',filesep);
    outpath=strcat('Sim_d',int2str(m),filesep);
    mkdir(outpath); %outpath needs to be create anew everytime
end
% -------------------------------------------------------------------------
%
%% Labels

% label lKb
if lKb>0
     lKbl='_lKb';
else
     lKbl='';
end

% label ccorr
if ccorr>0
     ccorrl='_ccorr';
else
     ccorrl='';
end

% label ccorrlast
if ccorrlast<=0
     ccorrlastl='_nccorrl';
else
     ccorrlastl='';
end

%label twostep
if twost>0
     twostl='_2st';
else
     twostl='';
end
% -------------------------------------------------------------------------
%
%% Define inputs

% diffusion parameters
mu=0.03;       
alpha1=-0.137e-2;    
alpha2=-1.386;    
beta0=-1.2;
beta1=0.04;
beta2=1.5;
betav=0.25;
rho1=-0.3;
rho2=-0.3;
u0=log(1.5);

% square root of equicorrelation
rhotild=sqrt(0.312);   % 0.312 (q_{0.5})

if isequal(m,2)

    % signal to noise ratio per obs
    gamma2=[0.835^2;2.007^2];        % 0.835^2 (q_{0.25]) or  2.007^2 (q_{0.75})

    % observation intensity
    lambda=[0.718;0.177];                                  % 0.177 (q_{0.25]) or  0.718 (q_{0.75})
    
elseif isequal(m,10)
     
    % signal to noise ratio per obs
    gamma2=[ 0.485; 0.692;0.938 ;1.181 ;1.585 ; 1.907 ; 1.992; 2.143;2.305;2.495].^2;     % deciles of gamma2 based on data
    
    % observation intensity
    lambda=[ 3.765 ; 1.259 ; 0.793; 0.696 ; 0.589 ; 0.460 ; 0.382; 0.221;  0.138 ;  0.099];    % deciles of lambda based on data

elseif isequal(m,15)
     
    % signal to noise ratio per obs
    gamma2=[0.381; 0.485; 0.692;0.938 ;1.181 ;1.585;1.585;1.585;1.585;1.585 ; 1.907 ; 1.992; 2.143;2.305;2.495].^2;     % deciles of gamma2 based on data
    
    % observation intensity
    lambda=[ 3.765 ; 1.259 ; 0.793; 0.696 ; 0.589 ; 0.460; 0.460; 0.460; 0.460; 0.460 ; 0.382; 0.221;  0.138 ;  0.099;0.063];    % deciles of lambda based on data
        
else    
    error('Parameter configurations for other dimensions not finalised, yet!')
end

 % 1st order Acorr of MA 1noise
    nrho=0.441*ones(m,1);  

% ma param?
    if ~isempty(nrho)
        theta=NaN*zeros(m,1);
        for iii=1:m
            theta(iii)=get_theta_ma1(nrho(iii));
        end
        nrho_l=strcat('_marh', num2str(nrho(1),'%tx'));
    else
        nrho_l='';
    end
    
    
% jump configuration
if doJumps
    J_time=0.6;
    J_size_fac=5;
    J_prob=0.75;
end
% -------------------------------------------------------------------------
%
%% Load estimates of intraday volatility

if diurn>0
    
    % obs times
    Obs_ind=1:steps;
    Obs_time=[0 Obs_ind/steps];
    Obs_ind=[1 Obs_ind+1]; %(add 1 because of starting value)

    if isequal(m,2)
       %load parameters
        FFFname1=strcat('FFF_maxD',int2str(20),'_spec',int2str(1),'_m15','_L1','_LOBSTER_','20100501','_','20140430',...
            'midp','_','ncl_rev','_freqs',int2str(300),'_freq',int2str(300),'_nss',int2str(10));
        load(strcat(inpathFFF,FFFname1));
        theta_FF_med1=theta_FF_med;
        FFFname2=strcat('FFF_maxD',int2str(20),'_spec',int2str(1),'_m15','_L2','_LOBSTER_','20100501','_','20140430',...
            'midp','_','ncl_rev','_freqs',int2str(300),'_freq',int2str(300),'_nss',int2str(10));
        load(strcat(inpathFFF,FFFname2));
        theta_FF_med2=theta_FF_med;

       % compute FFF
        phisq=[vola_fourier_gen(Obs_time',theta_FF_med1,1) vola_fourier_gen(Obs_time',theta_FF_med2,1)];
        
     elseif isequal(m,10)
        %load parameters
        FFFname1=strcat('FFF_maxD',int2str(20),'_spec',int2str(1),'_m15','_L1','_LOBSTER_','20100501','_','20140430',...
            'midp','_','ncl_rev','_freqs',int2str(300),'_freq',int2str(300),'_nss',int2str(10));
        load(strcat(inpathFFF,FFFname1));
        theta_FF_med1=theta_FF_med;
        FFFname2=strcat('FFF_maxD',int2str(20),'_spec',int2str(1),'_m15','_L2','_LOBSTER_','20100501','_','20140430',...
            'midp','_','ncl_rev','_freqs',int2str(300),'_freq',int2str(300),'_nss',int2str(10));
        load(strcat(inpathFFF,FFFname2));
        theta_FF_med2=theta_FF_med;
        
        % compute FFF
        phisq=[vola_fourier_gen(Obs_time',theta_FF_med1,1) vola_fourier_gen(Obs_time',theta_FF_med2,1)];
        phisq=[repmat(phisq(:,1),1,5) repmat(phisq(:,2),1,5)];
        
      elseif isequal(m,15)
        %load parameters
        FFFname1=strcat('FFF_maxD',int2str(20),'_spec',int2str(1),'_m10','_L3','_LOBSTER_','20100501','_','20140430',...
            'midp','_','ncl_rev','_freqs',int2str(300),'_freq',int2str(300),'_nss',int2str(10));
        load(strcat(inpathFFF,FFFname1));
        theta_FF_med1=theta_FF_med;
        FFFname2=strcat('FFF_maxD',int2str(20),'_spec',int2str(1),'_m10','_L4','_LOBSTER_','20100501','_','20140430',...
            'midp','_','ncl_rev','_freqs',int2str(300),'_freq',int2str(300),'_nss',int2str(10));
        load(strcat(inpathFFF,FFFname2));
        theta_FF_med2=theta_FF_med;
        FFFname3=strcat('FFF_maxD',int2str(20),'_spec',int2str(1),'_m10','_L5','_LOBSTER_','20100501','_','20140430',...
            'midp','_','ncl_rev','_freqs',int2str(300),'_freq',int2str(300),'_nss',int2str(10));
        load(strcat(inpathFFF,FFFname3));
        theta_FF_med3=theta_FF_med;
  
        % compute FFF
        phisq=[vola_fourier_gen(Obs_time',theta_FF_med1,1) vola_fourier_gen(Obs_time',theta_FF_med2,1) vola_fourier_gen(Obs_time',theta_FF_med3,1)];
        phisq=[repmat(phisq(:,1),1,5) repmat(phisq(:,2),1,5) repmat(phisq(:,3),1,5)];
                
    end
     
    diurnl='';
    
else
         phisq=[];
              
         diurnl='ndiurn_';
end
% -------------------------------------------------------------------------
%    
%% Monte Carlo loops

% designate global stream (for random numbers)
s= RandStream('mt19937ar','Seed', seedv);
RandStream.setGlobalStream(s); 

%labels
thml=num2str(theta_h_v(1),'%2.2f');
thml(thml=='.')='';
tKml=num2str(theta_K_v(1),'%2.2f');
tKml(tKml=='.')='';
rhotl=num2str(rhotild,'%2.2f');
rhotl(rhotl=='.')='';

%basename
basename=strcat(outpath,'inp_',int2str(length(input_v)),'_thm',thml,'_thv',int2str(length(theta_h_v)),...
    '_tJm',int2str(theta_J_v(1)),'_tJv',int2str(length(theta_J_v)),'_tKm',tKml,...
                '_tKv',int2str(length(theta_K_v)),'_J_p',int2str(J_p),'_K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,...
                '_',diurnl,'_',rhotl,nrho_l,'_d',int2str(m),'_st',num2str(steps),'_nsec',num2str(nsec_trad),'_nin',num2str(Nin));            
if doKern
    thkernl=num2str(theta_h_kern,'%2.3f');
    thkernl(thkernl=='.')='';
    tKkernml=num2str(theta_K_v_kern(1),'%2.3f');
    tKkernml(tKkernml=='.')='';
    K_p_thr_kernl=num2str(K_p_thr_kern,'%2.2f');
    K_p_thr_kernl(K_p_thr_kernl=='.')='';
    basename_kern=strcat(outpath,'inp_',int2str(length(input_v)),'_',upper(kern),'_th',thkernl,...
        '_tJ',int2str(theta_J_kern),'_tKm',tKkernml,...
                    '_tKv',int2str(length(theta_K_v_kern)),'_J_p',int2str(J_p_kern),'_K_pt',K_p_thr_kernl,ccorrl,ccorrlastl,twostl,...
                    '_',diurnl,'_',rhotl,nrho_l,'_d',int2str(m),'_st',num2str(steps),'_nsec',num2str(nsec_trad),'_nin',num2str(Nin));            
end

if doJumps
    jptl=num2str(J_time,'%2.2f');
    jptl(jptl=='.')='';
    jpsl=num2str(J_size_fac,'%2.2f');
    jpsl(jpsl=='.')='';
    jppl=num2str(J_prob,'%2.2f');
    jppl(jppl=='.')='';
    basename=strcat(basename,'_jpt',jptl,'_jps',jpsl,'_jpp',jppl);
    if doKern
        basename_kern=strcat(basename_kern,'_jpt',jptl,'_jps',jpsl,'_jpp',jppl);
    end
end

%initialize matrix
isigma2_mat=NaN*zeros(repl,m*(m+1)/2);
   
% create equicorrelation matrix (repeated)
EquiCorrArr=(1-eye(m))*(rhotild^2)+eye(m);
EquiCorrArr=EquiCorrArr(:,:,ones(steps+1,1));

% loop over dgps, simulate and compute estimates
%--------------------------------------------------------------------
parfor j=1:repl      

            %Status
            display([ 'Replication: ' int2str(j)]);
            
            % Simulate Log-Prices and volatilities
             %-------------------------------------------------------------
             if ~doJumps
                [y,sigma]=sim_svol_2f_seas_multivariate_factor(m,rhotild,mu,alpha1,alpha2,beta0,beta1,beta2,betav,rho1,rho2,steps,Nin,u0,phisq);
             else
                 [y,sigma]=sim_svol_2f_seas_multivariate_factor(m,rhotild,mu,alpha1,alpha2,beta0,beta1,beta2,betav,rho1,rho2,steps,Nin,u0,phisq,...
                     J_time,log(J_size_fac)/beta1,false,J_prob);
             end
             % compute integrated variances 
             isigma2_mat(j,:)=integ_covmat(vech3d(EquiCorrArr.*mtimesx(permute(sigma,[2 3 1]),permute(sigma,[3 2 1]))))  ;
             
            % add starting value
            y=[zeros(1,m);y];
           
             % create noisy and asymchronous data
            %----------------------------------------------------------------------------------
            
            % initialise cell array of data and noise
            data_samp=cell(m,1);
            eta_v=NaN*zeros(m,1);
            
            % loop over series
            for iii=1:m
            
                %simulate  observation time 
                Obs_time=sim_poisson(lambda(iii),nsec_trad);  % in sec from start of trading
                Obs_ind=floor(steps/nsec_trad*Obs_time)+1;      % turn into index (take price of beginning of spell and add 1 because of starting value)
            
                %add noise 
                if isempty(nrho)
                     [x,eta]=endog_noise_ma(y(Obs_ind,iii),sigma(:,iii),gamma2(iii),(length(Obs_ind)-1));
                else
                    [x,eta]=endog_noise_ma(y(Obs_ind,iii),sigma(:,iii),gamma2(iii),(length(Obs_ind)-1),theta(iii));
                end
             
                %create price vectors from log prices
                data_samp{iii}=[Obs_time(:) exp(x)];
                
                % store noise
                eta_v(iii)=eta;
                
            end
            
            % Compute Estimates
            %--------------------------------
            if doNorm
                Sigma_arr=spot_cov_grid_func_icov(input_v,data_samp,eta_v,0,(nsec_trad/3600),...
        J_p,theta_h_v,theta_J_v,theta_K_v,K_p_thr,twost,lKb,ccorr,ccorrlast);
            % save
            iSaveX(strcat(basename,'_r',num2str(j)),Sigma_arr)
            end
            if doKern
                 Sigma_arr_kern=spot_cov_grid_func_icov_kern(input_v,data_samp,eta_v,0,(nsec_trad/3600),...
        J_p_kern,theta_h_kern,theta_J_kern,theta_K_v_kern,K_p_thr_kern,twost,kern,ccorr,ccorrlast);
            % save
            iSaveX(strcat(basename_kern,'_r',num2str(j)),Sigma_arr_kern)
            end
            
            
end

%save integrated variances
save(strcat(basename,'_reps',num2str(repl),'_isigma2.mat'),'isigma2_mat')
        
% exit matlab if running on Camgrid
if onCam
    exit;
end

 
 
    
