%% run_sim_factor_svol_2f_plot_path_est_01062016.m
%--------------------------------------------------------------------------
% estimates spot variance using lmm for
%          *simple multivatiate factor model as in 
%               Barndorff-Nielsen, Hansen, Lunde & Shephard (2011, JE)
%               based on equicorrelation structure for signal 
%           * 2-factor stochastic volatility following Chernov et al. (2003, JE)
%           * intraday seasonality
 %           *dillluted by microstructure noise
 %           * plots one path along with estimates
%--------------------------------------------------------------------------
%
% Peter Malec, June 1, 2016
%
% -------------------------------------------------------------------------------------------------
%
%% Define INPUTS

% Clear system
clear all;
clc;

% add procs
myaddToPath;

% Choose basepath
basepath = 1;                    

% seed value
seedv=1;%;12345678;

%# number of simulation steps within a day
steps=23400*5;      

%# number of seconds within trading day
nsec_trad=23400;

% dimension
m=15;

%burnin second factor
Nin=1e6;  

% diurnal component
diurn=1; %if >0: deterministic diurnal component

% incorporate jumps ?
doJumps=true;

% points of estimation
input_v=0:0.01:1; %times are normalized
input_v_adapt= linspace(1.5/6.5,1,100); %times are normalized (start at noon)

% theta values
theta_h=0.175;
theta_J=6;
theta_K=0.5;%2; 

%remaining settings for lle
J_p=5;
K_p_thr=8;%;1;

% correction?
ccorr=1; % correction of variance and correlation estimates
ccorrlast=1; % last estimation step only

% less smoothing at end and beginning of day?
lKb=1;

% two step
twost=-1; % spot volas of 1st step are used as pilots for 2nd step

% do "normal" estimator
doNorm=false;

% do kernel-based estimator
doAdapt=true;

% do kernel-based estimator
doKern=false;

% implementation of kernel-based estimator
J_p_kern=5;
theta_h_kern=0.175;
theta_J_kern=6;
theta_K_v_kern=.02;
K_p_thr_kern=0;%.25;
kern='GAUSS';

% series to plot
asseti_plot=1:2;

% pre-specified y limits for comparison
comp_ylim=[0 3.5];

% use xlim of adative plot for vola plot
use_adapt_x_axis=true;
% -------------------------------------------------------------------------
%
%% Determination of Basepath


if basepath ==1
    
    pathproject = '~//Projects//Spot_corr//MATLAB//';
    
elseif basepath ==2
    
    pathproject = '~//Spot_corr//MATLAB//';    
    
elseif basepath ==0
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
elseif basepath ==-1
    
    pathproject = 'C:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
    
elseif basepath ==-2
    
    pathproject = 'X:\\peter.malec\\Spot_corr\\MATLAB\\';            
    
else
    
    pathproject = 'H:\\Spot_corr\\MATLAB\\';
    
end
% -------------------------------------------------------------------------
%
%% Determination of In- and Outpath 

inpathFFF=strcat(pathproject,'Emp_AnA',filesep,'Estimates',filesep,'FFF_Ret',filesep);
outpath=strcat(pathproject,'Sim',filesep,'Plots',filesep);
% -------------------------------------------------------------------------
%
%% Labels

% label lKb
if lKb>0
     lKbl='_lKb';
else
     lKbl='';
end

% label ccorr
if ccorr>0
     ccorrl='_ccorr';
else
     ccorrl='';
end

% label ccorrlast
if ccorrlast<=0
     ccorrlastl='_nccorrl';
else
     ccorrlastl='';
end

%label twostep
if twost>0
     twostl='_2st';
else
     twostl='';
end
% -------------------------------------------------------------------------
%
%% Define inputs

% diffusion parameters
mu=0.03;       
alpha1=-0.137e-2;    
alpha2=-1.386;    
beta0=-1.2;
beta1=0.04;
beta2=1.5;
betav=0.25;
rho1=-0.3;
rho2=-0.3;
u0=log(1.5);

% square root of equicorrelation
rhotild=sqrt(0.312);   % 0.312 (q_{0.5})

if isequal(m,2)

    % signal to noise ratio per obs
    gamma2=[0.835^2;2.007^2];        % 0.835^2 (q_{0.25]) or  2.007^2 (q_{0.75})

    % observation intensity
    lambda=[0.718;0.177];                                  % 0.177 (q_{0.25]) or  0.718 (q_{0.75})
    
elseif isequal(m,10)
     
    % signal to noise ratio per obs
    gamma2=[ 0.485; 0.692;0.938 ;1.181 ;1.585 ; 1.907 ; 1.992; 2.143;2.305;2.495].^2;     % deciles of gamma2 based on data
    
    % observation intensity
    lambda=[ 3.765 ; 1.259 ; 0.793; 0.696 ; 0.589 ; 0.460 ; 0.382; 0.221;  0.138 ;  0.099];    % deciles of lambda based on data

elseif isequal(m,15)
     
    % signal to noise ratio per obs
    gamma2=[0.381; 0.485; 0.692;0.938 ;1.181 ;1.585;1.585;1.585;1.585;1.585 ; 1.907 ; 1.992; 2.143;2.305;2.495].^2;     % deciles of gamma2 based on data
    
    % observation intensity
    lambda=[ 3.765 ; 1.259 ; 0.793; 0.696 ; 0.589 ; 0.460; 0.460; 0.460; 0.460; 0.460 ; 0.382; 0.221;  0.138 ;  0.099;0.063];    % deciles of lambda based on data
        
else    
    error('Parameter configurations for other dimensions not finalised, yet!')
end

 % 1st order Acorr of MA 1noise
    nrho=0.441*ones(m,1);  

% ma param?
    if ~isempty(nrho)
        theta=NaN*zeros(m,1);
        for iii=1:m
            theta(iii)=get_theta_ma1(nrho(iii));
        end
        nrho_l=strcat('_marh', num2str(nrho(1),'%tx'));
    else
        nrho_l='';
    end
    
    
% jump configuration
if doJumps
    J_time=0.6;
    J_size_fac=5;
    J_prob=1;%0.75;
end
% -------------------------------------------------------------------------
%
%% Load estimates of intraday volatility

if diurn>0
    
    % obs times
    Obs_ind=1:steps;
    Obs_time=[0 Obs_ind/steps];
    Obs_ind=[1 Obs_ind+1]; %(add 1 because of starting value)

    if isequal(m,2)
       %load parameters
        FFFname1=strcat('FFF_maxD',int2str(20),'_spec',int2str(1),'_m15','_L1','_LOBSTER_','20100501','_','20140430',...
            'midp','_','ncl_rev','_freqs',int2str(300),'_freq',int2str(300),'_nss',int2str(10));
        load(strcat(inpathFFF,FFFname1));
        theta_FF_med1=theta_FF_med;
        FFFname2=strcat('FFF_maxD',int2str(20),'_spec',int2str(1),'_m15','_L2','_LOBSTER_','20100501','_','20140430',...
            'midp','_','ncl_rev','_freqs',int2str(300),'_freq',int2str(300),'_nss',int2str(10));
        load(strcat(inpathFFF,FFFname2));
        theta_FF_med2=theta_FF_med;

       % compute FFF
        phisq=[vola_fourier_gen(Obs_time',theta_FF_med1,1) vola_fourier_gen(Obs_time',theta_FF_med2,1)];
        
     elseif isequal(m,10)
        %load parameters
        FFFname1=strcat('FFF_maxD',int2str(20),'_spec',int2str(1),'_m15','_L1','_LOBSTER_','20100501','_','20140430',...
            'midp','_','ncl_rev','_freqs',int2str(300),'_freq',int2str(300),'_nss',int2str(10));
        load(strcat(inpathFFF,FFFname1));
        theta_FF_med1=theta_FF_med;
        FFFname2=strcat('FFF_maxD',int2str(20),'_spec',int2str(1),'_m15','_L2','_LOBSTER_','20100501','_','20140430',...
            'midp','_','ncl_rev','_freqs',int2str(300),'_freq',int2str(300),'_nss',int2str(10));
        load(strcat(inpathFFF,FFFname2));
        theta_FF_med2=theta_FF_med;
        
        % compute FFF
        phisq=[vola_fourier_gen(Obs_time',theta_FF_med1,1) vola_fourier_gen(Obs_time',theta_FF_med2,1)];
        phisq=[repmat(phisq(:,1),1,5) repmat(phisq(:,2),1,5)];
        
      elseif isequal(m,15)
        %load parameters
        FFFname1=strcat('FFF_maxD',int2str(20),'_spec',int2str(1),'_m10','_L3','_LOBSTER_','20100501','_','20140430',...
            'midp','_','ncl_rev','_freqs',int2str(300),'_freq',int2str(300),'_nss',int2str(10));
        load(strcat(inpathFFF,FFFname1));
        theta_FF_med1=theta_FF_med;
        FFFname2=strcat('FFF_maxD',int2str(20),'_spec',int2str(1),'_m10','_L4','_LOBSTER_','20100501','_','20140430',...
            'midp','_','ncl_rev','_freqs',int2str(300),'_freq',int2str(300),'_nss',int2str(10));
        load(strcat(inpathFFF,FFFname2));
        theta_FF_med2=theta_FF_med;
        FFFname3=strcat('FFF_maxD',int2str(20),'_spec',int2str(1),'_m10','_L5','_LOBSTER_','20100501','_','20140430',...
            'midp','_','ncl_rev','_freqs',int2str(300),'_freq',int2str(300),'_nss',int2str(10));
        load(strcat(inpathFFF,FFFname3));
        theta_FF_med3=theta_FF_med;
  
        % compute FFF
        phisq=[vola_fourier_gen(Obs_time',theta_FF_med1,1) vola_fourier_gen(Obs_time',theta_FF_med2,1) vola_fourier_gen(Obs_time',theta_FF_med3,1)];
        phisq=[repmat(phisq(:,1),1,5) repmat(phisq(:,2),1,5) repmat(phisq(:,3),1,5)];
                
    end
     
    diurnl='';
    
else
         phisq=[];
              
         diurnl='ndiurn_';
end
% -------------------------------------------------------------------------
%    
%% Simulate and Estimate

% designate global stream (for random numbers)
s= RandStream('mt19937ar','Seed', seedv);
RandStream.setGlobalStream(s); 

%labels
thl=num2str(theta_h,'%2.2f');
thl(thl=='.')='';
tKl=num2str(theta_K,'%2.2f');
tKl(tKl=='.')='';
rhotl=num2str(rhotild,'%2.2f');
rhotl(rhotl=='.')='';

%basename
basename=strcat('inp_',int2str(length(input_v)),'_th',thl,...
    '_tJ',int2str(theta_J),'_tK',tKl,...
                '_J_p',int2str(J_p),'_K_pt',int2str(K_p_thr),lKbl,ccorrl,ccorrlastl,twostl,...
                '_',diurnl,'_',rhotl,nrho_l,'_d',int2str(m),'_st',num2str(steps),'_nsec',num2str(nsec_trad),'_nin',num2str(Nin),'_s',int2str(seedv));            
if doKern
    thkernl=num2str(theta_h_kern,'%2.3f');
    thkernl(thkernl=='.')='';
    tKkernl=num2str(theta_K_kern,'%2.3f');
    tKkernl(tKkernl=='.')='';
    K_p_thr_kernl=num2str(K_p_thr_kern,'%2.2f');
    K_p_thr_kernl(K_p_thr_kernl=='.')='';
    basename_kern=strcat('inp_',int2str(length(input_v)),'_',upper(kern),'_th',thkernl,...
        '_tJ',int2str(theta_J_kern),'_tK',tKkernl,...
                    '_J_p',int2str(J_p_kern),'_K_pt',K_p_thr_kernl,ccorrl,ccorrlastl,twostl,...
                    '_',diurnl,'_',rhotl,nrho_l,'_d',int2str(m),'_st',num2str(steps),'_nsec',num2str(nsec_trad),'_nin',num2str(Nin),'_s',int2str(seedv));            
end

if doJumps
    jptl=num2str(J_time,'%2.2f');
    jptl(jptl=='.')='';
    jpsl=num2str(J_size_fac,'%2.2f');
    jpsl(jpsl=='.')='';
    jppl=num2str(J_prob,'%2.2f');
    jppl(jppl=='.')='';
    basename=strcat(basename,'_jpt',jptl,'_jps',jpsl,'_jpp',jppl);
    if doKern
        basename_kern=strcat(basename_kern,'_jpt',jptl,'_jps',jpsl,'_jpp',jppl);
    end
end

% create equicorrelation matrix (repeated)
EquiCorrArr=(1-eye(m))*(rhotild^2)+eye(m);
EquiCorrArr=EquiCorrArr(:,:,ones(steps+1,1));

% Simulate Log-Prices and volatilities
 %-------------------------------------------------------------
 if ~doJumps
    [y,sigma]=sim_svol_2f_seas_multivariate_factor(m,rhotild,mu,alpha1,alpha2,beta0,beta1,beta2,betav,rho1,rho2,steps,Nin,u0,phisq);
 else
     [y,sigma]=sim_svol_2f_seas_multivariate_factor(m,rhotild,mu,alpha1,alpha2,beta0,beta1,beta2,betav,rho1,rho2,steps,Nin,u0,phisq,...
         J_time,log(J_size_fac)/beta1,false,J_prob);
 end

% add starting value
y=[zeros(1,m);y];

 % create noisy and asymchronous data
%----------------------------------------------------------------------------------

% initialise cell array of data and noise
data_samp=cell(m,1);
eta_v=NaN*zeros(m,1);

% loop over series
for iii=1:m

    %simulate  observation time 
    Obs_time=sim_poisson(lambda(iii),nsec_trad);  % in sec from start of trading
    Obs_ind=floor(steps/nsec_trad*Obs_time)+1;      % turn into index (take price of beginning of spell and add 1 because of starting value)

    %add noise 
    if isempty(nrho)
         [x,eta]=endog_noise_ma(y(Obs_ind,iii),sigma(:,iii),gamma2(iii),(length(Obs_ind)-1));
    else
        [x,eta]=endog_noise_ma(y(Obs_ind,iii),sigma(:,iii),gamma2(iii),(length(Obs_ind)-1),theta(iii));
    end

    %create price vectors from log prices
    data_samp{iii}=[Obs_time(:) exp(x)];

    % store noise
    eta_v(iii)=eta;

end

% Compute Estimates
%--------------------------------
if doNorm
    Sigma_Norm_mat=NaN*zeros(length(input_v),length(asseti_plot));
     [Sigma_Norm,~,~,~,~,~,~]=lle_spot_cov_md(input_v,data_samp,...
                    eta_v,0,(nsec_trad/3600),1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,-1,lKb,ccorr,ccorrlast);
    for iii=1:length(asseti_plot)
        [Sigma_Norm_sel,~]=retrieve_cov_el_univ(asseti_plot(iii),Sigma_Norm);
        Sigma_Norm_mat(:,iii)=Sigma_Norm_sel;
    end
end

if doAdapt
    Sigma_Adapt_mat=NaN*zeros(length(input_v_adapt),length(asseti_plot));
    [Sigma_Adapt,~,~,~,~,~,~,~,~,~]=lle_spot_cov_md_adpt_mult(input_v_adapt,data_samp,0,(nsec_trad/3600),...
        1,1,[],[],J_p,[],[],theta_h,theta_J,theta_K,[],K_p_thr,twost,-1,ccorr,ccorrlast);
     for iii=1:length(asseti_plot)
        [Sigma_Adapt_sel,~]=retrieve_cov_el_univ(asseti_plot(iii),Sigma_Adapt);
        Sigma_Adapt_mat(:,iii)=Sigma_Adapt_sel;
    end
end

if doKern
    Sigma_Kern_mat=NaN*zeros(length(input_v),length(asseti_plot));
     [Sigma_Kern,~,~,~,~,~,~]=lle_spot_cov_md_kern(input_v,data_samp,...
    eta_v,0,(nsec_trad/3600),1,1,[],[],J_p,[],[],theta_h_kern,theta_J_kern,theta_K_kern,[],K_p_thr_kern,twost,-1,kern,ccorr,ccorrlast);
    for iii=1:length(asseti_plot)
        [Sigma_Kern_sel,~]=retrieve_cov_el_univ(asseti_plot(iii),Sigma_Kern);
        Sigma_Kern_mat(:,iii)=Sigma_Kern_sel;
    end   
end

% -------------------------------------------------------------------------
%    
%% Create Plots

% True Volatilities
%-----------------------------------------------------

% % adjust sigma for plot
% sigma_times=[0 (1:steps)/steps]';
% sigma_sel=NaN*zeros(length(input_v),size(sigma,2));
% for iii=1:length(input_v)
%     sigma_sel(iii,:)=sigma(find(sigma_times<=input_v(iii),1,'last'),:);
% end
% 
% % times for plot
% times_pl=(input_v*6.5+9.5)/24;
%                                 % perc of 24h period
% times for plot
times_pl=([0 (1:steps)/steps]*6.5+9.5)/24;
                                % perc of 24h period

% plot
%-----------------------------
fh=figure;
 
set(fh, 'color', 'white');

h=plot(times_pl',sigma(:,asseti_plot));%sigma_sel(:,asseti_plot)

if length(asseti_plot)>=2
    set(h(1),'color',rgb('black'),'linestyle','-','linewidth',1.4);
    set(h(2),'color',rgb('darkgrey'),'linestyle','-','linewidth',1.4);
end

set(gca, 'TickDir', 'in', 'Box', 'off' ,'XMinorTick','Off','YMinorTick','Off','linewidth',1.5,...
    'XGrid','on','Ygrid','on'); % here gca means get current axis

if ~isempty(comp_ylim)
    set(gca,'Ylim',comp_ylim)
    set(gca,'YTick',linspace(comp_ylim(1),comp_ylim(2),5));
    comp_yl='_compy';
else
    comp_yl='';
    ytickv=get(gca,'Ylim');
    set(gca,'Ylim',[ytickv(1),ytickv(end)])
    set(gca,'YTick',linspace(ytickv(1),ytickv(end),5));
end

datetick('x','HH:MM');

xl = xlabel('\bfseries Time of Day');
yl = ylabel('\bfseries Spot Volatility');
   
set(xl,'interpreter','latex','FontSize',8);
set(yl,'interpreter','latex','FontSize',8);

if use_adapt_x_axis
    xlim([11/24 16/24])
    xlim_lab='_adapt_xax';
else
    xlim([9.5/24 16/24])
    xlim_lab='';
end

parent = get(h(1),'Parent');
set(parent,'FontSize',9,'FontWeight','demi');    

% save
nameout_true=strcat(outpath,'VolPath_',basename,xlim_lab,comp_yl);             
export_fig(nameout_true,'-pdf','-png');
                                
% "Normal Estimates"
%-----------------------------------------------------
if doNorm
    
    % times for plot
    times_pl=(input_v*6.5+9.5)/24;
                                    % perc of 24h period
    % plot
    %-----------------------------
    fh=figure;

    set(fh, 'color', 'white');

    h=plot(times_pl',Sigma_Norm_mat);

    if length(asseti_plot)>=2
        set(h(1),'color',rgb('black'),'linestyle','-','linewidth',1.4);
        set(h(2),'color',rgb('darkgrey'),'linestyle','-','linewidth',1.4);
    end

    set(gca, 'TickDir', 'in', 'Box', 'off' ,'XMinorTick','Off','YMinorTick','Off','linewidth',1.5,...
        'XGrid','on','Ygrid','on'); % here gca means get current axis

    if ~isempty(comp_ylim)
        set(gca,'Ylim',comp_ylim)
        set(gca,'YTick',linspace(comp_ylim(1),comp_ylim(2),5));
        comp_yl='_compy';
    else
        comp_yl='';
        ytickv=get(gca,'Ylim');
        set(gca,'Ylim',[ytickv(1),ytickv(end)])
        set(gca,'YTick',linspace(ytickv(1),ytickv(end),5));
    end

    datetick('x','HH:MM');

    xl = xlabel('\bfseries Time of Day');
    yl = ylabel('\bfseries Spot Volatility');

    set(xl,'interpreter','latex','FontSize',8);
    set(yl,'interpreter','latex','FontSize',8);

    xlim([9.5/24 16/24])

    parent = get(h(1),'Parent');
    set(parent,'FontSize',9,'FontWeight','demi');    

    % save
    nameout_true=strcat(outpath,'NormEst_',basename,comp_yl);             
    export_fig(nameout_true,'-pdf','-png');

end
            
% "Adaptive Estimates"
%-----------------------------------------------------
if doAdapt
    
    % times for plot
    times_pl=(input_v_adapt*6.5+9.5)/24;
                                    % perc of 24h period
    % plot
    %-----------------------------
    fh=figure;

    set(fh, 'color', 'white');

    h=plot(times_pl',Sigma_Adapt_mat);

    if length(asseti_plot)>=2
        set(h(1),'color',rgb('black'),'linestyle','-','linewidth',1.4);
        set(h(2),'color',rgb('darkgrey'),'linestyle','-','linewidth',1.4);
    end

    set(gca, 'TickDir', 'in', 'Box', 'off' ,'XMinorTick','Off','YMinorTick','Off','linewidth',1.5,...
        'XGrid','on','Ygrid','on'); % here gca means get current axis

    if ~isempty(comp_ylim)
        set(gca,'Ylim',comp_ylim)
        set(gca,'YTick',linspace(comp_ylim(1),comp_ylim(2),5));
        comp_yl='_compy';
    else
        comp_yl='';
        ytickv=get(gca,'Ylim');
        set(gca,'Ylim',[ytickv(1),ytickv(end)])
        set(gca,'YTick',linspace(ytickv(1),ytickv(end),5));
    end

    datetick('x','HH:MM');

    xl = xlabel('\bfseries Time of Day');
    yl = ylabel('\bfseries Spot Volatility');

    set(xl,'interpreter','latex','FontSize',8);
    set(yl,'interpreter','latex','FontSize',8);

    xlim([11/24 16/24])

    parent = get(h(1),'Parent');
    set(parent,'FontSize',9,'FontWeight','demi');    

    % save
    nameout_true=strcat(outpath,'AdaptEst_',basename,comp_yl);             
    export_fig(nameout_true,'-pdf','-png');

end

% "kernel-based Estimates"
%-----------------------------------------------------
if doKern
    
    % times for plot
    times_pl=(input_v*6.5+9.5)/24;
                                    % perc of 24h period
    % plot
    %-----------------------------
    fh=figure;

    set(fh, 'color', 'white');

    h=plot(times_pl',Sigma_Kern_mat);

    if length(asseti_plot)>=2
        set(h(1),'color',rgb('black'),'linestyle','-','linewidth',1.4);
        set(h(2),'color',rgb('darkgrey'),'linestyle','-','linewidth',1.4);
    end

    set(gca, 'TickDir', 'in', 'Box', 'off' ,'XMinorTick','Off','YMinorTick','Off','linewidth',1.5,...
        'XGrid','on','Ygrid','on'); % here gca means get current axis

    if ~isempty(comp_ylim)
        set(gca,'Ylim',comp_ylim)
        set(gca,'YTick',linspace(comp_ylim(1),comp_ylim(2),5));
        comp_yl='_compy';
    else
        ytickv=get(gca,'Ylim');
        comp_yl='';
        set(gca,'Ylim',[ytickv(1),ytickv(end)])
        set(gca,'YTick',linspace(ytickv(1),ytickv(end),5));
    end

    datetick('x','HH:MM');

    xl = xlabel('\bfseries Time of Day');
    yl = ylabel('\bfseries Spot Volatility');

    set(xl,'interpreter','latex','FontSize',8);
    set(yl,'interpreter','latex','FontSize',8);

    xlim([9.5/24 16/24])

    parent = get(h(1),'Parent');
    set(parent,'FontSize',9,'FontWeight','demi');    

    % save
    nameout_true=strcat(outpath,'KernEst_',basename,comp_yl);             
    export_fig(nameout_true,'-pdf','-png');

end


 
 
    
